@@ -68,7 +68,7 @@
 #ifdef HAVE_AMESOS_PARAKLETE
 #include "Amesos_Paraklete.h"
 #endif
-#ifdef HAVE_AMESOS_MUMPS
+#if defined(HAVE_AMESOS_MUMPS) && defined(HAVE_MPI)
 #include "Amesos_Mumps.h"
 #endif
 #ifdef HAVE_AMESOS_SCALAPACK
@@ -404,7 +404,7 @@ int Amesos_TestMultiSolver( Epetra_Comm &Comm, char *matrix_file, int numsolves,
       EPETRA_CHK_ERR( parklete.NumericFactorization( ) ); 
       EPETRA_CHK_ERR( parklete.Solve( ) ); 
 #endif
-#ifdef HAVE_AMESOS_MUMPS
+#if defined(HAVE_AMESOS_MUMPS) && defined(HAVE_MPI)
     } else if ( SparseSolver == MUMPS ) { 
       Teuchos::ParameterList ParamList ;
       Amesos_Mumps mumps( Problem ) ; 
