@@ -242,6 +242,20 @@ namespace Amesos2 {
                         "Please contact the Amesos2 developers." );
   }
 
+  template <class DerivedMat>
+  const RCP<const Tpetra::Map<MatrixTraits<Epetra_RowMatrix>::local_ordinal_t,
+                              MatrixTraits<Epetra_RowMatrix>::global_ordinal_t,
+                              MatrixTraits<Epetra_RowMatrix>::node_t> >
+  AbstractConcreteMatrixAdapter<Epetra_RowMatrix, DerivedMat>::getMap_impl() const
+  {
+    // Should Map() be used (returns Epetra_BlockMap)
+    /*
+    printf("Amesos2_EpetraRowMatrix_AbstractMatrixAdapter: Epetra does not support a 'getMap()' method. Returning rcp(Teuchos::null). \
+        If your map contains non-contiguous GIDs please use Tpetra instead of Epetra. \n");
+    */
+    return( Teuchos::null );
+  }
+
   template <class DerivedMat>
   const RCP<const Tpetra::Map<MatrixTraits<Epetra_RowMatrix>::local_ordinal_t,
                               MatrixTraits<Epetra_RowMatrix>::global_ordinal_t,
@@ -285,19 +299,62 @@ namespace Amesos2 {
     return this->mat_->IndicesAreGlobal();
   }
 
+
   template <class DerivedMat>
   RCP<const MatrixAdapter<DerivedMat> >
-  AbstractConcreteMatrixAdapter<Epetra_RowMatrix, DerivedMat>::get_impl(const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > map) const
+  AbstractConcreteMatrixAdapter<Epetra_RowMatrix, DerivedMat>::get_impl(const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > map, EDistribution distribution) const
   {
     // Delegate implementation to subclass
 #ifdef __CUDACC__
     // NVCC doesn't seem to like the static_cast, even though it is valid
-    return dynamic_cast<ConcreteMatrixAdapter<DerivedMat>*>(this)->get_impl(map);
+    return dynamic_cast<ConcreteMatrixAdapter<DerivedMat>*>(this)->get_impl(map, distribution);
 #else
-    return static_cast<ConcreteMatrixAdapter<DerivedMat>*>(this)->get_impl(map);
+    return static_cast<ConcreteMatrixAdapter<DerivedMat>*>(this)->get_impl(map, distribution);
 #endif
   }
 
+  template <class DerivedMat>
+  typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>
+  ::super_t::spmtx_ptr_t
+  AbstractConcreteMatrixAdapter<Epetra_RowMatrix, DerivedMat>::getSparseRowPtr() const 
+  { 
+    typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>::super_t::spmtx_ptr_t  sp_rowptr = nullptr;
+    typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>::super_t::spmtx_idx_t  sp_colind = nullptr;
+    typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>::super_t::spmtx_vals_t sp_values = nullptr;
+
+    this->mat_->ExtractCrsDataPointers(sp_rowptr, sp_colind, sp_values);
+
+    return sp_rowptr;
+  }
+
+  template <class DerivedMat>
+  typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>
+  ::super_t::spmtx_idx_t
+  AbstractConcreteMatrixAdapter<Epetra_RowMatrix, DerivedMat>::getSparseColInd() const 
+  { 
+    typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>::super_t::spmtx_ptr_t  sp_rowptr = nullptr;
+    typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>::super_t::spmtx_idx_t  sp_colind = nullptr;
+    typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>::super_t::spmtx_vals_t sp_values = nullptr;
+
+    this->mat_->ExtractCrsDataPointers(sp_rowptr, sp_colind, sp_values);
+
+    return sp_colind;
+  }
+
+  template <class DerivedMat>
+  typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>
+  ::super_t::spmtx_vals_t
+  AbstractConcreteMatrixAdapter<Epetra_RowMatrix, DerivedMat>::getSparseValues() const 
+  { 
+    typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>::super_t::spmtx_ptr_t  sp_rowptr = nullptr;
+    typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>::super_t::spmtx_idx_t  sp_colind = nullptr;
+    typename AbstractConcreteMatrixAdapter<Epetra_RowMatrix,DerivedMat>::super_t::spmtx_vals_t sp_values = nullptr;
+
+    this->mat_->ExtractCrsDataPointers(sp_rowptr, sp_colind, sp_values);
+
+    return sp_values;
+  }
+
 } // end namespace Amesos2
 
 #endif  // AMESOS2_EPETRAROWMATRIX_ABSTRACTMATRIXADAPTER_DEF_HPP
