@@ -104,6 +104,9 @@
 #ifdef HAVE_AMESOS2_SUPERLUMT   // Multi-threaded SuperLU
 #include "Amesos2_Superlumt.hpp"
 #endif
+#ifdef HAVE_AMESOS2_UMFPACK     // Umfpack
+#include "Amesos2_Umfpack.hpp"
+#endif
 #ifdef HAVE_AMESOS2_SUPERLU     // Sequential SuperLU
 #include "Amesos2_Superlu.hpp"
 #endif
@@ -391,8 +394,8 @@ struct throw_no_scalar_support_exception {
       solver_supports_scalar<ConcreteSolver, typename MatrixTraits<Matrix>::scalar_t>::value,
         create_solver_with_supported_type<ConcreteSolver,Matrix,Vector>,
         throw_no_scalar_support_exception<ConcreteSolver,Matrix,Vector> >::type::apply(A, X, B);
-  }
-    };
+    }
+  };
 
 
   /////////////////////
@@ -513,18 +516,16 @@ struct throw_no_scalar_support_exception {
     // We use compiler guards in case a user does want to disable KLU2
 #ifdef HAVE_AMESOS2_BASKER
     if((solverName == "Basker") || (solverName == "basker"))
-      {
-	
-	return handle_solver_type_support<Basker, Matrix,Vector>::apply(A,X,B);
-      }
+    {
+      return handle_solver_type_support<Basker, Matrix,Vector>::apply(A,X,B);
+    }
 #endif
 
 
 
 #ifdef HAVE_AMESOS2_KLU2 
-
-if((solverName == "amesos2_klu2") || (solverName == "klu2") ||
-   (solverName == "amesos2_klu")  || (solverName == "klu")){
+    if((solverName == "amesos2_klu2") || (solverName == "klu2") ||
+        (solverName == "amesos2_klu")  || (solverName == "klu")){
       return handle_solver_type_support<KLU2,Matrix,Vector>::apply(A, X, B);
     }
 #endif
@@ -547,6 +548,13 @@ if((solverName == "amesos2_klu2") || (solverName == "klu2") ||
     }
 #endif
 
+#ifdef HAVE_AMESOS2_UMFPACK
+    if((solverName == "amesos2_umfpack") ||
+       (solverName == "umfpack")){
+      return handle_solver_type_support<Umfpack,Matrix,Vector>::apply(A, X, B);
+    }
+#endif
+
 #ifdef HAVE_AMESOS2_SUPERLU
     if((solverName == "amesos2_superlu") ||
        (solverName == "superlu")){
