@@ -69,10 +69,11 @@ namespace Amesos2 {
 				const Teuchos::ArrayView<typename MatrixAdapter<Matrix>::global_size_t> rowptr,
 				typename MatrixAdapter<Matrix>::global_size_t& nnz,
 				const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t, global_ordinal_t, node_t> > rowmap,
-				EStorage_Ordering ordering) const
+				EStorage_Ordering ordering,
+		    EDistribution distribution) const
   {
     help_getCrs(nzval, colind, rowptr,
-		nnz, rowmap, ordering,
+		nnz, rowmap, distribution, ordering,
 		typename adapter_t::get_crs_spec());
   }
 
@@ -89,7 +90,7 @@ namespace Amesos2 {
       = Util::getDistributionMap<local_ordinal_t,global_ordinal_t,global_size_t,node_t>(distribution,
 											this->getGlobalNumRows(),
 											this->getComm());
-    this->getCrs(nzval, colind, rowptr, nnz, Teuchos::ptrInArg(*rowmap), ordering);
+    this->getCrs(nzval, colind, rowptr, nnz, Teuchos::ptrInArg(*rowmap), ordering, distribution);
   }
 
   template < class Matrix >
@@ -99,10 +100,11 @@ namespace Amesos2 {
 				const Teuchos::ArrayView<typename MatrixAdapter<Matrix>::global_size_t> colptr,
 				typename MatrixAdapter<Matrix>::global_size_t& nnz,
 				const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t, global_ordinal_t, node_t> > colmap,
-				EStorage_Ordering ordering) const
+				EStorage_Ordering ordering,
+		    EDistribution distribution) const
   {
     help_getCcs(nzval, rowind, colptr,
-		nnz, colmap, ordering,
+		nnz, colmap, distribution, ordering,
 		typename adapter_t::get_ccs_spec());
   }
 
@@ -119,7 +121,7 @@ namespace Amesos2 {
       = Util::getDistributionMap<local_ordinal_t,global_ordinal_t,global_size_t,node_t>(distribution,
 											this->getGlobalNumCols(),
 											this->getComm());
-    this->getCcs(nzval, rowind, colptr, nnz, Teuchos::ptrInArg(*colmap), ordering);
+    this->getCcs(nzval, rowind, colptr, nnz, Teuchos::ptrInArg(*colmap), ordering, distribution);
   }
 
   template < class Matrix >
@@ -178,13 +180,14 @@ namespace Amesos2 {
     return static_cast<const adapter_t*>(this)->getLocalNNZ_impl();
   }
 
+  // NDE: This is broken for Epetra_CrsMatrix
   template < class Matrix >
   std::string
   MatrixAdapter<Matrix>::description() const
   {
     std::ostringstream oss;
     oss << "Amesos2::MatrixAdapter wrapping: ";
-    oss << mat_->description();
+    oss << mat_->description(); // NDE: This is not defined in Epetra_CrsMatrix, only in Tpetra::CrsMatrix
     return oss.str();
   }
   
@@ -194,6 +197,26 @@ namespace Amesos2 {
 				  const Teuchos::EVerbosityLevel verbLevel) const
   {}
   
+  template < class Matrix >
+  typename MatrixAdapter<Matrix>::spmtx_ptr_t
+  MatrixAdapter<Matrix>::returnRowPtr() const
+  {
+    return static_cast<const adapter_t*>(this)->getSparseRowPtr();
+  }
+
+  template < class Matrix >
+  typename MatrixAdapter<Matrix>::spmtx_idx_t
+  MatrixAdapter<Matrix>::returnColInd() const
+  {
+    return static_cast<const adapter_t*>(this)->getSparseColInd();
+  }
+
+  template < class Matrix >
+  typename MatrixAdapter<Matrix>::spmtx_vals_t
+  MatrixAdapter<Matrix>::returnValues() const
+  {
+    return static_cast<const adapter_t*>(this)->getSparseValues();
+  }
 
 
   /******************************
@@ -207,6 +230,7 @@ namespace Amesos2 {
 				     const Teuchos::ArrayView<typename MatrixAdapter<Matrix>::global_size_t> rowptr,
 				     typename MatrixAdapter<Matrix>::global_size_t& nnz,
 				     const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > rowmap,
+		         EDistribution distribution,
 				     EStorage_Ordering ordering,
 				     has_special_impl hsi) const
   {
@@ -222,6 +246,7 @@ namespace Amesos2 {
 				     const Teuchos::ArrayView<typename MatrixAdapter<Matrix>::global_size_t> rowptr,
 				     typename MatrixAdapter<Matrix>::global_size_t& nnz,
 				     const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > rowmap,
+		         EDistribution distribution,
 				     EStorage_Ordering ordering,
 				     no_special_impl nsi) const
   {
@@ -229,7 +254,7 @@ namespace Amesos2 {
     //Added void to remove parameter not used warning
     ((void)nsi);
     do_getCrs(nzval, colind, rowptr,
-	      nnz, rowmap, ordering,
+	      nnz, rowmap, distribution, ordering,
 	      typename adapter_t::major_access());
   }
 
@@ -240,6 +265,7 @@ namespace Amesos2 {
 				   const Teuchos::ArrayView<typename MatrixAdapter<Matrix>::global_size_t> rowptr,
 				   typename MatrixAdapter<Matrix>::global_size_t& nnz,
 				   const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > rowmap,
+		       EDistribution distribution,
 				   EStorage_Ordering ordering,
 				   row_access ra) const
   {
@@ -256,7 +282,7 @@ namespace Amesos2 {
       // No need to redistribute
       get_mat = rcp(this,false); // non-owning
     } else {
-      get_mat = get(rowmap);
+      get_mat = get(rowmap, distribution);
     }
     // RCP<const type> get_mat = get(rowmap);
 
@@ -266,11 +292,11 @@ namespace Amesos2 {
     //
     // TODO: There may be some more checking between the row map
     // compatibility, but things are working fine now.
-    RCP<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > rmap = get_mat->getRowMap();
 
+    RCP<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > rmap = get_mat->getRowMap();
     ArrayView<const global_ordinal_t> node_elements = rmap->getNodeElementList();
     if( node_elements.size() == 0 ) return; // no more contribution
-    
+
     typename ArrayView<const global_ordinal_t>::iterator row_it, row_end;
     row_end = node_elements.end();
 
@@ -280,9 +306,9 @@ namespace Amesos2 {
       rowptr[rowptr_ind++] = rowInd;
       size_t rowNNZ = get_mat->getGlobalRowNNZ(*row_it);
       size_t nnzRet = OrdinalTraits<size_t>::zero();
-      ArrayView<global_ordinal_t> colind_view = colind.view(rowInd,rowNNZ);
+      ArrayView<global_ordinal_t> colind_view = colind.view(rowInd,rowNNZ); 
       ArrayView<scalar_t> nzval_view = nzval.view(rowInd,rowNNZ);
-      
+
       get_mat->getGlobalRowCopy(*row_it, colind_view, nzval_view, nnzRet);
       for (size_t rr = 0; rr < nnzRet ; rr++)
       {
@@ -293,7 +319,7 @@ namespace Amesos2 {
       // individually, that we instead do a double-transpose at the
       // end, which would also lead to the indices being sorted.
       if( ordering == SORTED_INDICES ){
-	Tpetra::sort2(colind_view.begin(), colind_view.end(), nzval_view.begin());
+        Tpetra::sort2(colind_view.begin(), colind_view.end(), nzval_view.begin());
       }
       
       TEUCHOS_TEST_FOR_EXCEPTION( rowNNZ != nnzRet,
@@ -313,6 +339,7 @@ namespace Amesos2 {
 				   const Teuchos::ArrayView<typename MatrixAdapter<Matrix>::global_size_t> rowptr,
 				   typename MatrixAdapter<Matrix>::global_size_t& nnz,
 				   const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > rowmap,
+		       EDistribution distribution,
 				   EStorage_Ordering ordering,
 				   col_access ca) const
   {
@@ -322,7 +349,7 @@ namespace Amesos2 {
     Array<scalar_t> nzval_tmp(nzval.size(), 0);
     Array<global_ordinal_t> rowind(colind.size(), 0);
     Array<global_size_t> colptr(this->getGlobalNumCols() + 1);
-    this->getCcs(nzval_tmp(), rowind(), colptr(), nnz, rowmap, ordering);
+    this->getCcs(nzval_tmp(), rowind(), colptr(), nnz, rowmap, ordering, distribution);
     
     if( !nzval.is_null() && !colind.is_null() && !rowptr.is_null() )
       Util::transpose(nzval_tmp(), rowind(), colptr(), nzval, colind, rowptr);
@@ -335,6 +362,7 @@ namespace Amesos2 {
 				     const Teuchos::ArrayView<typename MatrixAdapter<Matrix>::global_size_t> colptr,
 				     typename MatrixAdapter<Matrix>::global_size_t& nnz,
 				     const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > colmap,
+		         EDistribution distribution,
 				     EStorage_Ordering ordering,
 				     has_special_impl hsi) const
   {
@@ -349,13 +377,14 @@ namespace Amesos2 {
 				     const Teuchos::ArrayView<typename MatrixAdapter<Matrix>::global_size_t> colptr,
 				     typename MatrixAdapter<Matrix>::global_size_t& nnz,
 				     const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > colmap,
+		         EDistribution distribution,
 				     EStorage_Ordering ordering,
 				     no_special_impl nsi) const
   {
     ((void)nsi);
    
     do_getCcs(nzval, rowind, colptr,
-	      nnz, colmap, ordering,
+	      nnz, colmap, distribution, ordering,
 	      typename adapter_t::major_access());
   }
 
@@ -366,6 +395,7 @@ namespace Amesos2 {
 				   const Teuchos::ArrayView<typename MatrixAdapter<Matrix>::global_size_t> colptr,
 				   typename MatrixAdapter<Matrix>::global_size_t& nnz,
 				   const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > colmap,
+		       EDistribution distribution,
 				   EStorage_Ordering ordering,
 				   row_access ra) const
   {
@@ -377,7 +407,7 @@ namespace Amesos2 {
     Array<scalar_t> nzval_tmp(nzval.size(), 0);
     Array<global_ordinal_t> colind(rowind.size(), 0);
     Array<global_size_t> rowptr(this->getGlobalNumRows() + 1);
-    this->getCrs(nzval_tmp(), colind(), rowptr(), nnz, colmap, ordering);
+    this->getCrs(nzval_tmp(), colind(), rowptr(), nnz, colmap, ordering, distribution);
 
     if( !nzval.is_null() && !rowind.is_null() && !colptr.is_null() )
       Util::transpose(nzval_tmp(), colind(), rowptr(), nzval, rowind, colptr);
@@ -390,6 +420,7 @@ namespace Amesos2 {
 				   const Teuchos::ArrayView<typename MatrixAdapter<Matrix>::global_size_t> colptr,
 				   typename MatrixAdapter<Matrix>::global_size_t& nnz,
 				   const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > colmap,
+		       EDistribution distribution,
 				   EStorage_Ordering ordering,
 				   col_access ca) const
   {
@@ -402,7 +433,7 @@ namespace Amesos2 {
       // No need to redistribute
       get_mat = rcp(this,false); // non-owning
     } else {
-      get_mat = get(colmap);
+      get_mat = get(colmap, distribution);
     }
 
     // If all is well and good, then colmap == cmap
@@ -429,7 +460,7 @@ namespace Amesos2 {
       // individually, that we instead do a double-transpose at the
       // end, which would also lead to the indices being sorted.
       if( ordering == SORTED_INDICES ){
-	Tpetra::sort2(rowind_view.begin(), rowind_view.end(), nzval_view.begin());
+        Tpetra::sort2(rowind_view.begin(), rowind_view.end(), nzval_view.begin());
       }
       
       TEUCHOS_TEST_FOR_EXCEPTION( colNNZ != nnzRet,
@@ -518,12 +549,13 @@ namespace Amesos2 {
   {
     return static_cast<const adapter_t*>(this)->isGloballyIndexed_impl();
   }
-  
+
+
   template < class Matrix >
   Teuchos::RCP<const MatrixAdapter<Matrix> >
-  MatrixAdapter<Matrix>::get(const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > map) const
+  MatrixAdapter<Matrix>::get(const Teuchos::Ptr<const Tpetra::Map<local_ordinal_t,global_ordinal_t,node_t> > map, EDistribution distribution) const
   {
-    return static_cast<const adapter_t*>(this)->get_impl(map);
+    return static_cast<const adapter_t*>(this)->get_impl(map, distribution);
   }
 
 
