@@ -586,7 +586,7 @@ namespace {
     const Tpetra::Map<int,int> half_map(6, my_num_rows, 0,
 					to_teuchos_comm(comm));
 
-    adapter->getCrs(nzvals,colind,rowptr,nnz, Teuchos::ptrInArg(half_map), Amesos2::SORTED_INDICES);
+    adapter->getCrs(nzvals,colind,rowptr,nnz, Teuchos::ptrInArg(half_map), Amesos2::SORTED_INDICES, Amesos2::DISTRIBUTED); // ROOTED = default distribution
 
     /*
      * Check that you got the entries you'd expect
