@@ -1,3 +1,43 @@
+// @HEADER
+// ***********************************************************************
+//
+//                 Anasazi: Block Eigensolvers Package
+//                 Copyright 2004 Sandia Corporation
+//
+// Under terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
+// the U.S. Government retains certain rights in this software.
+//
+// Redistribution and use in source and binary forms, with or without
+// modification, are permitted provided that the following conditions are
+// met:
+//
+// 1. Redistributions of source code must retain the above copyright
+// notice, this list of conditions and the following disclaimer.
+//
+// 2. Redistributions in binary form must reproduce the above copyright
+// notice, this list of conditions and the following disclaimer in the
+// documentation and/or other materials provided with the distribution.
+//
+// 3. Neither the name of the Corporation nor the names of the
+// contributors may be used to endorse or promote products derived from
+// this software without specific prior written permission.
+//
+// THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
+// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
+// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+//
+// Questions? Contact Michael A. Heroux (maherou@sandia.gov)
+//
+// ***********************************************************************
+// @HEADER
 /// \example LOBPCGEpetraEx.cpp
 /// \brief Use LOBPCG with Epetra test problem (computed here).
 ///
@@ -47,7 +87,7 @@ main (int argc, char *argv[])
   printer.stream(Errors) << Anasazi_Version() << std::endl << std::endl;
 
   // Get the sorting std::string from the command line
-  std::string which ("LM");
+  std::string which ("SM");
   Teuchos::CommandLineProcessor cmdp (false, true);
   cmdp.setOption("sort", &which, "Targetted eigenvalues (SM or LM).");
   if (cmdp.parse (argc, argv) != Teuchos::CommandLineProcessor::PARSE_SUCCESSFUL) {
@@ -261,6 +301,7 @@ main (int argc, char *argv[])
   const int blockSize = 5;
   const int maxIters  = 500;
   const double tol    = 1.0e-8;
+  const int verbosity = Anasazi::Errors + Anasazi::Warnings + Anasazi::FinalSummary;
 
   typedef Epetra_MultiVector MV;
   typedef Epetra_Operator OP;
@@ -300,6 +341,7 @@ main (int argc, char *argv[])
   MyPL.set ("Convergence Tolerance", tol);
   MyPL.set ("Full Ortho", true);
   MyPL.set ("Use Locking", true);
+  MyPL.set ("Verbosity", verbosity);
 
   // Create the solver manager
   LOBPCGSolMgr<double, MV, OP> MySolverMan (MyProblem, MyPL);
