@@ -2,25 +2,38 @@
 // ***********************************************************************
 //
 //                 Anasazi: Block Eigensolvers Package
-//                 Copyright (2004) Sandia Corporation
+//                 Copyright 2004 Sandia Corporation
 //
-// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
-// license for use of this work by or on behalf of the U.S. Government.
+// Under terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
+// the U.S. Government retains certain rights in this software.
 //
-// This library is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 2.1 of the
-// License, or (at your option) any later version.
+// Redistribution and use in source and binary forms, with or without
+// modification, are permitted provided that the following conditions are
+// met:
 //
-// This library is distributed in the hope that it will be useful, but
-// WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Lesser General Public License for more details.
+// 1. Redistributions of source code must retain the above copyright
+// notice, this list of conditions and the following disclaimer.
+//
+// 2. Redistributions in binary form must reproduce the above copyright
+// notice, this list of conditions and the following disclaimer in the
+// documentation and/or other materials provided with the distribution.
+//
+// 3. Neither the name of the Corporation nor the names of the
+// contributors may be used to endorse or promote products derived from
+// this software without specific prior written permission.
+//
+// THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
+// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
+// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
-// You should have received a copy of the GNU Lesser General Public
-// License along with this library; if not, write to the Free Software
-// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
-// USA
 // Questions? Contact Michael A. Heroux (maherou@sandia.gov)
 //
 // ***********************************************************************
@@ -420,9 +433,6 @@ namespace Anasazi {
       using Teuchos::Comm;
       using Teuchos::RCP;
       using Teuchos::rcp;
-      using Teuchos::REDUCE_SUM;
-      using Teuchos::reduceAll;
-      using Teuchos::SerialComm;
       using Teuchos::TimeMonitor;
       typedef Tpetra::Map<LO,GO,Node> map_type;
 
@@ -467,10 +477,12 @@ namespace Anasazi {
         return;
       }
 
-      RCP<Comm<int> > serialComm (new SerialComm<int> ());
-      // create local map with serial comm
+      // get comm
+      RCP<const Comm<int> > pcomm = A.getMap ()->getComm ();
+
+      // create local map with comm
       RCP<const map_type> LocalMap =
-        rcp (new map_type (numRowsC, 0, serialComm, LocallyReplicated,
+        rcp (new map_type (numRowsC, 0, pcomm, LocallyReplicated,
                            A.getMap ()->getNode ()));
       // create local multivector to hold the result
       const bool INIT_TO_ZERO = true;
@@ -479,36 +491,14 @@ namespace Anasazi {
       // multiply result into local multivector
       C_mv.multiply (Teuchos::CONJ_TRANS, Teuchos::NO_TRANS, alpha, A, B,
                      Teuchos::ScalarTraits<Scalar>::zero ());
-      // get comm
-      RCP<const Comm<int> > pcomm = A.getMap ()->getComm ();
+
       // create arrayview encapsulating the Teuchos::SerialDenseMatrix
       Teuchos::ArrayView<Scalar> C_view (C.values (), strideC * numColsC);
-      if (pcomm->getSize() == 1) {
-        // No accumulation to do; simply extract the multivector data
-        // into C.  Extract a copy of the result into the array view
-        // (and therefore, the SerialDenseMatrix).
-        C_mv.get1dCopy (C_view, strideC);
-      }
-      else {
-        // get a const host view of the data in C_mv
-        Teuchos::ArrayRCP<const Scalar> C_mv_view = C_mv.get1dView();
-        if (strideC == numRowsC) {
-          // sum-all into C
-          reduceAll<int, Scalar> (*pcomm, REDUCE_SUM, numColsC*numRowsC,
-                                  C_mv_view.getRawPtr (), C_view.getRawPtr ());
-        }
-        else {
-          // sum-all into temp, copy into C
-          Teuchos::Array<Scalar> destBuff (numColsC * numRowsC);
-          reduceAll<int,Scalar> (*pcomm, REDUCE_SUM, numColsC*numRowsC,
-                                 C_mv_view.getRawPtr (), destBuff.getRawPtr ());
-          for (int j=0; j < numColsC; ++j) {
-            for (int i=0; i < numRowsC; ++i) {
-              C_view[strideC*j+i] = destBuff[numRowsC*j+i];
-            }
-          }
-        }
-      }
+
+      // No accumulation to do; simply extract the multivector data
+      // into C.  Extract a copy of the result into the array view
+      // (and therefore, the SerialDenseMatrix).
+      C_mv.get1dCopy (C_view, strideC);
     }
 
     //! For all columns j of A, set <tt>dots[j] := A[j]^T * B[j]</tt>.
