@@ -320,7 +320,7 @@ EpetraMultiVec::EpetraMultiVec (const Epetra_BlockMap& Map_in,
 				double * array, 
 			        const int numvecs, 
 				const int stride)
-  : Epetra_MultiVector(Epetra_DataAccess::Copy, Map_in, array, stride, numvecs) 
+  : Epetra_MultiVector(BELOSEPETRACOPY, Map_in, array, stride, numvecs) 
 {
 }
 
@@ -379,14 +379,14 @@ MultiVec<double>* EpetraMultiVec::CloneCopy() const
 
 MultiVec<double>* EpetraMultiVec::CloneCopy ( const std::vector<int>& index ) const
 {
-  EpetraMultiVec * ptr_apv = new EpetraMultiVec(Epetra_DataAccess::Copy, *this, index);
+  EpetraMultiVec * ptr_apv = new EpetraMultiVec(BELOSEPETRACOPY, *this, index);
   return ptr_apv; // safe upcast.
 }
 
 
 MultiVec<double>* EpetraMultiVec::CloneViewNonConst ( const std::vector<int>& index ) 
 {
-  EpetraMultiVec * ptr_apv = new EpetraMultiVec(Epetra_DataAccess::View, *this, index);
+  EpetraMultiVec * ptr_apv = new EpetraMultiVec(BELOSEPETRAVIEW, *this, index);
   return ptr_apv; // safe upcast.
 }
   
@@ -394,7 +394,7 @@ MultiVec<double>* EpetraMultiVec::CloneViewNonConst ( const std::vector<int>& in
 const MultiVec<double>* 
 EpetraMultiVec::CloneView (const std::vector<int>& index) const
 {
-  EpetraMultiVec * ptr_apv = new EpetraMultiVec(Epetra_DataAccess::View, *this, index);
+  EpetraMultiVec * ptr_apv = new EpetraMultiVec(BELOSEPETRAVIEW, *this, index);
   return ptr_apv; // safe upcast.
 }
   
@@ -403,7 +403,7 @@ void
 EpetraMultiVec::SetBlock (const MultiVec<double>& A, 
 			  const std::vector<int>& index) 
 {	
-  EpetraMultiVec temp_vec(Epetra_DataAccess::View, *this, index);
+  EpetraMultiVec temp_vec(BELOSEPETRAVIEW, *this, index);
   
   int numvecs = index.size();
   if ( A.GetNumberVecs() != numvecs ) {
@@ -416,7 +416,7 @@ EpetraMultiVec::SetBlock (const MultiVec<double>& A,
 		       "Belos::EpetraMultiVec::SetBlock: Dynamic cast from "
 		       "Belos::MultiVec<double> to Belos::EpetraMultiVec "
 		       "failed.");
-    EpetraMultiVec A_vec(Epetra_DataAccess::View, *tmp_vec, index2);
+    EpetraMultiVec A_vec(BELOSEPETRAVIEW, *tmp_vec, index2);
     temp_vec.MvAddMv( 1.0, A_vec, 0.0, A_vec );
   }
   else {
@@ -434,7 +434,7 @@ void EpetraMultiVec::MvTimesMatAddMv ( const double alpha, const MultiVec<double
 				       const Teuchos::SerialDenseMatrix<int,double>& B, const double beta ) 
 {
   Epetra_LocalMap LocalMap(B.numRows(), 0, Map().Comm());
-  Epetra_MultiVector B_Pvec(Epetra_DataAccess::View, LocalMap, B.values(), B.stride(), B.numCols());
+  Epetra_MultiVector B_Pvec(BELOSEPETRAVIEW, LocalMap, B.values(), B.stride(), B.numCols());
   
   EpetraMultiVec *A_vec = dynamic_cast<EpetraMultiVec *>(&const_cast<MultiVec<double> &>(A)); 
   TEUCHOS_TEST_FOR_EXCEPTION(A_vec==NULL, EpetraMultiVecFailure,
@@ -486,7 +486,7 @@ void EpetraMultiVec::MvScale ( const std::vector<double>& alpha )
   int ret = 0;
   std::vector<int> tmp_index( 1, 0 );
   for (int i=0; i<numvecs; i++) {
-    Epetra_MultiVector temp_vec(Epetra_DataAccess::View, *this, &tmp_index[0], 1);
+    Epetra_MultiVector temp_vec(BELOSEPETRAVIEW, *this, &tmp_index[0], 1);
     ret = temp_vec.Scale( alpha[i] );
     TEUCHOS_TEST_FOR_EXCEPTION(ret!=0, EpetraMultiVecFailure, 
 		       "Belos::MultiVecTraits<double,Epetra_MultiVec>::MvScale: "
@@ -509,7 +509,7 @@ void EpetraMultiVec::MvTransMv ( const double alpha, const MultiVec<double>& A,
   
   if (A_vec) {
     Epetra_LocalMap LocalMap(B.numRows(), 0, Map().Comm());
-    Epetra_MultiVector B_Pvec(Epetra_DataAccess::View, LocalMap, B.values(), B.stride(), B.numCols());
+    Epetra_MultiVector B_Pvec(BELOSEPETRAVIEW, LocalMap, B.values(), B.stride(), B.numCols());
     
     int info = B_Pvec.Multiply( 'T', 'N', alpha, *A_vec, *this, 0.0 );
     TEUCHOS_TEST_FOR_EXCEPTION(info!=0, EpetraMultiVecFailure, 
