@@ -156,6 +156,12 @@ public:
    *   - "Verbosity" - a sum of MsgType specifying the verbosity. Default: Belos::Errors
    *   - "Output Style" - a OutputType specifying the style of output. Default: Belos::General
    *   - "Convergence Tolerance" - a \c MagnitudeType specifying the level that residual norms must reach to decide convergence. Default: 1e-8
+   *		\param pl [in] ParameterList with construction information
+   *			\htmlonly
+   *			<iframe src="belos_BlockGmres.xml" width=100% scrolling="no" frameborder="0">
+   *			</iframe>
+   *			<hr />
+   *			\endhtmlonly
    */
   BlockGmresSolMgr( const Teuchos::RCP<LinearProblem<ScalarType,MV,OP> > &problem,
     const Teuchos::RCP<Teuchos::ParameterList> &pl );
@@ -225,6 +231,9 @@ public:
   //! Set the parameters the solver manager should use to solve the linear problem.
   void setParameters( const Teuchos::RCP<Teuchos::ParameterList> &params );
 
+  //! Set a debug status test that will be checked at the same time as the top-level status test.
+  void setDebugStatusTest( const Teuchos::RCP<StatusTest<ScalarType,MV,OP> > &debugStatusTest );
+
   //@}
 
   //! @name Reset methods
@@ -292,6 +301,7 @@ private:
   Teuchos::RCP<std::ostream> outputStream_;
 
   // Status test.
+  Teuchos::RCP<StatusTest<ScalarType,MV,OP> > debugStatusTest_;
   Teuchos::RCP<StatusTest<ScalarType,MV,OP> > sTest_;
   Teuchos::RCP<StatusTestMaxIters<ScalarType,MV,OP> > maxIterTest_;
   Teuchos::RCP<StatusTest<ScalarType,MV,OP> > convTest_;
@@ -481,8 +491,7 @@ BlockGmresSolMgr<ScalarType,MV,OP>::getValidParameters() const
     pl->set("Maximum Restarts", maxRestarts_default_,
       "The maximum number of restarts allowed for each\n"
       "set of RHS solved.");
-    pl->set(
-      "Maximum Iterations", maxIters_default_,
+    pl->set("Maximum Iterations", maxIters_default_,
       "The maximum number of block iterations allowed for each\n"
       "set of RHS solved.");
     pl->set("Num Blocks", numBlocks_default_,
@@ -520,7 +529,6 @@ BlockGmresSolMgr<ScalarType,MV,OP>::getValidParameters() const
       "The type of scaling used in the explicit residual convergence test.");
     pl->set("Timer Label", label_default_,
       "The string to use as a prefix for the timer labels.");
-    //  pl->set("Restart Timers", restartTimers_);
     pl->set("Orthogonalization", orthoType_default_,
       "The type of orthogonalization to use: DGKS, ICGS, or IMGS.");
     pl->set("Orthogonalization Constant",orthoKappa_default_,
@@ -627,6 +635,7 @@ void BlockGmresSolMgr<ScalarType,MV,OP>::setParameters( const Teuchos::RCP<Teuch
                         "Belos::BlockGmresSolMgr: \"Orthogonalization\" must be either \"DGKS\", \"ICGS\", or \"IMGS\".");
     if (tempOrthoType != orthoType_) {
       orthoType_ = tempOrthoType;
+      params_->set("Orthogonalization", orthoType_);
       // Create orthogonalization manager
       if (orthoType_=="DGKS") {
         if (orthoKappa_ <= 0) {
@@ -796,6 +805,7 @@ void BlockGmresSolMgr<ScalarType,MV,OP>::setParameters( const Teuchos::RCP<Teuch
 
   // Create orthogonalization manager if we need to.
   if (ortho_ == Teuchos::null) {
+    params_->set("Orthogonalization", orthoType_);
     if (orthoType_=="DGKS") {
       if (orthoKappa_ <= 0) {
         ortho_ = Teuchos::rcp( new DGKSOrthoManager<ScalarType,MV,OP>( label_ ) );
@@ -894,6 +904,12 @@ bool BlockGmresSolMgr<ScalarType,MV,OP>::checkStatusTest() {
   // Create the status test.
   sTest_ = Teuchos::rcp( new StatusTestCombo_t( StatusTestCombo_t::OR, maxIterTest_, convTest_ ) );
 
+  // Add debug status test, if one is provided by the user
+  if (nonnull(debugStatusTest_) ) {
+    // Add debug convergence test
+    Teuchos::rcp_dynamic_cast<StatusTestCombo_t>(sTest_)->addStatusTest( debugStatusTest_ );
+  }
+
   // Create the status test output class.
   // This class manages and formats the output from the status test.
   StatusTestOutputFactory<ScalarType,MV,OP> stoFactory( outputStyle_ );
@@ -911,6 +927,15 @@ bool BlockGmresSolMgr<ScalarType,MV,OP>::checkStatusTest() {
   return false;
 }
 
+template<class ScalarType, class MV, class OP>
+void BlockGmresSolMgr<ScalarType,MV,OP>::setDebugStatusTest(
+  const Teuchos::RCP<StatusTest<ScalarType,MV,OP> > &debugStatusTest
+  )
+{
+  debugStatusTest_ = debugStatusTest;
+}
+
+
 // solve()
 template<class ScalarType, class MV, class OP>
 ReturnType BlockGmresSolMgr<ScalarType,MV,OP>::solve() {
