@@ -98,8 +98,7 @@ namespace Belos {
     /// Creates an unpreconditioned LinearProblem instance with the
     /// operator (\c A), initial guess (\c X), and right hand side (\c
     /// B).  Preconditioners can be set using the \c setLeftPrec() and
-    /// \c setRightPrec() methods, and scaling can also be set using
-    /// the \c setLeftScale() and \c setRightScale() methods.
+    /// \c setRightPrec() methods.
     LinearProblem (const Teuchos::RCP<const OP> &A, 
 		   const Teuchos::RCP<MV> &X, 
 		   const Teuchos::RCP<const MV> &B);
@@ -148,6 +147,8 @@ namespace Belos {
     /// \brief Set the user-defined residual of linear problem \f$AX = B\f$.
     ///
     /// The multivector is set by pointer; no copy of the object is made.
+    /// \note If the passed in residual vector is not compatible with B,
+    ///       this vector will be ignored.
     void setInitResVec(const Teuchos::RCP<const MV> &R0) {
       R0_user_ = R0;
       isSet_=false;
@@ -156,6 +157,8 @@ namespace Belos {
     /// \brief Set the user-defined preconditioned residual of linear problem \f$AX = B\f$.
     ///
     /// The multivector is set by pointer; no copy of the object is made.
+    /// \note If the passed in residual vector is not compatible with B,
+    ///       this vector will be ignored.
     void setInitPrecResVec(const Teuchos::RCP<const MV> &PR0) {
       PR0_user_ = PR0;
       isSet_=false;
@@ -550,12 +553,6 @@ namespace Belos {
     //! @name Booleans to keep track of linear problem attributes and status.
     //@{ 
 
-    //! Is there a left scaling?
-    bool Left_Scale_;
-
-    //! Is there a right scaling?
-    bool Right_Scale_;
-
     //! Has the linear problem to solve been set?
     bool isSet_;
 
@@ -585,8 +582,6 @@ namespace Belos {
     num2Solve_(0),
     rhsIndex_(0),
     lsNum_(0),
-    Left_Scale_(false),
-    Right_Scale_(false),
     isSet_(false),
     isHermitian_(false),
     solutionUpdated_(false),
@@ -606,8 +601,6 @@ namespace Belos {
     num2Solve_(0),
     rhsIndex_(0),
     lsNum_(0),
-    Left_Scale_(false),
-    Right_Scale_(false),
     isSet_(false),
     isHermitian_(false),
     solutionUpdated_(false),
@@ -634,8 +627,6 @@ namespace Belos {
     num2Solve_(Problem.num2Solve_),
     rhsIndex_(Problem.rhsIndex_),
     lsNum_(Problem.lsNum_),
-    Left_Scale_(Problem.Left_Scale_),
-    Right_Scale_(Problem.Right_Scale_),
     isSet_(Problem.isSet_),
     isHermitian_(Problem.isHermitian_),
     solutionUpdated_(Problem.solutionUpdated_),
@@ -907,26 +898,43 @@ namespace Belos {
       }
     }
     else { // User specified the residuals
+      // If the user did not specify the right sized residual, create one and set R0_user_ to null.
       if (MVT::GetNumberVecs( *R0_user_ )!=MVT::GetNumberVecs( *B_ )) {
         Teuchos::RCP<MV> helper = MVT::Clone( *B_, MVT::GetNumberVecs( *B_ ) );
         computeCurrResVec( &*helper, &*X_, &*B_ );
-        R0_user_ = helper;
+        R0_user_ = Teuchos::null;
+        R0_ = helper;
       }
 
       if (LP_!=Teuchos::null) {
-        if (PR0_user_==Teuchos::null || (PR0_user_==R0_) || (MVT::GetNumberVecs(*PR0_user_)!=MVT::GetNumberVecs(*B_))) {
+        // If the user provided preconditioned residual is the wrong size or pointing at
+        // the wrong object, create one and set the PR0_user_ to null.
+        if (PR0_user_==Teuchos::null || (PR0_user_==R0_) || (PR0_user_==R0_user_) 
+          || (MVT::GetNumberVecs(*PR0_user_)!=MVT::GetNumberVecs(*B_))) {
           Teuchos::RCP<MV> helper = MVT::Clone( *B_, MVT::GetNumberVecs( *B_ ) );
           {
+            // Get the initial residual from getInitResVec because R0_user_ may be null from above.
 #ifdef BELOS_TEUCHOS_TIME_MONITOR
             Teuchos::TimeMonitor PrecTimer(*timerPrec_);
 #endif
-            OPT::Apply( *LP_, *R0_user_, *helper );
+            OPT::Apply( *LP_, *getInitResVec(), *helper );
           }
-          PR0_user_ = helper;
+          PR0_user_ = Teuchos::null;
+          PR0_ = helper;
         }
       }
       else {
-        PR0_user_ = R0_user_;
+        // The preconditioned initial residual vector is the residual vector.
+        // NOTE:  R0_user_ could be null if incompatible.
+        if (R0_user_!=Teuchos::null)  
+        {
+          PR0_user_ = R0_user_;
+        }
+        else
+        {
+          PR0_user_ = Teuchos::null;
+          PR0_ = R0_;
+        }
       }
     }
 
