@@ -50,6 +50,7 @@
 #include "BelosConfigDefs.hpp"
 #include "BelosTypes.hpp"
 #include "BelosLinearProblem.hpp"
+#include "BelosStatusTestCombo.hpp"
 
 #include "Teuchos_ParameterList.hpp"
 #include "Teuchos_RCP.hpp"
@@ -139,7 +140,9 @@ class SolverManager : virtual public Teuchos::Describable {
 
   //! Set user-defined convergence status test.
   virtual void setUserConvStatusTest(
-    const Teuchos::RCP<StatusTest<ScalarType,MV,OP> > &userConvStatusTest
+    const Teuchos::RCP<StatusTest<ScalarType,MV,OP> > &userConvStatusTest,
+    const typename StatusTestCombo<ScalarType,MV,OP>::ComboType &comboType =
+        StatusTestCombo<ScalarType,MV,OP>::SEQ
     )
     {
       TEUCHOS_TEST_FOR_EXCEPT_MSG(true, "Error, the function setUserConvStatusTest() has not been"
