@@ -363,19 +363,33 @@ void Epetra_LAPACK::LAMCH( const char CMACH, double & T) const {
 //=============================================================================
 void Epetra_LAPACK::GGSVD(const char JOBU, const char JOBV, const char JOBQ, const int M, const int N, const int P, int * K, int * L,
 			  double* A,  const int LDA,  double* B,  const int LDB,
-                          double* ALPHA,  double* BETA,  double* U,  const int LDU, double* V, const int LDV, double* Q, const int LDQ, double* WORK, int* IWORK,
-                          int* INFO) const {
+                          double* ALPHA,  double* BETA,  double* U,  const int LDU, double* V, const int LDV, double* Q, const int LDQ, double* WORK,
+          #ifdef HAVE_EPETRA_LAPACK_GSSVD3
+                          const int LWORK,
+          #endif
+                          int* IWORK, int* INFO) const {
   DGGSVD_F77(CHAR_MACRO(JOBU), CHAR_MACRO(JOBV), CHAR_MACRO(JOBQ), &M, &N, &P, K, L,  A,  &LDA,  B,  &LDB,
-	     ALPHA,  BETA,  U,  &LDU, V, &LDV, Q, &LDQ, WORK, IWORK, INFO);
+            ALPHA,  BETA,  U,  &LDU, V, &LDV, Q, &LDQ, WORK,
+          #ifdef HAVE_EPETRA_LAPACK_GSSVD3
+            &LWORK,
+          #endif
+            IWORK, INFO);
 }
 
 //=============================================================================
 void Epetra_LAPACK::GGSVD(const char JOBU, const char JOBV, const char JOBQ, const int M, const int N, const int P, int * K, int * L,
 			  float* A,  const int LDA,  float* B,  const int LDB,
-                          float* ALPHA,  float* BETA,  float* U,  const int LDU, float* V, const int LDV, float* Q, const int LDQ, float* WORK, int* IWORK,
-                          int* INFO) const {
+                          float* ALPHA,  float* BETA,  float* U,  const int LDU, float* V, const int LDV, float* Q, const int LDQ, float* WORK,
+          #ifdef HAVE_EPETRA_LAPACK_GSSVD3
+                          const int LWORK,
+          #endif
+                          int* IWORK, int* INFO) const {
   SGGSVD_F77(CHAR_MACRO(JOBU), CHAR_MACRO(JOBV), CHAR_MACRO(JOBQ), &M, &N, &P, K, L,  A,  &LDA,  B,  &LDB,
-	     ALPHA,  BETA,  U,  &LDU, V, &LDV, Q, &LDQ, WORK, IWORK, INFO);
+            ALPHA,  BETA,  U,  &LDU, V, &LDV, Q, &LDQ, WORK,
+          #ifdef HAVE_EPETRA_LAPACK_GSSVD3
+            &LWORK,
+          #endif
+            IWORK, INFO);
 }
 
 //=============================================================================
