@@ -169,7 +169,7 @@ int build_matrix_unfused(const Epetra_CrsMatrix & SourceMatrix, Epetra_Export &
 
 
 
-int build_test_matrix(Epetra_MpiComm & Comm, int test_number, Epetra_CrsMatrix *&A){
+void build_test_matrix(Epetra_MpiComm & Comm, int test_number, Epetra_CrsMatrix *&A){
   int NumProc = Comm.NumProc();
   int MyPID   = Comm.MyPID();
 
@@ -242,7 +242,6 @@ int build_test_matrix(Epetra_MpiComm & Comm, int test_number, Epetra_CrsMatrix *
     delete [] Indices;
 
   }
-  return 0;
 }
 
 
@@ -268,7 +267,7 @@ void build_test_map(const Epetra_Map & oldMap, Epetra_Map *& newMap) {
 
 int main(int argc, char *argv[])
 {
-  int ierr = 0, total_err=0;
+  int total_err=0;
 
   // Initialize MPI
 
@@ -320,7 +319,7 @@ int main(int argc, char *argv[])
 #ifdef ENABLE_TEST_1
   {
     double diff;
-    ierr=build_test_matrix(Comm,1,A);
+    build_test_matrix(Comm,1,A);
     int num_global = A->RowMap().NumGlobalElements();
 
     // New map with all on Proc1
@@ -359,7 +358,7 @@ int main(int argc, char *argv[])
 #ifdef ENABLE_TEST_2
   {
     double diff;
-    ierr=build_test_matrix(Comm,1,A);
+    build_test_matrix(Comm,1,A);
     int num_local = A->RowMap().NumMyElements();
 
     std::vector<int> MyGIDS(num_local);
@@ -400,7 +399,7 @@ int main(int argc, char *argv[])
 #ifdef ENABLE_TEST_3
   {
     double diff;
-    ierr=build_test_matrix(Comm,1,A);
+    build_test_matrix(Comm,1,A);
     int num_local  = A->RowMap().NumMyElements();
     int num_global = A->RowMap().NumGlobalElements();
     int num_scansum = 0;
@@ -446,7 +445,7 @@ int main(int argc, char *argv[])
 #ifdef ENABLE_TEST_4
   {
     double diff;
-    ierr=build_test_matrix(Comm,1,A);
+    build_test_matrix(Comm,1,A);
 
     // Assume we always own the diagonal
     int num_local = A->NumMyCols()-A->NumMyRows();
@@ -499,7 +498,7 @@ int main(int argc, char *argv[])
 #ifdef ENABLE_TEST_5
   {
     double diff;
-    ierr=build_test_matrix(Comm,1,A);
+    build_test_matrix(Comm,1,A);
 
     // New map with all on Procs 0 and 2
     build_test_map(A->RowMap(),Map1);
@@ -536,7 +535,7 @@ int main(int argc, char *argv[])
 #ifdef ENABLE_TEST_6
   {
     double diff;
-    ierr=build_test_matrix(Comm,1,A);
+    build_test_matrix(Comm,1,A);
 
     // New map with all on Procs 0 and 2
     build_test_map(A->RowMap(),Map1);
