@@ -62,12 +62,12 @@ namespace Galeri {
     class Elasticity3DProblem : public Problem<Map,Matrix,MultiVector> {
     public:
       Elasticity3DProblem(Teuchos::ParameterList& list, const Teuchos::RCP<const Map>& map) : Problem<Map,Matrix,MultiVector>(list, map) {
-        E  = list.get("E", 1e9);
-        nu = list.get("nu", 0.25);
+        E  = list.get("E", Teuchos::as<typename Teuchos::ScalarTraits<Scalar>::magnitudeType>(1e9));
+        nu = list.get("nu", Teuchos::as<typename Teuchos::ScalarTraits<Scalar>::magnitudeType>(0.25));
 
-        nx_ = list.get("nx", -1);
-        ny_ = list.get("ny", -1);
-        nz_ = list.get("nz", -1);
+        nx_ = list.get<GlobalOrdinal>("nx", -1);
+        ny_ = list.get<GlobalOrdinal>("ny", -1);
+        nz_ = list.get<GlobalOrdinal>("nz", -1);
 
         nDim_ = 3;
         double one = 1.0;
@@ -110,7 +110,7 @@ namespace Galeri {
 
       std::vector<char>              dirichlet_;
 
-      Scalar                         E, nu;
+      typename Teuchos::ScalarTraits<Scalar>::magnitudeType  E, nu;
       std::vector<Scalar>            stretch;
       std::string                    mode_;
 
@@ -129,6 +129,8 @@ namespace Galeri {
     Teuchos::RCP<Matrix> Elasticity3DProblem<Scalar,LocalOrdinal,GlobalOrdinal,Map,Matrix,MultiVector>::BuildMatrix() {
       using Teuchos::SerialDenseMatrix;
 
+      typedef Teuchos::ScalarTraits<Scalar> TST;
+
       BuildMesh();
 
       const size_t numDofPerNode   = 3;
@@ -198,7 +200,7 @@ namespace Galeri {
 
         // Check if element is a translation of the previous element
         SC xMove = elementNodes(0,0) - prevElementNodes(0,0), yMove = elementNodes(0,1) - prevElementNodes(0,1), zMove = elementNodes(0,2) - prevElementNodes(0,2);
-        SC eps = 1e-15;         // coordinate comparison criteria
+        typename TST::magnitudeType eps = 1e-15;         // coordinate comparison criteria
         bool recompute = false;
         {
           size_t j = 0;
@@ -307,7 +309,7 @@ namespace Galeri {
                   if ((j == k) || (std::abs(j-k) <  4 && ((j+k) & 0x1)) || (std::abs(j-k) == 4)) {
                     // Nodes j and k are connected by an edge, or j == k
                     LO k0 = numDofPerNode*k, k1 = k0+1, k2 = k0+2;
-                    SC f = pow(2*Teuchos::ScalarTraits<SC>::one(), Teuchos::as<int>(std::min(dirichlet_[elemNodes[j]], dirichlet_[elemNodes[k]])));
+                    SC f = pow(2.0*Teuchos::ScalarTraits<SC>::one(), Teuchos::as<int>(std::min(dirichlet_[elemNodes[j]], dirichlet_[elemNodes[k]])));
 
                     KE(j0,k0) *= f; KE(j0,k1) *= f; KE(j0,k2) *= f;
                     KE(j1,k0) *= f; KE(j1,k1) *= f; KE(j1,k2) *= f;
@@ -334,6 +336,8 @@ namespace Galeri {
       // as we cannot construct a single DOF map in Problem, we repeat the coords
       this->Coords_ = MultiVectorTraits<Map,MultiVector>::Build(this->Map_, nDim_);
 
+      typedef Teuchos::ScalarTraits<Scalar> TST;
+
       Teuchos::ArrayRCP<SC> x = this->Coords_->getDataNonConst(0);
       Teuchos::ArrayRCP<SC> y = this->Coords_->getDataNonConst(1);
       Teuchos::ArrayRCP<SC> z = this->Coords_->getDataNonConst(2);
@@ -343,7 +347,9 @@ namespace Galeri {
       // NOTE: coordinates vector local ordering is consistent with that of the
       // matrix map, as it is constructed by going through GIDs and translating
       // those.
-      const SC hx = stretch[0], hy = stretch[1], hz = stretch[2];
+      const typename TST::magnitudeType hx = TST::magnitude(stretch[0]),
+                                        hy = TST::magnitude(stretch[1]),
+                                        hz = TST::magnitude(stretch[2]);
       for (GO p = 0; p < GIDs.size(); p += 3) { // FIXME: we assume that DOF for the same node are label consequently
         GlobalOrdinal ind = GIDs[p] / 3;
         size_t i = ind % nx_, k = ind / (nx_*ny_), j = (ind - k*nx_*ny_) / nx_;
@@ -358,6 +364,9 @@ namespace Galeri {
 
     template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Map, typename Matrix, typename MultiVector>
     RCP<MultiVector> Elasticity3DProblem<Scalar,LocalOrdinal,GlobalOrdinal,Map,Matrix,MultiVector>::BuildNullspace() {
+
+      typedef Teuchos::ScalarTraits<Scalar> TST;
+
       const int numVectors = 6;
       this->Nullspace_ = MultiVectorTraits<Map,MultiVector>::Build(this->Map_, numVectors);
 
@@ -371,7 +380,7 @@ namespace Galeri {
       Teuchos::ArrayRCP<SC> y = this->Coords_->getDataNonConst(1);
       Teuchos::ArrayRCP<SC> z = this->Coords_->getDataNonConst(2);
 
-      SC one = Teuchos::ScalarTraits<SC>::one();
+      SC one = TST::one();
 
       // NOTE: nullspace local ordering is consistent with that of the matrix
       // map, as it inherits ordering from coordinates, which is consistent.
@@ -407,22 +416,29 @@ namespace Galeri {
 
       // Equalize norms of all vectors to that of the first one
       // We do not normalize them as a vector of ones seems nice
-      Teuchos::Array<typename Teuchos::ScalarTraits<SC>::magnitudeType> norms2(numVectors);
+      Teuchos::Array<typename TST::magnitudeType> norms2(numVectors);
       for (int i = 1; i < numVectors; i++)
         norms2[i] = norms2[0] / norms2[i];
-      norms2[0] = Teuchos::ScalarTraits<SC>::one();
+      norms2[0] = TST::magnitude(TST::one());
       this->Nullspace_->norm2(norms2);
-      this->Nullspace_->scale(norms2);
+      Teuchos::Array<Scalar> norms2scalar(numVectors);
+      for (int i = 1; i < numVectors; i++)
+        norms2scalar[i] = norms2[i];
+      this->Nullspace_->scale(norms2scalar);
 
       return this->Nullspace_;
     }
 
     template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Map, typename Matrix, typename MultiVector>
     void Elasticity3DProblem<Scalar,LocalOrdinal,GlobalOrdinal,Map,Matrix,MultiVector>::BuildMesh() {
-      const SC hx = stretch[0], hy = stretch[1], hz = stretch[2];
+      typedef Teuchos::ScalarTraits<Scalar> TST;
+      const typename TST::magnitudeType hx = TST::magnitude(stretch[0]),
+                                        hy = TST::magnitude(stretch[1]),
+                                        hz = TST::magnitude(stretch[2]);
 
       GO myPID = this->Map_->getComm()->getRank();
-      GO mx = this->list_.get("mx", -1), my = this->list_.get("my", -1), mz = this->list_.get("mz", -1);
+      GO const & negOne=-1;
+      GO mx = this->list_.get("mx", negOne), my = this->list_.get("my", negOne), mz = this->list_.get("mz", negOne);
 
       const GO mxy = mx*my;
 
@@ -489,7 +505,7 @@ namespace Galeri {
     template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Map, typename Matrix, typename MultiVector>
     void Elasticity3DProblem<Scalar,LocalOrdinal,GlobalOrdinal,Map,Matrix,MultiVector>::BuildMaterialMatrix(Teuchos::SerialDenseMatrix<LocalOrdinal,Scalar>& D) {
       D.shape(6,6);
-      SC c = E / (1 + nu) / (1 - 2*nu);
+      typename Teuchos::ScalarTraits<SC>::magnitudeType c = E / (1 + nu) / (1 - 2*nu);
       D(0,0) = c*(1-nu);      D(0,1) = c*nu;      D(0,2) = c*nu;
       D(1,0) = c*nu;          D(1,1) = c*(1-nu);  D(1,2) = c*nu;
       D(2,0) = c*nu;          D(2,1) = c*nu;      D(2,2) = c*(1-nu);
@@ -527,19 +543,19 @@ namespace Galeri {
     template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Map, typename Matrix, typename MultiVector>
     void Elasticity3DProblem<Scalar,LocalOrdinal,GlobalOrdinal,Map,Matrix,MultiVector>::EvalDxi(const std::vector<Point>& refPoints, Point& gaussPoint, SC * dxi) {
       for (size_t j = 0; j < refPoints.size(); j++)
-        dxi[j] = refPoints[j].x * (1 + refPoints[j].y*gaussPoint.y) * (1 + refPoints[j].z*gaussPoint.z) / 8;
+        dxi[j] = refPoints[j].x * (1.0 + refPoints[j].y*gaussPoint.y) * (1.0 + refPoints[j].z*gaussPoint.z) / 8.;
     }
 
     template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Map, typename Matrix, typename MultiVector>
     void Elasticity3DProblem<Scalar,LocalOrdinal,GlobalOrdinal,Map,Matrix,MultiVector>::EvalDeta(const std::vector<Point>& refPoints, Point& gaussPoint, SC * deta) {
       for (size_t j = 0; j < refPoints.size(); j++)
-        deta[j] = (1 + refPoints[j].x*gaussPoint.x) * refPoints[j].y * (1 + refPoints[j].z*gaussPoint.z) / 8;
+        deta[j] = (1.0 + refPoints[j].x*gaussPoint.x) * refPoints[j].y * (1.0 + refPoints[j].z*gaussPoint.z) / 8.;
     }
 
     template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Map, typename Matrix, typename MultiVector>
     void Elasticity3DProblem<Scalar,LocalOrdinal,GlobalOrdinal,Map,Matrix,MultiVector>::EvalDzeta(const std::vector<Point>& refPoints, Point& gaussPoint, SC * dzeta) {
       for (size_t j = 0; j < refPoints.size(); j++)
-        dzeta[j] = (1 + refPoints[j].x*gaussPoint.x) * (1 + refPoints[j].y*gaussPoint.y) * refPoints[j].z / 8;
+        dzeta[j] = (1.0 + refPoints[j].x*gaussPoint.x) * (1.0 + refPoints[j].y*gaussPoint.y) * refPoints[j].z / 8.;
     }
 
   } // namespace Xpetra
