@@ -103,20 +103,15 @@ namespace Ifpack2 {
 /// that they are the same.
 template<class MatrixType,
          class LocalScalarType,
-         const bool supportsLocalScalarType =
-         ::Ifpack2::Details::LapackSupportsScalar<LocalScalarType>::value >
-class BandedContainer {};
+         bool supportsLapackScalar = ::Ifpack2::Details::LapackSupportsScalar<LocalScalarType>::value>
+class BandedContainer;
 
-/// \brief Partial specialization with the non-stub implementation,
-///   for LocalScalarType types that LAPACK supports.
-template<class MatrixType,
-         class LocalScalarType>
+template<class MatrixType, class LocalScalarType>
 class BandedContainer<MatrixType, LocalScalarType, true> :
     public Container<MatrixType> {
-public:
-  //! \name Public typedefs
+  //! @name Internal typedefs (private)
   //@{
-
+private:
   /// \brief The first template parameter of this class.
   ///
   /// This must be either a Tpetra::RowMatrix specialization or a
@@ -126,21 +121,30 @@ public:
   typedef MatrixType matrix_type;
   //! The second template parameter of this class.
   typedef LocalScalarType local_scalar_type;
+  //! The internal representation of LocalScalarType in Kokkos::View
+  typedef typename Kokkos::Details::ArithTraits<local_scalar_type>::val_type local_impl_scalar_type;
 
   //! The type of entries in the input (global) matrix.
-  typedef typename MatrixType::scalar_type scalar_type;
+  typedef typename Container<MatrixType>::scalar_type scalar_type;
   //! The type of local indices in the input (global) matrix.
-  typedef typename MatrixType::local_ordinal_type local_ordinal_type;
+  typedef typename Container<MatrixType>::local_ordinal_type local_ordinal_type;
   //! The type of global indices in the input (global) matrix.
-  typedef typename MatrixType::global_ordinal_type global_ordinal_type;
+  typedef typename Container<MatrixType>::global_ordinal_type global_ordinal_type;
   //! The Node type of the input (global) matrix.
-  typedef typename MatrixType::node_type node_type;
+  typedef typename Container<MatrixType>::node_type node_type;
+
+  typedef typename Container<MatrixType>::mv_type mv_type;
+  typedef typename Container<MatrixType>::map_type map_type;
+  typedef Tpetra::MultiVector<local_scalar_type, local_ordinal_type, global_ordinal_type, node_type> local_mv_type;
+  typedef typename Container<MatrixType>::vector_type vector_type;
+  typedef typename Container<MatrixType>::partitioner_type partitioner_type;
+  typedef typename Container<MatrixType>::import_type import_type;
+
+  typedef typename Container<MatrixType>::HostView HostView;
+  typedef typename local_mv_type::dual_view_type::t_host HostViewLocal;
 
   static_assert(std::is_same<MatrixType,
-                  Tpetra::RowMatrix<typename MatrixType::scalar_type,
-                    typename MatrixType::local_ordinal_type,
-                    typename MatrixType::global_ordinal_type,
-                    typename MatrixType::node_type> >::value,
+                  Tpetra::RowMatrix<scalar_type, local_ordinal_type, global_ordinal_type, node_type> >::value,
                 "Ifpack2::BandedContainer: Please use MatrixType = Tpetra::RowMatrix.");
 
   /// \brief The (base class) type of the input matrix.
@@ -154,6 +158,7 @@ public:
   typedef typename Container<MatrixType>::row_matrix_type row_matrix_type;
 
   //@}
+public:
   //! \name Constructor and destructor
   //@{
 
@@ -174,7 +179,13 @@ public:
   ///   <tt>number of superdiagonals. Note: Internally, we store a Teuchos::SerialBandedMatrix
   ///       with kl+ku superdiagonals, as we need the addtional storage for the LU decomposition.
   BandedContainer (const Teuchos::RCP<const row_matrix_type>& matrix,
-                   const Teuchos::ArrayView<const local_ordinal_type>& localRows);
+                   const Teuchos::Array<Teuchos::Array<local_ordinal_type> >& partitions,
+                   const Teuchos::RCP<const import_type>& importer,
+                   int OverlapLevel,
+                   scalar_type DampingFactor);
+
+  BandedContainer (const Teuchos::RCP<const row_matrix_type>& matrix,
+                   const Teuchos::Array<local_ordinal_type>& localRows);
 
   //! Destructor (declared virtual for memory safety of derived classes).
   virtual ~BandedContainer ();
@@ -183,14 +194,6 @@ public:
   //! \name Get and set methods
   //@{
 
-  /// \brief The number of rows in the local matrix on the calling process.
-  ///
-  /// Local matrices must be square.  Each process has exactly one
-  /// matrix.  Those matrices may vary in dimensions.
-  virtual size_t getNumRows() const {
-    return numRows_;
-  }
-
   //! Whether the container has been successfully initialized.
   virtual bool isInitialized () const {
     return IsInitialized_;
@@ -211,25 +214,31 @@ public:
   //! Do all set-up operations that only require matrix structure.
   virtual void initialize ();
 
-  //! Extract the local diagonal block and prepare the solver.
+  //! Initialize and compute each block.
   virtual void compute ();
 
+  void clearBlocks();
+
   //! Compute <tt>Y := alpha * M^{-1} X + beta*Y</tt>.
   virtual void
-  apply (const Tpetra::MultiVector<scalar_type,local_ordinal_type,global_ordinal_type,node_type>& X,
-         Tpetra::MultiVector<scalar_type,local_ordinal_type,global_ordinal_type,node_type>& Y,
-         Teuchos::ETransp mode=Teuchos::NO_TRANS,
-         scalar_type alpha=Teuchos::ScalarTraits<scalar_type>::one(),
-         scalar_type beta=Teuchos::ScalarTraits<scalar_type>::zero()) const;
+  apply (HostView& X,
+         HostView& Y,
+         int blockIndex,
+         int stride,
+         Teuchos::ETransp mode = Teuchos::NO_TRANS,
+         scalar_type alpha = Teuchos::ScalarTraits<scalar_type>::one(),
+         scalar_type beta = Teuchos::ScalarTraits<scalar_type>::zero()) const;
 
   //! Compute <tt>Y := alpha * diag(D) * M^{-1} (diag(D) * X) + beta*Y</tt>.
   virtual void
-  weightedApply (const Tpetra::MultiVector<scalar_type,local_ordinal_type,global_ordinal_type,node_type>& X,
-                 Tpetra::MultiVector<scalar_type,local_ordinal_type,global_ordinal_type,node_type>& Y,
-                 const Tpetra::Vector<scalar_type,local_ordinal_type,global_ordinal_type,node_type>& D,
-                 Teuchos::ETransp mode=Teuchos::NO_TRANS,
-                 scalar_type alpha=Teuchos::ScalarTraits<scalar_type>::one(),
-                 scalar_type beta=Teuchos::ScalarTraits<scalar_type>::zero()) const;
+  weightedApply (HostView& X,
+                 HostView& Y,
+                 HostView& D,
+                 int blockIndex,
+                 int stride,
+                 Teuchos::ETransp mode = Teuchos::NO_TRANS,
+                 scalar_type alpha = Teuchos::ScalarTraits<scalar_type>::one(),
+                 scalar_type beta = Teuchos::ScalarTraits<scalar_type>::zero()) const;
 
   //@}
   //! \name Miscellaneous methods
@@ -263,16 +272,13 @@ private:
   BandedContainer (const BandedContainer<MatrixType, LocalScalarType>& rhs);
 
   //! Extract the submatrix identified by the local indices set by the constructor.
-  void extract (const Teuchos::RCP<const row_matrix_type>& globalMatrix);
+  void extract ();
 
   /// \brief Factor the extracted submatrix.
   ///
   /// Call this after calling extract().
   void factor ();
 
-  typedef Tpetra::MultiVector<local_scalar_type, local_ordinal_type,
-                              global_ordinal_type, node_type> local_mv_type;
-
   /// \brief Post-permutation, post-view version of apply().
   ///
   /// apply() first does any necessary subset permutation and view
@@ -282,50 +288,48 @@ private:
   /// \param X [in] Subset permutation of the input X of apply().
   /// \param Y [in] Subset permutation of the input/output Y of apply().
   void
-  applyImpl (const local_mv_type& X,
-             local_mv_type& Y,
+  applyImpl (HostViewLocal& X,
+             HostViewLocal& Y,
+             int blockIndex,
+             int stride,
              Teuchos::ETransp mode,
              const local_scalar_type alpha,
              const local_scalar_type beta) const;
 
-  //! Number of rows in the local matrix.
-  size_t numRows_;
-
   //! The local diagonal block, which compute() extracts.
-  Teuchos::RCP<Teuchos::SerialBandDenseMatrix<int, local_scalar_type> > diagBlock_;
+  std::vector<Teuchos::SerialBandDenseMatrix<int, local_scalar_type> > diagBlocks_;
+
+  //! Temporary X vector used in apply().
+  mutable std::vector<HostViewLocal> X_local;
+
+  //! Temporary Y vector used in apply().
+  mutable std::vector<HostViewLocal> Y_local;
 
   //! Permutation array from LAPACK (GETRF).
   Teuchos::Array<int> ipiv_;
 
-  //! Map of the input and output Tpetra::MultiVector arguments of applyImpl().
-  Teuchos::RCP<const Tpetra::Map<local_ordinal_type, global_ordinal_type, node_type> > localMap_;
-
-  //! Solution vector.
-  mutable Teuchos::RCP<local_mv_type> Y_;
-
-  //! Input vector for local problems
-  mutable Teuchos::RCP<local_mv_type> X_;
-
   //! If \c true, the container has been successfully initialized.
   bool IsInitialized_;
 
   //! If \c true, the container has been successfully computed.
   bool IsComputed_;
 
-  local_ordinal_type kl_; //< number of subdiagonals
-  local_ordinal_type ku_; //< number of superdiagonals
+  Teuchos::Array<local_ordinal_type> kl_; //< number of subdiagonals
+  Teuchos::Array<local_ordinal_type> ku_; //< number of superdiagonals
+
+  //! Scalar data for all blocks
+  local_scalar_type* scalars_;
+
+  //! Offsets in scalars_ array for all blocks
+  Teuchos::Array<local_ordinal_type> scalarOffsets_;
 };
 
-/// \brief Partial specialization of BandedContainer with the stub
-///   implementation, for LocalScalarType types that LAPACK does NOT
-///   support.
 template<class MatrixType, class LocalScalarType>
 class BandedContainer<MatrixType, LocalScalarType, false> :
     public Container<MatrixType> {
-public:
-  //! \name Public typedefs
+  //! @name Internal typedefs (private)
   //@{
-
+private:
   /// \brief The first template parameter of this class.
   ///
   /// This must be either a Tpetra::RowMatrix specialization or a
@@ -335,21 +339,30 @@ public:
   typedef MatrixType matrix_type;
   //! The second template parameter of this class.
   typedef LocalScalarType local_scalar_type;
+  //! The internal representation of LocalScalarType in Kokkos::View
+  typedef typename Kokkos::Details::ArithTraits<local_scalar_type>::val_type local_impl_scalar_type;
 
   //! The type of entries in the input (global) matrix.
-  typedef typename MatrixType::scalar_type scalar_type;
+  typedef typename Container<MatrixType>::scalar_type scalar_type;
   //! The type of local indices in the input (global) matrix.
-  typedef typename MatrixType::local_ordinal_type local_ordinal_type;
+  typedef typename Container<MatrixType>::local_ordinal_type local_ordinal_type;
   //! The type of global indices in the input (global) matrix.
-  typedef typename MatrixType::global_ordinal_type global_ordinal_type;
+  typedef typename Container<MatrixType>::global_ordinal_type global_ordinal_type;
   //! The Node type of the input (global) matrix.
-  typedef typename MatrixType::node_type node_type;
+  typedef typename Container<MatrixType>::node_type node_type;
+
+  typedef typename Container<MatrixType>::mv_type mv_type;
+  typedef typename Container<MatrixType>::map_type map_type;
+  typedef Tpetra::MultiVector<local_scalar_type, local_ordinal_type, global_ordinal_type, node_type> local_mv_type;
+  typedef typename Container<MatrixType>::vector_type vector_type;
+  typedef typename Container<MatrixType>::partitioner_type partitioner_type;
+  typedef typename Container<MatrixType>::import_type import_type;
+
+  typedef typename Container<MatrixType>::HostView HostView;
+  typedef typename local_mv_type::dual_view_type::t_host HostViewLocal;
 
   static_assert(std::is_same<MatrixType,
-                  Tpetra::RowMatrix<typename MatrixType::scalar_type,
-                    typename MatrixType::local_ordinal_type,
-                    typename MatrixType::global_ordinal_type,
-                    typename MatrixType::node_type> >::value,
+                  Tpetra::RowMatrix<scalar_type, local_ordinal_type, global_ordinal_type, node_type> >::value,
                 "Ifpack2::BandedContainer: Please use MatrixType = Tpetra::RowMatrix.");
 
   /// \brief The (base class) type of the input matrix.
@@ -363,6 +376,7 @@ public:
   typedef typename Container<MatrixType>::row_matrix_type row_matrix_type;
 
   //@}
+public:
   //! \name Constructor and destructor
   //@{
 
@@ -383,7 +397,13 @@ public:
   ///   <tt>number of superdiagonals. Note: Internally, we store a Teuchos::SerialBandedMatrix
   ///       with kl+ku superdiagonals, as we need the addtional storage for the LU decomposition.
   BandedContainer (const Teuchos::RCP<const row_matrix_type>& matrix,
-                   const Teuchos::ArrayView<const local_ordinal_type>& localRows);
+                   const Teuchos::Array<Teuchos::Array<local_ordinal_type> >& partitions,
+                   const Teuchos::RCP<const import_type>& importer,
+                   int OverlapLevel,
+                   scalar_type DampingFactor);
+
+  BandedContainer (const Teuchos::RCP<const row_matrix_type>& matrix,
+                   const Teuchos::Array<local_ordinal_type>& localRows);
 
   //! Destructor (declared virtual for memory safety of derived classes).
   virtual ~BandedContainer ();
@@ -392,14 +412,6 @@ public:
   //! \name Get and set methods
   //@{
 
-  /// \brief The number of rows in the local matrix on the calling process.
-  ///
-  /// Local matrices must be square.  Each process has exactly one
-  /// matrix.  Those matrices may vary in dimensions.
-  virtual size_t getNumRows() const {
-    return numRows_;
-  }
-
   //! Whether the container has been successfully initialized.
   virtual bool isInitialized () const {
     return IsInitialized_;
@@ -420,25 +432,31 @@ public:
   //! Do all set-up operations that only require matrix structure.
   virtual void initialize ();
 
-  //! Extract the local diagonal block and prepare the solver.
+  //! Initialize and compute each block.
   virtual void compute ();
 
+  void clearBlocks();
+
   //! Compute <tt>Y := alpha * M^{-1} X + beta*Y</tt>.
   virtual void
-  apply (const Tpetra::MultiVector<scalar_type,local_ordinal_type,global_ordinal_type,node_type>& X,
-         Tpetra::MultiVector<scalar_type,local_ordinal_type,global_ordinal_type,node_type>& Y,
-         Teuchos::ETransp mode=Teuchos::NO_TRANS,
-         scalar_type alpha=Teuchos::ScalarTraits<scalar_type>::one(),
-         scalar_type beta=Teuchos::ScalarTraits<scalar_type>::zero()) const;
+  apply (HostView& X,
+         HostView& Y,
+         int blockIndex,
+         int stride,
+         Teuchos::ETransp mode = Teuchos::NO_TRANS,
+         scalar_type alpha = Teuchos::ScalarTraits<scalar_type>::one(),
+         scalar_type beta = Teuchos::ScalarTraits<scalar_type>::zero()) const;
 
   //! Compute <tt>Y := alpha * diag(D) * M^{-1} (diag(D) * X) + beta*Y</tt>.
   virtual void
-  weightedApply (const Tpetra::MultiVector<scalar_type,local_ordinal_type,global_ordinal_type,node_type>& X,
-                 Tpetra::MultiVector<scalar_type,local_ordinal_type,global_ordinal_type,node_type>& Y,
-                 const Tpetra::Vector<scalar_type,local_ordinal_type,global_ordinal_type,node_type>& D,
-                 Teuchos::ETransp mode=Teuchos::NO_TRANS,
-                 scalar_type alpha=Teuchos::ScalarTraits<scalar_type>::one(),
-                 scalar_type beta=Teuchos::ScalarTraits<scalar_type>::zero()) const;
+  weightedApply (HostView& X,
+                 HostView& Y,
+                 HostView& D,
+                 int blockIndex,
+                 int stride,
+                 Teuchos::ETransp mode = Teuchos::NO_TRANS,
+                 scalar_type alpha = Teuchos::ScalarTraits<scalar_type>::one(),
+                 scalar_type beta = Teuchos::ScalarTraits<scalar_type>::zero()) const;
 
   //@}
   //! \name Miscellaneous methods
@@ -461,6 +479,7 @@ public:
   describe (Teuchos::FancyOStream &out,
             const Teuchos::EVerbosityLevel verbLevel =
             Teuchos::Describable::verbLevel_default) const;
+
   //@}
 
   /// \brief Get the name of this container type for Details::constructContainer()
@@ -471,16 +490,13 @@ private:
   BandedContainer (const BandedContainer<MatrixType, LocalScalarType>& rhs);
 
   //! Extract the submatrix identified by the local indices set by the constructor.
-  void extract (const Teuchos::RCP<const row_matrix_type>& globalMatrix);
+  void extract ();
 
   /// \brief Factor the extracted submatrix.
   ///
   /// Call this after calling extract().
   void factor ();
 
-  typedef Tpetra::MultiVector<local_scalar_type, local_ordinal_type,
-                              global_ordinal_type, node_type> local_mv_type;
-
   /// \brief Post-permutation, post-view version of apply().
   ///
   /// apply() first does any necessary subset permutation and view
@@ -490,40 +506,41 @@ private:
   /// \param X [in] Subset permutation of the input X of apply().
   /// \param Y [in] Subset permutation of the input/output Y of apply().
   void
-  applyImpl (const local_mv_type& X,
-             local_mv_type& Y,
+  applyImpl (HostViewLocal& X,
+             HostViewLocal& Y,
+             int blockIndex,
+             int stride,
              Teuchos::ETransp mode,
              const local_scalar_type alpha,
              const local_scalar_type beta) const;
 
-  //! Number of rows in the local matrix.
-  size_t numRows_;
-
   //! The local diagonal block, which compute() extracts.
-  Teuchos::RCP<Teuchos::SerialBandDenseMatrix<int, local_scalar_type> > diagBlock_;
+  std::vector<Teuchos::SerialBandDenseMatrix<int, local_scalar_type> > diagBlocks_;
+
+  //! Temporary X vector used in apply().
+  mutable std::vector<HostViewLocal> X_local;
+
+  //! Temporary Y vector used in apply().
+  mutable std::vector<HostViewLocal> Y_local;
 
   //! Permutation array from LAPACK (GETRF).
   Teuchos::Array<int> ipiv_;
 
-  //! Map of the input and output Tpetra::MultiVector arguments of applyImpl().
-  Teuchos::RCP<const Tpetra::Map<local_ordinal_type, global_ordinal_type, node_type> > localMap_;
-
-  //! Solution vector.
-  mutable Teuchos::RCP<local_mv_type> Y_;
-
-  //! Input vector for local problems
-  mutable Teuchos::RCP<local_mv_type> X_;
-
   //! If \c true, the container has been successfully initialized.
   bool IsInitialized_;
 
   //! If \c true, the container has been successfully computed.
   bool IsComputed_;
 
-  local_ordinal_type kl_; //< number of subdiagonals
-  local_ordinal_type ku_; //< number of superdiagonals
-};
+  Teuchos::Array<local_ordinal_type> kl_; //< number of subdiagonals
+  Teuchos::Array<local_ordinal_type> ku_; //< number of superdiagonals
 
+  //! Scalar data for all blocks
+  local_scalar_type* scalars_;
+
+  //! Offsets in scalars_ array for all blocks
+  Teuchos::Array<local_ordinal_type> scalarOffsets_;
+};
 
 }// namespace Ifpack2
 
