@@ -420,11 +420,13 @@ private:
   /// This is the value actually used by ifpackApplyImpl().
   ST lambdaMaxForApply_;
 
-  /// @brief Factor used to increase estimate of A's maximum eigenvalue.
-  /// lambdaMaxForApply_ is multiplied by this factor in ifpackApplyImpl(). The idea is to ensure that
-  /// A's maximum eigenvalue is less than the result. Otherwise high-energy error modes could
-  /// actually be magnified by the smoother.  The default value is 1.1.
-  ST boostFactor_;
+  /// \brief Factor used to increase estimate of A's maximum eigenvalue.
+  ///
+  /// ifpackApplyImpl() multiplies lambdaMaxForApply_ (which see) by
+  /// this factor. The idea is to ensure that A's maximum eigenvalue
+  /// is less than the result. Otherwise the smoother could actually
+  /// magnify high-energy error modes.  The default value is 1.1.
+  MT boostFactor_;
   /// Estimate for minimum eigenvalue of A.
   /// This is the value actually used by ifpackApplyImpl().
   ST lambdaMinForApply_;
@@ -486,6 +488,14 @@ private:
   //! Whether apply() will compute and return the max residual norm.
   bool computeMaxResNorm_;
 
+  /// \brief Output stream for debug output ONLY.
+  ///
+  /// This is ONLY valid if debug_ is true.
+  Teuchos::RCP<Teuchos::FancyOStream> out_;
+
+  //! Whether to print copious debug output.
+  bool debug_;
+
   //@}
   //! \name Computational helper methods
   //@{
@@ -626,6 +636,19 @@ private:
                    const ST eigRatio,
                    const V& D_inv);
 
+  /// \brief Fill x with random initial guess for power method
+  ///
+  /// \param x [out] Initial guess vector; a domain Map vector of the
+  ///   matrix.
+  /// \param nonnegativeRealParts [in] Whether to force all entries of
+  ///   x (on output) to have nonnegative real parts.  Defaults to
+  ///   false (don't force).
+  ///
+  /// This is an implementation detail of powerMethod() below.  For a
+  /// justification of the second parameter, see Github Issues #64 and
+  /// #567.
+  void computeInitialGuessForPowerMethod (V& x, const bool nonnegativeRealParts = false) const;
+
   /// \brief Use the power method to estimate the maximum eigenvalue
   ///   of A*D_inv, given an initial guess vector x.
   ///
@@ -638,7 +661,7 @@ private:
   ///   A.  This method may use this Vector as scratch space.
   ///
   /// \return Estimate of the maximum eigenvalue of A*D_inv.
-  static ST
+  ST
   powerMethodWithInitGuess (const op_type& A, const V& D_inv, const int numIters, V& x);
 
   /// \brief Use the power method to estimate the maximum eigenvalue
@@ -650,7 +673,7 @@ private:
   ///   method.
   ///
   /// \return Estimate of the maximum eigenvalue of A*D_inv.
-  static ST
+  ST
   powerMethod (const op_type& A, const V& D_inv, const int numIters);
 
   //! The maximum infinity norm of all the columns of X.
