@@ -85,7 +85,7 @@ namespace Ifpack2 {
     /// In order to override the default, just specialize this
     /// function for your particular ScalarType.
     template<class ScalarType>
-    typename Teuchos::ScalarTraits<ScalarType>::magnitudeType
+    inline typename Teuchos::ScalarTraits<ScalarType>::magnitudeType
     ilutDefaultDropTolerance () {
       using Teuchos::as;
       typedef Teuchos::ScalarTraits<ScalarType> STS;
@@ -104,7 +104,7 @@ namespace Ifpack2 {
     // Full specialization for ScalarType = double.
     // This specialization preserves ILUT's previous default behavior.
     template<>
-    Teuchos::ScalarTraits<double>::magnitudeType
+    inline Teuchos::ScalarTraits<double>::magnitudeType
     ilutDefaultDropTolerance<double> () {
       return 1e-12;
     }
@@ -346,6 +346,17 @@ double ILUT<MatrixType>::getApplyTime () const {
 }
 
 
+template<class MatrixType>
+size_t ILUT<MatrixType>::getNodeSmootherComplexity() const {
+  TEUCHOS_TEST_FOR_EXCEPTION(
+    A_.is_null (), std::runtime_error, "Ifpack2::ILUT::getNodeSmootherComplexity: "
+    "The input matrix A is null.  Please call setMatrix() with a nonnull "
+    "input matrix, then call compute(), before calling this method.");
+  // ILUT methods cost roughly one apply + the nnz in the upper+lower triangles
+  return A_->getNodeNumEntries() + getNodeNumEntries();
+}
+
+
 template<class MatrixType>
 global_size_t ILUT<MatrixType>::getGlobalNumEntries () const {
   return L_->getGlobalNumEntries () + U_->getGlobalNumEntries ();
