@@ -74,7 +74,9 @@ RILUK<MatrixType>::RILUK (const Teuchos::RCP<const row_matrix_type>& Matrix_in)
     RelaxValue_ (Teuchos::ScalarTraits<magnitude_type>::zero ()),
     Athresh_ (Teuchos::ScalarTraits<magnitude_type>::zero ()),
     Rthresh_ (Teuchos::ScalarTraits<magnitude_type>::one ())
-{}
+{
+  allocateSolvers();
+}
 
 
 template<class MatrixType>
@@ -94,12 +96,20 @@ RILUK<MatrixType>::RILUK (const Teuchos::RCP<const crs_matrix_type>& Matrix_in)
     RelaxValue_ (Teuchos::ScalarTraits<magnitude_type>::zero ()),
     Athresh_ (Teuchos::ScalarTraits<magnitude_type>::zero ()),
     Rthresh_ (Teuchos::ScalarTraits<magnitude_type>::one ())
-{}
+{
+  allocateSolvers();
+}
 
 
 template<class MatrixType>
 RILUK<MatrixType>::~RILUK() {}
 
+template<class MatrixType>
+void RILUK<MatrixType>::allocateSolvers ()
+{
+  L_solver_ = Teuchos::rcp (new LocalSparseTriangularSolver<row_matrix_type> ());
+  U_solver_ = Teuchos::rcp (new LocalSparseTriangularSolver<row_matrix_type> ());
+}
 
 template<class MatrixType>
 void
@@ -377,6 +387,10 @@ setParameters (const Teuchos::ParameterList& params)
     // Accept the default value.
   }
 
+  // Forward to trisolvers.
+  L_solver_->setParameters(params);
+  U_solver_->setParameters(params);
+
   //Experimental
   //Note: just following RILUK original style.
   //Do not think catch is the method for this. JDB
@@ -584,6 +598,10 @@ void RILUK<MatrixType>::initialize ()
         Graph_->initialize ();
         allocate_L_and_U ();
         checkOrderingConsistency (*A_local_);
+        L_solver_->setMatrix (L_);
+        L_solver_->initialize ();
+        U_solver_->setMatrix( U_);
+        U_solver_->initialize ();
         // Do not call initAllValues. compute() always calls initAllValues to
         // fill L and U with possibly new numbers. initialize() is concerned
         // only with the nonzero pattern.
@@ -1025,12 +1043,7 @@ void RILUK<MatrixType>::compute ()
       ! U_->isUpperTriangular (), std::runtime_error,
       "Ifpack2::RILUK::compute: U isn't lower triangular.");
 
-    L_solver_ = Teuchos::rcp (new LocalSparseTriangularSolver<row_matrix_type> (L_));
-    L_solver_->initialize ();
     L_solver_->compute ();
-
-    U_solver_ = Teuchos::rcp (new LocalSparseTriangularSolver<row_matrix_type> (U_));
-    U_solver_->initialize ();
     U_solver_->compute ();
   }
   else {
@@ -1188,43 +1201,28 @@ apply (const Tpetra::MultiVector<scalar_type,local_ordinal_type,global_ordinal_t
     Teuchos::TimeMonitor timeMon (timer);
     if (alpha == one && beta == zero) {
       if (mode == Teuchos::NO_TRANS) { // Solve L (D (U Y)) = X for Y.
-        // Start by solving L C = X for C.  C must have the same Map
-        // as D.  We have to use a temp multivector, since our
-        // implementation of triangular solves does not allow its
-        // input and output to alias one another.
-        //
-        // FIXME (mfh 24 Jan 2014) Cache this temp multivector.
-        MV C (D_->getMap (), X.getNumVectors ());
-        L_solver_->apply (X, C, mode);
+        // Start by solving L Y = X for Y.
+        L_solver_->apply (X, Y, mode);
 
-        // Solve D Y_tmp = C.  Y_tmp must have the same Map as C, and
-        // the operation lets us do this in place in C, so we can
-        // write "solve D C = C for C."
-        C.elementWiseMultiply (one, *D_, C, zero);
+        // Solve D Y = Y.  The operation lets us do this in place in Y, so we can
+        // write "solve D Y = Y for Y."
+        Y.elementWiseMultiply (one, *D_, Y, zero);
 
-        U_solver_->apply (C, Y, mode); // Solve U Y = C.
+        U_solver_->apply (Y, Y, mode); // Solve U Y = Y.
       }
       else { // Solve U^P (D^P (U^P Y)) = X for Y (where P is * or T).
 
-        // Start by solving U^P C = X for C.  C must have the same Map
-        // as D.  We have to use a temp multivector, since our
-        // implementation of triangular solves does not allow its
-        // input and output to alias one another.
-        //
-        // FIXME (mfh 24 Jan 2014) Cache this temp multivector.
-        MV C (D_->getMap (), X.getNumVectors ());
-        U_solver_->apply (X, C, mode);
+        // Start by solving U^P Y = X for Y.
+        U_solver_->apply (X, Y, mode);
 
-        // Solve D^P Y_tmp = C.  Y_tmp must have the same Map as C,
-        // and the operation lets us do this in place in C, so we can
-        // write "solve D^P C = C for C."
+        // Solve D^P Y = Y.
         //
         // FIXME (mfh 24 Jan 2014) If mode = Teuchos::CONJ_TRANS, we
         // need to do an elementwise multiply with the conjugate of
         // D_, not just with D_ itself.
-        C.elementWiseMultiply (one, *D_, C, zero);
+        Y.elementWiseMultiply (one, *D_, Y, zero);
 
-        L_solver_->apply (C, Y, mode); // Solve L^P Y = C.
+        L_solver_->apply (Y, Y, mode); // Solve L^P Y = Y.
       }
     }
     else { // alpha != 1 or beta != 0
@@ -1235,9 +1233,8 @@ apply (const Tpetra::MultiVector<scalar_type,local_ordinal_type,global_ordinal_t
           Y.scale (beta);
         }
       } else { // alpha != zero
-        MV Y_tmp (Y.getMap (), Y.getNumVectors ());
-        apply (X, Y_tmp, mode);
-        Y.update (alpha, Y_tmp, beta);
+        apply (X, Y, mode);
+        Y.update (alpha, Y, beta);
       }
     }
   }
@@ -1346,6 +1343,9 @@ std::string RILUK<MatrixType>::description () const
        << ", Global nnz: " << A_->getGlobalNumEntries();
   }
 
+  if (! L_solver_.is_null ()) os << ", " << L_solver_->description ();
+  if (! U_solver_.is_null ()) os << ", " << U_solver_->description ();
+
   os << "}";
   return os.str ();
 }
