@@ -435,7 +435,6 @@ TEUCHOS_UNIT_TEST_TEMPLATE_3_DECL(Ifpack2BlockRelaxation, LinePartition, Scalar,
 
 TEUCHOS_UNIT_TEST_TEMPLATE_3_DECL(Ifpack2BlockRelaxation, OverlappingPartition, Scalar, LocalOrdinal, GlobalOrdinal)
 {
-#if 0
   // Test BlockRelaxation with user-provided blocks with overlap 1.
   // Convergence of block Gauss-Seidel is compared against that of point Gauss-Seidel,
   // and the test passes if the block residual norm is smaller at each iteration.
@@ -469,6 +468,8 @@ TEUCHOS_UNIT_TEST_TEMPLATE_3_DECL(Ifpack2BlockRelaxation, OverlappingPartition,
   out << "#local blocks = " << numLocalBlocks << std::endl;
 
   //out.setOutputToRootOnly(-1);
+  //Teuchos::RCP<const Teuchos::Comm<int> > comm = Tpetra::DefaultPlatform::getDefaultPlatform().getComm();
+  //const int myRank = comm->getRank ();
   for (int i=0,j=0; i<numLocalBlocks; ++i) {
     ArrayRCP<LocalOrdinal> block(3);
     block[0] = j++;
@@ -573,10 +574,10 @@ TEUCHOS_UNIT_TEST_TEMPLATE_3_DECL(Ifpack2BlockRelaxation, OverlappingPartition,
     TEST_EQUALITY( dbNorms[0] < pNorms[0], true);
     out << dbNorms[0] << " < " << pNorms[0] << std::endl;
 #if defined(HAVE_IFPACK2_AMESOS2)
+    TEST_EQUALITY( sbNorms[0] < pNorms[0], true);
     TEST_EQUALITY( dbNorms[0] - sbNorms[0] < 1e-12, true);
 #endif
   }
-#endif
 
 } //OverlappingPartition test
 
