@@ -97,8 +97,6 @@ TEUCHOS_UNIT_TEST_TEMPLATE_3_DECL(DenseSolver, LapackComparison, ScalarType, Loc
 
   RCP<const Teuchos::Comm<int> > comm =
     Tpetra::DefaultPlatform::getDefaultPlatform ().getComm ();
-  RCP<node_type> node =
-    Tpetra::DefaultPlatform::getDefaultPlatform ().getNode ();
 
   // We are now in a class method declared by the above macro.
   // The method has these input arguments:
@@ -115,7 +113,7 @@ TEUCHOS_UNIT_TEST_TEMPLATE_3_DECL(DenseSolver, LapackComparison, ScalarType, Loc
   const GST globalNumRows = comm->getSize () * localNumRows;
   const global_ordinal_type indexBase = 0;
 
-  RCP<const map_type> rowMap (new map_type (globalNumRows, localNumRows, indexBase, comm, node));
+  RCP<const map_type> rowMap (new map_type (globalNumRows, localNumRows, indexBase, comm));
   RCP<const map_type> colMap = rowMap;
   RCP<const map_type> domMap = rowMap;
   RCP<const map_type> ranMap = rowMap;
