@@ -44,13 +44,12 @@
 #ifndef IFPACK2_UNITTESTHELPERS_HPP
 #define IFPACK2_UNITTESTHELPERS_HPP
 
-#include <Teuchos_Comm.hpp>
-#include <Teuchos_OrdinalTraits.hpp>
-#include <Teuchos_ScalarTraits.hpp>
-#include <Tpetra_ConfigDefs.hpp>
-#include <Tpetra_DefaultPlatform.hpp>
-#include <Tpetra_CrsGraph.hpp>
-#include <Tpetra_CrsMatrix.hpp>
+#include "Tpetra_DefaultPlatform.hpp"
+#include "Tpetra_CrsGraph.hpp"
+#include "Tpetra_CrsMatrix.hpp"
+#include "Teuchos_Comm.hpp"
+#include "Teuchos_OrdinalTraits.hpp"
+#include "Teuchos_ScalarTraits.hpp"
 
 namespace tif_utest {
 using Tpetra::global_size_t;
@@ -64,42 +63,64 @@ Teuchos::RCP<const Teuchos::Comm<int> > getDefaultComm()
 }
 
 template<class LocalOrdinal,class GlobalOrdinal,class Node>
-const Teuchos::RCP<const Tpetra::Map<LocalOrdinal,GlobalOrdinal,Node> > create_tpetra_map(LocalOrdinal num_elements_per_proc)
+Teuchos::RCP<const Tpetra::Map<LocalOrdinal,GlobalOrdinal,Node> >
+create_tpetra_map (const LocalOrdinal num_elements_per_proc)
 {
-  Teuchos::RCP<const Teuchos::Comm<int> > comm = getDefaultComm();
+  using Teuchos::RCP;
+  using Teuchos::rcp;
+  typedef Tpetra::Map<LocalOrdinal,GlobalOrdinal,Node> map_type;
+
+  RCP<const Teuchos::Comm<int> > comm = getDefaultComm();
 
   const global_size_t INVALID = Teuchos::OrdinalTraits<global_size_t>::invalid();
   const LocalOrdinal indexBase = 0;
 
-  Teuchos::RCP<const Tpetra::Map<LocalOrdinal,GlobalOrdinal,Node> > tmap = Teuchos::rcp(new Tpetra::Map<LocalOrdinal,GlobalOrdinal,Node>(INVALID, num_elements_per_proc, indexBase, comm));
+  RCP<const map_type> tmap =
+    rcp (new map_type (INVALID, num_elements_per_proc, indexBase, comm));
 
   return tmap;
 }
 
 template<class LocalOrdinal,class GlobalOrdinal,class Node>
-Teuchos::RCP<const Tpetra::CrsGraph<LocalOrdinal,GlobalOrdinal,Node> > create_tridiag_graph(LocalOrdinal num_rows_per_proc)
+Teuchos::RCP<const Tpetra::CrsGraph<LocalOrdinal,GlobalOrdinal,Node> >
+create_tridiag_graph (const LocalOrdinal num_rows_per_proc)
 {
-  Teuchos::RCP<const Teuchos::Comm<int> > comm = getDefaultComm();
+  using Teuchos::RCP;
+  using Teuchos::rcp;
+  typedef Tpetra::Map<LocalOrdinal,GlobalOrdinal,Node> map_type;
+
+  RCP<const Teuchos::Comm<int> > comm = getDefaultComm();
 
   const global_size_t INVALID = Teuchos::OrdinalTraits<global_size_t>::invalid();
   const LocalOrdinal indexBase = 0;
 
-  Teuchos::RCP<const Tpetra::Map<LocalOrdinal,GlobalOrdinal,Node> > rowmap = Teuchos::rcp(new Tpetra::Map<LocalOrdinal,GlobalOrdinal,Node>(INVALID, num_rows_per_proc, indexBase, comm));
+  RCP<const map_type> rowmap =
+    rcp (new map_type (INVALID, num_rows_per_proc, indexBase, comm));
 
-  Teuchos::RCP<Tpetra::CrsGraph<LocalOrdinal,GlobalOrdinal,Node> > crsgraph = Teuchos::rcp(new Tpetra::CrsGraph<LocalOrdinal,GlobalOrdinal,Node>(rowmap, 0));
+  RCP<Tpetra::CrsGraph<LocalOrdinal,GlobalOrdinal,Node> > crsgraph =
+    rcp (new Tpetra::CrsGraph<LocalOrdinal,GlobalOrdinal,Node> (rowmap, 0));
 
   Teuchos::Array<GlobalOrdinal> cols;
- for(LocalOrdinal l_row = 0; (size_t) l_row<rowmap->getNodeNumElements(); l_row++) {
+  const LocalOrdinal lclNumRows =
+    static_cast<LocalOrdinal> (rowmap->getNodeNumElements ());
+  for (LocalOrdinal l_row = 0; l_row < lclNumRows; ++l_row) {
     GlobalOrdinal g_row = rowmap->getGlobalElement(l_row);
     if (g_row == rowmap->getMinAllGlobalIndex() ||
-        g_row == rowmap->getMaxAllGlobalIndex()) cols.resize(2);
-    else cols.resize(3);
+        g_row == rowmap->getMaxAllGlobalIndex()) {
+      cols.resize(2);
+    }
+    else {
+      cols.resize(3);
+    }
 
     size_t coloffset = 0;
-    if (g_row > rowmap->getMinAllGlobalIndex()) cols[coloffset++] = g_row-1;
+    if (g_row > rowmap->getMinAllGlobalIndex()) {
+      cols[coloffset++] = g_row-1;
+    }
     cols[coloffset++] = g_row;
-    if (g_row < rowmap->getMaxAllGlobalIndex()) cols[coloffset++] = g_row+1;
-
+    if (g_row < rowmap->getMaxAllGlobalIndex()) {
+      cols[coloffset++] = g_row+1;
+    }
     crsgraph->insertGlobalIndices(g_row, cols());
   }
 
@@ -109,7 +130,8 @@ Teuchos::RCP<const Tpetra::CrsGraph<LocalOrdinal,GlobalOrdinal,Node> > create_tr
 }
 
 template<class LocalOrdinal,class GlobalOrdinal,class Node>
-Teuchos::RCP<Tpetra::CrsGraph<LocalOrdinal,GlobalOrdinal,Node> > create_test_graph(LocalOrdinal num_rows_per_proc)
+Teuchos::RCP<Tpetra::CrsGraph<LocalOrdinal,GlobalOrdinal,Node> >
+create_test_graph (const LocalOrdinal num_rows_per_proc)
 {
   Teuchos::RCP<const Teuchos::Comm<int> > comm = getDefaultComm();
 
