@@ -1298,7 +1298,7 @@ public:
     // For CUDA the constant random access View does not return
     // an lvalue reference due to retrieving through texture cache
     // therefore not allowed to query the underlying pointer.
-#if defined(KOKKOS_HAVE_CUDA)
+#if defined(KOKKOS_ENABLE_CUDA)
     if ( ! std::is_same< typename device::execution_space , Kokkos::Cuda >::value )
 #endif
     {
@@ -1408,7 +1408,7 @@ public:
     ASSERT_EQ( ds5.dimension_4() , ds5plus.dimension_4() );
     ASSERT_EQ( ds5.dimension_5() , ds5plus.dimension_5() );
 
-#if ! defined( KOKKOS_HAVE_CUDA ) || defined ( KOKKOS_USE_CUDA_UVM )
+#if ! defined( KOKKOS_ENABLE_CUDA ) || defined ( KOKKOS_ENABLE_CUDA_UVM )
     ASSERT_EQ( & ds5(1,1,1,1,0) - & ds5plus(1,1,1,1,0) , 0 );
     ASSERT_EQ( & ds5(1,1,1,1,0,0) - & ds5plus(1,1,1,1,0,0) , 0 );  // passing argument to rank beyond the view's rank is allowed iff it is a 0. 
 #endif
