@@ -44,7 +44,8 @@
 #ifndef KOKKOS_IMPL_CUDA_TASK_HPP
 #define KOKKOS_IMPL_CUDA_TASK_HPP
 
-#if defined( KOKKOS_ENABLE_TASKPOLICY )
+#include <Kokkos_Macros.hpp>
+#if defined( KOKKOS_ENABLE_TASKDAG )
 
 //----------------------------------------------------------------------------
 //----------------------------------------------------------------------------
@@ -61,6 +62,8 @@ void set_cuda_task_base_apply_function_pointer
 
 }
 
+template< class > class TaskExec ;
+
 template<>
 class TaskQueueSpecialization< Kokkos::Cuda >
 {
@@ -69,6 +72,7 @@ public:
   using execution_space = Kokkos::Cuda ;
   using memory_space    = Kokkos::CudaUVMSpace ;
   using queue_type      = TaskQueue< execution_space > ;
+  using member_type     = TaskExec< Kokkos::Cuda > ;
 
   static
   void iff_single_thread_recursive_execute( queue_type * const ) {}
@@ -79,13 +83,15 @@ public:
   static
   void execute( queue_type * const );
 
-  template< typename FunctorType >
+  template< typename TaskType >
   static
-  void proc_set_apply( TaskBase<execution_space,void,void>::function_type * ptr )
+  typename TaskType::function_type
+  get_function_pointer()
     {
-      using TaskType = TaskBase< execution_space
-                               , typename FunctorType::value_type
-                               , FunctorType > ;
+      using function_type = typename TaskType::function_type ;
+
+      function_type * const ptr =
+        (function_type*) cuda_internal_scratch_unified( sizeof(function_type) );
 
       CUDA_SAFE_CALL( cudaDeviceSynchronize() );
 
@@ -93,13 +99,15 @@ public:
 
       CUDA_SAFE_CALL( cudaGetLastError() );
       CUDA_SAFE_CALL( cudaDeviceSynchronize() );
+
+      return *ptr ;
     }
 };
 
 extern template class TaskQueue< Kokkos::Cuda > ;
 
 //----------------------------------------------------------------------------
-/**\brief  Impl::TaskExec<Cuda> is the TaskPolicy<Cuda>::member_type
+/**\brief  Impl::TaskExec<Cuda> is the TaskScheduler<Cuda>::member_type
  *         passed to tasks running in a Cuda space.
  *
  *  Cuda thread blocks for tasking are dimensioned:
@@ -318,7 +326,7 @@ ValueType shfl_warp_broadcast
   return Kokkos::shfl(val, src_lane, width);
 }
 
-// all-reduce across corresponding vector lanes between team members within warp
+/*// all-reduce across corresponding vector lanes between team members within warp
 // assume vec_length*team_size == warp_size
 // blockDim.x == vec_length == stride
 // blockDim.y == team_size
@@ -344,7 +352,7 @@ void parallel_reduce
                           loop_boundaries.thread.team_size(),
                           blockDim.x);
   initialized_result = shfl_warp_broadcast<ValueType>( initialized_result, threadIdx.x, Impl::CudaTraits::WarpSize );
-}
+}*/
 
 // all-reduce across corresponding vector lanes between team members within warp
 // if no join() provided, use sum
@@ -375,13 +383,36 @@ void parallel_reduce
   initialized_result = shfl_warp_broadcast<ValueType>( initialized_result, threadIdx.x, Impl::CudaTraits::WarpSize );
 }
 
+template< typename iType, class Lambda, typename ReducerType >
+KOKKOS_INLINE_FUNCTION
+void parallel_reduce
+  (const Impl::TeamThreadRangeBoundariesStruct<iType,Impl::TaskExec< Kokkos::Cuda > >& loop_boundaries,
+   const Lambda & lambda,
+   const ReducerType& reducer) {
+
+  typedef typename ReducerType::value_type ValueType;
+  //TODO what is the point of creating this temporary?
+  ValueType result = ValueType();
+  reducer.init(result);
+
+  for( iType i = loop_boundaries.start; i < loop_boundaries.end; i+=loop_boundaries.increment) {
+    lambda(i,result);
+  }
+
+  strided_shfl_warp_reduction(
+                          [&] (ValueType& val1, const ValueType& val2) { reducer.join(val1,val2); },
+                          result,
+                          loop_boundaries.thread.team_size(),
+                          blockDim.x);
+  reducer.reference() = shfl_warp_broadcast<ValueType>( result, threadIdx.x, Impl::CudaTraits::WarpSize );
+}
 // all-reduce within team members within warp
 // assume vec_length*team_size == warp_size
 // blockDim.x == vec_length == stride
 // blockDim.y == team_size
 // threadIdx.x == position in vec
 // threadIdx.y == member number
-template< typename iType, class Lambda, typename ValueType, class JoinType >
+/*template< typename iType, class Lambda, typename ValueType, class JoinType >
 KOKKOS_INLINE_FUNCTION
 void parallel_reduce
   (const Impl::ThreadVectorRangeBoundariesStruct<iType,Impl::TaskExec< Kokkos::Cuda > >& loop_boundaries,
@@ -397,7 +428,7 @@ void parallel_reduce
 
   multi_shfl_warp_reduction<ValueType, JoinType>(join, initialized_result, blockDim.x);
   initialized_result = shfl_warp_broadcast<ValueType>( initialized_result, 0, blockDim.x );
-}
+}*/
 
 // all-reduce within team members within warp
 // if no join() provided, use sum
@@ -429,24 +460,54 @@ void parallel_reduce
   initialized_result = shfl_warp_broadcast<ValueType>( initialized_result, 0, blockDim.x );
 }
 
+template< typename iType, class Lambda, typename ReducerType >
+KOKKOS_INLINE_FUNCTION
+void parallel_reduce
+  (const Impl::ThreadVectorRangeBoundariesStruct<iType,Impl::TaskExec< Kokkos::Cuda > >& loop_boundaries,
+   const Lambda & lambda,
+   const ReducerType& reducer) {
+
+  typedef typename ReducerType::value_type ValueType;
+
+  ValueType result = ValueType();
+  reducer.init(result);
+
+  for( iType i = loop_boundaries.start; i < loop_boundaries.end; i+=loop_boundaries.increment) {
+    lambda(i,result);
+  }
+
+  multi_shfl_warp_reduction(
+                          [&] (ValueType& val1, const ValueType& val2) { reducer.join(val1, val2); },
+                          result,
+                          blockDim.x);
+  reducer.reference() = shfl_warp_broadcast<ValueType>( result, 0, blockDim.x );
+}
 // scan across corresponding vector lanes between team members within warp
 // assume vec_length*team_size == warp_size
 // blockDim.x == vec_length == stride
 // blockDim.y == team_size
 // threadIdx.x == position in vec
 // threadIdx.y == member number
-template< typename ValueType, typename iType, class Lambda >
+template< typename iType, class Closure >
 KOKKOS_INLINE_FUNCTION
 void parallel_scan
   (const Impl::TeamThreadRangeBoundariesStruct<iType,Impl::TaskExec< Kokkos::Cuda > >& loop_boundaries,
-   const Lambda & lambda) {
+   const Closure & closure )
+{
+  // Extract value_type from closure
 
-  ValueType accum = 0 ;
-  ValueType val, y, local_total;
+  using value_type =
+    typename Kokkos::Impl::FunctorAnalysis
+      < Kokkos::Impl::FunctorPatternInterface::SCAN
+      , void
+      , Closure >::value_type ;
+
+  value_type accum = 0 ;
+  value_type val, y, local_total;
 
   for( iType i = loop_boundaries.start; i < loop_boundaries.end; i+=loop_boundaries.increment) {
     val = 0;
-    lambda(i,val,false);
+    closure(i,val,false);
 
     // intra-blockDim.y exclusive scan on 'val'
     // accum = accumulated, sum in total for this iteration
@@ -458,7 +519,7 @@ void parallel_scan
     }
 
     // pass accum to all threads
-    local_total = shfl_warp_broadcast<ValueType>(val,
+    local_total = shfl_warp_broadcast<value_type>(val,
                                             threadIdx.x+Impl::CudaTraits::WarpSize-blockDim.x,
                                             Impl::CudaTraits::WarpSize);
 
@@ -467,7 +528,7 @@ void parallel_scan
     if ( threadIdx.y == 0 ) { val = 0 ; }
 
     val += accum;
-    lambda(i,val,true);
+    closure(i,val,true);
     accum += local_total;
   }
 }
@@ -478,18 +539,26 @@ void parallel_scan
 // blockDim.y == team_size
 // threadIdx.x == position in vec
 // threadIdx.y == member number
-template< typename iType, class Lambda, typename ValueType >
+template< typename iType, class Closure >
 KOKKOS_INLINE_FUNCTION
 void parallel_scan
   (const Impl::ThreadVectorRangeBoundariesStruct<iType,Impl::TaskExec< Kokkos::Cuda > >& loop_boundaries,
-   const Lambda & lambda)
+   const Closure & closure )
 {
-  ValueType accum = 0 ;
-  ValueType val, y, local_total;
+  // Extract value_type from closure
+
+  using value_type =
+    typename Kokkos::Impl::FunctorAnalysis
+      < Kokkos::Impl::FunctorPatternInterface::SCAN
+      , void
+      , Closure >::value_type ;
+
+  value_type accum = 0 ;
+  value_type val, y, local_total;
 
   for( iType i = loop_boundaries.start; i < loop_boundaries.end; i+=loop_boundaries.increment) {
     val = 0;
-    lambda(i,val,false);
+    closure(i,val,false);
 
     // intra-blockDim.x exclusive scan on 'val'
     // accum = accumulated, sum in total for this iteration
@@ -501,14 +570,14 @@ void parallel_scan
     }
 
     // pass accum to all threads
-    local_total = shfl_warp_broadcast<ValueType>(val, blockDim.x-1, blockDim.x);
+    local_total = shfl_warp_broadcast<value_type>(val, blockDim.x-1, blockDim.x);
 
     // make EXCLUSIVE scan by shifting values over one
     val = Kokkos::shfl_up(val, 1, blockDim.x);
     if ( threadIdx.x == 0 ) { val = 0 ; }
 
     val += accum;
-    lambda(i,val,true);
+    closure(i,val,true);
     accum += local_total;
   }
 }
@@ -518,6 +587,6 @@ void parallel_scan
 //----------------------------------------------------------------------------
 //----------------------------------------------------------------------------
 
-#endif /* #if defined( KOKKOS_ENABLE_TASKPOLICY ) */
+#endif /* #if defined( KOKKOS_ENABLE_TASKDAG ) */
 #endif /* #ifndef KOKKOS_IMPL_CUDA_TASK_HPP */
 
