@@ -1,13 +1,13 @@
 /*
 //@HEADER
 // ************************************************************************
-// 
+//
 //                        Kokkos v. 2.0
 //              Copyright (2014) Sandia Corporation
-// 
+//
 // Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
 // the U.S. Government retains certain rights in this software.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are
 // met:
@@ -36,7 +36,7 @@
 // SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 // Questions? Contact  H. Carter Edwards (hcedwar@sandia.gov)
-// 
+//
 // ************************************************************************
 //@HEADER
 */
@@ -44,9 +44,10 @@
 #ifndef KOKKOS_CUDASPACE_HPP
 #define KOKKOS_CUDASPACE_HPP
 
-#include <Kokkos_Core_fwd.hpp>
+#include <Kokkos_Macros.hpp>
+#if defined( KOKKOS_ENABLE_CUDA )
 
-#if defined( KOKKOS_HAVE_CUDA )
+#include <Kokkos_Core_fwd.hpp>
 
 #include <iosfwd>
 #include <typeinfo>
@@ -88,6 +89,9 @@ public:
   void deallocate( void * const arg_alloc_ptr
                  , const size_t arg_alloc_size ) const ;
 
+  /**\brief Return Name of the MemorySpace */
+  static constexpr const char* name();
+
   /*--------------------------------*/
   /** \brief  Error reporting for HostSpace attempt to access CudaSpace */
   static void access_error();
@@ -97,7 +101,8 @@ private:
 
   int  m_device ; ///< Which Cuda device
 
-  // friend class Kokkos::Impl::SharedAllocationRecord< Kokkos::CudaSpace , void > ;
+  static constexpr const char* m_name = "Cuda";
+  friend class Kokkos::Impl::SharedAllocationRecord< Kokkos::CudaSpace , void > ;
 };
 
 namespace Impl {
@@ -156,6 +161,14 @@ public:
   /** \brief  If UVM capability is available */
   static bool available();
 
+
+  /*--------------------------------*/
+  /** \brief  CudaUVMSpace specific routine */
+  static int number_of_allocations();
+
+  /*--------------------------------*/
+
+
   /*--------------------------------*/
 
   CudaUVMSpace();
@@ -172,10 +185,16 @@ public:
   void deallocate( void * const arg_alloc_ptr
                  , const size_t arg_alloc_size ) const ;
 
+  /**\brief Return Name of the MemorySpace */
+  static constexpr const char* name();
+
   /*--------------------------------*/
 
 private:
   int  m_device ; ///< Which Cuda device
+
+  static constexpr const char* m_name = "CudaUVM";
+
 };
 
 } // namespace Kokkos
@@ -214,6 +233,13 @@ public:
   void deallocate( void * const arg_alloc_ptr
                  , const size_t arg_alloc_size ) const ;
 
+  /**\brief Return Name of the MemorySpace */
+  static constexpr const char* name();
+
+private:
+
+  static constexpr const char* m_name = "CudaHostPinned";
+
   /*--------------------------------*/
 };
 
@@ -229,6 +255,8 @@ static_assert( Kokkos::Impl::MemorySpaceAccess< Kokkos::CudaSpace , Kokkos::Cuda
 static_assert( Kokkos::Impl::MemorySpaceAccess< Kokkos::CudaUVMSpace , Kokkos::CudaUVMSpace >::assignable , "" );
 static_assert( Kokkos::Impl::MemorySpaceAccess< Kokkos::CudaHostPinnedSpace , Kokkos::CudaHostPinnedSpace >::assignable , "" );
 
+//----------------------------------------
+
 template<>
 struct MemorySpaceAccess< Kokkos::HostSpace , Kokkos::CudaSpace > {
   enum { assignable = false };
@@ -252,6 +280,7 @@ struct MemorySpaceAccess< Kokkos::HostSpace , Kokkos::CudaHostPinnedSpace > {
   enum { deepcopy   = true };
 };
 
+//----------------------------------------
 
 template<>
 struct MemorySpaceAccess< Kokkos::CudaSpace , Kokkos::HostSpace > {
@@ -262,6 +291,7 @@ struct MemorySpaceAccess< Kokkos::CudaSpace , Kokkos::HostSpace > {
 
 template<>
 struct MemorySpaceAccess< Kokkos::CudaSpace , Kokkos::CudaUVMSpace > {
+  // CudaSpace::execution_space == CudaUVMSpace::execution_space
   enum { assignable = true };
   enum { accessible = true };
   enum { deepcopy   = true };
@@ -275,13 +305,14 @@ struct MemorySpaceAccess< Kokkos::CudaSpace , Kokkos::CudaHostPinnedSpace > {
   enum { deepcopy   = true };
 };
 
+//----------------------------------------
+// CudaUVMSpace::execution_space == Cuda
+// CudaUVMSpace accessible to both Cuda and Host
 
 template<>
 struct MemorySpaceAccess< Kokkos::CudaUVMSpace , Kokkos::HostSpace > {
-  // CudaUVMSpace::execution_space == Cuda
-  // Cuda cannot access HostSpace
   enum { assignable = false };
-  enum { accessible = false };
+  enum { accessible = false }; // Cuda cannot access HostSpace
   enum { deepcopy   = true };
 };
 
@@ -305,12 +336,14 @@ struct MemorySpaceAccess< Kokkos::CudaUVMSpace , Kokkos::CudaHostPinnedSpace > {
 };
 
 
+//----------------------------------------
+// CudaHostPinnedSpace::execution_space == HostSpace::execution_space
+// CudaHostPinnedSpace accessible to both Cuda and Host
+
 template<>
 struct MemorySpaceAccess< Kokkos::CudaHostPinnedSpace , Kokkos::HostSpace > {
-  // Can access CudaHostPinnedSpace from Cuda
-  // Cannot access HostSpace from Cuda
   enum { assignable = false }; // Cannot access from Cuda
-  enum { accessible = false }; // CudaHostPinnedSpace::execution_space
+  enum { accessible = true };  // CudaHostPinnedSpace::execution_space
   enum { deepcopy   = true };
 };
 
@@ -328,6 +361,8 @@ struct MemorySpaceAccess< Kokkos::CudaHostPinnedSpace , Kokkos::CudaUVMSpace > {
   enum { deepcopy   = true };
 };
 
+//----------------------------------------
+
 }} // namespace Kokkos::Impl
 
 /*--------------------------------------------------------------------------*/
@@ -683,7 +718,7 @@ private:
   static ::cudaTextureObject_t
   attach_texture_object( const unsigned sizeof_alias
                        , void * const   alloc_ptr
-                       , const size_t   alloc_size ); 
+                       , const size_t   alloc_size );
 
   static RecordBase s_root_record ;
 
@@ -905,6 +940,6 @@ public:
 //----------------------------------------------------------------------------
 //----------------------------------------------------------------------------
 
-#endif /* #if defined( KOKKOS_HAVE_CUDA ) */
+#endif /* #if defined( KOKKOS_ENABLE_CUDA ) */
 #endif /* #define KOKKOS_CUDASPACE_HPP */
 
