@@ -507,7 +507,9 @@ struct ThreadVectorRangeBoundariesStruct {
   enum {increment = 1};
 
   KOKKOS_INLINE_FUNCTION
-  ThreadVectorRangeBoundariesStruct ( const TeamMemberType& thread, const iType& count ) : end( count ) {}
+  ThreadVectorRangeBoundariesStruct ( const TeamMemberType, const iType& count ) : end( count ) {}
+  KOKKOS_INLINE_FUNCTION
+  ThreadVectorRangeBoundariesStruct ( const iType& count ) : end( count ) {}
 };
 
 template<class TeamMemberType>
@@ -563,5 +565,3 @@ ThreadVectorRange( const TeamMemberType&, const iType& count );
 
 #endif /* #define KOKKOS_EXECPOLICY_HPP */
 
-//----------------------------------------------------------------------------
-//----------------------------------------------------------------------------
