@@ -1,13 +1,13 @@
 /*
 //@HEADER
 // ************************************************************************
-// 
+//
 //                        Kokkos v. 2.0
 //              Copyright (2014) Sandia Corporation
-// 
+//
 // Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
 // the U.S. Government retains certain rights in this software.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are
 // met:
@@ -36,12 +36,13 @@
 // SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 // Questions? Contact  H. Carter Edwards (hcedwar@sandia.gov)
-// 
+//
 // ************************************************************************
 //@HEADER
 */
 
-#if defined( KOKKOS_ENABLE_TASKPOLICY )
+#include <Kokkos_Macros.hpp>
+#if defined( KOKKOS_ENABLE_TASKDAG )
 
 namespace Kokkos {
 namespace Impl {
@@ -58,13 +59,8 @@ void TaskQueue< ExecSpace >::Destroy::destroy_shared_allocation()
 
 template< typename ExecSpace >
 TaskQueue< ExecSpace >::TaskQueue
-  ( const TaskQueue< ExecSpace >::memory_space & arg_space
-  , unsigned const arg_memory_pool_capacity
-  , unsigned const arg_memory_pool_superblock_capacity_log2
-  )
-  : m_memory( arg_space
-            , arg_memory_pool_capacity
-            , arg_memory_pool_superblock_capacity_log2 )
+  ( typename TaskQueue< ExecSpace >::memory_pool const & arg_memory_pool )
+  : m_memory( arg_memory_pool )
   , m_ready()
   , m_accum_alloc(0)
   , m_count_alloc(0)
@@ -117,14 +113,14 @@ void TaskQueue< ExecSpace >::decrement
   }
 #endif
 
-  if ( ( 1 == count ) && 
+  if ( ( 1 == count ) &&
        ( task->m_next == (task_root_type *) task_root_type::LockTag ) ) {
     // Reference count is zero and task is complete, deallocate.
     task->m_queue->deallocate( task , task->m_alloc_size );
-  }   
-  else if ( count <= 1 ) { 
+  }
+  else if ( count <= 1 ) {
     Kokkos::abort("TaskScheduler task has negative reference count or is incomplete" );
-  }   
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -170,6 +166,7 @@ bool TaskQueue< ExecSpace >::push_task
   )
 {
   // Push task into a concurrently pushed and popped queue.
+  // The queue can be either a ready task queue or a waiting task queue.
   // The queue is a linked list where 'task->m_next' form the links.
   // Fail the push attempt if the queue is locked;
   // otherwise retry until the push succeeds.
@@ -227,13 +224,12 @@ bool TaskQueue< ExecSpace >::push_task
 template< typename ExecSpace >
 KOKKOS_FUNCTION
 typename TaskQueue< ExecSpace >::task_root_type *
-TaskQueue< ExecSpace >::pop_task
+TaskQueue< ExecSpace >::pop_ready_task
   ( TaskQueue< ExecSpace >::task_root_type * volatile * const queue )
 {
-  // Pop task from a concurrently pushed and popped queue.
+  // Pop task from a concurrently pushed and popped ready task queue.
   // The queue is a linked list where 'task->m_next' form the links.
 
-  task_root_type * const zero = (task_root_type *) 0 ;
   task_root_type * const lock = (task_root_type *) task_root_type::LockTag ;
   task_root_type * const end  = (task_root_type *) task_root_type::EndTag ;
 
@@ -252,85 +248,201 @@ TaskQueue< ExecSpace >::pop_task
     // (1) lock, (2) end, or (3) a valid task.
     // Thus zero will never appear in the queue.
     //
-    // If queue is locked then just read by guaranteeing
-    // the CAS will fail.
+    // If queue is locked then just read by guaranteeing the CAS will fail.
 
     if ( lock == task ) task = 0 ;
 
     task_root_type * const x = task ;
 
-    task = Kokkos::atomic_compare_exchange(queue,task,lock);
+    task = Kokkos::atomic_compare_exchange(queue,x,lock);
 
-    if ( x == task ) break ; // CAS succeeded and queue is locked
-  }
+    if ( x == task ) {
+      // CAS succeeded and queue is locked
+      //
+      // This thread has locked the queue and removed 'task' from the queue.
+      // Extract the next entry of the queue from 'task->m_next'
+      // and mark 'task' as popped from a queue by setting
+      // 'task->m_next = lock'.
+      //
+      // Place the next entry in the head of the queue,
+      // which also unlocks the queue.
+      //
+      // This thread has exclusive access to
+      // the queue and the popped task's m_next.
 
-  if ( end != task ) {
+      *queue = task->m_next ; task->m_next = lock ;
 
-    // This thread has locked the queue and removed 'task' from the queue.
-    // Extract the next entry of the queue from 'task->m_next'
-    // and mark 'task' as popped from a queue by setting
-    // 'task->m_next = lock'.
+      Kokkos::memory_fence();
 
-    task_root_type * const next =
-      Kokkos::atomic_exchange( & task->m_next , lock );
+#if 0
+      printf( "pop_ready_task( 0x%lx 0x%lx { 0x%lx 0x%lx %d %d %d } )\n"
+            , uintptr_t(queue)
+            , uintptr_t(task)
+            , uintptr_t(task->m_wait)
+            , uintptr_t(task->m_next)
+            , int(task->m_task_type)
+            , int(task->m_priority)
+            , int(task->m_ref_count) );
+#endif
 
-    // Place the next entry in the head of the queue,
-    // which also unlocks the queue.
-
-    task_root_type * const unlock =
-      Kokkos::atomic_exchange( queue , next );
-
-    if ( next == zero || next == lock || lock != unlock ) {
-      Kokkos::abort("TaskQueue::pop_task ERROR");
+      return task ;
     }
   }
 
-#if 0
-  if ( end != task ) {
-    printf( "pop_task( 0x%lx 0x%lx { 0x%lx 0x%lx %d %d %d } )\n"
-          , uintptr_t(queue)
-          , uintptr_t(task)
-          , uintptr_t(task->m_wait)
-          , uintptr_t(task->m_next)
-          , int(task->m_task_type)
-          , int(task->m_priority)
-          , int(task->m_ref_count) );
-  }
-#endif
-
-  return task ;
+  return end ;
 }
 
 //----------------------------------------------------------------------------
 
 template< typename ExecSpace >
 KOKKOS_FUNCTION
-void TaskQueue< ExecSpace >::schedule
+void TaskQueue< ExecSpace >::schedule_runnable
   ( TaskQueue< ExecSpace >::task_root_type * const task )
 {
-  // Schedule a runnable or when_all task upon construction / spawn
+  // Schedule a runnable task upon construction / spawn
   // and upon completion of other tasks that 'task' is waiting on.
-
-  // Precondition on runnable task state:
-  //   task is either constructing or executing
+  //
+  // Precondition:
+  // - called by a single thread for the input task
+  // - calling thread has exclusive access to the task
+  // - task is not a member of a queue
+  // - if runnable then task is either constructing or respawning
   //
   //   Constructing state:
   //     task->m_wait == 0
-  //     task->m_next == dependence
-  //   Executing-respawn state:
-  //     task->m_wait == head of linked list
-  //     task->m_next == dependence
+  //     task->m_next == dependence or 0
+  //   Respawn state:
+  //     task->m_wait == head of linked list: 'end' or valid task
+  //     task->m_next == dependence or 0
   //
   //  Task state transition:
-  //     Constructing      ->  Waiting
-  //     Executing-respawn ->  Waiting
+  //     Constructing ->  Waiting
+  //     Respawn      ->  Waiting
   //
   //  Postcondition on task state:
-  //     task->m_wait == head of linked list
-  //     task->m_next == member of linked list
+  //     task->m_wait == head of linked list (queue)
+  //     task->m_next == member of linked list (queue)
 
 #if 0
-  printf( "schedule( 0x%lx { 0x%lx 0x%lx %d %d %d }\n"
+  printf( "schedule_runnable( 0x%lx { 0x%lx 0x%lx %d %d %d }\n"
+        , uintptr_t(task)
+        , uintptr_t(task->m_wait)
+        , uintptr_t(task->m_next)
+        , task->m_task_type
+        , task->m_priority
+        , task->m_ref_count );
+#endif
+
+  task_root_type * const zero = (task_root_type *) 0 ;
+  task_root_type * const lock = (task_root_type *) task_root_type::LockTag ;
+  task_root_type * const end  = (task_root_type *) task_root_type::EndTag ;
+
+  bool respawn = false ;
+
+  //----------------------------------------
+
+  if ( zero == task->m_wait ) {
+    // Task in Constructing state
+    // - Transition to Waiting state
+    // Preconditions:
+    // - call occurs exclusively within a single thread
+
+    task->m_wait = end ;
+    // Task in Waiting state
+  }
+  else if ( lock != task->m_wait ) {
+    // Task in Executing state with Respawn request
+    // - Update dependence
+    // - Transition to Waiting state
+    respawn = true ;
+  }
+  else {
+    // Task in Complete state
+    Kokkos::abort("TaskQueue::schedule_runnable ERROR: task is complete");
+  }
+
+  //----------------------------------------
+  // Scheduling a runnable task which may have a depencency 'dep'.
+  // Extract dependence, if any, from task->m_next.
+  // If 'dep' is not null then attempt to push 'task'
+  // into the wait queue of 'dep'.
+  // If the push succeeds then 'task' may be
+  // processed or executed by another thread at any time.
+  // If the push fails then 'dep' is complete and 'task'
+  // is ready to execute.
+
+  // Exclusive access so don't need an atomic exchange
+  // task_root_type * dep = Kokkos::atomic_exchange( & task->m_next , zero );
+  task_root_type * dep = task->m_next ; task->m_next = zero ;
+
+  const bool is_ready =
+    ( 0 == dep ) || ( ! push_task( & dep->m_wait , task ) );
+
+  if ( ( 0 != dep ) && respawn ) {
+    // Reference count for dep was incremented when
+    // respawn assigned dependency to task->m_next
+    // so that if dep completed prior to the
+    // above push_task dep would not be destroyed.
+    // dep reference count can now be decremented,
+    // which may deallocate the task.
+    TaskQueue::assign( & dep , (task_root_type *)0 );
+  }
+
+  if ( is_ready ) {
+
+    // No dependence or 'dep' is complete so push task into ready queue.
+    // Increment the ready count before pushing into ready queue
+    // to track number of ready + executing tasks.
+    // The ready count will be decremented when the task is complete.
+
+    Kokkos::atomic_increment( & m_ready_count );
+
+    task_root_type * volatile * const ready_queue =
+      & m_ready[ task->m_priority ][ task->m_task_type ];
+
+    // A push_task fails if the ready queue is locked.
+    // A ready queue is only locked during a push or pop;
+    // i.e., it is never permanently locked.
+    // Retry push to ready queue until it succeeds.
+    // When the push succeeds then 'task' may be
+    // processed or executed by another thread at any time.
+
+    while ( ! push_task( ready_queue , task ) );
+  }
+
+  //----------------------------------------
+  // Postcondition:
+  // - A runnable 'task' was pushed into a wait or ready queue.
+  // - Concurrent execution may have already popped 'task'
+  //   from a queue and processed it as appropriate.
+}
+
+template< typename ExecSpace >
+KOKKOS_FUNCTION
+void TaskQueue< ExecSpace >::schedule_aggregate
+  ( TaskQueue< ExecSpace >::task_root_type * const task )
+{
+  // Schedule an aggregate task upon construction
+  // and upon completion of other tasks that 'task' is waiting on.
+  //
+  // Precondition:
+  // - called by a single thread for the input task
+  // - calling thread has exclusive access to the task
+  // - task is not a member of a queue
+  //
+  //   Constructing state:
+  //     task->m_wait == 0
+  //     task->m_next == dependence or 0
+  //
+  //  Task state transition:
+  //     Constructing ->  Waiting
+  //
+  //  Postcondition on task state:
+  //     task->m_wait == head of linked list (queue)
+  //     task->m_next == member of linked list (queue)
+
+#if 0
+  printf( "schedule_aggregate( 0x%lx { 0x%lx 0x%lx %d %d %d }\n"
         , uintptr_t(task)
         , uintptr_t(task->m_wait)
         , uintptr_t(task->m_next)
@@ -344,134 +456,107 @@ void TaskQueue< ExecSpace >::schedule
   task_root_type * const end  = (task_root_type *) task_root_type::EndTag ;
 
   //----------------------------------------
-  {
-    // If Constructing then task->m_wait == 0
-    // Change to waiting by task->m_wait = EndTag
 
-    task_root_type * const init =
-      Kokkos::atomic_compare_exchange( & task->m_wait , zero , end );
+  if ( zero == task->m_wait ) {
+    // Task in Constructing state
+    // - Transition to Waiting state
+    // Preconditions:
+    // - call occurs exclusively within a single thread
 
-    // Precondition
-
-    if ( lock == init ) {
-      Kokkos::abort("TaskQueue::schedule ERROR: task is complete");
-    }
-
-    // if ( init == 0 ) Constructing       ->  Waiting
-    // else             Executing-Respawn  ->  Waiting
+    task->m_wait = end ;
+    // Task in Waiting state
   }
+  else if ( lock == task->m_wait ) {
+    // Task in Complete state
+    Kokkos::abort("TaskQueue::schedule_aggregate ERROR: task is complete");
+  }
+
   //----------------------------------------
+  // Scheduling a 'when_all' task with multiple dependences.
+  // This scheduling may be called when the 'when_all' is
+  // (1) created or
+  // (2) being removed from a completed task's wait list.
 
-  if ( task_root_type::Aggregate != task->m_task_type ) {
+  task_root_type ** const aggr = task->aggregate_dependences();
 
-    // Scheduling a runnable task which may have a depencency 'dep'.
-    // Extract dependence, if any, from task->m_next.
-    // If 'dep' is not null then attempt to push 'task'
-    // into the wait queue of 'dep'.
-    // If the push succeeds then 'task' may be
-    // processed or executed by another thread at any time.
-    // If the push fails then 'dep' is complete and 'task'
-    // is ready to execute.
+  // Assume the 'when_all' is complete until a dependence is
+  // found that is not complete.
 
-    task_root_type * dep = Kokkos::atomic_exchange( & task->m_next , zero );
+  bool is_complete = true ;
 
-    const bool is_ready = 
-      ( 0 == dep ) || ( ! push_task( & dep->m_wait , task ) );
+  for ( int i = task->m_dep_count ; 0 < i && is_complete ; ) {
 
-    // Reference count for dep was incremented when assigned
-    // to task->m_next so that if it completed prior to the
-    // above push_task dep would not be destroyed.
-    // dep reference count can now be decremented,
-    // which may deallocate the task.
-    TaskQueue::assign( & dep , (task_root_type *)0 );
+    --i ;
 
-    if ( is_ready ) {
+    // Loop dependences looking for an incomplete task.
+    // Add this task to the incomplete task's wait queue.
 
-      // No dependence or 'dep' is complete so push task into ready queue.
-      // Increment the ready count before pushing into ready queue
-      // to track number of ready + executing tasks.
-      // The ready count will be decremented when the task is complete.
+    // Remove a task 'x' from the dependence list.
+    // The reference count of 'x' was incremented when
+    // it was assigned into the dependence list.
 
-      Kokkos::atomic_increment( & m_ready_count );
+    // Exclusive access so don't need an atomic exchange
+    // task_root_type * x = Kokkos::atomic_exchange( aggr + i , zero );
+    task_root_type * x = aggr[i] ; aggr[i] = zero ;
 
-      task_root_type * volatile * const queue =
-        & m_ready[ task->m_priority ][ task->m_task_type ];
+    if ( x ) {
 
-      // A push_task fails if the ready queue is locked.
-      // A ready queue is only locked during a push or pop;
-      // i.e., it is never permanently locked.
-      // Retry push to ready queue until it succeeds.
-      // When the push succeeds then 'task' may be
-      // processed or executed by another thread at any time.
+      // If x->m_wait is not locked then push succeeds
+      // and the aggregate is not complete.
+      // If the push succeeds then this when_all 'task' may be
+      // processed by another thread at any time.
+      // For example, 'x' may be completeed by another
+      // thread and then re-schedule this when_all 'task'.
 
-      while ( ! push_task( queue , task ) );
+      is_complete = ! push_task( & x->m_wait , task );
+
+      // Decrement reference count which had been incremented
+      // when 'x' was added to the dependence list.
+
+      TaskQueue::assign( & x , zero );
     }
   }
-  //----------------------------------------
-  else {
-    // Scheduling a 'when_all' task with multiple dependences.
-    // This scheduling may be called when the 'when_all' is
-    // (1) created or
-    // (2) being removed from a completed task's wait list.
 
-    task_root_type ** const aggr = task->aggregate_dependences();
+  if ( is_complete ) {
+    // The when_all 'task' was not added to a wait queue because
+    // all dependences were complete so this aggregate is complete.
+    // Complete the when_all 'task' to schedule other tasks
+    // that are waiting for the when_all 'task' to complete.
 
-    // Assume the 'when_all' is complete until a dependence is
-    // found that is not complete.
+    task->m_next = lock ;
 
-    bool is_complete = true ;
+    complete( task );
 
-    for ( int i = task->m_dep_count ; 0 < i && is_complete ; ) {
-
-      --i ;
-
-      // Loop dependences looking for an incomplete task.
-      // Add this task to the incomplete task's wait queue.
-
-      // Remove a task 'x' from the dependence list.
-      // The reference count of 'x' was incremented when
-      // it was assigned into the dependence list.
-
-      task_root_type * x = Kokkos::atomic_exchange( aggr + i , zero );
-
-      if ( x ) {
-
-        // If x->m_wait is not locked then push succeeds
-        // and the aggregate is not complete.
-        // If the push succeeds then this when_all 'task' may be
-        // processed by another thread at any time.
-        // For example, 'x' may be completeed by another
-        // thread and then re-schedule this when_all 'task'.
-
-        is_complete = ! push_task( & x->m_wait , task );
-
-        // Decrement reference count which had been incremented
-        // when 'x' was added to the dependence list.
-
-        TaskQueue::assign( & x , zero );
-      }
-    }
-
-    if ( is_complete ) {
-      // The when_all 'task' was not added to a wait queue because
-      // all dependences were complete so this aggregate is complete.
-      // Complete the when_all 'task' to schedule other tasks
-      // that are waiting for the when_all 'task' to complete.
-
-      task->m_next = lock ;
-
-      complete( task );
-
-      // '*task' may have been deleted upon completion
-    }
+    // '*task' may have been deleted upon completion
   }
+
   //----------------------------------------
   // Postcondition:
-  //   A runnable 'task' was pushed into a wait or ready queue.
-  //   An aggregate 'task' was either pushed to a wait queue
-  //   or completed.
-  // Concurrent execution may have already popped 'task'
-  // from a queue and processed it as appropriate.
+  // - An aggregate 'task' was either pushed to a wait queue or completed.
+  // - Concurrent execution may have already popped 'task'
+  //   from a queue and processed it as appropriate.
+}
+
+//----------------------------------------------------------------------------
+
+template< typename ExecSpace >
+KOKKOS_FUNCTION
+void TaskQueue< ExecSpace >::reschedule( task_root_type * task )
+{
+  // Precondition:
+  //   task is in Executing state
+  //   task->m_next == LockTag
+  //
+  // Postcondition:
+  //   task is in Executing-Respawn state
+  //   task->m_next == 0 (no dependence)
+
+  task_root_type * const zero = (task_root_type *) 0 ;
+  task_root_type * const lock = (task_root_type *) task_root_type::LockTag ;
+
+  if ( lock != Kokkos::atomic_exchange( & task->m_next, zero ) ) {
+    Kokkos::abort("TaskScheduler::respawn ERROR: already respawned");
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -507,7 +592,7 @@ void TaskQueue< ExecSpace >::complete
     // Is a runnable task has finished executing and requested respawn.
     // Schedule the task for subsequent execution.
 
-    schedule( task );
+    schedule_runnable( task );
   }
   //----------------------------------------
   else {
@@ -534,18 +619,22 @@ void TaskQueue< ExecSpace >::complete
       TaskQueue::assign( & task , zero );
 
       // This thread has exclusive access to the wait list so
-      // the concurrency-safe pop_task function is not needed.
+      // the concurrency-safe pop_ready_task function is not needed.
       // Schedule the tasks that have been waiting on the input 'task',
       // which may have been deleted.
 
       while ( x != end ) {
+        // Have exclusive access to 'x' until it is scheduled
+        // Set x->m_next = zero  <=  no dependence, not a respawn
 
-        // Set x->m_next = zero  <=  no dependence
+        task_root_type * const next = x->m_next ; x->m_next = 0 ;
 
-        task_root_type * const next =
-          (task_root_type *) Kokkos::atomic_exchange( & x->m_next , zero );
-
-        schedule( x );
+        if ( task_root_type::Aggregate != x->m_task_type ) {
+          schedule_runnable( x );
+        }
+        else {
+          schedule_aggregate( x );
+        }
 
         x = next ;
       }
@@ -565,6 +654,5 @@ void TaskQueue< ExecSpace >::complete
 } /* namespace Impl */
 } /* namespace Kokkos */
 
-
-#endif /* #if defined( KOKKOS_ENABLE_TASKPOLICY ) */
+#endif /* #if defined( KOKKOS_ENABLE_TASKDAG ) */
 
