@@ -63,7 +63,7 @@ struct VectorImport ;
 } // namespace Example
 } // namespace Kokkos
 
-#if ! defined( KOKKOS_HAVE_MPI )
+#if ! defined( KOKKOS_ENABLE_MPI )
 
 //----------------------------------------------------------------------------
 //----------------------------------------------------------------------------
@@ -100,7 +100,7 @@ struct VectorImport {
 //----------------------------------------------------------------------------
 //----------------------------------------------------------------------------
 
-#else /* defined( KOKKOS_HAVE_MPI ) */
+#else /* defined( KOKKOS_ENABLE_MPI ) */
 
 namespace Kokkos {
 namespace Example {
