@@ -1,13 +1,13 @@
 /*
 //@HEADER
 // ************************************************************************
-// 
+//
 //                        Kokkos v. 2.0
 //              Copyright (2014) Sandia Corporation
-// 
+//
 // Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
 // the U.S. Government retains certain rights in this software.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are
 // met:
@@ -36,7 +36,7 @@
 // SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 // Questions? Contact  H. Carter Edwards (hcedwar@sandia.gov)
-// 
+//
 // ************************************************************************
 //@HEADER
 */
@@ -44,7 +44,7 @@
 #ifndef KOKKOS_EXPLICITFUNCTORS_HPP
 #define KOKKOS_EXPLICITFUNCTORS_HPP
 
-#include <math.h>
+#include <cmath>
 #include <Kokkos_Core.hpp>
 #include <FEMesh.hpp>
 
@@ -461,8 +461,8 @@ struct grad
 
   const typename Fields::elem_node_ids_type     elem_node_connectivity ;
   const typename Fields::node_coords_type       model_coords ;
-  const typename Fields::geom_state_array_type  displacement ; 
-  const typename Fields::geom_state_array_type  velocity ; 
+  const typename Fields::geom_state_array_type  displacement ;
+  const typename Fields::geom_state_array_type  velocity ;
   const typename Fields::elem_tensor_type       vel_grad ;
   const typename Fields::scalar_type            dt ;
 
@@ -1171,14 +1171,14 @@ struct internal_force
                             dot8<Scalar,execution_space>( grad_y , grad_y ) +
                             dot8<Scalar,execution_space>( grad_z , grad_z ) );
 
-    const Scalar dtrial = sqrt(elem_mass(ielem) * aspect / dil);
+    const Scalar dtrial = std::sqrt(elem_mass(ielem) * aspect / dil);
     const Scalar traced = (rot_stretch(ielem, 0) + rot_stretch(ielem, 1) + rot_stretch(ielem, 2));
 
     const Scalar eps = traced < 0 ? (lin_bulk_visc - quad_bulk_visc * traced * dtrial) : lin_bulk_visc ;
 
     const Scalar bulkq = eps * dil * dtrial * traced;
 
-    Scalar cur_time_step = dtrial * ( sqrt( 1.0 + eps * eps) - eps);
+    Scalar cur_time_step = dtrial * ( std::sqrt( 1.0 + eps * eps) - eps);
 
     // force fixed time step if input
 
