@@ -106,7 +106,7 @@ namespace Belos {
     //@{
 
     //! Default constructor
-    XpetraOp (const RCP<Xpetra::Matrix<Scalar, LocalOrdinal, GlobalOrdinal, Node> > & Op) : Op_(Op) {}
+    XpetraOp (const RCP<Xpetra::Operator<Scalar, LocalOrdinal, GlobalOrdinal, Node> > & Op) : Op_(Op) {}
 
     //! Destructor.
     virtual ~XpetraOp() {};
@@ -154,11 +154,11 @@ namespace Belos {
     }
 #endif
 
-    RCP<const Xpetra::Matrix<Scalar, LocalOrdinal, GlobalOrdinal, Node> > getOperator() const { return Op_; }
+    RCP<const Xpetra::Operator<Scalar, LocalOrdinal, GlobalOrdinal, Node> > getOperator() const { return Op_; }
 
   private:
 
-    RCP<Xpetra::Matrix<Scalar, LocalOrdinal, GlobalOrdinal, Node> > Op_;
+    RCP<Xpetra::Operator<Scalar, LocalOrdinal, GlobalOrdinal, Node> > Op_;
   };
 
 #ifdef HAVE_MUELU_EPETRA
@@ -192,7 +192,7 @@ namespace Belos {
 
   public:
 
-    XpetraOp(const RCP<Xpetra::Matrix<Scalar, LocalOrdinal, GlobalOrdinal, Node> > & Op) : Op_(Op) {}
+    XpetraOp(const RCP<Xpetra::Operator<Scalar, LocalOrdinal, GlobalOrdinal, Node> > & Op) : Op_(Op) {}
 
     virtual ~XpetraOp() {};
 
@@ -249,11 +249,11 @@ namespace Belos {
     }
 #endif
 
-    RCP<const Xpetra::Matrix<Scalar, LocalOrdinal, GlobalOrdinal, Node> > getOperator() const { return Op_; }
+    RCP<const Xpetra::Operator<Scalar, LocalOrdinal, GlobalOrdinal, Node> > getOperator() const { return Op_; }
 
   private:
 
-    RCP<Xpetra::Matrix<Scalar, LocalOrdinal, GlobalOrdinal, Node> > Op_;
+    RCP<Xpetra::Operator<Scalar, LocalOrdinal, GlobalOrdinal, Node> > Op_;
   };
 #endif // !EPETRA_NO_32BIT_GLOBAL_INDICES
 #endif // HAVE_MUELU_EPETRA
@@ -290,7 +290,7 @@ namespace Belos {
 
   public:
 
-    XpetraOp(const RCP<Xpetra::Matrix<Scalar, LocalOrdinal, GlobalOrdinal, Node> > & Op) : Op_(Op) {}
+    XpetraOp(const RCP<Xpetra::Operator<Scalar, LocalOrdinal, GlobalOrdinal, Node> > & Op) : Op_(Op) {}
 
     virtual ~XpetraOp() {};
 
@@ -347,11 +347,11 @@ namespace Belos {
     }
 #endif
 
-    RCP<const Xpetra::Matrix<Scalar, LocalOrdinal, GlobalOrdinal, Node> > getOperator() const { return Op_; }
+    RCP<const Xpetra::Operator<Scalar, LocalOrdinal, GlobalOrdinal, Node> > getOperator() const { return Op_; }
 
   private:
 
-    RCP<Xpetra::Matrix<Scalar, LocalOrdinal, GlobalOrdinal, Node> > Op_;
+    RCP<Xpetra::Operator<Scalar, LocalOrdinal, GlobalOrdinal, Node> > Op_;
   };
 #endif // !EPETRA_NO_64BIT_GLOBAL_INDICES
 #endif // HAVE_MUELU_EPETRA
