@@ -8,6 +8,9 @@
 #ifndef PACKAGES_MUELU_ADAPTERS_XPETRA_MUELU_CREATEXPETRAPRECONDITIONER_HPP_
 #define PACKAGES_MUELU_ADAPTERS_XPETRA_MUELU_CREATEXPETRAPRECONDITIONER_HPP_
 
+//! @file
+//! @brief Various adapters that will create a MueLu preconditioner that is an Xpetra::Matrix.
+
 #include <Teuchos_XMLParameterListHelpers.hpp>
 #include <Xpetra_CrsMatrix.hpp>
 #include <Xpetra_MultiVector.hpp>
@@ -23,7 +26,18 @@
 #include <MueLu_Utilities.hpp>
 #include <MueLu_HierarchyUtils.hpp>
 
+#include <stdlib.h>
+
 namespace MueLu {
+  /*!
+    @brief Helper function to create a MueLu preconditioner that can be used by Xpetra.
+    @ingroup MueLuAdapters
+    Given an Xpetra::Matrix, this function returns a constructed MueLu preconditioner.
+    @param[in] inA Matrix
+    @param[in] inParamList Parameter list
+    @param[in] inCoords (optional) Coordinates.  The first vector is x, the second (if necessary) y, the third (if necessary) z.
+    @param[in] inNullspace (optional) Near nullspace of the matrix.
+  */
 
   template <class Scalar, class LocalOrdinal, class GlobalOrdinal, class Node>
   Teuchos::RCP<MueLu::Hierarchy<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
@@ -42,12 +56,14 @@ namespace MueLu {
     RCP<Teuchos::Time> tm = Teuchos::TimeMonitor::getNewTimer(timerName);
     tm->start();
 
-    ParameterList paramList = inParamList;
-
-    bool hasParamList = paramList.numParams();
+    bool hasParamList = inParamList.numParams();
 
     RCP<HierarchyManager> mueLuFactory;
 
+    // Rip off non-serializable data before validation
+    Teuchos::ParameterList nonSerialList,paramList;
+    MueLu::ExtractNonSerializableData(inParamList, paramList, nonSerialList);
+
     std::string syntaxStr = "parameterlist: syntax";
     if (hasParamList && paramList.isParameter(syntaxStr) && paramList.get<std::string>(syntaxStr) == "ml") {
       paramList.remove(syntaxStr);
@@ -56,9 +72,12 @@ namespace MueLu {
       mueLuFactory = rcp(new ParameterListInterpreter(paramList,op->getDomainMap()->getComm()));
     }
 
+    // Create Hierarchy
     RCP<Hierarchy> H = mueLuFactory->CreateHierarchy();
     H->setlib(op->getDomainMap()->lib());
 
+    // Stick the non-serializible data on the hierarchy.
+    HierarchyUtils::AddNonSerializableDataToHierarchy(*mueLuFactory,*H, nonSerialList);
 
     // Set fine level operator
     H->GetLevel(0)->Set("A", op);
@@ -101,10 +120,67 @@ namespace MueLu {
     H->GetLevel(0)->Set("Nullspace", nullspace);
 
 
-    Teuchos::ParameterList nonSerialList,dummyList;
-    MueLu::ExtractNonSerializableData(paramList, dummyList, nonSerialList);
+    mueLuFactory->SetupHierarchy(*H);
+
+    tm->stop();
+    tm->incrementNumCalls();
+
+    if (H->GetVerbLevel() & Statistics0) {
+      const bool alwaysWriteLocal = true;
+      const bool writeGlobalStats = true;
+      const bool writeZeroTimers  = false;
+      const bool ignoreZeroTimers = true;
+      const std::string filter    = timerName;
+      Teuchos::TimeMonitor::summarize(op->getRowMap()->getComm().ptr(), std::cout, alwaysWriteLocal, writeGlobalStats,
+                                      writeZeroTimers, Teuchos::Union, filter, ignoreZeroTimers);
+    }
+
+    tm->reset();
+
+    return H;
+  }
+
+  template <class Scalar, class LocalOrdinal, class GlobalOrdinal, class Node>
+  Teuchos::RCP<MueLu::Hierarchy<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
+  CreateXpetraPreconditioner(Teuchos::RCP<Xpetra::Matrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > op,
+                             const Teuchos::ParameterList& inParamList,
+                             const Teuchos::ParameterList& dummy) {
+    typedef MueLu::HierarchyManager<Scalar,LocalOrdinal,GlobalOrdinal,Node> HierarchyManager;
+    typedef MueLu::HierarchyUtils<Scalar,LocalOrdinal,GlobalOrdinal,Node> HierarchyUtils;
+    typedef MueLu::Hierarchy<Scalar,LocalOrdinal,GlobalOrdinal,Node> Hierarchy;
+    typedef MueLu::MLParameterListInterpreter<Scalar,LocalOrdinal,GlobalOrdinal,Node> MLParameterListInterpreter;
+    typedef MueLu::ParameterListInterpreter<Scalar,LocalOrdinal,GlobalOrdinal,Node> ParameterListInterpreter;
+
+    std::string timerName = "MueLu setup time";
+    RCP<Teuchos::Time> tm = Teuchos::TimeMonitor::getNewTimer(timerName);
+    tm->start();
+
+    bool hasParamList = inParamList.numParams();
+
+    RCP<HierarchyManager> mueLuFactory;
+
+    // Rip off non-serializable data before validation
+    Teuchos::ParameterList nonSerialList,paramList;
+    MueLu::ExtractNonSerializableData(inParamList, paramList, nonSerialList);
+
+    std::string syntaxStr = "parameterlist: syntax";
+    if (hasParamList && paramList.isParameter(syntaxStr) && paramList.get<std::string>(syntaxStr) == "ml") {
+      paramList.remove(syntaxStr);
+      mueLuFactory = rcp(new MLParameterListInterpreter(paramList));
+    } else {
+      mueLuFactory = rcp(new ParameterListInterpreter(paramList,op->getDomainMap()->getComm()));
+    }
+
+    // Create Hierarchy
+    RCP<Hierarchy> H = mueLuFactory->CreateHierarchy();
+    H->setlib(op->getDomainMap()->lib());
+
+    // Stick the non-serializible data on the hierarchy.
     HierarchyUtils::AddNonSerializableDataToHierarchy(*mueLuFactory,*H, nonSerialList);
 
+    // Set fine level operator
+    H->GetLevel(0)->Set("A", op);
+
     mueLuFactory->SetupHierarchy(*H);
 
     tm->stop();
