@@ -194,7 +194,7 @@ int main_(Teuchos::CommandLineProcessor &clp, int argc, char *argv[]) {
 
   // Retrieve matrix parameters (they may have been changed on the command line)
   // [for instance, if we changed matrix type from 2D to 3D we need to update nz]
-  ParameterList galeriList = galeriParameters.GetParameterList();
+  Teuchos::ParameterList galeriList = galeriParameters.GetParameterList();
 
   // =========================================================================
   // Problem construction
@@ -232,10 +232,10 @@ int main_(Teuchos::CommandLineProcessor &clp, int argc, char *argv[]) {
   std::string thickSeparator = "=============================================================";
   std::string thinSeparator  = "-------------------------------------------------------------";
 
-  ParameterList paramList;
+  Teuchos::ParameterList paramList;
   paramList.set("verbosity", "none");
   if (xmlFileName != "")
-    Teuchos::updateParametersFromXmlFileAndBroadcast(xmlFileName, Teuchos::Ptr<ParameterList>(&paramList), *comm);
+    Teuchos::updateParametersFromXmlFileAndBroadcast(xmlFileName, Teuchos::Ptr<Teuchos::ParameterList>(&paramList), *comm);
 
   out << "Parameter list:" << std::endl << paramList << std::endl;
 
