@@ -125,6 +125,11 @@ template<> MuemexType getMuemexType<RCP<MAmalInfo>>() {return AMALGAMATION_INFO;
 template<> MuemexType getMuemexType(const RCP<MGraph>& data) {return GRAPH;}
 template<> MuemexType getMuemexType<RCP<MGraph>>() {return GRAPH;}
 
+#ifdef HAVE_MUELU_INTREPID2
+template<> MuemexType getMuemexType(const RCP<FieldContainer_ordinal>& data) {return FIELDCONTAINER_ORDINAL;}
+template<> MuemexType getMuemexType<RCP<FieldContainer_ordinal>>() {return FIELDCONTAINER_ORDINAL;}
+#endif
+
 /* "prototypes" for specialized functions used in other specialized functions */
 
 template<> mxArray* createMatlabSparse<double>(int numRows, int numCols, int nnz);
@@ -195,7 +200,7 @@ template<>
 string loadDataFromMatlab<string>(const mxArray* mxa)
 {
   string rv = "";
-  if(!mxGetClassID(mxa) != mxCHAR_CLASS)
+  if (mxGetClassID(mxa) != mxCHAR_CLASS)
   {
     throw runtime_error("Can't construct string from anything but a char array.");
   }
@@ -656,6 +661,34 @@ RCP<MGraph> loadDataFromMatlab<RCP<MGraph>>(const mxArray* mxa)
   return mgraph;
 }
 
+
+#ifdef HAVE_MUELU_INTREPID2
+template<>
+RCP<FieldContainer_ordinal> loadDataFromMatlab<RCP<FieldContainer_ordinal>>(const mxArray* mxa)
+{
+  if(mxGetClassID(mxa) != mxINT32_CLASS)
+    throw runtime_error("FieldContainer must have integer storage entries");
+
+  int *data = (int *) mxGetData(mxa);
+  int nr = mxGetM(mxa);
+  int nc = mxGetN(mxa);
+
+#ifdef HAVE_MUELU_INTREPID2_REFACTOR 
+  RCP<FieldContainer_ordinal> fc = rcp(new FieldContainer_ordinal("FC from Matlab",nr,nc));
+#else
+  RCP<FieldContainer_ordinal> fc = rcp(new FieldContainer_ordinal(nr,nc));
+#endif
+  for(int col = 0; col < nc; col++)
+  {
+    for(int row = 0; row < nr; row++)
+    {
+      (*fc)(row,col) = data[col * nr + row];
+    }
+  }
+  return fc;
+}
+#endif
+
 /* ******************************* */
 /* saveDataToMatlab                */
 /* ******************************* */
@@ -769,6 +802,8 @@ mxArray* saveDataToMatlab(RCP<Xpetra_Matrix_double>& data)
   int nr = data->getGlobalNumRows();
   int nc = data->getGlobalNumCols();
   int nnz = data->getGlobalNumEntries();
+
+  if(nnz==-1) nnz=data->getNodeNumEntries(); // Workaround for global constants stuff.
 #ifdef VERBOSE_OUTPUT
   RCP<Teuchos::FancyOStream> fancyStream = Teuchos::fancyOStream(Teuchos::rcpFromRef(std::cout));
   mat->describe(*fancyStream, Teuchos::VERB_EXTREME);
@@ -780,7 +815,10 @@ mxArray* saveDataToMatlab(RCP<Xpetra_Matrix_double>& data)
   {
     jc[i] = 0;
   }
+
   size_t maxEntriesPerRow = data->getGlobalMaxNumRowEntries();
+  if(maxEntriesPerRow == Teuchos::OrdinalTraits<size_t>::invalid() || maxEntriesPerRow == 0) maxEntriesPerRow = data->getNodeMaxNumRowEntries();
+
   int* rowProgress = new int[nc];
   //The array that will be copied to Pr and (if complex) Pi later
   Scalar* sparseVals = new Scalar[nnz];
@@ -799,6 +837,7 @@ mxArray* saveDataToMatlab(RCP<Xpetra_Matrix_double>& data)
         jc[rowIndices[entry] + 1]++; //for each entry, increase jc for the entry's column
       }
     }
+
     //now jc holds the number of elements in each column, but needs cumulative sum over all previous columns also
     int entriesAccum = 0;
     for(int n = 0; n <= nc; n++)
@@ -1259,6 +1298,34 @@ mxArray* saveDataToMatlab(RCP<MGraph>& data)
   return out[0];
 }
 
+#ifdef HAVE_MUELU_INTREPID2
+template<>
+mxArray* saveDataToMatlab(RCP<FieldContainer_ordinal>& data)
+{
+  int rank = data->rank();
+  // NOTE: Only supports rank 2 arrays
+  if(rank!=2)
+    throw std::runtime_error("Error: Only rank two FieldContainers are supported.");
+
+  int nr = data->dimension(0);
+  int nc = data->dimension(1);
+  
+  mwSize dims[]={(mwSize)nr,(mwSize)nc};
+  mxArray* mxa = mxCreateNumericArray(2,dims, mxINT32_CLASS, mxREAL);
+  int *array = (int*) mxGetData(mxa);
+  
+  for(int col = 0; col < nc; col++)
+  {
+    for(int row = 0; row < nr; row++)
+    {
+      array[col * nr + row] = (*data)(row,col);
+    }
+  }
+  return mxa;
+}
+#endif
+
+
 template<typename T>
 MuemexData<T>::MuemexData(const mxArray* mxa) : MuemexArg(getMuemexType<T>())
 {
@@ -1289,7 +1356,7 @@ T& MuemexData<T>::getData()
 template<typename T>
 void MuemexData<T>::setData(T& newData)
 {
-  this->data = data;
+  this->data = newData;
 }
 
 /* ***************************** */
@@ -1317,7 +1384,7 @@ const T& getLevelVariable(std::string& name, Level& lvl)
 }
 
 //Functions used to put data through matlab factories - first arg is "this" pointer of matlab factory
-template<typename Scalar = double, typename LocalOrdinal = mm_LocalOrd, typename GlobalOrdinal = mm_GlobalOrd, typename Node = mm_node_t>
+template<typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
 std::vector<Teuchos::RCP<MuemexArg>> processNeeds(const Factory* factory, std::string& needsParam, Level& lvl)
 {
   using namespace std;
@@ -1449,7 +1516,7 @@ std::vector<Teuchos::RCP<MuemexArg>> processNeeds(const Factory* factory, std::s
   return args;
 }
 
-template<typename Scalar = double, typename LocalOrdinal = mm_LocalOrd, typename GlobalOrdinal = mm_GlobalOrd, typename Node = mm_node_t>
+template<typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
 void processProvides(std::vector<Teuchos::RCP<MuemexArg>>& mexOutput, const Factory* factory, std::string& providesParam, Level& lvl)
 {
   using namespace std;
