@@ -49,6 +49,7 @@
 
 #include <Xpetra_Map.hpp>
 #include <Xpetra_Vector.hpp>
+#include <Xpetra_MultiVectorFactory.hpp>
 #include <Xpetra_VectorFactory.hpp>
 
 #include "MueLu_LWGraph_kokkos.hpp"
@@ -136,7 +137,7 @@ namespace MueLu {
 
       ComputeAggregateSizesFunctor<decltype(procWinner), decltype(vertex2AggId), decltype(aggregateSizesAtomic), LO>
         computeAggSizesFunctor(procWinner, vertex2AggId, myPID, aggregateSizesAtomic);
-      Kokkos::parallel_for("MueLu:Aggregates:ComputeAggregateSizes:for", procWinner.size(), computeAggSizesFunctor);
+      Kokkos::parallel_for("MueLu:Aggregates:ComputeAggregateSizes:for", range_type(0,procWinner.size()), computeAggSizesFunctor);
 
       if (cacheSizes)
         aggregateSizes_ = aggregateSizes;
