@@ -89,6 +89,8 @@
 #include "MueLu_DropNegativeEntriesFactory.hpp"
 #include "MueLu_EminPFactory.hpp"
 #include "MueLu_FilteredAFactory.hpp"
+#include "MueLu_FineLevelInputDataFactory.hpp"
+#include "MueLu_GeneralGeometricPFactory.hpp"
 #include "MueLu_GenericRFactory.hpp"
 #ifdef HAVE_MUELU_EXPERIMENTAL
 #include "MueLu_IndefBlockedDiagonalSmoother.hpp"
@@ -116,11 +118,13 @@
 #include "MueLu_ReorderBlockAFactory.hpp"
 #include "MueLu_SaPFactory.hpp"
 #include "MueLu_SegregatedAFactory.hpp"
+#include "MueLu_SemiCoarsenPFactory.hpp"
 #ifdef HAVE_MUELU_EXPERIMENTAL
 #include "MueLu_SchurComplementFactory.hpp"
 #include "MueLu_SimpleSmoother.hpp"
 #endif
 #include "MueLu_SmootherFactory.hpp"
+#include "MueLu_StructuredLineDetectionFactory.hpp"
 #include "MueLu_SubBlockAFactory.hpp"
 #ifdef HAVE_MUELU_EXPERIMENTAL
 #ifdef HAVE_MUELU_TEKO
@@ -133,12 +137,13 @@
 #include "MueLu_TrilinosSmoother.hpp"
 #include "MueLu_TransPFactory.hpp"
 #include "MueLu_UncoupledAggregationFactory.hpp"
+#include "MueLu_UnsmooshFactory.hpp"
 #include "MueLu_UserAggregationFactory.hpp"
 #include "MueLu_UserPFactory.hpp"
-#include "MueLu_SemiCoarsenPFactory.hpp"
 #ifdef HAVE_MUELU_EXPERIMENTAL
 #include "MueLu_UzawaSmoother.hpp"
 #endif
+#include "MueLu_VariableDofLaplacianFactory.hpp"
 #include "MueLu_ZoltanInterface.hpp"
 #include "MueLu_Zoltan2Interface.hpp"
 
@@ -152,6 +157,10 @@
 #include "../matlab/src/MueLu_MatlabSmoother_def.hpp"
 #endif
 
+#ifdef HAVE_MUELU_INTREPID2
+#include "MueLu_IntrepidPCoarsenFactory.hpp"
+#endif
+
 namespace MueLu {
 
   /*! class FactoryFactory
@@ -170,17 +179,23 @@ namespace MueLu {
 
   public:
 
-    // Parameter List Parsing:
-    // ---------
-    //     <Parameter name="smootherFact0" type="string" value="TrilinosSmoother"/>
-    //
-    // or:
-    //
-    //     <ParameterList name="smootherFact1">
-    //       <Parameter name="factory" type="string" value="TrilinosSmoother"/>
-    //       ...
-    //     </ParameterList>
-    //
+    /// \brief: Interpret Factory parameter list and build new factory
+    ///
+    /// \param param [in]: ParameterEntry being either the parameter list containing the "factory" parameter declaring the factory type (e.g., "TrilinosSmoother") or being a plain Parameter containing the factory type as value
+    /// \param factoryMapIn [in]: FactoryMap containing a map between factory name (e.g., "smootherFact1") and corresponding factory of all previously defined factories
+    /// \param factoryManagersIn [in]: FactoryManagerMap containing a map between group names and Factory manager objects. Needed for factories with sub-factory managers.
+    ///
+    /// Parameter List Parsing:
+    /// ---------
+    ///     <Parameter name="smootherFact0" type="string" value="TrilinosSmoother"/>
+    ///
+    /// or:
+    ///
+    ///     <ParameterList name="smootherFact1">
+    ///       <Parameter name="factory" type="string" value="TrilinosSmoother"/>
+    ///       ...
+    ///     </ParameterList>
+    ///
     virtual RCP<const FactoryBase> BuildFactory(const Teuchos::ParameterEntry& param, const FactoryMap& factoryMapIn, const FactoryManagerMap& factoryManagersIn) const {
       // Find factory
       std::string            factoryName;
@@ -196,49 +211,54 @@ namespace MueLu {
       if (factoryName == "AggregationExportFactory")        return Build2<AggregationExportFactory>      (paramList, factoryMapIn, factoryManagersIn);
       if (factoryName == "AmalgamationFactory")             return Build2<AmalgamationFactory>           (paramList, factoryMapIn, factoryManagersIn);
 #ifdef HAVE_MUELU_EXPERIMENTAL
-      if (factoryName == "BlockedCoarseMapFactory")         return Build2<BlockedCoarseMapFactory>       (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "BlockedRAPFactory")               return BuildRAPFactory<BlockedRAPFactory>    (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "BlockedCoarseMapFactory")            return Build2<BlockedCoarseMapFactory>            (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "BlockedRAPFactory")                  return BuildRAPFactory<BlockedRAPFactory>         (paramList, factoryMapIn, factoryManagersIn);
 #endif
-      if (factoryName == "BrickAggregationFactory")         return Build2<BrickAggregationFactory>       (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "CloneRepartitionInterface")       return Build2<CloneRepartitionInterface>     (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "CoarseMapFactory")                return Build2<CoarseMapFactory>              (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "CoarseningVisualizationFactory")  return Build2<CoarseningVisualizationFactory>(paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "CoalesceDropFactory")             return Build2<CoalesceDropFactory>           (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "ConstraintFactory")               return Build2<ConstraintFactory>             (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "CoupledAggregationFactory")       return BuildCoupledAggregationFactory        (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "CoordinatesTransferFactory")      return Build2<CoordinatesTransferFactory>    (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "DirectSolver")                    return BuildDirectSolver                     (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "DropNegativeEntriesFactory")      return Build2<DropNegativeEntriesFactory>    (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "EminPFactory")                    return Build2<EminPFactory>                  (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "FilteredAFactory")                return Build2<FilteredAFactory>              (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "GenericRFactory")                 return Build2<GenericRFactory>               (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "LineDetectionFactory")            return Build2<LineDetectionFactory>          (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "MapTransferFactory")              return Build2<MapTransferFactory>            (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "MatrixAnalysisFactory")           return Build2<MatrixAnalysisFactory>         (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "MultiVectorTransferFactory")      return Build2<MultiVectorTransferFactory>    (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "NoFactory")                       return MueLu::NoFactory::getRCP();
-      if (factoryName == "NoSmoother")                      return rcp(new SmootherFactory(Teuchos::null));
-      if (factoryName == "NullspaceFactory")                return Build2<NullspaceFactory>              (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "NullspacePresmoothFactory")       return Build2<NullspacePresmoothFactory>     (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "PatternFactory")                  return Build2<PatternFactory>                (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "PgPFactory")                      return Build2<PgPFactory>                    (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "SaPFactory")                      return Build2<SaPFactory>                    (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "RAPFactory")                      return BuildRAPFactory<RAPFactory>           (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "RebalanceAcFactory")              return Build2<RebalanceAcFactory>            (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "RebalanceTransferFactory")        return Build2<RebalanceTransferFactory>      (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "ReorderBlockAFactory")            return Build2<ReorderBlockAFactory>          (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "SegregatedAFactory")              return Build2<SegregatedAFactory>            (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "SubBlockAFactory")                return Build2<SubBlockAFactory>              (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "TentativePFactory")               return Build2<TentativePFactory>             (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "ToggleCoordinatesTransferFactory")return BuildToggleCoordinatesTransferFactory (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "TogglePFactory")                  return BuildTogglePFactory<TogglePFactory>   (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "TransPFactory")                   return Build2<TransPFactory>                 (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "TrilinosSmoother")                return BuildTrilinosSmoother                 (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "UncoupledAggregationFactory")     return Build2<UncoupledAggregationFactory>   (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "UserAggregationFactory")          return Build2<UserAggregationFactory>        (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "UserPFactory")                    return Build2<UserPFactory>                  (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "SemiCoarsenPFactory")             return Build2<SemiCoarsenPFactory>           (paramList, factoryMapIn, factoryManagersIn);
-      if (factoryName == "RepartitionInterface")            return Build2<RepartitionInterface>          (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "BrickAggregationFactory")            return Build2<BrickAggregationFactory>            (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "CloneRepartitionInterface")          return Build2<CloneRepartitionInterface>          (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "CoarseMapFactory")                   return Build2<CoarseMapFactory>                   (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "CoarseningVisualizationFactory")     return Build2<CoarseningVisualizationFactory>     (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "CoalesceDropFactory")                return Build2<CoalesceDropFactory>                (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "ConstraintFactory")                  return Build2<ConstraintFactory>                  (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "CoupledAggregationFactory")          return BuildCoupledAggregationFactory             (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "CoordinatesTransferFactory")         return Build2<CoordinatesTransferFactory>         (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "DirectSolver")                       return BuildDirectSolver                          (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "DropNegativeEntriesFactory")         return Build2<DropNegativeEntriesFactory>         (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "EminPFactory")                       return Build2<EminPFactory>                       (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "FilteredAFactory")                   return Build2<FilteredAFactory>                   (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "FineLevelInputDataFactory")          return Build2<FineLevelInputDataFactory>          (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "GeneralGeometricPFactory")           return Build2<GeneralGeometricPFactory>           (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "GenericRFactory")                    return Build2<GenericRFactory>                    (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "LineDetectionFactory")               return Build2<LineDetectionFactory>               (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "MapTransferFactory")                 return Build2<MapTransferFactory>                 (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "MatrixAnalysisFactory")              return Build2<MatrixAnalysisFactory>              (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "MultiVectorTransferFactory")         return Build2<MultiVectorTransferFactory>         (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "NoFactory")                          return MueLu::NoFactory::getRCP();
+      if (factoryName == "NoSmoother")                         return rcp(new SmootherFactory(Teuchos::null));
+      if (factoryName == "NullspaceFactory")                   return Build2<NullspaceFactory>                   (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "NullspacePresmoothFactory")          return Build2<NullspacePresmoothFactory>          (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "PatternFactory")                     return Build2<PatternFactory>                     (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "PgPFactory")                         return Build2<PgPFactory>                         (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "SaPFactory")                         return Build2<SaPFactory>                         (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "RAPFactory")                         return BuildRAPFactory<RAPFactory>                (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "RebalanceAcFactory")                 return Build2<RebalanceAcFactory>                 (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "RebalanceTransferFactory")           return Build2<RebalanceTransferFactory>           (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "ReorderBlockAFactory")               return Build2<ReorderBlockAFactory>               (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "RepartitionInterface")               return Build2<RepartitionInterface>               (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "SegregatedAFactory")                 return Build2<SegregatedAFactory>                 (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "SemiCoarsenPFactory")                return Build2<SemiCoarsenPFactory>                (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "StructuredLineDetectionFactory")     return Build2<StructuredLineDetectionFactory>     (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "SubBlockAFactory")                   return Build2<SubBlockAFactory>                   (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "TentativePFactory")                  return Build2<TentativePFactory>                  (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "ToggleCoordinatesTransferFactory")   return BuildToggleCoordinatesTransferFactory      (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "TogglePFactory")                     return BuildTogglePFactory<TogglePFactory>        (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "TransPFactory")                      return Build2<TransPFactory>                      (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "TrilinosSmoother")                   return BuildTrilinosSmoother                      (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "UncoupledAggregationFactory")        return Build2<UncoupledAggregationFactory>        (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "UnsmooshFactory")                    return Build2<UnsmooshFactory>                    (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "UserAggregationFactory")             return Build2<UserAggregationFactory>             (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "UserPFactory")                       return Build2<UserPFactory>                       (paramList, factoryMapIn, factoryManagersIn);
+      if (factoryName == "VariableDofLaplacianFactory")        return Build2<VariableDofLaplacianFactory>        (paramList, factoryMapIn, factoryManagersIn);
 
       if (factoryName == "ZoltanInterface") {
 #if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
@@ -301,6 +321,10 @@ namespace MueLu {
       if (factoryName == "MatlabSmoother")                  return BuildMatlabSmoother                  (paramList, factoryMapIn, factoryManagersIn);
 #endif
 
+#ifdef HAVE_MUELU_INTREPID2
+      if (factoryName == "IntrepidPCoarsenFactory")           return Build2<IntrepidPCoarsenFactory>        (paramList, factoryMapIn, factoryManagersIn);
+#endif
+
       // Use a user defined factories (in <Factories> node)
       if (factoryMapIn.find(factoryName) != factoryMapIn.end()) {
         TEUCHOS_TEST_FOR_EXCEPTION((param.isList() && (++paramList.begin() != paramList.end())), Exceptions::RuntimeError,
@@ -353,7 +377,8 @@ namespace MueLu {
       ParameterList paramListWithFactories;
 
       // Read the RCP<Factory> parameters of the class T
-      RCP<const ParameterList> validParamList = factory->GetValidParameterList();
+      RCP<const ParameterList> validParamList = factory->GetValidParameterList(); // TODO check for Teuchos::null (no parameter list validation)
+      TEUCHOS_TEST_FOR_EXCEPTION(validParamList == Teuchos::null, Exceptions::RuntimeError, "FactoryFactory::Build2: default parameter list is null. Please fix this.");
       for (ParameterList::ConstIterator param = validParamList->begin(); param != validParamList->end(); ++param) {
         const std::string& pName = validParamList->name(param);
 
@@ -413,7 +438,7 @@ namespace MueLu {
     RCP<T> BuildTogglePFactory(const Teuchos::ParameterList & paramList, const FactoryMap& factoryMapIn, const FactoryManagerMap& factoryManagersIn) const {
       RCP<T> factory;
       if (paramList.isSublist("TransferFactories") == false) {
-    	  //TODO put in an error message: the TogglePFactory needs a TransferFactories sublist!
+          //TODO put in an error message: the TogglePFactory needs a TransferFactories sublist!
         factory = Build2<T>(paramList, factoryMapIn, factoryManagersIn);
 
       } else {
