@@ -49,17 +49,9 @@
 #ifdef HAVE_MUELU_EXPERIMENTAL
 
 #include <Xpetra_BlockedCrsMatrix.hpp>
-#include <Xpetra_MultiVectorFactory.hpp>
-#include <Xpetra_VectorFactory.hpp>
-#include <Xpetra_MatrixFactory.hpp>
-#include <Xpetra_Matrix.hpp>
-#include <Xpetra_CrsMatrixWrap.hpp>
-#include <Xpetra_BlockedCrsMatrix.hpp>
-#include <Xpetra_CrsMatrix.hpp>
 #include "MueLu_Level.hpp"
 #include "MueLu_Monitor.hpp"
-#include "MueLu_Utilities.hpp"
-//#include "MueLu_HierarchyHelpers.hpp"
+#include "MueLu_PerfUtils.hpp"
 
 #include "MueLu_MergedBlockedMatrixFactory.hpp"
 
@@ -95,6 +87,8 @@ void MergedBlockedMatrixFactory<Scalar, LocalOrdinal, GlobalOrdinal, Node>::Buil
 
   Teuchos::RCP<Matrix> mergedA = bA->Merge();
   {
+    GetOStream(Statistics1) << PerfUtils::PrintMatrixInfo(*mergedA, "A (merged)");
+
     // note: variable "A" generated by this MergedBlockedMatrix factory is in fact the a merged version
     // of the blocked matrix A (from the input)
     Set(currentLevel, "A", mergedA);
