@@ -70,6 +70,7 @@
 #include "MueLu_Level_fwd.hpp"
 #include "MueLu_MasterList.hpp"
 #include "MueLu_NoFactory.hpp"
+#include "MueLu_PerfUtils_fwd.hpp"
 #include "MueLu_PFactory_fwd.hpp"
 #include "MueLu_RFactory_fwd.hpp"
 #include "MueLu_SmootherBase_fwd.hpp"
@@ -181,6 +182,9 @@ namespace MueLu {
     // This function is global
     double GetOperatorComplexity() const;
 
+    // This function is global
+    double GetSmootherComplexity() const;
+
     //! Helper function
     void CheckLevel(Level& level, int levelID);
 
@@ -240,6 +244,9 @@ namespace MueLu {
     //! Supports VCYCLE and WCYCLE types.
     void      SetCycle(CycleType Cycle)        { Cycle_ = Cycle; }
 
+    //! Specify damping factor alpha such that x = x + alpha*P*c, where c is the coarse grid correction.
+    void SetProlongatorScalingFactor(double scalingFactor) { scalingFactor_ = scalingFactor; }
+
     /*!
       @brief Apply the multigrid preconditioner.
 
@@ -289,7 +296,7 @@ namespace MueLu {
     //@{
 
     //! Return a simple one-line description of this object.
-    std::string description() const;
+    std::string description() const; 
 
     /*! @brief Print the Hierarchy with some verbosity level to a FancyOStream object.
 
@@ -323,6 +330,10 @@ namespace MueLu {
     void setlib(Xpetra::UnderlyingLib inlib) { lib_ = inlib; }
     Xpetra::UnderlyingLib lib() { return lib_; }
 
+    // force recreation of cached description_ next time description() is called: 
+    void ResetDescription() {
+      description_ = "";
+    }
   protected:
     const RCP<const FactoryManagerBase>& GetLevelManager(const int levelID) const {
       return levelManagers_[levelID];
@@ -359,9 +370,15 @@ namespace MueLu {
     // V- or W-cycle
     CycleType Cycle_;
 
+    // Scaling factor to be applied to coarse grid correction.
+    double scalingFactor_;
+
     // Epetra/Tpetra mode
     Xpetra::UnderlyingLib lib_;
 
+    // cache description to avoid recreating in each call to description() - use ResetDescription() to force recreation in Setup, SetupRe, etc.
+    mutable std::string description_ = ""; // mutable so that we can lazily initialize in description(), which is declared const
+
     //! Graph dumping
     // If enabled, we dump the graph on a specified level into a specified file
     bool isDumpingEnabled_;
