@@ -146,6 +146,9 @@ namespace MueLu {
     //using MueLu::Describable::describe; // overloading, not hiding
     void print(Teuchos::FancyOStream &out, const VerbLevel verbLevel = Default) const;
 
+    //! Get a rough estimate of cost per iteration
+    size_t getNodeSmootherComplexity() const;
+
     //@}
 
   private:
