@@ -65,9 +65,10 @@
 #include "MueLu_AmalgamationFactory.hpp"
 #include "MueLu_AmalgamationInfo.hpp"
 #include "MueLu_CoarseMapFactory.hpp"
+#include "MueLu_MasterList.hpp"
+#include "MueLu_Monitor.hpp"
 #include "MueLu_NullspaceFactory.hpp"
 #include "MueLu_PerfUtils.hpp"
-#include "MueLu_Monitor.hpp"
 #include "MueLu_Utilities.hpp"
 
 namespace MueLu {
@@ -76,11 +77,21 @@ namespace MueLu {
   RCP<const ParameterList> TentativePFactory<Scalar, LocalOrdinal, GlobalOrdinal, Node>::GetValidParameterList() const {
     RCP<ParameterList> validParamList = rcp(new ParameterList());
 
+#define SET_VALID_ENTRY(name) validParamList->setEntry(name, MasterList::getEntry(name))
+    SET_VALID_ENTRY("tentative: calculate qr");
+#undef  SET_VALID_ENTRY
+
     validParamList->set< RCP<const FactoryBase> >("A",                  Teuchos::null, "Generating factory of the matrix A");
     validParamList->set< RCP<const FactoryBase> >("Aggregates",         Teuchos::null, "Generating factory of the aggregates");
     validParamList->set< RCP<const FactoryBase> >("Nullspace",          Teuchos::null, "Generating factory of the nullspace");
     validParamList->set< RCP<const FactoryBase> >("UnAmalgamationInfo", Teuchos::null, "Generating factory of UnAmalgamationInfo");
     validParamList->set< RCP<const FactoryBase> >("CoarseMap",          Teuchos::null, "Generating factory of the coarse map");
+
+    // Make sure we don't recursively validate options for the matrixmatrix kernels
+    ParameterList norecurse;
+    norecurse.disableRecursiveValidation();
+    validParamList->set<ParameterList> ("matrixmatrix: kernel params", norecurse, "MatrixMatrix kernel parameters");
+
     return validParamList;
   }
 
@@ -111,7 +122,7 @@ namespace MueLu {
     RCP<Matrix>           Ptentative;
     RCP<MultiVector>      coarseNullspace;
     if (!aggregates->AggregatesCrossProcessors())
-      BuildPuncoupled(A, aggregates, amalgInfo, fineNullspace, coarseMap, Ptentative, coarseNullspace);
+      BuildPuncoupled(A, aggregates, amalgInfo, fineNullspace, coarseMap, Ptentative, coarseNullspace,coarseLevel.GetLevelID());
     else
       BuildPcoupled  (A, aggregates, amalgInfo, fineNullspace, coarseMap, Ptentative, coarseNullspace);
 
@@ -141,7 +152,7 @@ namespace MueLu {
   template <class Scalar,class LocalOrdinal, class GlobalOrdinal, class Node>
   void TentativePFactory<Scalar, LocalOrdinal, GlobalOrdinal, Node>::
   BuildPuncoupled(RCP<Matrix> A, RCP<Aggregates> aggregates, RCP<AmalgamationInfo> amalgInfo, RCP<MultiVector> fineNullspace,
-                RCP<const Map> coarseMap, RCP<Matrix>& Ptentative, RCP<MultiVector>& coarseNullspace) const {
+                RCP<const Map> coarseMap, RCP<Matrix>& Ptentative, RCP<MultiVector>& coarseNullspace, const int levelID) const {
     RCP<const Map> rowMap = A->getRowMap();
     RCP<const Map> colMap = A->getColMap();
 
@@ -180,6 +191,9 @@ namespace MueLu {
 
     coarseNullspace = MultiVectorFactory::Build(coarseMap, NSDim);
 
+    const ParameterList& pL = GetParameterList();
+    const bool &doQRStep = pL.get<bool>("tentative: calculate qr");
+
     // Pull out the nullspace vectors so that we can have random access.
     ArrayRCP<ArrayRCP<const SC> > fineNS  (NSDim);
     ArrayRCP<ArrayRCP<SC> >       coarseNS(NSDim);
@@ -214,131 +228,207 @@ namespace MueLu {
       val[j] = zero;
     }
 
-    for (GO agg = 0; agg < numAggs; agg++) {
-      LO aggSize = aggStart[agg+1] - aggStart[agg];
 
-      Xpetra::global_size_t offset = agg*NSDim;
+    if (doQRStep) {
+      ////////////////////////////////
+      // Standard aggregate-wise QR //
+      ////////////////////////////////
+      for (GO agg = 0; agg < numAggs; agg++) {
+        LO aggSize = aggStart[agg+1] - aggStart[agg];
 
-      // Extract the piece of the nullspace corresponding to the aggregate, and
-      // put it in the flat array, "localQR" (in column major format) for the
-      // QR routine.
-      Teuchos::SerialDenseMatrix<LO,SC> localQR(aggSize, NSDim);
-      if (goodMap) {
-        for (size_t j = 0; j < NSDim; j++)
-          for (LO k = 0; k < aggSize; k++)
-            localQR(k,j) = fineNS[j][aggToRowMapLO[aggStart[agg]+k]];
-      } else {
-        for (size_t j = 0; j < NSDim; j++)
-          for (LO k = 0; k < aggSize; k++)
-            localQR(k,j) = fineNS[j][rowMap->getLocalElement(aggToRowMapGO[aggStart[agg]+k])];
-      }
-
-      // Test for zero columns
-      for (size_t j = 0; j < NSDim; j++) {
-        bool bIsZeroNSColumn = true;
-
-        for (LO k = 0; k < aggSize; k++)
-          if (localQR(k,j) != zero)
-            bIsZeroNSColumn = false;
-
-        TEUCHOS_TEST_FOR_EXCEPTION(bIsZeroNSColumn == true, Exceptions::RuntimeError,
-                                   "MueLu::TentativePFactory::MakeTentative: fine level NS part has a zero column");
-      }
-
-      // Calculate QR decomposition (standard)
-      // NOTE: Q is stored in localQR and R is stored in coarseNS
-      if (aggSize >= Teuchos::as<LO>(NSDim)) {
-
-        if (NSDim == 1) {
-          // Only one nullspace vector, calculate Q and R by hand
-          Magnitude norm = STS::magnitude(zero);
-          for (size_t k = 0; k < Teuchos::as<size_t>(aggSize); k++)
-            norm += STS::magnitude(localQR(k,0)*localQR(k,0));
-          norm = Teuchos::ScalarTraits<Magnitude>::squareroot(norm);
-
-          // R = norm
-          coarseNS[0][offset] = norm;
-
-          // Q = localQR(:,0)/norm
-          for (LO i = 0; i < aggSize; i++)
-            localQR(i,0) /= norm;
+        Xpetra::global_size_t offset = agg*NSDim;
 
+        // Extract the piece of the nullspace corresponding to the aggregate, and
+        // put it in the flat array, "localQR" (in column major format) for the
+        // QR routine.
+        Teuchos::SerialDenseMatrix<LO,SC> localQR(aggSize, NSDim);
+        if (goodMap) {
+          for (size_t j = 0; j < NSDim; j++)
+            for (LO k = 0; k < aggSize; k++)
+              localQR(k,j) = fineNS[j][aggToRowMapLO[aggStart[agg]+k]];
         } else {
-          Teuchos::SerialQRDenseSolver<LO,SC> qrSolver;
-          qrSolver.setMatrix(Teuchos::rcp(&localQR, false));
-          qrSolver.factor();
-
-          // R = upper triangular part of localQR
           for (size_t j = 0; j < NSDim; j++)
-            for (size_t k = 0; k <= j; k++)
-              coarseNS[j][offset+k] = localQR(k,j); //TODO is offset+k the correct local ID?!
-
-          // Calculate Q, the tentative prolongator.
-          // The Lapack GEQRF call only works for myAggsize >= NSDim
-          qrSolver.formQ();
-          Teuchos::RCP<Teuchos::SerialDenseMatrix<LO,SC> > qFactor = qrSolver.getQ();
-          for (size_t j = 0; j < NSDim; j++)
-            for (size_t i = 0; i < Teuchos::as<size_t>(aggSize); i++)
-              localQR(i,j) = (*qFactor)(i,j);
+            for (LO k = 0; k < aggSize; k++)
+              localQR(k,j) = fineNS[j][rowMap->getLocalElement(aggToRowMapGO[aggStart[agg]+k])];
         }
 
-      } else {
-        // Special handling for aggSize < NSDim (i.e. single node aggregates in structural mechanics)
+        // Test for zero columns
+        for (size_t j = 0; j < NSDim; j++) {
+          bool bIsZeroNSColumn = true;
 
-        // The local QR decomposition is not possible in the "overconstrained"
-        // case (i.e. number of columns in localQR > number of rows), which
-        // corresponds to #DOFs in Aggregate < NSDim. For usual problems this
-        // is only possible for single node aggregates in structural mechanics.
-        // (Similar problems may arise in discontinuous Galerkin problems...)
-        // We bypass the QR decomposition and use an identity block in the
-        // tentative prolongator for the single node aggregate and transfer the
-        // corresponding fine level null space information 1-to-1 to the coarse
-        // level null space part.
+          for (LO k = 0; k < aggSize; k++)
+            if (localQR(k,j) != zero)
+              bIsZeroNSColumn = false;
 
-        // NOTE: The resulting tentative prolongation operator has
-        // (aggSize*DofsPerNode-NSDim) zero columns leading to a singular
-        // coarse level operator A.  To deal with that one has the following
-        // options:
-        // - Use the "RepairMainDiagonal" flag in the RAPFactory (default:
-        //   false) to add some identity block to the diagonal of the zero rows
-        //   in the coarse level operator A, such that standard level smoothers
-        //   can be used again.
-        // - Use special (projection-based) level smoothers, which can deal
-        //   with singular matrices (very application specific)
-        // - Adapt the code below to avoid zero columns. However, we do not
-        //   support a variable number of DOFs per node in MueLu/Xpetra which
-        //   makes the implementation really hard.
+          TEUCHOS_TEST_FOR_EXCEPTION(bIsZeroNSColumn == true, Exceptions::RuntimeError,
+                                     "MueLu::TentativePFactory::MakeTentative: fine level NS part has a zero column");
+        }
 
-        // R = extended (by adding identity rows) localQR
-        for (size_t j = 0; j < NSDim; j++)
-          for (size_t k = 0; k < NSDim; k++)
-            if (k < as<size_t>(aggSize))
-              coarseNS[j][offset+k] = localQR(k,j);
-            else
-              coarseNS[j][offset+k] = (k == j ? one : zero);
+        // Calculate QR decomposition (standard)
+        // NOTE: Q is stored in localQR and R is stored in coarseNS
+        if (aggSize >= Teuchos::as<LO>(NSDim)) {
 
-        // Q = I (rectangular)
-        for (size_t i = 0; i < as<size_t>(aggSize); i++)
+          if (NSDim == 1) {
+            // Only one nullspace vector, calculate Q and R by hand
+            Magnitude norm = STS::magnitude(zero);
+            for (size_t k = 0; k < Teuchos::as<size_t>(aggSize); k++)
+              norm += STS::magnitude(localQR(k,0)*localQR(k,0));
+            norm = Teuchos::ScalarTraits<Magnitude>::squareroot(norm);
+
+            // R = norm
+            coarseNS[0][offset] = norm;
+
+            // Q = localQR(:,0)/norm
+            for (LO i = 0; i < aggSize; i++)
+              localQR(i,0) /= norm;
+
+          } else {
+            Teuchos::SerialQRDenseSolver<LO,SC> qrSolver;
+            qrSolver.setMatrix(Teuchos::rcp(&localQR, false));
+            qrSolver.factor();
+
+            // R = upper triangular part of localQR
+            for (size_t j = 0; j < NSDim; j++)
+              for (size_t k = 0; k <= j; k++)
+                coarseNS[j][offset+k] = localQR(k,j); //TODO is offset+k the correct local ID?!
+
+            // Calculate Q, the tentative prolongator.
+            // The Lapack GEQRF call only works for myAggsize >= NSDim
+            qrSolver.formQ();
+            Teuchos::RCP<Teuchos::SerialDenseMatrix<LO,SC> > qFactor = qrSolver.getQ();
+            for (size_t j = 0; j < NSDim; j++)
+              for (size_t i = 0; i < Teuchos::as<size_t>(aggSize); i++)
+                localQR(i,j) = (*qFactor)(i,j);
+          }
+
+        } else {
+          // Special handling for aggSize < NSDim (i.e. single node aggregates in structural mechanics)
+
+          // The local QR decomposition is not possible in the "overconstrained"
+          // case (i.e. number of columns in localQR > number of rows), which
+          // corresponds to #DOFs in Aggregate < NSDim. For usual problems this
+          // is only possible for single node aggregates in structural mechanics.
+          // (Similar problems may arise in discontinuous Galerkin problems...)
+          // We bypass the QR decomposition and use an identity block in the
+          // tentative prolongator for the single node aggregate and transfer the
+          // corresponding fine level null space information 1-to-1 to the coarse
+          // level null space part.
+
+          // NOTE: The resulting tentative prolongation operator has
+          // (aggSize*DofsPerNode-NSDim) zero columns leading to a singular
+          // coarse level operator A.  To deal with that one has the following
+          // options:
+          // - Use the "RepairMainDiagonal" flag in the RAPFactory (default:
+          //   false) to add some identity block to the diagonal of the zero rows
+          //   in the coarse level operator A, such that standard level smoothers
+          //   can be used again.
+          // - Use special (projection-based) level smoothers, which can deal
+          //   with singular matrices (very application specific)
+          // - Adapt the code below to avoid zero columns. However, we do not
+          //   support a variable number of DOFs per node in MueLu/Xpetra which
+          //   makes the implementation really hard.
+
+          // R = extended (by adding identity rows) localQR
           for (size_t j = 0; j < NSDim; j++)
-            localQR(i,j) = (j == i ? one : zero);
-      }
+            for (size_t k = 0; k < NSDim; k++)
+              if (k < as<size_t>(aggSize))
+                coarseNS[j][offset+k] = localQR(k,j);
+              else
+                coarseNS[j][offset+k] = (k == j ? one : zero);
 
-      // Process each row in the local Q factor
-      // FIXME: What happens if maps are blocked?
-      for (LO j = 0; j < aggSize; j++) {
-        LO localRow = (goodMap ? aggToRowMapLO[aggStart[agg]+j] : rowMap->getLocalElement(aggToRowMapGO[aggStart[agg]+j]));
+          // Q = I (rectangular)
+          for (size_t i = 0; i < as<size_t>(aggSize); i++)
+            for (size_t j = 0; j < NSDim; j++)
+              localQR(i,j) = (j == i ? one : zero);
+        }
 
-        size_t rowStart = ia[localRow];
-        for (size_t k = 0, lnnz = 0; k < NSDim; k++) {
-          // Skip zeros (there may be plenty of them, i.e., NSDim > 1 or boundary conditions)
-          if (localQR(j,k) != zero) {
-            ja [rowStart+lnnz] = offset + k;
-            val[rowStart+lnnz] = localQR(j,k);
-            lnnz++;
+
+        // Process each row in the local Q factor
+        // FIXME: What happens if maps are blocked?
+        for (LO j = 0; j < aggSize; j++) {
+          LO localRow = (goodMap ? aggToRowMapLO[aggStart[agg]+j] : rowMap->getLocalElement(aggToRowMapGO[aggStart[agg]+j]));
+
+          size_t rowStart = ia[localRow];
+          for (size_t k = 0, lnnz = 0; k < NSDim; k++) {
+            // Skip zeros (there may be plenty of them, i.e., NSDim > 1 or boundary conditions)
+            if (localQR(j,k) != zero) {
+              ja [rowStart+lnnz] = offset + k;
+              val[rowStart+lnnz] = localQR(j,k);
+              lnnz++;
+            }
           }
         }
       }
-    }
+
+    } else {
+      GetOStream(Runtime1) << "TentativePFactory : bypassing local QR phase" << std::endl;
+      if (NSDim>1)
+        GetOStream(Warnings0) << "TentativePFactor : for nontrivial nullspace, this may degrade performance" << std::endl;
+      /////////////////////////////
+      //      "no-QR" option     //
+      /////////////////////////////
+      // Local Q factor is just the fine nullspace support over the current aggregate.
+      // Local R factor is the identity.
+      // TODO I have not implemented any special handling for aggregates that are too
+      // TODO small to locally support the nullspace, as is done in the standard QR
+      // TODO case above.
+      if (goodMap) {
+        for (GO agg = 0; agg < numAggs; agg++) {
+          const LO aggSize = aggStart[agg+1] - aggStart[agg];
+          Xpetra::global_size_t offset = agg*NSDim;
+
+          // Process each row in the local Q factor
+          // FIXME: What happens if maps are blocked?
+          for (LO j = 0; j < aggSize; j++) {
+
+            //TODO Here I do not check for a zero nullspace column on the aggregate.
+            //     as is done in the standard QR case.
+
+            const LO localRow = aggToRowMapLO[aggStart[agg]+j];
+
+            const size_t rowStart = ia[localRow];
+
+            for (size_t k = 0, lnnz = 0; k < NSDim; k++) {
+              // Skip zeros (there may be plenty of them, i.e., NSDim > 1 or boundary conditions)
+              const SC qr_jk = fineNS[k][aggToRowMapLO[aggStart[agg]+j]];
+              if (qr_jk != zero) {
+                ja [rowStart+lnnz] = offset + k;
+                val[rowStart+lnnz] = qr_jk;
+                lnnz++;
+              }
+            }
+          }
+          for (size_t j = 0; j < NSDim; j++)
+            coarseNS[j][offset+j] = one;
+        } //for (GO agg = 0; agg < numAggs; agg++)
+
+      } else {
+        for (GO agg = 0; agg < numAggs; agg++) {
+          const LO aggSize = aggStart[agg+1] - aggStart[agg];
+          Xpetra::global_size_t offset = agg*NSDim;
+          for (LO j = 0; j < aggSize; j++) {
+
+            const LO localRow = rowMap->getLocalElement(aggToRowMapGO[aggStart[agg]+j]);
+
+            const size_t rowStart = ia[localRow];
+
+            for (size_t k = 0, lnnz = 0; k < NSDim; k++) {
+              // Skip zeros (there may be plenty of them, i.e., NSDim > 1 or boundary conditions)
+              const SC qr_jk = fineNS[k][rowMap->getLocalElement(aggToRowMapGO[aggStart[agg]+j])];
+              if (qr_jk != zero) {
+                ja [rowStart+lnnz] = offset + k;
+                val[rowStart+lnnz] = qr_jk;
+                lnnz++;
+              }
+            }
+          }
+          for (size_t j = 0; j < NSDim; j++)
+            coarseNS[j][offset+j] = one;
+        } //for (GO agg = 0; agg < numAggs; agg++)
+
+      } //if (goodmap) else ...
+
+    } //if doQRStep ... else
 
     // Compress storage (remove all INVALID, which happen when we skip zeros)
     // We do that in-place
@@ -364,7 +454,22 @@ namespace MueLu {
     GetOStream(Runtime1) << "TentativePFactory : aggregates do not cross process boundaries" << std::endl;
 
     PtentCrs->setAllValues(iaPtent, jaPtent, valPtent);
-    PtentCrs->expertStaticFillComplete(coarseMap, A->getDomainMap());
+
+
+    // Managing labels & constants for ESFC
+    RCP<ParameterList> FCparams;
+    if(pL.isSublist("matrixmatrix: kernel params")) 
+      FCparams=rcp(new ParameterList(pL.sublist("matrixmatrix: kernel params")));
+    else 
+      FCparams= rcp(new ParameterList);
+    // By default, we don't need global constants for TentativeP
+    FCparams->set("compute global constants",FCparams->get("compute global constants",false));
+    std::string levelIDs = toString(levelID);
+    FCparams->set("Timer Label",std::string("MueLu::TentativeP-")+levelIDs);
+    RCP<const Export> dummy_e;
+    RCP<const Import> dummy_i;
+
+    PtentCrs->expertStaticFillComplete(coarseMap, A->getDomainMap(),dummy_i,dummy_e,FCparams);
   }
 
   template <class Scalar,class LocalOrdinal, class GlobalOrdinal, class Node>
