@@ -409,11 +409,15 @@ int main_(int argc, char **argv) {
   execution_space::fence();
   Kokkos::Impl::Timer timer;
 
+#ifdef KOKKOS_HAVE_SERIAL
   if (typeid(device_type) == typeid(Kokkos::Serial)) {
     for (int i = 0; i < loop; i++)
       kernel_coalesce_drop_serial(A);
 
   } else {
+#else
+  {
+#endif
     for (int i = 0; i < loop; i++)
       kernel_coalesce_drop_device(A);
   }
@@ -455,21 +459,21 @@ int main(int argc, char* argv[]) {
 #ifdef KOKKOS_HAVE_SERIAL
     return main_<double,int,Kokkos::Serial>(argc, argv);
 #else
-    throw std::runtime_error("Serial node type is disabled");
+    std::cout << "Error: Serial node type is disabled" << std::endl;
 #endif
 
   } else if (node == "openmp") {
 #ifdef KOKKOS_HAVE_OPENMP
     return main_<double,int,Kokkos::OpenMP>(argc, argv);
 #else
-    throw std::runtime_error("OpenMP node type is disabled");
+    std::cout << "Error: OpenMP node type is disabled" << std::endl;
 #endif
 
   } else if (node == "cuda") {
 #ifdef KOKKOS_HAVE_CUDA
     return main_<double,int,Kokkos::Cuda>(argc, argv);
 #else
-    throw std::runtime_error("CUDA node type is disabled");
+    std::cout << "Error: CUDA node type is disabled" << std::endl;
 #endif
   }
 
