@@ -122,7 +122,7 @@ int main_(Teuchos::CommandLineProcessor &clp, int argc, char *argv[]) {
   double      dtol              = 1e-12, tol;        clp.setOption("tol",                   &dtol,              "solver convergence tolerance");
   bool        binaryFormat      = false;             clp.setOption("binary", "ascii",       &binaryFormat,      "print timings to screen");
 
-  std::string mapFile;                               clp.setOption("map",                   &mapFile,           "map data file");
+  std::string rowmapFile;                            clp.setOption("rowmap",                &rowmapFile,        "map data file");
   std::string colMapFile;                            clp.setOption("colmap",                &colMapFile,        "colmap data file");
   std::string domainMapFile;                         clp.setOption("domainmap",             &domainMapFile,     "domainmap data file");
   std::string rangeMapFile;                          clp.setOption("rangemap",              &rangeMapFile,      "rangemap data file");
@@ -165,6 +165,13 @@ int main_(Teuchos::CommandLineProcessor &clp, int argc, char *argv[]) {
   // Problem construction
   // =========================================================================
   std::ostringstream galeriStream;
+#ifdef HAVE_MUELU_OPENMP
+  std::string node_name = Node::name();
+  if(!comm->getRank() && !node_name.compare("OpenMP/Wrapper"))
+    galeriStream<<"OpenMP Max Threads = "<<omp_get_max_threads()<<std::endl;
+#endif
+
+
   comm->barrier();
   RCP<TimeMonitor> globalTimeMonitor = rcp(new TimeMonitor(*TimeMonitor::getNewTimer("Driver: S - Global Time")));
   RCP<TimeMonitor> tm                = rcp(new TimeMonitor(*TimeMonitor::getNewTimer("Driver: 1 - Matrix Build")));
@@ -235,8 +242,8 @@ int main_(Teuchos::CommandLineProcessor &clp, int argc, char *argv[]) {
     }
 
   } else {
-    if (!mapFile.empty())
-      map = Xpetra::IO<SC,LO,GO,Node>::ReadMap(mapFile, lib, comm);
+    if (!rowmapFile.empty())
+      map = Xpetra::IO<SC,LO,GO,Node>::ReadMap(rowmapFile, lib, comm);
     comm->barrier();
 
     if (!binaryFormat && !map.is_null()) {
@@ -294,6 +301,7 @@ int main_(Teuchos::CommandLineProcessor &clp, int argc, char *argv[]) {
 
   galeriStream << "Galeri complete.\n========================================================" << std::endl;
 
+
   int numReruns = 1;
   if (paramList.isParameter("number of reruns"))
     numReruns = paramList.get<int>("number of reruns");
