@@ -74,21 +74,18 @@
 #include "MueLu_EpetraOperator.hpp"
 #endif
 
+#if defined(HAVE_MUELU_EPETRA) && defined(HAVE_MUELU_SERIAL)
+
 #include "MueLu_UseDefaultTypes.hpp"
 
 namespace MueLuTests {
 
 #include "MueLu_UseShortNames.hpp"
 
-  typedef MueLu::Utils<SC,LO,GO,NO> Utils;
+  typedef MueLu::Utilities<SC,LO,GO,NO> Utils;
 
   TEUCHOS_UNIT_TEST(PetraOperator, CreatePreconditioner)
   {
-
-    typedef Tpetra::CrsMatrix<SC,LO,GO,NO> tpetra_crsmatrix_type;
-    typedef Tpetra::Operator<SC,LO,GO,NO> tpetra_operator_type;
-    typedef Tpetra::MultiVector<SC,LO,GO,NO> tpetra_multivector_type;
-
     out << "version: " << MueLu::Version() << std::endl;
 
     using Teuchos::RCP;
@@ -98,35 +95,38 @@ namespace MueLuTests {
 
     GO nx = 1000;
 
-    // Matrix
-    RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
-    RCP<const Map > map = Op->getRowMap();
-
-    // Normalized RHS
-    RCP<MultiVector> RHS1 = MultiVectorFactory::Build(map, 1);
-    RHS1->setSeed(846930886);
-    RHS1->randomize();
-    Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
-    RHS1->norm2(norms);
-    RHS1->scale(1/norms[0]);
-
-    // Zero initial guess
-    RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
-    X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
-
-#if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
-    Teuchos::ParameterList galeriList;
-    galeriList.set("nx", nx);
-    RCP<MultiVector> coordinates = Galeri::Xpetra::Utils::CreateCartesianCoordinates<SC,LO,GO,Map,MultiVector>("1D", Op->getRowMap(), galeriList);
-    RCP<MultiVector> nullspace   = Xpetra::MultiVectorFactory<SC,LO,GO,NO>::Build(Op->getDomainMap(), 1);
-    nullspace->putScalar(Teuchos::ScalarTraits<SC>::one());
-#endif
+    std::string xmlFileName = "test.xml";
 
     if (lib == Xpetra::UseTpetra) {
-#ifdef HAVE_MUELU_TPETRA
-      std::string xmlFileName = "test.xml";
+#if defined(HAVE_MUELU_TPETRA) && defined(HAVE_MUELU_TPETRA_INST_INT_INT)
+      typedef Tpetra::CrsMatrix<SC,LO,GO,NO> tpetra_crsmatrix_type;
+      typedef Tpetra::Operator<SC,LO,GO,NO> tpetra_operator_type;
+      typedef Tpetra::MultiVector<SC,LO,GO,NO> tpetra_multivector_type;
 
-      RCP<tpetra_crsmatrix_type> tpA = MueLu::Utils<SC,LO,GO,NO>::Op2NonConstTpetraCrs(Op);
+      // Matrix
+      RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
+      RCP<const Map > map = Op->getRowMap();
+
+      // Normalized RHS
+      RCP<MultiVector> RHS1 = MultiVectorFactory::Build(map, 1);
+      RHS1->setSeed(846930886);
+      RHS1->randomize();
+      Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+      RHS1->norm2(norms);
+      RHS1->scale(1/norms[0]);
+
+      // Zero initial guess
+      RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
+      X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
+
+#if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
+      Teuchos::ParameterList galeriList;
+      galeriList.set("nx", nx);
+      RCP<MultiVector> coordinates = Galeri::Xpetra::Utils::CreateCartesianCoordinates<SC,LO,GO,Map,MultiVector>("1D", Op->getRowMap(), galeriList);
+      RCP<MultiVector> nullspace   = Xpetra::MultiVectorFactory<SC,LO,GO,NO>::Build(Op->getDomainMap(), 1);
+      nullspace->putScalar(Teuchos::ScalarTraits<SC>::one());
+
+      RCP<tpetra_crsmatrix_type> tpA = MueLu::Utilities<SC,LO,GO,NO>::Op2NonConstTpetraCrs(Op);
 
       RCP<MueLu::TpetraOperator<SC,LO,GO,NO> > tH = MueLu::CreateTpetraPreconditioner<SC,LO,GO,NO>(RCP<tpetra_operator_type>(tpA), xmlFileName);
       tH->apply(*(Utils::MV2TpetraMV(RHS1)), *(Utils::MV2NonConstTpetraMV(X1)));
@@ -139,7 +139,6 @@ namespace MueLuTests {
       out << "after apply, ||b-A*x||_2 = " << std::setiosflags(std::ios::fixed) << std::setprecision(10) <<
           Utils::ResidualNorm(*Op, *X1, *RHS1) << std::endl;
 
-#if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
       xmlFileName = "testWithRebalance.xml";
 
       RCP<tpetra_multivector_type> tpcoordinates = Utils::MV2NonConstTpetraMV(coordinates);
@@ -187,14 +186,35 @@ namespace MueLuTests {
 #endif
 
 #else
-      TEUCHOS_TEST_FOR_EXCEPTION(true, MueLu::Exceptions::InvalidArgument, "Tpetra is not available");
-#endif
+      std::cout << "Skip PetraOperator::CreatePreconditioner: Tpetra is not available (with GO=int enabled)" << std::endl;
+#endif // #if defined(HAVE_MUELU_TPETRA) && defined(HAVE_MUELU_TPETRA_INST_INT_INT)
 
     } else if (lib == Xpetra::UseEpetra) {
 #ifdef HAVE_MUELU_EPETRA
-      std::string xmlFileName = "test.xml";
+      // Matrix
+      RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
+      RCP<const Map > map = Op->getRowMap();
 
-      RCP<Epetra_CrsMatrix> epA = MueLu::Utils<SC,LO,GO,NO>::Op2NonConstEpetraCrs(Op);
+      // Normalized RHS
+      RCP<MultiVector> RHS1 = MultiVectorFactory::Build(map, 1);
+      RHS1->setSeed(846930886);
+      RHS1->randomize();
+      Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+      RHS1->norm2(norms);
+      RHS1->scale(1/norms[0]);
+
+      // Zero initial guess
+      RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
+      X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
+
+#if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
+      Teuchos::ParameterList galeriList;
+      galeriList.set("nx", nx);
+      RCP<MultiVector> coordinates = Galeri::Xpetra::Utils::CreateCartesianCoordinates<SC,LO,GO,Map,MultiVector>("1D", Op->getRowMap(), galeriList);
+      RCP<MultiVector> nullspace   = Xpetra::MultiVectorFactory<SC,LO,GO,NO>::Build(Op->getDomainMap(), 1);
+      nullspace->putScalar(Teuchos::ScalarTraits<SC>::one());
+
+      RCP<Epetra_CrsMatrix> epA = Utils::Op2NonConstEpetraCrs(Op);
 
       RCP<MueLu::EpetraOperator> eH = MueLu::CreateEpetraPreconditioner(epA, xmlFileName);
 
@@ -202,7 +222,6 @@ namespace MueLuTests {
       out << "after apply, ||b-A*x||_2 = " << std::setiosflags(std::ios::fixed) << std::setprecision(10) <<
           Utils::ResidualNorm(*Op, *X1, *RHS1) << std::endl;
 
-#if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
       xmlFileName = "testWithRebalance.xml";
 
       RCP<Epetra_MultiVector> epcoordinates = Utils::MV2NonConstEpetraMV(coordinates);
@@ -224,7 +243,7 @@ namespace MueLuTests {
 #endif
 
 #else
-      TEUCHOS_TEST_FOR_EXCEPTION(true, MueLu::Exceptions::InvalidArgument, "Epetra is not available");
+      std::cout << "Skip PetraOperator::CreatePreconditioner: Epetra is not available" << std::endl;
 #endif
 
     } else {
@@ -237,8 +256,6 @@ namespace MueLuTests {
  TEUCHOS_UNIT_TEST(PetraOperator, CreatePreconditioner_XMLOnList)
   {
     out << "version: " << MueLu::Version() << std::endl;
-
-    typedef Tpetra::Operator<SC,LO,GO,NO> tpetra_operator_type;
     using Teuchos::RCP;
 
     Xpetra::UnderlyingLib          lib  = TestHelpers::Parameters::getLib();
@@ -246,36 +263,37 @@ namespace MueLuTests {
 
     GO nx = 1000;
 
-    // Matrix
-    RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
-    RCP<const Map > map = Op->getRowMap();
-
-    // Normalized RHS
-    RCP<MultiVector> RHS1 = MultiVectorFactory::Build(map, 1);
-    RHS1->setSeed(846930886);
-    RHS1->randomize();
-    Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
-    RHS1->norm2(norms);
-    RHS1->scale(1/norms[0]);
-
-    // Zero initial guess
-    RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
-    X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
-
-#if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
-    Teuchos::ParameterList galeriList;
-    galeriList.set("nx", nx);
-    RCP<MultiVector> coordinates = Galeri::Xpetra::Utils::CreateCartesianCoordinates<SC,LO,GO,Map,MultiVector>("1D", Op->getRowMap(), galeriList);
-    RCP<MultiVector> nullspace   = Xpetra::MultiVectorFactory<SC,LO,GO,NO>::Build(Op->getDomainMap(), 1);
-    nullspace->putScalar(Teuchos::ScalarTraits<SC>::one());
-#endif
+    Teuchos::ParameterList mylist;
+    mylist.set("xml parameter file","test.xml");
 
     if (lib == Xpetra::UseTpetra) {
-#ifdef HAVE_MUELU_TPETRA
-      Teuchos::ParameterList mylist;
-      mylist.set("xml parameter file","test.xml");
+#if defined(HAVE_MUELU_TPETRA) && defined(HAVE_MUELU_TPETRA_INST_INT_INT)
+      typedef Tpetra::Operator<SC,LO,GO,NO> tpetra_operator_type;
 
-      RCP<Tpetra::CrsMatrix<SC,LO,GO,NO> > tpA = MueLu::Utils<SC,LO,GO,NO>::Op2NonConstTpetraCrs(Op);
+      // Matrix
+      RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
+      RCP<const Map > map = Op->getRowMap();
+
+      // Normalized RHS
+      RCP<MultiVector> RHS1 = MultiVectorFactory::Build(map, 1);
+      RHS1->setSeed(846930886);
+      RHS1->randomize();
+      Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+      RHS1->norm2(norms);
+      RHS1->scale(1/norms[0]);
+
+      // Zero initial guess
+      RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
+      X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
+
+#if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
+      Teuchos::ParameterList galeriList;
+      galeriList.set("nx", nx);
+      RCP<MultiVector> coordinates = Galeri::Xpetra::Utils::CreateCartesianCoordinates<SC,LO,GO,Map,MultiVector>("1D", Op->getRowMap(), galeriList);
+      RCP<MultiVector> nullspace   = Xpetra::MultiVectorFactory<SC,LO,GO,NO>::Build(Op->getDomainMap(), 1);
+      nullspace->putScalar(Teuchos::ScalarTraits<SC>::one());
+
+      RCP<Tpetra::CrsMatrix<SC,LO,GO,NO> > tpA = MueLu::Utilities<SC,LO,GO,NO>::Op2NonConstTpetraCrs(Op);
 
       RCP<MueLu::TpetraOperator<SC,LO,GO,NO> > tH = MueLu::CreateTpetraPreconditioner<SC,LO,GO,NO>(RCP<tpetra_operator_type>(tpA),mylist);
       tH->apply(*(Utils::MV2TpetraMV(RHS1)), *(Utils::MV2NonConstTpetraMV(X1)));
@@ -288,7 +306,6 @@ namespace MueLuTests {
       out << "after apply, ||b-A*x||_2 = " << std::setiosflags(std::ios::fixed) << std::setprecision(10) <<
           Utils::ResidualNorm(*Op, *X1, *RHS1) << std::endl;
 
-#if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
       mylist.set("xml parameter file","testWithRebalance.xml");
 
       RCP<Tpetra::MultiVector<SC,LO,GO,NO> > tpcoordinates = Utils::MV2NonConstTpetraMV(coordinates);
@@ -322,16 +339,35 @@ namespace MueLuTests {
 #endif
 
 #else
-      TEUCHOS_TEST_FOR_EXCEPTION(true, MueLu::Exceptions::InvalidArgument, "Tpetra is not available");
-#endif
+      std::cout << "Skip PetraOperator::CreatePreconditioner_XMLOnList: Tpetra is not available (with GO=int enabled)" << std::endl;
+#endif // #if defined(HAVE_MUELU_TPETRA) && defined(HAVE_MUELU_TPETRA_INST_INT_INT)
 
     } else if (lib == Xpetra::UseEpetra) {
 #ifdef HAVE_MUELU_EPETRA
-      Teuchos::ParameterList mylist;
-      mylist.set("xml parameter file","test.xml");
+      // Matrix
+      RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
+      RCP<const Map > map = Op->getRowMap();
 
+      // Normalized RHS
+      RCP<MultiVector> RHS1 = MultiVectorFactory::Build(map, 1);
+      RHS1->setSeed(846930886);
+      RHS1->randomize();
+      Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+      RHS1->norm2(norms);
+      RHS1->scale(1/norms[0]);
 
-      RCP<Epetra_CrsMatrix> epA = MueLu::Utils<SC,LO,GO,NO>::Op2NonConstEpetraCrs(Op);
+      // Zero initial guess
+      RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
+      X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
+
+#if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
+      Teuchos::ParameterList galeriList;
+      galeriList.set("nx", nx);
+      RCP<MultiVector> coordinates = Galeri::Xpetra::Utils::CreateCartesianCoordinates<SC,LO,GO,Map,MultiVector>("1D", Op->getRowMap(), galeriList);
+      RCP<MultiVector> nullspace   = Xpetra::MultiVectorFactory<SC,LO,GO,NO>::Build(Op->getDomainMap(), 1);
+      nullspace->putScalar(Teuchos::ScalarTraits<SC>::one());
+
+      RCP<Epetra_CrsMatrix> epA = Utils::Op2NonConstEpetraCrs(Op);
 
       RCP<MueLu::EpetraOperator> eH = MueLu::CreateEpetraPreconditioner(epA, mylist);
 
@@ -339,7 +375,6 @@ namespace MueLuTests {
       out << "after apply, ||b-A*x||_2 = " << std::setiosflags(std::ios::fixed) << std::setprecision(10) <<
           Utils::ResidualNorm(*Op, *X1, *RHS1) << std::endl;
 
-#if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
       mylist.set("xml parameter file","testWithRebalance.xml");
 
       RCP<Epetra_MultiVector> epcoordinates = Utils::MV2NonConstEpetraMV(coordinates);
@@ -361,7 +396,7 @@ namespace MueLuTests {
 #endif
 
 #else
-      TEUCHOS_TEST_FOR_EXCEPTION(true, MueLu::Exceptions::InvalidArgument, "Epetra is not available");
+      std::cout << "Skip PetraOperator::CreatePreconditioner_XMLOnList: Epetra is not available" << std::endl;
 #endif
 
     } else {
@@ -374,49 +409,48 @@ namespace MueLuTests {
   TEUCHOS_UNIT_TEST(PetraOperator, CreatePreconditioner_PDESystem)
   {
     out << "version: " << MueLu::Version() << std::endl;
-
-    typedef Tpetra::Operator<SC,LO,GO,NO> tpetra_operator_type;
     using Teuchos::RCP;
 
-
     Xpetra::UnderlyingLib          lib  = TestHelpers::Parameters::getLib();
     RCP<const Teuchos::Comm<int> > comm = TestHelpers::Parameters::getDefaultComm();
 
     GO nx = 972;
 
-    // Matrix
-    RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
-    RCP<const Map > map = Op->getRowMap();
-
 #if defined(HAVE_MUELU_ZOLTAN) && defined(HAVE_MPI)
-    Teuchos::ParameterList clist;
-    clist.set("nx", (nx * comm->getSize())/3);
-    RCP<const Map>   cmap        = MapFactory::Build(lib, Teuchos::as<size_t>((nx * comm->getSize())/3), Teuchos::as<int>(0), comm);
-    RCP<MultiVector> coordinates = Galeri::Xpetra::Utils::CreateCartesianCoordinates<SC,LO,GO,Map,MultiVector>("1D", cmap, clist);
-    RCP<MultiVector> nullspace   = Xpetra::MultiVectorFactory<SC,LO,GO,NO>::Build(Op->getDomainMap(), 1);
-    nullspace->putScalar(Teuchos::ScalarTraits<SC>::one());
-
 
     for (int k = 0; k < 2; k++) {
       std::string xmlFileName;
       if (k == 0) xmlFileName = "testPDE.xml";
       if (k == 1) xmlFileName = "testPDE1.xml";
 
-      // Normalized RHS
-      RCP<MultiVector> RHS1 = MultiVectorFactory::Build(Op->getRowMap(), 1);
-      RHS1->setSeed(846930886);
-      RHS1->randomize();
-      Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
-      RHS1->norm2(norms);
-      RHS1->scale(1/norms[0]);
-
-      // Zero initial guess
-      RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
-      X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
-
       if (lib == Xpetra::UseTpetra) {
-#ifdef HAVE_MUELU_TPETRA
-        RCP<Tpetra::CrsMatrix<SC,LO,GO,NO> >   tpA           = MueLu::Utils<SC,LO,GO,NO>::Op2NonConstTpetraCrs(Op);
+#if defined(HAVE_MUELU_TPETRA) && defined(HAVE_MUELU_TPETRA_INST_INT_INT)
+        typedef Tpetra::Operator<SC,LO,GO,NO> tpetra_operator_type;
+
+        // Matrix
+        RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
+        RCP<const Map > map = Op->getRowMap();
+
+        Teuchos::ParameterList clist;
+        clist.set("nx", (nx * comm->getSize())/3);
+        RCP<const Map>   cmap        = MapFactory::Build(lib, Teuchos::as<size_t>((nx * comm->getSize())/3), Teuchos::as<int>(0), comm);
+        RCP<MultiVector> coordinates = Galeri::Xpetra::Utils::CreateCartesianCoordinates<SC,LO,GO,Map,MultiVector>("1D", cmap, clist);
+        RCP<MultiVector> nullspace   = Xpetra::MultiVectorFactory<SC,LO,GO,NO>::Build(Op->getDomainMap(), 1);
+        nullspace->putScalar(Teuchos::ScalarTraits<SC>::one());
+
+        // Normalized RHS
+        RCP<MultiVector> RHS1 = MultiVectorFactory::Build(Op->getRowMap(), 1);
+        RHS1->setSeed(846930886);
+        RHS1->randomize();
+        Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+        RHS1->norm2(norms);
+        RHS1->scale(1/norms[0]);
+
+        // Zero initial guess
+        RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
+        X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
+
+        RCP<Tpetra::CrsMatrix<SC,LO,GO,NO> >   tpA           = MueLu::Utilities<SC,LO,GO,NO>::Op2NonConstTpetraCrs(Op);
         RCP<Tpetra::MultiVector<SC,LO,GO,NO> > tpcoordinates = Utils::MV2NonConstTpetraMV(coordinates);
         RCP<Tpetra::MultiVector<SC,LO,GO,NO> > tpnullspace   = Utils::MV2NonConstTpetraMV(nullspace);
 
@@ -437,19 +471,42 @@ namespace MueLuTests {
         out << "after apply, ||b-A*x||_2 = " << std::setiosflags(std::ios::fixed) << std::setprecision(10) <<
             Utils::ResidualNorm(*Op, *X1, *RHS1) << std::endl;
 
-      out << "Testing deprecated method" << std::endl;
+        out << "Testing deprecated method" << std::endl;
         tH = MueLu::CreateTpetraPreconditioner<SC,LO,GO,NO>(tpA, xmlFileName, tpcoordinates, tpnullspace);
         X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
         tH->apply(*(Utils::MV2TpetraMV(RHS1)), *(Utils::MV2NonConstTpetraMV(X1)));
         out << "after apply, ||b-A*x||_2 = " << std::setiosflags(std::ios::fixed) << std::setprecision(10) <<
             Utils::ResidualNorm(*Op, *X1, *RHS1) << std::endl;
 #else
-        TEUCHOS_TEST_FOR_EXCEPTION(true, MueLu::Exceptions::InvalidArgument, "Tpetra is not available");
-#endif
+        std::cout << "Skip PetraOperator::CreatePreconditioner_PDESystem: Tpetra is not available (with GO=int enabled)" << std::endl;
+#endif // #if defined(HAVE_MUELU_TPETRA) && defined(HAVE_MUELU_TPETRA_INST_INT_INT)
 
       } else if (lib == Xpetra::UseEpetra) {
 #ifdef HAVE_MUELU_EPETRA
-        RCP<Epetra_CrsMatrix>   epA           = MueLu::Utils<SC,LO,GO,NO>::Op2NonConstEpetraCrs(Op);
+        // Matrix
+        RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
+        RCP<const Map > map = Op->getRowMap();
+
+        Teuchos::ParameterList clist;
+        clist.set("nx", (nx * comm->getSize())/3);
+        RCP<const Map>   cmap        = MapFactory::Build(lib, Teuchos::as<size_t>((nx * comm->getSize())/3), Teuchos::as<int>(0), comm);
+        RCP<MultiVector> coordinates = Galeri::Xpetra::Utils::CreateCartesianCoordinates<SC,LO,GO,Map,MultiVector>("1D", cmap, clist);
+        RCP<MultiVector> nullspace   = Xpetra::MultiVectorFactory<SC,LO,GO,NO>::Build(Op->getDomainMap(), 1);
+        nullspace->putScalar(Teuchos::ScalarTraits<SC>::one());
+
+        // Normalized RHS
+        RCP<MultiVector> RHS1 = MultiVectorFactory::Build(Op->getRowMap(), 1);
+        RHS1->setSeed(846930886);
+        RHS1->randomize();
+        Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+        RHS1->norm2(norms);
+        RHS1->scale(1/norms[0]);
+
+        // Zero initial guess
+        RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
+        X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
+
+        RCP<Epetra_CrsMatrix>   epA           = MueLu::Utilities<SC,LO,GO,NO>::Op2NonConstEpetraCrs(Op);
         RCP<Epetra_MultiVector> epcoordinates = Utils::MV2NonConstEpetraMV(coordinates);
         RCP<Epetra_MultiVector> epnullspace   = Utils::MV2NonConstEpetraMV(nullspace);
 
@@ -466,7 +523,7 @@ namespace MueLuTests {
         out << "after apply, ||b-A*x||_2 = " << std::setiosflags(std::ios::fixed) << std::setprecision(10) <<
             Utils::ResidualNorm(*Op, *X1, *RHS1) << std::endl;
 #else
-        TEUCHOS_TEST_FOR_EXCEPTION(true, MueLu::Exceptions::InvalidArgument, "Epetra is not available");
+        std::cout << "Skip PetraOperator::CreatePreconditioner_PDESystem: Epetra is not available" << std::endl;
 #endif
       } else {
         TEUCHOS_TEST_FOR_EXCEPTION(true, MueLu::Exceptions::InvalidArgument, "Unknown Xpetra lib");
@@ -478,35 +535,35 @@ namespace MueLuTests {
   TEUCHOS_UNIT_TEST(PetraOperator, ReusePreconditioner)
   {
     out << "version: " << MueLu::Version() << std::endl;
-
-    typedef Tpetra::Operator<SC,LO,GO,NO> tpetra_operator_type;
     using Teuchos::RCP;
 
     Xpetra::UnderlyingLib          lib  = TestHelpers::Parameters::getLib();
     RCP<const Teuchos::Comm<int> > comm = TestHelpers::Parameters::getDefaultComm();
 
     GO nx = 1000;
-
-    // Matrix
-    RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
-    RCP<const Map > map = Op->getRowMap();
-
-    // Normalized RHS
-    RCP<MultiVector> RHS1 = MultiVectorFactory::Build(Op->getRowMap(), 1);
-    RHS1->setSeed(846930886);
-    RHS1->randomize();
-    Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
-    RHS1->norm2(norms);
-    RHS1->scale(1/norms[0]);
-
-    // Zero initial guess
-    RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
-    X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
-
     std::string xmlFileName = "testReuse.xml";
+
     if (lib == Xpetra::UseTpetra) {
-#ifdef HAVE_MUELU_TPETRA
-      RCP<Tpetra::CrsMatrix<SC,LO,GO,NO> > tpA = MueLu::Utils<SC,LO,GO,NO>::Op2NonConstTpetraCrs(Op);
+#if defined(HAVE_MUELU_TPETRA) && defined(HAVE_MUELU_TPETRA_INST_INT_INT)
+      typedef Tpetra::Operator<SC,LO,GO,NO> tpetra_operator_type;
+
+      // Matrix
+      RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
+      RCP<const Map > map = Op->getRowMap();
+
+      // Normalized RHS
+      RCP<MultiVector> RHS1 = MultiVectorFactory::Build(Op->getRowMap(), 1);
+      RHS1->setSeed(846930886);
+      RHS1->randomize();
+      Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+      RHS1->norm2(norms);
+      RHS1->scale(1/norms[0]);
+
+      // Zero initial guess
+      RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
+      X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
+
+      RCP<Tpetra::CrsMatrix<SC,LO,GO,NO> > tpA = MueLu::Utilities<SC,LO,GO,NO>::Op2NonConstTpetraCrs(Op);
 
       RCP<MueLu::TpetraOperator<SC,LO,GO,NO> > tH = MueLu::CreateTpetraPreconditioner<SC,LO,GO,NO>(RCP<tpetra_operator_type>(tpA), xmlFileName);
       tH->apply(*(Utils::MV2TpetraMV(RHS1)), *(Utils::MV2NonConstTpetraMV(X1)));
@@ -527,12 +584,28 @@ namespace MueLuTests {
       out << "after apply, ||b-A*x||_2 = " << std::setiosflags(std::ios::fixed) << std::setprecision(10) <<
           Utils::ResidualNorm(*Op, *X1, *RHS1) << std::endl;
 #else
-      TEUCHOS_TEST_FOR_EXCEPTION(true, MueLu::Exceptions::InvalidArgument, "Tpetra is not available");
-#endif
+      std::cout << "Skip PetraOperator::ReusePreconditioner: Tpetra is not available (with GO=int enabled)" << std::endl;
+#endif // #if defined(HAVE_MUELU_TPETRA) && defined(HAVE_MUELU_TPETRA_INST_INT_INT)
 
     } else if (lib == Xpetra::UseEpetra) {
 #ifdef HAVE_MUELU_EPETRA
-      RCP<Epetra_CrsMatrix> epA = MueLu::Utils<SC,LO,GO,NO>::Op2NonConstEpetraCrs(Op);
+      // Matrix
+      RCP<Matrix>     Op  = TestHelpers::TestFactory<SC, LO, GO, NO>::Build1DPoisson(nx * comm->getSize(), lib);
+      RCP<const Map > map = Op->getRowMap();
+
+      // Normalized RHS
+      RCP<MultiVector> RHS1 = MultiVectorFactory::Build(Op->getRowMap(), 1);
+      RHS1->setSeed(846930886);
+      RHS1->randomize();
+      Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+      RHS1->norm2(norms);
+      RHS1->scale(1/norms[0]);
+
+      // Zero initial guess
+      RCP<MultiVector> X1   = MultiVectorFactory::Build(Op->getRowMap(), 1);
+      X1->putScalar(Teuchos::ScalarTraits<SC>::zero());
+
+      RCP<Epetra_CrsMatrix> epA = MueLu::Utilities<SC,LO,GO,NO>::Op2NonConstEpetraCrs(Op);
 
       RCP<MueLu::EpetraOperator> eH = MueLu::CreateEpetraPreconditioner(epA, xmlFileName);
 
@@ -548,7 +621,7 @@ namespace MueLuTests {
       out << "after apply, ||b-A*x||_2 = " << std::setiosflags(std::ios::fixed) << std::setprecision(10) <<
           Utils::ResidualNorm(*Op, *X1, *RHS1) << std::endl;
 #else
-      TEUCHOS_TEST_FOR_EXCEPTION(true, MueLu::Exceptions::InvalidArgument, "Epetra is not available");
+      std::cout << "Skip PetraOperator::ReusePreconditioner: Epetra is not available" << std::endl;
 #endif
 
     } else {
@@ -557,3 +630,5 @@ namespace MueLuTests {
   }
 
 }//namespace MueLuTests
+
+#endif // HAVE_MUELU_EPETRA && HAVE_MUELU_SERIAL
