@@ -71,6 +71,7 @@
 #include <MueLu_TransPFactory.hpp>
 #include <MueLu_TrilinosSmoother.hpp>
 #include <MueLu_DirectSolver.hpp>
+#include <MueLu_CreateXpetraPreconditioner.hpp>
 
 #ifdef HAVE_MUELU_KOKKOSCORE
 #include <KokkosCompat_ClassicNodeAPI_Wrapper.hpp>
@@ -91,6 +92,57 @@ namespace MueLuTests {
 
   } //Constructor
 
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(Hierarchy, DescriptionCaching, Scalar, LocalOrdinal, GlobalOrdinal, Node)
+  {
+#   include <MueLu_UseShortNames.hpp>
+    /*
+     * Test to confirm that Hierarchy::description():
+     * a) gives the same result before and after a call to SetupRe() when the number of levels has not changed
+     * b) gives a different result before and after a call to SetupRe() when the number of levels has changed
+     *
+     * The occasion for this test is the introduction of caching for the result of description(), to avoid redundant
+     * computation.
+     */
+    MUELU_TESTING_SET_OSTREAM;
+    MUELU_TESTING_LIMIT_SCOPE(Scalar,GlobalOrdinal,Node);
+    out << "version: " << MueLu::Version() << std::endl;
+
+    RCP<const Teuchos::Comm<int> > comm = TestHelpers::Parameters::getDefaultComm();
+    int numRows = 399;
+    RCP<Matrix> A = TestHelpers::TestFactory<Scalar, LocalOrdinal, GlobalOrdinal, Node>::Build1DPoisson(numRows);
+
+    Teuchos::ParameterList MueLuList;
+    MueLuList.set("verbosity","none");
+    //MueLuList.set("verbosity","high");
+    MueLuList.set("coarse: max size",numRows-1); // make it so we want two levels
+    MueLuList.set("max levels",2);
+
+    Teuchos::RCP<MueLu::Hierarchy<Scalar,LocalOrdinal,GlobalOrdinal,Node> > H =
+        MueLu::CreateXpetraPreconditioner<Scalar,LocalOrdinal,GlobalOrdinal,Node>(
+            A, MueLuList, Teuchos::null, Teuchos::null);
+
+    // confirm that we did get a hierarchy with two levels -- a sanity check for this test
+    TEST_EQUALITY(2, H->GetGlobalNumLevels());
+    
+    using namespace std;
+    string descriptionTwoLevel = H->description();
+
+    // SetupRe() will reset description, but since we haven't changed anything, the result from description() should not change
+    H->SetupRe();
+    string descriptionActual = H->description();
+    TEST_EQUALITY(descriptionActual,descriptionTwoLevel);
+
+    // now, we allow a larger coarse size; we should get just one level during SetupRe()
+    H->SetMaxCoarseSize(numRows+1);
+    H->SetupRe();
+    // as a sanity check for the test, make sure that we do have just one level
+    TEST_EQUALITY(1, H->GetGlobalNumLevels());
+    descriptionActual = H->description();
+
+    // since the number of levels has changed, the new description should differ from the old
+    TEST_INEQUALITY(descriptionActual, descriptionTwoLevel);
+  }//DescriptionCaching
+
   TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(Hierarchy, SetAndGetLevel, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
 #   include <MueLu_UseShortNames.hpp>
@@ -293,7 +345,7 @@ namespace MueLuTests {
     RCP<SaPFactory>         Pfact = rcp( new SaPFactory() );
     RCP<TransPFactory>      Rfact = rcp( new TransPFactory());
     RCP<RAPFactory>         Acfact = rcp( new RAPFactory() );
-    ParameterList Aclist = *(Acfact->GetValidParameterList());
+    Teuchos::ParameterList Aclist = *(Acfact->GetValidParameterList());
     Aclist.set("transpose: use implicit", true);
     Acfact->SetParameterList(Aclist);
 
@@ -880,7 +932,7 @@ namespace MueLuTests {
 
     // Build block SGS smoother
     std::string ifpack2Type;
-    ParameterList ifpack2List;
+    Teuchos::ParameterList ifpack2List;
     ifpack2Type = "RBILUK";
     out << ifpack2Type << std::endl;
     RCP<SmootherPrototype> smooProto = Teuchos::rcp( new Ifpack2Smoother(ifpack2Type) );
@@ -939,6 +991,7 @@ namespace MueLuTests {
 
 # define MUELU_ETI_GROUP(Scalar, LO, GO, Node) \
     TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(Hierarchy, Constructor, Scalar, LO, GO, Node) \
+    TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(Hierarchy, DescriptionCaching, Scalar, LO, GO, Node) \
     TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(Hierarchy, SetAndGetLevel, Scalar, LO, GO, Node) \
     TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(Hierarchy, GetNumLevels, Scalar, LO, GO, Node) \
     TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(Hierarchy, KeepAggregates, Scalar, LO, GO, Node) \
