@@ -53,30 +53,29 @@
 #include <Teuchos_UnitTestHarness.hpp>
 #include <Teuchos_DefaultComm.hpp>
 
-#include "MueLu_TestHelpers.hpp"
-#include "MueLu_Version.hpp"
+#include <MueLu_TestHelpers.hpp>
+#include <MueLu_Version.hpp>
 
 #include <Xpetra_MultiVectorFactory.hpp>
 #include <Xpetra_MatrixMatrix.hpp>
 
-#include "MueLu_TentativePFactory.hpp"
-#include "MueLu_PgPFactory.hpp"
-#include "MueLu_GenericRFactory.hpp"
-#include "MueLu_TransPFactory.hpp"
-#include "MueLu_TrilinosSmoother.hpp"
-#include "MueLu_CoupledAggregationFactory.hpp"
-#include "MueLu_RAPFactory.hpp"
-#include "MueLu_SmootherFactory.hpp"
-#include "MueLu_Utilities.hpp"
-
-#include "MueLu_UseDefaultTypes.hpp"
+#include <MueLu_TentativePFactory.hpp>
+#include <MueLu_PgPFactory.hpp>
+#include <MueLu_GenericRFactory.hpp>
+#include <MueLu_TransPFactory.hpp>
+#include <MueLu_TrilinosSmoother.hpp>
+#include <MueLu_CoupledAggregationFactory.hpp>
+#include <MueLu_RAPFactory.hpp>
+#include <MueLu_SmootherFactory.hpp>
+#include <MueLu_Utilities.hpp>
 
 namespace MueLuTests {
 
-#include "MueLu_UseShortNames.hpp"
-
-  TEUCHOS_UNIT_TEST(PgPFactory, Test0)
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(PgPFactory, Test0, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
+#   include <MueLu_UseShortNames.hpp>
+    MUELU_TESTING_SET_OSTREAM;
+    MUELU_TESTING_LIMIT_SCOPE(Scalar,GlobalOrdinal,Node);
     out << "version: " << MueLu::Version() << std::endl;
 
     RCP<PgPFactory> pgpFactory = rcp(new PgPFactory);
@@ -85,36 +84,44 @@ namespace MueLuTests {
     out << *pgpFactory << std::endl;
   }
 
-  TEUCHOS_UNIT_TEST(PgPFactory, nonsymExample)
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(PgPFactory, nonsymExample, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
+#   if defined(IFPACK) && defined(IFPACK2)
+#   include <MueLu_UseShortNames.hpp>
+    MUELU_TESTING_SET_OSTREAM;
+    MUELU_TESTING_LIMIT_SCOPE(Scalar,GlobalOrdinal,Node);
+    out << "Skipping test because not all required packages are enabled (Ifpack, Ifpack2)." << std::endl;
+    return;
     out << "version: " << MueLu::Version() << std::endl;
     out << "Test PgPFactory within" << std::endl;
     out << "level AMG solver using Petrov Galerkin smoothed aggregation with" << std::endl;
     out << "one SGS sweep on each multigrid level as pre- and postsmoother" << std::endl;
 
+    typedef typename Teuchos::ScalarTraits<SC>::magnitudeType magnitude_type;
+
     RCP<const Teuchos::Comm<int> > comm = Teuchos::DefaultComm<int>::getComm();
 
-    Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> results(2);
+    Teuchos::Array<magnitude_type> results(2);
 
     // used Xpetra lib (for maps and smoothers)
     Xpetra::UnderlyingLib lib = MueLuTests::TestHelpers::Parameters::getLib();
 
     // generate problem
-    LO maxLevels = 3;
-    LO its=10;
-    LO nEle = 63;
+    LocalOrdinal maxLevels = 3;
+    LocalOrdinal its=10;
+    LocalOrdinal nEle = 63;
     const RCP<const Map> map = MapFactory::Build(lib, nEle, 0, comm);
     Teuchos::ParameterList matrixParameters;
     matrixParameters.set("nx",nEle);
 
     // create nonsymmetric tridiagonal matrix
     Scalar epsilon = 1e-3;
-    RCP<Matrix> Op = Galeri::Xpetra::TriDiag<SC,LO,GO,Map,CrsMatrixWrap>(map, nEle, 1.0, 1.0-epsilon, epsilon);
+    RCP<Matrix> Op = Galeri::Xpetra::TriDiag<SC,LocalOrdinal,GlobalOrdinal,Map,CrsMatrixWrap>(map, nEle, 1.0, 1.0-epsilon, epsilon);
 
     // build nullspace
     RCP<MultiVector> nullSpace = MultiVectorFactory::Build(map,1);
     nullSpace->putScalar( (SC) 1.0);
-    Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+    Teuchos::Array<magnitude_type> norms(1);
     nullSpace->norm1(norms);
     if (comm->getRank() == 0)
       out << "||NS|| = " << norms[0] << std::endl;
@@ -144,7 +151,7 @@ namespace MueLuTests {
     // setup smoothers
     Teuchos::ParameterList smootherParamList;
     smootherParamList.set("relaxation: type", "Symmetric Gauss-Seidel");
-    smootherParamList.set("relaxation: sweeps", (LO) 1);
+    smootherParamList.set("relaxation: sweeps", (LocalOrdinal) 1);
     smootherParamList.set("relaxation: damping factor", (SC) 1.0);
     RCP<SmootherPrototype> smooProto = rcp( new TrilinosSmoother("RELAXATION", smootherParamList) );
     RCP<SmootherFactory> SmooFact = rcp( new SmootherFactory(smooProto) );
@@ -255,21 +262,26 @@ namespace MueLuTests {
       if (comm->getRank() == 0)
         out << "||X_" << std::setprecision(2) << its << "|| = " << std::setiosflags(std::ios::fixed) << std::setprecision(10) << norms[0] << std::endl;
     }
-
-  } //EpetraVsTpetra
+#   else
+    out << "Skipping test because some required packages are not enabled (Ifpack, Ifpack2)." << std::endl;
+#   endif
+  } //nonsymExample
 
 
 #if 0
-  TEUCHOS_UNIT_TEST(PgPFactory, NonStandardMaps)
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(PgPFactory, NonStandardMaps, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
+#   include <MueLu_UseShortNames.hpp>
+    MUELU_TESTING_SET_OSTREAM;
+    MUELU_TESTING_LIMIT_SCOPE(Scalar,GlobalOrdinal,Node);
     RCP<const Teuchos::Comm<int> > comm = Teuchos::DefaultComm<int>::getComm();
     Xpetra::UnderlyingLib lib = MueLuTests::TestHelpers::Parameters::getLib();
 
     // generate problem
-    LO maxLevels = 3;
-    //LO its=10;
-    GO nEle = 63;
-    GO nIndexBase = 10;
+    LocalOrdinal maxLevels = 3;
+    //LocalOrdinal its=10;
+    GlobalOrdinal nEle = 63;
+    GlobalOrdinal nIndexBase = 10;
     const RCP<const Map> map = MapFactory::Build(lib, nEle, nIndexBase, comm);
 
     RCP<CrsMatrixWrap> mtx = Galeri::Xpetra::MatrixTraits<Map,CrsMatrixWrap>::Build(map, 3);
@@ -363,7 +375,7 @@ namespace MueLuTests {
     // setup smoothers
     Teuchos::ParameterList smootherParamList;
     smootherParamList.set("relaxation: type", "Symmetric Gauss-Seidel");
-    smootherParamList.set("relaxation: sweeps", (LO) 1);
+    smootherParamList.set("relaxation: sweeps", (LocalOrdinal) 1);
     smootherParamList.set("relaxation: damping factor", (SC) 1.0);
     RCP<SmootherPrototype> smooProto = rcp( new TrilinosSmoother("RELAXATION", smootherParamList) );
     RCP<SmootherFactory> SmooFact = rcp( new SmootherFactory(smooProto) );
@@ -437,8 +449,11 @@ namespace MueLuTests {
   }
 #endif
 
-  TEUCHOS_UNIT_TEST(PgPFactory, MinimizationModes)
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(PgPFactory, MinimizationModes, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
+#   include <MueLu_UseShortNames.hpp>
+    MUELU_TESTING_SET_OSTREAM;
+    MUELU_TESTING_LIMIT_SCOPE(Scalar,GlobalOrdinal,Node);
     out << "version: " << MueLu::Version() << std::endl;
     out << "Test PgPFactory (minimization modes)" << std::endl;
 
@@ -454,8 +469,11 @@ namespace MueLuTests {
   }
 
 #if 0 // TODO check me
-  TEUCHOS_UNIT_TEST(PgPFactory, ColumnBasedOmegas)
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(PgPFactory, ColumnBasedOmegas, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
+#   include <MueLu_UseShortNames.hpp>
+    MUELU_TESTING_SET_OSTREAM;
+    MUELU_TESTING_LIMIT_SCOPE(Scalar,GlobalOrdinal,Node);
     out << "version: " << MueLu::Version() << std::endl;
     out << "Test PgPFactory (column based omegas)" << std::endl;
 
@@ -466,15 +484,15 @@ namespace MueLuTests {
     Xpetra::UnderlyingLib lib = MueLuTests::TestHelpers::Parameters::getLib();
 
     // generate problem
-    LO maxLevels = 3;
-    LO its=10;
-    LO nEle = 63;
+    LocalOrdinal maxLevels = 3;
+    LocalOrdinal its=10;
+    LocalOrdinal nEle = 63;
     const RCP<const Map> map = MapFactory::Build(lib, nEle, 0, comm);
     Teuchos::ParameterList matrixParameters;
     matrixParameters.set("nx",nEle);
 
     // create nonsymmetric tridiagonal matrix
-    RCP<Matrix> Op = Galeri::Xpetra::TriDiag<SC,LO,GO,Map,CrsMatrixWrap>(map, nEle, 2.0, -1.0, -1.0);
+    RCP<Matrix> Op = Galeri::Xpetra::TriDiag<SC,LocalOrdinal,GlobalOrdinal,Map,CrsMatrixWrap>(map, nEle, 2.0, -1.0, -1.0);
 
     // build nullspace
     RCP<MultiVector> nullSpace = MultiVectorFactory::Build(map,1);
@@ -512,7 +530,7 @@ namespace MueLuTests {
     // setup smoothers
     Teuchos::ParameterList smootherParamList;
     smootherParamList.set("relaxation: type", "Symmetric Gauss-Seidel");
-    smootherParamList.set("relaxation: sweeps", (LO) 1);
+    smootherParamList.set("relaxation: sweeps", (LocalOrdinal) 1);
     smootherParamList.set("relaxation: damping factor", (SC) 1.0);
     RCP<SmootherPrototype> smooProto = rcp( new TrilinosSmoother("RELAXATION", smootherParamList) );
     RCP<SmootherFactory> SmooFact = rcp( new SmootherFactory(smooProto) );
@@ -615,31 +633,39 @@ namespace MueLuTests {
   }
 #endif
 
-  TEUCHOS_UNIT_TEST(PgPFactory, ReUseOmegas)
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(PgPFactory, ReUseOmegas, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
+#   include <MueLu_UseShortNames.hpp>
+    MUELU_TESTING_SET_OSTREAM;
+    MUELU_TESTING_LIMIT_SCOPE(Scalar,GlobalOrdinal,Node);
+#   if !defined(HAVE_MUELU_IFPACK2)
+    MUELU_TESTING_DO_NOT_TEST(Xpetra::UseTpetra,"Ifpack2");
+#   endif
     out << "version: " << MueLu::Version() << std::endl;
     out << "Test PgPFactory (reuse row based omegas for restriction operator)" << std::endl;
 
+    typedef typename Teuchos::ScalarTraits<SC>::magnitudeType magnitude_type;
+
     RCP<const Teuchos::Comm<int> > comm = Teuchos::DefaultComm<int>::getComm();
 
     // used Xpetra lib (for maps and smoothers)
     Xpetra::UnderlyingLib lib = MueLuTests::TestHelpers::Parameters::getLib();
 
     // generate problem
-    LO maxLevels = 3;
-    LO its       = 10;
-    LO nEle      = 63;
+    LocalOrdinal maxLevels = 3;
+    LocalOrdinal its       = 10;
+    LocalOrdinal nEle      = 63;
     const RCP<const Map> map = MapFactory::Build(lib, nEle, 0, comm);
     Teuchos::ParameterList matrixParameters;
     matrixParameters.set("nx", nEle);
 
     // create nonsymmetric tridiagonal matrix
-    RCP<Matrix> Op = Galeri::Xpetra::TriDiag<SC,LO,GO,Map,CrsMatrixWrap>(map, nEle, 2.0, -1.0, -1.0);
+    RCP<Matrix> Op = Galeri::Xpetra::TriDiag<SC,LocalOrdinal,GlobalOrdinal,Map,CrsMatrixWrap>(map, nEle, 2.0, -1.0, -1.0);
 
     // build nullspace
     RCP<MultiVector> nullSpace = MultiVectorFactory::Build(map,1);
     nullSpace->putScalar( (SC) 1.0);
-    Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+    Teuchos::Array<magnitude_type> norms(1);
     nullSpace->norm1(norms);
     if (comm->getRank() == 0)
       out << "||NS|| = " << norms[0] << std::endl;
@@ -671,7 +697,7 @@ namespace MueLuTests {
     // setup smoothers
     Teuchos::ParameterList smootherParamList;
     smootherParamList.set("relaxation: type",           "Symmetric Gauss-Seidel");
-    smootherParamList.set("relaxation: sweeps",         (LO) 1);
+    smootherParamList.set("relaxation: sweeps",         (LocalOrdinal) 1);
     smootherParamList.set("relaxation: damping factor", (SC) 1.0);
     RCP<SmootherPrototype> smooProto = rcp(new TrilinosSmoother("RELAXATION", smootherParamList));
     RCP<SmootherFactory>   SmooFact  = rcp(new SmootherFactory(smooProto));
@@ -780,13 +806,20 @@ namespace MueLuTests {
     TEST_EQUALITY(l2->GetKeepFlag("PreSmoother",  MueLu::NoFactory::get()), MueLu::Final);
   }
 
-  TEUCHOS_UNIT_TEST(PgPFactory, ReUseOmegasTransP)
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(PgPFactory, ReUseOmegasTransP, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
     // reuse row based omegas in PgPFactory activated but not used, since TransPFactory is set as restriction factory
     // check if RowBasedOmega is not stored in Level!
+#   include <MueLu_UseShortNames.hpp>
+    MUELU_TESTING_SET_OSTREAM;
+    MUELU_TESTING_LIMIT_SCOPE(Scalar,GlobalOrdinal,Node);
+#   if !defined(HAVE_MUELU_AMESOS2) || !defined(HAVE_MUELU_IFPACK2)
+    MUELU_TESTING_DO_NOT_TEST(Xpetra::UseTpetra,"Amesos2, Ifpack2");
+#   endif
     out << "version: " << MueLu::Version() << std::endl;
     out << "Test PgPFactory (reuse row based omegas for restriction operator)" << std::endl;
 
+    typedef typename Teuchos::ScalarTraits<SC>::magnitudeType magnitude_type;
 
     RCP<const Teuchos::Comm<int> > comm = Teuchos::DefaultComm<int>::getComm();
 
@@ -794,20 +827,20 @@ namespace MueLuTests {
     Xpetra::UnderlyingLib lib = MueLuTests::TestHelpers::Parameters::getLib();
 
     // generate problem
-    LO maxLevels = 3;
-    LO its=10;
-    LO nEle = 63;
+    LocalOrdinal maxLevels = 3;
+    LocalOrdinal its=10;
+    LocalOrdinal nEle = 63;
     const RCP<const Map> map = MapFactory::Build(lib, nEle, 0, comm);
     Teuchos::ParameterList matrixParameters;
     matrixParameters.set("nx",nEle);
 
     // create nonsymmetric tridiagonal matrix
-    RCP<Matrix> Op = Galeri::Xpetra::TriDiag<SC,LO,GO,Map,CrsMatrixWrap>(map, nEle, 2.0, -1.0, -1.0);
+    RCP<Matrix> Op = Galeri::Xpetra::TriDiag<SC,LocalOrdinal,GlobalOrdinal,Map,CrsMatrixWrap>(map, nEle, 2.0, -1.0, -1.0);
 
     // build nullspace
     RCP<MultiVector> nullSpace = MultiVectorFactory::Build(map,1);
     nullSpace->putScalar( (SC) 1.0);
-    Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+    Teuchos::Array<magnitude_type> norms(1);
     nullSpace->norm1(norms);
     if (comm->getRank() == 0)
       out << "||NS|| = " << norms[0] << std::endl;
@@ -839,7 +872,7 @@ namespace MueLuTests {
     // setup smoothers
     Teuchos::ParameterList smootherParamList;
     smootherParamList.set("relaxation: type", "Symmetric Gauss-Seidel");
-    smootherParamList.set("relaxation: sweeps", (LO) 1);
+    smootherParamList.set("relaxation: sweeps", (LocalOrdinal) 1);
     smootherParamList.set("relaxation: damping factor", (SC) 1.0);
     RCP<SmootherPrototype> smooProto = rcp( new TrilinosSmoother("RELAXATION", smootherParamList) );
     RCP<SmootherFactory> SmooFact = rcp( new SmootherFactory(smooProto) );
@@ -948,17 +981,23 @@ namespace MueLuTests {
     TEST_EQUALITY(l2->GetKeepFlag("PreSmoother",MueLu::NoFactory::get()), MueLu::Final);
   }
 
-#if defined(HAVE_MUELU_TPETRA) && defined(HAVE_MUELU_EPETRA) && defined(HAVE_MUELU_EPETRAEXT) && defined(HAVE_MUELU_IFPACK) && defined(HAVE_MUELU_IFPACK2)
-  TEUCHOS_UNIT_TEST(PgPFactory, EpetraVsTpetra)
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(PgPFactory, EpetraVsTpetra, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
+#   if defined(HAVE_MUELU_TPETRA) && defined(HAVE_MUELU_EPETRA) && defined(HAVE_MUELU_EPETRAEXT) && defined(HAVE_MUELU_IFPACK) && defined(HAVE_MUELU_IFPACK2)
+#   include <MueLu_UseShortNames.hpp>
+    MUELU_TESTING_SET_OSTREAM;
     out << "version: " << MueLu::Version() << std::endl;
     out << "Compare results of Epetra and Tpetra" << std::endl;
     out << "for 3 level AMG solver using Petrov Galerkin smoothed aggregation with" << std::endl;
     out << "one SGS sweep on each multigrid level as pre- and postsmoother" << std::endl;
 
+    MUELU_TESTING_LIMIT_EPETRA_SCOPE_TPETRA_IS_DEFAULT(Scalar,GlobalOrdinal,Node);
+
+    typedef typename Teuchos::ScalarTraits<SC>::magnitudeType magnitude_type;
+
     RCP<const Teuchos::Comm<int> > comm = Teuchos::DefaultComm<int>::getComm();
 
-    Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> results(2);
+    Teuchos::Array<magnitude_type> results(2);
 
     // run test only on 1 procs
     // then we can check shape of transfer operators
@@ -974,21 +1013,21 @@ namespace MueLuTests {
         else lib = Xpetra::UseTpetra;
 
         // generate problem
-        LO maxLevels = 3;
-        LO its=10;
-        LO nEle = 63;
+        LocalOrdinal maxLevels = 3;
+        LocalOrdinal its=10;
+        GlobalOrdinal nEle = 63;
         const RCP<const Map> map = MapFactory::Build(lib, nEle, 0, comm);
         Teuchos::ParameterList matrixParameters;
         matrixParameters.set("nx",nEle);
 
         RCP<Galeri::Xpetra::Problem<Map,CrsMatrixWrap,MultiVector> > Pr =
-          Galeri::Xpetra::BuildProblem<SC, LO, GO, Map, CrsMatrixWrap, MultiVector>("Laplace1D", map, matrixParameters);
+          Galeri::Xpetra::BuildProblem<SC, LocalOrdinal, GlobalOrdinal, Map, CrsMatrixWrap, MultiVector>("Laplace1D", map, matrixParameters);
         RCP<Matrix> Op = Pr->BuildMatrix();
 
         // build nullspace
         RCP<MultiVector> nullSpace = MultiVectorFactory::Build(map,1);
         nullSpace->putScalar( (SC) 1.0);
-        Teuchos::Array<Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
+        Teuchos::Array<magnitude_type> norms(1);
         nullSpace->norm1(norms);
         if (comm->getRank() == 0)
           out << "||NS|| = " << norms[0] << std::endl;
@@ -1018,7 +1057,7 @@ namespace MueLuTests {
         // setup smoothers
         Teuchos::ParameterList smootherParamList;
         smootherParamList.set("relaxation: type", "Symmetric Gauss-Seidel");
-        smootherParamList.set("relaxation: sweeps", (LO) 1);
+        smootherParamList.set("relaxation: sweeps", (LocalOrdinal) 1);
         smootherParamList.set("relaxation: damping factor", (SC) 1.0);
         RCP<SmootherPrototype> smooProto = rcp( new TrilinosSmoother("RELAXATION", smootherParamList) );
         RCP<SmootherFactory> SmooFact = rcp( new SmootherFactory(smooProto) );
@@ -1106,7 +1145,7 @@ namespace MueLuTests {
         TEST_EQUALITY(R2->getGlobalNumRows(), 7);
         TEST_EQUALITY(R2->getGlobalNumCols(), 21);
 
-        Teuchos::RCP<Xpetra::Matrix<Scalar,LO,GO> > PtentTPtent = Xpetra::MatrixMatrix<Scalar,LO,GO>::Multiply(*P1,true,*P1,false,out);
+        Teuchos::RCP<Xpetra::Matrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > PtentTPtent = Xpetra::MatrixMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node>::Multiply(*P1,true,*P1,false,out);
         TEST_EQUALITY(PtentTPtent->getGlobalMaxNumRowEntries()-3<1e-12, true);
         TEST_EQUALITY(P1->getGlobalMaxNumRowEntries()-2<1e-12, true);
         TEST_EQUALITY(P2->getGlobalMaxNumRowEntries()-2<1e-12, true);
@@ -1138,9 +1177,22 @@ namespace MueLuTests {
       std::cout << results[0] << " VS " << results[1] << std::endl;
       TEST_EQUALITY(results[0] - results[1] < 1e-10, true); // check results of EPETRA vs TPETRA
     } // comm->getSize == 1
+#   else
+    out << "Skipping test because some required packages are not enabled (Tpetra, Epetra, EpetraExt, Ifpack, Ifpack2)." << std::endl;
+#   endif
 
   } //EpetraVsTpetra
-#endif
+
+
+#   define MUELU_ETI_GROUP(Scalar, LO, GO, Node) \
+      TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(PgPFactory, Test0, Scalar, LO, GO, Node) \
+      TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(PgPFactory, nonsymExample, Scalar, LO, GO, Node) \
+      TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(PgPFactory, MinimizationModes, Scalar, LO, GO, Node) \
+      TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(PgPFactory, ReUseOmegas, Scalar, LO, GO, Node) \
+      TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(PgPFactory, ReUseOmegasTransP, Scalar, LO, GO, Node) \
+      TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(PgPFactory, EpetraVsTpetra, Scalar, LO, GO, Node)
+
+# include <MueLu_ETI_4arg.hpp>
 
 }//namespace MueLuTests
 
