@@ -182,7 +182,7 @@ Teuchos::RCP<Xpetra::BlockedCrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
     if(comm->getSize() == 2) localEntries = 299;
     if(comm->getSize() == 1) localEntries = 298;
     TEST_EQUALITY(sOp->getNodeNumEntries(), localEntries);
-    TEST_EQUALITY(sOp->getGlobalNumEntries(), comm->getSize() * 300 - 2);
+    TEST_EQUALITY(sOp->getGlobalNumEntries(), Teuchos::as<size_t>(comm->getSize() * 300 - 2));
 
     RCP<Vector> v = VectorFactory::Build(sOp->getRangeMap(),true);
     sOp->getLocalDiagCopy(*v);
@@ -211,7 +211,7 @@ Teuchos::RCP<Xpetra::BlockedCrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
     if(comm->getSize() == 2) localEntries = 299;
     if(comm->getSize() == 1) localEntries = 298;
     TEST_EQUALITY(sOp->getNodeNumEntries(), localEntries);
-    TEST_EQUALITY(sOp->getGlobalNumEntries(), comm->getSize() * 300 - 2);
+    TEST_EQUALITY(sOp->getGlobalNumEntries(), Teuchos::as<size_t>(comm->getSize() * 300 - 2));
 
     /*v = VectorFactory::Build(sOp->getRangeMap(),true);
     sOp->getLocalDiagCopy(*v);
@@ -258,7 +258,7 @@ Teuchos::RCP<Xpetra::BlockedCrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
     TEST_EQUALITY(Teuchos::rcp_dynamic_cast<BlockedCrsMatrix>(sOp), Teuchos::null);
 
     TEST_EQUALITY(sOp->getNodeNumEntries(), 5);
-    TEST_EQUALITY(sOp->getGlobalNumEntries(), comm->getSize() * 5);
+    TEST_EQUALITY(sOp->getGlobalNumEntries(), Teuchos::as<size_t>(comm->getSize() * 5));
 
     RCP<Vector> v = VectorFactory::Build(sOp->getRangeMap(),true);
     sOp->getLocalDiagCopy(*v);
@@ -329,12 +329,15 @@ Teuchos::RCP<Xpetra::BlockedCrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
 
     RCP<Vector> v = VectorFactory::Build(sOp->getRangeMap(),true);
     sOp->getLocalDiagCopy(*v);
-    Teuchos::ArrayRCP<const Scalar> vdata = v->getData(0);
+    RCP<BlockedVector> bv = Teuchos::rcp_dynamic_cast<BlockedVector>(v);
+    TEST_EQUALITY(bv->getBlockedMap()->getNumMaps(),2);
+
+    RCP<MultiVector> mergedv = bv->Merge();
+    Teuchos::ArrayRCP<const Scalar> vdata = mergedv->getData(0);
     bool bCheck = true;
     for(int i=0; i<100; i++) if(vdata[i] != Teuchos::as<Scalar>(3.50)) bCheck = false;
     for(int i=100; i<200; i++) if(vdata[i] != Teuchos::as<Scalar>(4.00)) bCheck = false;
     TEST_EQUALITY(bCheck, true);
-
   } // SchurConstructor3x3
 
   TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(SchurComplementFactory, SchurConstructorXpetra4x4, Scalar, LocalOrdinal, GlobalOrdinal, Node)
@@ -377,7 +380,7 @@ Teuchos::RCP<Xpetra::BlockedCrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
 
     // generate Schur complement operator
     schurFact->Build(level);
-
+#if 1
     RCP<Matrix> sOp = level.Get<RCP<Matrix> >("A", schurFact.get());
     TEST_EQUALITY(sOp.is_null(), false);
     TEST_EQUALITY(sOp->getRangeMap()->getMinGlobalIndex(), comm->getRank() * 40 + 5);
@@ -386,15 +389,21 @@ Teuchos::RCP<Xpetra::BlockedCrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
     TEST_EQUALITY(sOp->getDomainMap()->getMaxGlobalIndex(), comm->getRank() * 40 + 19);
 
     TEST_EQUALITY(sOp->getNodeNumEntries(), 15);
-    TEST_EQUALITY(sOp->getGlobalNumEntries(), comm->getSize() * 15);
+    TEST_EQUALITY(sOp->getGlobalNumEntries(), Teuchos::as<size_t>(comm->getSize() * 15));
 
     RCP<Vector> v = VectorFactory::Build(sOp->getRangeMap(),true);
     sOp->getLocalDiagCopy(*v);
-    Teuchos::ArrayRCP<const Scalar> vdata = v->getData(0);
+    RCP<BlockedVector> bv = Teuchos::rcp_dynamic_cast<BlockedVector>(v);
+    TEST_EQUALITY(bv.is_null(),false);
+    TEST_EQUALITY(bv->getBlockedMap()->getNumMaps(),2);
+
+    RCP<MultiVector> mergedv = bv->Merge();
+    Teuchos::ArrayRCP<const Scalar> vdata = mergedv->getData(0);
     bool bCheck = true;
     for(int i=0; i<5;  i++) if(vdata[i] != Teuchos::as<Scalar>(2.0)) bCheck = false;
     for(int i=5; i<15; i++) if(vdata[i] != Teuchos::as<Scalar>(3.0)) bCheck = false;
     TEST_EQUALITY(bCheck, true);
+#endif
   }
 
 
