@@ -61,7 +61,7 @@
 #include "Phalanx_FieldTag_STL_Functors.hpp"
 
 #ifdef PHX_ENABLE_KOKKOS_AMT
-#include "Kokkos_TaskPolicy.hpp"
+#include "Kokkos_TaskScheduler.hpp"
 #endif
 
 //=======================================================================
@@ -113,7 +113,7 @@ registerEvaluator(const Teuchos::RCP<PHX::Evaluator<Traits> >& p)
 
   // insert evaluated fields into map, check for multiple evaluators
   // that provide the same field.
-  nodes_.push_back(PHX::DagNode<Traits>(static_cast<const int>(nodes_.size()),p));
+  nodes_.push_back(PHX::DagNode<Traits>(static_cast<int>(nodes_.size()),p));
   const std::vector<Teuchos::RCP<PHX::FieldTag>>& evaluatedFields = 
     p->evaluatedFields();
   for (auto i=evaluatedFields.cbegin(); i != evaluatedFields.cend(); ++i) {
@@ -444,9 +444,9 @@ void PHX::DagManager<Traits>::
 evaluateFieldsTaskParallel(const int& work_size,
 			   typename Traits::EvalData d)
 {
-  using execution_space = PHX::Device::execution_space;
+  using execution_space = PHX::exec_space;
   using memory_space = PHX::Device::memory_space;
-  using policy_type = Kokkos::TaskPolicy<execution_space>;
+  using policy_type = Kokkos::TaskScheduler<execution_space>;
 
   // Requested the ability to query policy for required sizes of calls
   // to spawn and wait_all. For now hard code to something
@@ -461,7 +461,7 @@ evaluateFieldsTaskParallel(const int& work_size,
 
   // Issue in reusing vector. The assign doesn't like the change of policy.
   //node_futures_.resize(nodes_.size());
-  std::vector<Kokkos::Future<void,PHX::Device::execution_space>> node_futures_(nodes_.size());
+  std::vector<Kokkos::Future<void,PHX::exec_space>> node_futures_(nodes_.size());
 
   for (std::size_t n = 0; n < topoSortEvalIndex.size(); ++n) {
     
@@ -648,7 +648,6 @@ writeGraphvizDfsVisit(PHX::DagNode<Traits>& node,
     }
     if (writeEvaluatedFields) {
       ofs << "\\n   Contributes:";
-      const auto& contrib_fields = node.get()->contributedFields(); 
       for (const auto& field : contrib_fields)
 	ofs << "\\n      " << field->identifier();
     }
@@ -812,6 +811,9 @@ void PHX::DagManager<Traits>::createEvalautorBindingFieldMap()
     for (const auto& f : e->evaluatedFields())
       field_to_evaluators_binding_[f->identifier()].push_back(e);
 
+    for (const auto& f : e->contributedFields())
+      field_to_evaluators_binding_[f->identifier()].push_back(e);
+
     for (const auto& f : e->dependentFields())
       field_to_evaluators_binding_[f->identifier()].push_back(e);
   }
