@@ -74,7 +74,7 @@ buildEvaluators(const std::map<std::string, Teuchos::RCP<Teuchos::ParameterList>
     bool found_type = false;
     int object_type = p->get<int>("Type");
     static const int size = Sacado::mpl::size<typename FactoryTraits::EvaluatorTypes>::value;
-    Sacado::mpl::for_each< Sacado::mpl::range_c<int,0,size> >( UFO<Traits,FactoryTraits>(object_type, p, tm, found_type) );
+    Sacado::mpl::for_each_no_kokkos< Sacado::mpl::range_c<int,0,size> >( UFO<Traits,FactoryTraits>(object_type, p, tm, found_type) );
 
     if (!found_type) {
       std::ostringstream msg;
