@@ -16,7 +16,7 @@ namespace PHX {
   struct TaskWrap {
     
     typedef void value_type;
-    typedef Kokkos::TaskPolicy<Space> policy_type;
+    typedef Kokkos::TaskScheduler<Space> policy_type;
     
     const int work_size;
     const Functor functor;
@@ -38,25 +38,25 @@ namespace PHX {
   template<typename Traits,typename Derived>
   struct TaskBase : public PHX::EvaluatorWithBaseImpl<Traits> {
 
-    virtual Kokkos::Future<void,PHX::Device::execution_space>
-    createTask(Kokkos::TaskPolicy<PHX::Device::execution_space>& policy,
+    virtual Kokkos::Future<void,PHX::exec_space>
+    createTask(Kokkos::TaskScheduler<PHX::exec_space>& policy,
 	       const int& work_size,
-               const std::vector<Kokkos::Future<void,PHX::Device::execution_space>>& dependent_futures,
+               const std::vector<Kokkos::Future<void,PHX::exec_space>>& dependent_futures,
 	       typename Traits::EvalData ) override
     {
       if (dependent_futures.size() == 0)
-        return policy.host_spawn(PHX::TaskWrap<PHX::Device::execution_space,Derived>(work_size,*dynamic_cast<Derived*>(this)),Kokkos::TaskTeam);
+        return policy.host_spawn(PHX::TaskWrap<PHX::exec_space,Derived>(work_size,*dynamic_cast<Derived*>(this)),Kokkos::TaskTeam);
       else if (dependent_futures.size() == 1)
-        return policy.host_spawn(PHX::TaskWrap<PHX::Device::execution_space,Derived>(work_size,*dynamic_cast<Derived*>(this)),Kokkos::TaskTeam,dependent_futures[0]);
+        return policy.host_spawn(PHX::TaskWrap<PHX::exec_space,Derived>(work_size,*dynamic_cast<Derived*>(this)),Kokkos::TaskTeam,dependent_futures[0]);
 
       auto aggregate_future = policy.when_all(dependent_futures.size(),dependent_futures.data());
-      return policy.host_spawn(PHX::TaskWrap<PHX::Device::execution_space,Derived>(work_size,*dynamic_cast<Derived*>(this)),Kokkos::TaskTeam,aggregate_future);
+      return policy.host_spawn(PHX::TaskWrap<PHX::exec_space,Derived>(work_size,*dynamic_cast<Derived*>(this)),Kokkos::TaskTeam,aggregate_future);
     }
 
     //! Returns the size of the task functor in bytes
     unsigned taskSize() const override
     {
-      return sizeof(PHX::TaskWrap<PHX::Device::execution_space,Derived>);
+      return sizeof(PHX::TaskWrap<PHX::exec_space,Derived>);
     }
   };
 
