@@ -1,16 +1,19 @@
 #include "Teuchos_UnitTestRepository.hpp"
 #include "Teuchos_GlobalMPISession.hpp"
 #include "Phalanx_config.hpp"
-#include "Phalanx_KokkosUtilities.hpp"
+#include "Phalanx_KokkosDeviceTypes.hpp"
 
 int main( int argc, char* argv[] )
 {
+  // Note that the dtor for GlobalMPISession will call
+  // Kokkos::finalize_all() but does NOT call Kokkos::initialize() for
+  // any node type!
   Teuchos::GlobalMPISession mpiSession(&argc, &argv);
   Kokkos::initialize(argc,argv);
   {
     Teuchos::FancyOStream out(Teuchos::rcpFromRef(std::cout));
     out.setOutputToRootOnly(0);
-    PHX::Device::execution_space::print_configuration(out);
+    PHX::exec_space::print_configuration(out);
   }
   Teuchos::UnitTestRepository::setGloballyReduceTestResult(true);
   return Teuchos::UnitTestRepository::runUnitTestsFromMain(argc, argv);
