@@ -90,10 +90,10 @@ Piro::LOCASolver<Scalar>::LOCASolver(
   globalData_(LOCA::createGlobalData(piroParams)),
   paramVector_(),
   group_(),
-  model_(model), 
   locaStatusTests_(),
   noxStatusTests_(),
-  stepper_()
+  stepper_(),
+  model_(model)
 {
   const int l = 0; // TODO: Allow user to select parameter index
   const Detail::ModelEvaluatorParamName paramName(this->getModel().get_p_names(l));
