@@ -107,6 +107,7 @@ int main(int argc, char* argv[]) {
     Teuchos::RCP<std::vector<RealT> > p_rcp  = Teuchos::rcp( new std::vector<RealT>(nx,0.0) );
     ROL::StdVector<RealT> p(p_rcp);
     Teuchos::RCP<ROL::Vector<RealT> > up = Teuchos::rcp(&u,false);
+    Teuchos::RCP<ROL::Vector<RealT> > zp = Teuchos::rcp(&z,false);
     Teuchos::RCP<ROL::Vector<RealT> > pp = Teuchos::rcp(&p,false);
     /**********************************************************************************************/
     /************************* CONSTRUCT SOL COMPONENTS *******************************************/
@@ -130,7 +131,7 @@ int main(int argc, char* argv[]) {
     Teuchos::RCP<ROL::EqualityConstraint_SimOpt<RealT> > pconSimOpt
       = Teuchos::rcp(new EqualityConstraint_BurgersControl<RealT>(nx));
     Teuchos::RCP<ROL::Objective<RealT> > pObj
-      = Teuchos::rcp(new ROL::Reduced_Objective_SimOpt<RealT>(pobjSimOpt,pconSimOpt,up,pp));
+      = Teuchos::rcp(new ROL::Reduced_Objective_SimOpt<RealT>(pobjSimOpt,pconSimOpt,up,zp,pp));
     Teuchos::RCP<ROL::Objective<RealT> > obj = Teuchos::rcp(new ROL::RiskNeutralObjective<RealT>(pObj, sampler, true));
     // Test parametrized objective functions
     *outStream << "Check Derivatives of Parametrized Objective Function\n";
