@@ -80,7 +80,7 @@ private:
   const Teuchos::RCP<PDE<Real> > pde_;
   Teuchos::RCP<Assembler<Real> > assembler_;
   Teuchos::RCP<Solver<Real> >    solver_;
-  bool initZvec_, initZpar_;
+  bool initZvec_, initZpar_, isStochastic_;
   bool assembleRHS_, assembleJ1_, assembleJ2_, assembleJ3_, setSolver_;
 
   Teuchos::RCP<Tpetra::MultiVector<> > cvec_;
@@ -95,6 +95,17 @@ private:
 
   void assemble(const Teuchos::RCP<const Tpetra::MultiVector<> > &zf,
                 const Teuchos::RCP<const std::vector<Real> > &zp) {
+    // Initialize field component of z.
+    if (initZvec_ && zf != Teuchos::null) {
+      zvec_ = assembler_->createControlVector();
+      zvec_->putScalar(static_cast<Real>(0));
+    }
+    initZvec_ = false;
+    // Initialize parameter component of z.
+    if (initZpar_ && zp != Teuchos::null) {
+      zpar_ = Teuchos::rcp(new std::vector<Real>(zp->size(),static_cast<Real>(0)));
+    }
+    initZpar_ = false;
     // Assemble affine term.
     if (assembleRHS_) {
       assembler_->assemblePDEResidual(vecR_,pde_,uvec_,zvec_,zpar_);
@@ -216,13 +227,16 @@ private:
   }
 
 public:
+  virtual ~Linear_PDE_Constraint() {}
+
   Linear_PDE_Constraint(const Teuchos::RCP<PDE<Real> > &pde,
                         const Teuchos::RCP<MeshManager<Real> > &meshMgr,
                         const Teuchos::RCP<const Teuchos::Comm<int> > &comm,
                         Teuchos::ParameterList &parlist,
-                        std::ostream &outStream = std::cout)
+                        std::ostream &outStream = std::cout,
+                        const bool isStochastic = false)
     : ROL::EqualityConstraint_SimOpt<Real>(), pde_(pde),
-      initZvec_(true), initZpar_(true),
+      initZvec_(true), initZpar_(true), isStochastic_(isStochastic),
       assembleRHS_(true), assembleJ1_(true), assembleJ2_(true), assembleJ3_(true), setSolver_(true) {
     // Construct assembler.
     assembler_ = Teuchos::rcp(new Assembler<Real>(pde_->getFields(),meshMgr,comm,parlist,outStream));
@@ -236,38 +250,30 @@ public:
   }
 
   void setParameter(const std::vector<Real> &param) {
-    ROL::EqualityConstraint_SimOpt<Real>::setParameter(param);
-    pde_->setParameter(param);
-    assembleRHS_  = true;
-    assembleJ1_   = true;
-    assembleJ2_   = true;
-    assembleJ3_   = true;
-    setSolver_    = true;
+    if (isStochastic_) {
+      ROL::EqualityConstraint_SimOpt<Real>::setParameter(param);
+      pde_->setParameter(param);
+      assembleRHS_ = true;
+      assembleJ1_  = true;
+      assembleJ2_  = true;
+      assembleJ3_  = true;
+      setSolver_   = true;
+    }
   }
 
   const Teuchos::RCP<Assembler<Real> > getAssembler(void) const {
     return assembler_;
   }
 
+  const Teuchos::RCP<PDE<Real> > getPDE(void) const {
+    return pde_;
+  }
+
   using ROL::EqualityConstraint_SimOpt<Real>::update_1;
   void update_1(const ROL::Vector<Real> &u, bool flag = true, int iter = -1) {}
 
   using ROL::EqualityConstraint_SimOpt<Real>::update_2;
-  void update_2(const ROL::Vector<Real> &z, bool flag = true, int iter = -1) {
-    // Initialize field component of z.
-    Teuchos::RCP<const Tpetra::MultiVector<> > zf = getConstField(z);
-    if (initZvec_ && zf != Teuchos::null) {
-      zvec_ = assembler_->createControlVector();
-      zvec_->putScalar(static_cast<Real>(0));
-    }
-    initZvec_ = false;
-    // Initialize parameter component of z.
-    Teuchos::RCP<const std::vector<Real> >     zp = getConstParameter(z);
-    if (initZpar_ && zp != Teuchos::null) {
-      zpar_ = Teuchos::rcp(new std::vector<Real>(zp->size(),static_cast<Real>(0)));
-    }
-    initZpar_ = false;
-  }
+  void update_2(const ROL::Vector<Real> &z, bool flag = true, int iter = -1) {}
 
   using ROL::EqualityConstraint_SimOpt<Real>::update;
   void update(const ROL::Vector<Real> &u, const ROL::Vector<Real> &z, bool flag = true, int iter = -1) {
@@ -357,8 +363,9 @@ public:
       jvf->update(one,*cvec_,one);
     }
     Teuchos::RCP<const std::vector<Real> >     vp = getConstParameter(v);
+    bool zeroOut = (vf == Teuchos::null);
     if (vp != Teuchos::null) {
-      applyJacobian3(cvec_,vp,false);
+      applyJacobian3(cvec_,vp,zeroOut);
       jvf->update(one,*cvec_,one);
     }
   }
