@@ -102,6 +102,8 @@ private:
     return ip;
   }
 
+  using ROL::EqualityConstraint_SimOpt<Real>::update;
+
   void update(std::vector<Real> &u, const std::vector<Real> &s, const Real alpha=1.0) {
     for (unsigned i = 0; i < u.size(); i++) {
       u[i] += alpha*s[i];
@@ -327,7 +329,7 @@ private:
     compute_residual(r,uold,zold,u,znew);
     Real rnorm = compute_norm(r);
     // Define tolerances
-    Real rtol  = 1.e2*ROL::ROL_EPSILON;
+    Real rtol  = 1.e2*ROL::ROL_EPSILON<Real>();
     unsigned maxit = 500;
     // Initialize Jacobian storage
     std::vector<Real> d(nx_,0.0);
@@ -350,7 +352,7 @@ private:
       update(utmp,s,-alpha);
       compute_residual(r,uold,zold,utmp,znew);
       rnorm = compute_norm(r); 
-      while ( rnorm > (1.0-1.e-4*alpha)*tmp && alpha > std::sqrt(ROL::ROL_EPSILON) ) {
+      while ( rnorm > (1.0-1.e-4*alpha)*tmp && alpha > std::sqrt(ROL::ROL_EPSILON<Real>()) ) {
         alpha *= 0.5;
         utmp.assign(u.begin(),u.end());
         update(utmp,s,-alpha);
