@@ -41,7 +41,7 @@
 // ************************************************************************
 // @HEADER
 
-/*! \file  example_03.cpp
+/*! \file  example_07.cpp
     \brief Shows how to solve a steady Burgers' optimal control problem using
            full-space methods.
 */
@@ -188,7 +188,7 @@ int main(int argc, char *argv[]) {
     bool storage = true, fdhess = false;
     Teuchos::RCP<ROL::Objective<RealT> > robj
       = Teuchos::rcp(new ROL::Reduced_Objective_SimOpt<RealT>(
-          pobj,pcon,up,lp,gup,cp,storage,fdhess));
+          pobj,pcon,up,zp,lp,gup,gzp,cp,storage,fdhess));
     RealT order = 2.0, threshold = -0.85*(1.0-x);
     Teuchos::RCP<ROL::Objective<RealT> > obj
       = Teuchos::rcp(new ROL::BPOEObjective<RealT>(
