@@ -124,8 +124,8 @@ private:
       ---
      */
     Real Newton(const Real I, const Real Vsrc, const Real Is, const Real Rs){
-      double EPS = 1.e-16;
-      double TOL = 1.e-13;
+      Real EPS = 1.e-16;
+      Real TOL = 1.e-13;
       int MAXIT = 200;
       Real IN = I;
       Real fval  = diode(IN,Vsrc,Is,Rs);
@@ -715,7 +715,7 @@ public:
 //       input_file.seekg(0,std::ios::beg); 
 //       Vsrc_ = Teuchos::rcp(new std::vector<Real>(dim,0.0));
 //       Imeas_ = Teuchos::rcp(new std::vector<Real>(dim,0.0));
-//       double Vsrc, Imeas;
+//       Real Vsrc, Imeas;
 //       std::cout << "Using input file to generate data." << "\n";
 //       for(int i=0;i<dim;i++){
 //         input_file >> Vsrc;
@@ -798,8 +798,8 @@ public:
 //       ---
 //      */
 //     Real Newton(const Real I, const Real Vsrc, const Real Is, const Real Rs){
-//       double EPS = 1.e-16;
-//       double TOL = 1.e-13;
+//       Real EPS = 1.e-16;
+//       Real TOL = 1.e-13;
 //       int MAXIT = 200;
 //       Real IN = I;
 //       Real fval  = diode(IN,Vsrc,Is,Rs);
@@ -854,7 +854,7 @@ public:
 //       ierr = 2 if the computer arithmetic contains a bug.
 //       xi may be disregarded (it is the error).
       
-//       Prototype: void lambertw( double, double, int, double);
+//       Prototype: void lambertw( Real, Real, int, Real);
       
 //       Reference:
 //       T.C. Banwell
@@ -1156,7 +1156,7 @@ public:
 //       	  (Teuchos::dyn_cast<StdVector<Real> >(const_cast<Vector<Real> &>(v))).getVector();
 //       	Teuchos::RCP<const std::vector<Real> > Sp =
 //       	  (Teuchos::dyn_cast<StdVector<Real> >(const_cast<Vector<Real> &>(S))).getVector();
-//       	Real gtol = std::sqrt(ROL_EPSILON);
+//       	Real gtol = std::sqrt(ROL_EPSILON<Real>()));
 	
 //       	// Get Step Length                                                                                     
 //       	Real h = std::max(1.0,S.norm()/v.norm())*tol;
@@ -1293,8 +1293,8 @@ public:
 //       ---
 //      */
 //     void generate_plot(Real Is_lo, Real Is_up, Real Is_step, Real Rs_lo, Real Rs_up, Real Rs_step){
-//       Teuchos::RCP<std::vector<double> > S_rcp = Teuchos::rcp(new std::vector<double>(2,0.0) );
-//       ROL::StdVector<double> S(S_rcp);
+//       Teuchos::RCP<std::vector<Real> > S_rcp = Teuchos::rcp(new std::vector<Real>(2,0.0) );
+//       ROL::StdVector<Real> S(S_rcp);
 //       std::ofstream output ("Objective.dat");
 
 //       Real Is = 0.0;
