@@ -47,7 +47,6 @@
 #include "Teuchos_RCP.hpp"
 #include "ROL_RiskVector.hpp"
 #include "ROL_Objective.hpp"
-#include "ROL_ParametrizedObjective.hpp"
 #include "ROL_SampleGenerator.hpp"
 
 namespace ROL {
@@ -55,7 +54,7 @@ namespace ROL {
 template<class Real>
 class HMCRObjective : public Objective<Real> {
 private:
-  Teuchos::RCP<ParametrizedObjective<Real> > ParametrizedObjective_;
+  Teuchos::RCP<Objective<Real> > ParametrizedObjective_;
 
   Real order_;
   Real prob_;
@@ -98,11 +97,8 @@ private:
 
   void unwrap_const_CVaR_vector(Teuchos::RCP<Vector<Real> > &xvec, Real &xvar,
                           const Vector<Real> &x) {
-    xvec = Teuchos::rcp_const_cast<Vector<Real> >(
-      Teuchos::dyn_cast<const RiskVector<Real> >(
-        Teuchos::dyn_cast<const Vector<Real> >(x)).getVector());
-    xvar = Teuchos::dyn_cast<const RiskVector<Real> >(
-        Teuchos::dyn_cast<const Vector<Real> >(x)).getStatistic();
+    xvec = Teuchos::rcp_const_cast<Vector<Real> >(Teuchos::dyn_cast<const RiskVector<Real> >(x).getVector());
+    xvar = Teuchos::dyn_cast<const RiskVector<Real> >(x).getStatistic(0);
     if ( !initialized_ ) {
       initialize(*xvec);
     }
@@ -148,11 +144,11 @@ private:
 public:
   virtual ~HMCRObjective() {}
 
-  HMCRObjective( Teuchos::RCP<ParametrizedObjective<Real> > &pObj,
+  HMCRObjective( Teuchos::RCP<Objective<Real> > &pObj,
                  Real order, Real prob,
-                 Teuchos::RCP<SampleGenerator<Real> >       &vsampler, 
-                 Teuchos::RCP<SampleGenerator<Real> >       &gsampler,
-                 Teuchos::RCP<SampleGenerator<Real> >       &hsampler,
+                 Teuchos::RCP<SampleGenerator<Real> > &vsampler, 
+                 Teuchos::RCP<SampleGenerator<Real> > &gsampler,
+                 Teuchos::RCP<SampleGenerator<Real> > &hsampler,
                  bool storage = true )
     : ParametrizedObjective_(pObj),
       ValueSampler_(vsampler), GradientSampler_(gsampler), HessianSampler_(hsampler),
@@ -163,10 +159,10 @@ public:
     gradient_storage_.clear();
   }
 
-  HMCRObjective( Teuchos::RCP<ParametrizedObjective<Real> > &pObj,
+  HMCRObjective( Teuchos::RCP<Objective<Real> > &pObj,
                  Real order, Real prob,
-                 Teuchos::RCP<SampleGenerator<Real> >       &vsampler, 
-                 Teuchos::RCP<SampleGenerator<Real> >       &gsampler,
+                 Teuchos::RCP<SampleGenerator<Real> > &vsampler, 
+                 Teuchos::RCP<SampleGenerator<Real> > &gsampler,
                  bool storage = true )
     : ParametrizedObjective_(pObj),
       ValueSampler_(vsampler), GradientSampler_(gsampler), HessianSampler_(gsampler),
@@ -177,9 +173,9 @@ public:
     gradient_storage_.clear();
   }
 
-  HMCRObjective( Teuchos::RCP<ParametrizedObjective<Real> > &pObj,
+  HMCRObjective( Teuchos::RCP<Objective<Real> > &pObj,
                  Real order, Real prob,
-                 Teuchos::RCP<SampleGenerator<Real> >       &sampler,
+                 Teuchos::RCP<SampleGenerator<Real> > &sampler,
                  bool storage = true )
     : ParametrizedObjective_(pObj), order_(order), prob_(prob),
       ValueSampler_(sampler), GradientSampler_(sampler), HessianSampler_(sampler),
@@ -239,8 +235,7 @@ public:
   void gradient( Vector<Real> &g, const Vector<Real> &x, Real &tol ) {
     Teuchos::RCP<Vector<Real> > xvec; Real xvar = 0.0;
     unwrap_const_CVaR_vector(xvec,xvar,x);
-    RiskVector<Real> &gc = Teuchos::dyn_cast<RiskVector<Real> >(
-      Teuchos::dyn_cast<Vector<Real> >(g));
+    RiskVector<Real> &gc = Teuchos::dyn_cast<RiskVector<Real> >(g);
     // Initialize storage
     g.zero(); sumGrad0_->zero();
     std::vector<Real> point, val(2,0.0), myval(2,0.0);
@@ -281,7 +276,7 @@ public:
     }
     // Set gradient components of CVaR vector
     gc.setStatistic(gvar);
-    gc.setVector(*(Teuchos::rcp_dynamic_cast<Vector<Real> >(gradient0_)));
+    gc.setVector(*gradient0_);
   }
 
   void hessVec( Vector<Real> &hv, const Vector<Real> &v,
@@ -290,8 +285,7 @@ public:
     unwrap_const_CVaR_vector(xvec,xvar,x);
     Teuchos::RCP<Vector<Real> > vvec; Real vvar = 0.0;
     unwrap_const_CVaR_vector(vvec,vvar,v);
-    RiskVector<Real> &hvc = Teuchos::dyn_cast<RiskVector<Real> >(
-      Teuchos::dyn_cast<Vector<Real> >(hv));
+    RiskVector<Real> &hvc = Teuchos::dyn_cast<RiskVector<Real> >(hv);
     // Initialize storage
     hv.zero();
     sumGrad0_->zero(); sumGrad1_->zero(); sumGrad2_->zero(); sumHess_->zero();
@@ -360,7 +354,7 @@ public:
     }
     // Set gradient components of CVaR vector
     hvc.setStatistic(hvar);
-    hvc.setVector(*(Teuchos::rcp_dynamic_cast<Vector<Real> >(hessvec_)));
+    hvc.setVector(*hessvec_);
   }
 
   virtual void precond( Vector<Real> &Pv, const Vector<Real> &v,
