@@ -63,7 +63,7 @@ private:
   Teuchos::RCP<Vector<Real> > gradient_;
   Teuchos::RCP<Vector<Real> > pointDual_;
   Teuchos::RCP<Vector<Real> > sumDual_;
- 
+
   bool firstUpdate_;
   bool storage_;
 
@@ -105,7 +105,7 @@ private:
     ParametrizedObjective_->setParameter(param);
     ParametrizedObjective_->hessVec(hv,v,x,tol);
   }
- 
+
 
 public:
   virtual ~RiskNeutralObjective() {}
@@ -117,7 +117,7 @@ public:
                         const bool storage = true )
     : ParametrizedObjective_(pObj),
       ValueSampler_(vsampler), GradientSampler_(gsampler), HessianSampler_(hsampler),
-      firstUpdate_(true), storage_(true) {
+      firstUpdate_(true), storage_(storage) {
     value_storage_.clear();
     gradient_storage_.clear();
   }
@@ -128,7 +128,7 @@ public:
                         const bool storage = true )
     : ParametrizedObjective_(pObj),
       ValueSampler_(vsampler), GradientSampler_(gsampler), HessianSampler_(gsampler),
-      firstUpdate_(true), storage_(true) {
+      firstUpdate_(true), storage_(storage) {
     value_storage_.clear();
     gradient_storage_.clear();
   }
@@ -138,7 +138,7 @@ public:
                         const bool storage = true )
     : ParametrizedObjective_(pObj),
       ValueSampler_(sampler), GradientSampler_(sampler), HessianSampler_(sampler),
-      firstUpdate_(true), storage_(true) {
+      firstUpdate_(true), storage_(storage) {
     value_storage_.clear();
     gradient_storage_.clear();
   }
@@ -150,13 +150,13 @@ public:
       sumDual_   = (x.dual()).clone();
       firstUpdate_ = false;
     }
-    ParametrizedObjective_->update(x,flag,iter);
+    ParametrizedObjective_->update(x,(flag && iter>=0),iter);
     ValueSampler_->update(x);
-    value_ = 0.0;
+    value_ = static_cast<Real>(0);
     if ( storage_ ) {
       value_storage_.clear();
     }
-    if ( flag ) {
+    if ( flag && iter>=0 ) {
       GradientSampler_->update(x);
       HessianSampler_->update(x);
       gradient_->zero();
@@ -182,6 +182,7 @@ public:
     ValueSampler_->sumAll(&myval,&val,1);
     value_ += val;
     ValueSampler_->setSamples();
+    tol = error;
     return value_;
   }
 
@@ -198,12 +199,16 @@ public:
         (ptgs.back())->set(*pointDual_);
       }
       error = GradientSampler_->computeError(ptgs,x);
+//if (GradientSampler_->batchID()==0) {
+//  std::cout << "IN GRADIENT: ERROR = " << error << "  TOL = " << tol << std::endl;  
+//}
       ptgs.clear();
     }
     GradientSampler_->sumAll(*sumDual_,g);
     gradient_->plus(g);
     g.set(*(gradient_));
     GradientSampler_->setSamples();
+    tol = error;
   }
 
   virtual void hessVec( Vector<Real> &hv, const Vector<Real> &v,
