@@ -69,6 +69,10 @@ public:
                          const Real & alpha)
     : sampler_(sampler), pobj_(pobj), pfunc_(pfunc), alpha_(alpha) {}
 
+  void update( const Vector<Real> &x, bool flag = true, int iter = -1 ) {
+    pobj_->update(x,flag,iter);
+  }
+
   Real value(const Vector<Real> &x,
              Real &tol) {
     const Vector_SimOpt<Real> &uz = Teuchos::dyn_cast<const Vector_SimOpt<Real> >(x);
@@ -90,6 +94,7 @@ public:
       weight = sampler_->getMyWeight(static_cast<int>(i));
       pobj_->setParameter(param);
       //tmpval = pobj_->value(*(pu.get(i)), *zptr, tol);
+      pobj_->update(*(pu.get(i)), *z);
       tmpval = pobj_->value(*(pu.get(i)), *z, tol);
       tmpplus = pfunc_->evaluate(tmpval-t, 0);
       tmpsum += tmpplus*weight;
@@ -130,6 +135,7 @@ public:
       param = sampler_->getMyPoint(static_cast<int>(i));
       weight = sampler_->getMyWeight(static_cast<int>(i));
       pobj_->setParameter(param);
+      pobj_->update(*(pxu.get(i)), *xz);
       //tmpval = pobj_->value(*(pxu.get(i)), *xzptr, tol);
       tmpval = pobj_->value(*(pxu.get(i)), *xz, tol);
       tmpplus = pfunc_->evaluate(tmpval-xt, 1);
@@ -183,6 +189,7 @@ public:
       Vector_SimOpt<Real> xi(Teuchos::rcp_const_cast<Vector<Real> >(pxu.get(i)), Teuchos::rcp_const_cast<Vector<Real> >(xzptr));
       Vector_SimOpt<Real> vi(Teuchos::rcp_const_cast<Vector<Real> >(pvu.get(i)), Teuchos::rcp_const_cast<Vector<Real> >(vzptr));
       Vector_SimOpt<Real> hvi(phvu.get(i), tmp1);
+      pobj_->update(xi);
       pobj_->hessVec(hvi, vi, xi, tol);
       hvi.scale(weight);
       tmp2->plus(*tmp1);
