@@ -131,13 +131,13 @@ public:
   }
 
   Real invertCDF(const Real input) const {
-    if ( input <= ROL_EPSILON ) {
+    if ( input <= ROL_EPSILON<Real>() ) {
       return 0.;
     }
-    if ( input >= 1.-ROL_EPSILON ) {
+    if ( input >= 1.-ROL_EPSILON<Real>() ) {
       return 1.;
     }
-    Real a  = ROL_EPSILON, b = 1.-ROL_EPSILON, c  = 0.;
+    Real a  = ROL_EPSILON<Real>(), b = 1.-ROL_EPSILON<Real>(), c  = 0.;
     Real fa = evaluateCDF(a) - input;
     Real fc = 0.;
     Real sa = ((fa < 0.) ? -1. : ((fa > 0.) ? 1. : 0.));
@@ -146,7 +146,7 @@ public:
       c  = (a+b)*0.5;
       fc = evaluateCDF(c) - input;
       sc = ((fc < 0.) ? -1. : ((fc > 0.) ? 1. : 0.));
-      if ( fc == 0. || (b-a)*0.5 < ROL_EPSILON ) {
+      if ( fc == 0. || (b-a)*0.5 < ROL_EPSILON<Real>() ) {
         break;
       }
       if ( sc == sa ) { a = c; fa = fc; sa = sc; }
