@@ -88,7 +88,7 @@ public:
     Real val = 0.;
     switch(m) {
       case 1: val = mean_;                                        break;
-      case 2: val = std::pow(var_*M_PI,2)/3. + std::pow(mean_,2); break;
+      case 2: val = std::pow(var_*Teuchos::ScalarTraits<Real>::pi(),2)/3. + std::pow(mean_,2); break;
       default:
         TEUCHOS_TEST_FOR_EXCEPTION( true, std::invalid_argument,
           ">>> ERROR (ROL::Logistic): Logistic moment not implemented for m > 2!");
