@@ -44,7 +44,7 @@
 #ifndef ROL_BUNDLE_STEP_H
 #define ROL_BUNDLE_STEP_H
 
-#include "ROL_Bundle.hpp"
+#include "ROL_Bundle_AS.hpp"
 //#include "ROL_Bundle_TT.hpp"
 #include "ROL_Types.hpp"
 #include "ROL_Step.hpp"
@@ -108,6 +108,8 @@ private:
 
   Real ftol_;
 
+  int verbosity_;
+
 public:
 
   using Step<Real>::initialize;
@@ -123,7 +125,7 @@ public:
       T_(0), tol_(0), m1_(0), m2_(0), m3_(0), nu_(0),
       ls_maxit_(0), first_print_(true), isConvex_(false),
       ftol_(ROL_EPSILON<Real>()) {
-    Real zero(0), oem3(1.e-3), oem6(1.e-6), oem8(1.e-8), p1(0.1), p2(0.2), p9(0.9), oe3(1.e3), oe8(1.e8);
+    Real zero(0), two(2), oem3(1.e-3), oem6(1.e-6), oem8(1.e-8), p1(0.1), p2(0.2), p9(0.9), oe3(1.e3), oe8(1.e8);
     Teuchos::RCP<StepState<Real> > state = Step<Real>::getState();
     state->searchSize = parlist.sublist("Step").sublist("Bundle").get("Initial Trust-Region Parameter", oe3);
     T_   = parlist.sublist("Step").sublist("Bundle").get("Maximum Trust-Region Parameter",       oe8); 
@@ -135,14 +137,15 @@ public:
 
     // Initialize bundle
     Real coeff        = parlist.sublist("Step").sublist("Bundle").get("Distance Measure Coefficient",   zero);
+    Real omega        = parlist.sublist("Step").sublist("Bundle").get("Locality Measure Coefficient",   two);
     unsigned maxSize  = parlist.sublist("Step").sublist("Bundle").get("Maximum Bundle Size",            200);
     unsigned remSize  = parlist.sublist("Step").sublist("Bundle").get("Removal Size for Bundle Update", 2);
     if ( parlist.sublist("Step").sublist("Bundle").get("Cutting Plane Solver",0) == 1 ) {
       //bundle_ = Teuchos::rcp(new Bundle_TT<Real>(maxSize,coeff,remSize));
-      bundle_ = Teuchos::rcp(new Bundle<Real>(maxSize,coeff,remSize));
+      bundle_ = Teuchos::rcp(new Bundle_AS<Real>(maxSize,coeff,omega,remSize));
     }
     else {
-      bundle_ = Teuchos::rcp(new Bundle<Real>(maxSize,coeff,remSize));
+      bundle_ = Teuchos::rcp(new Bundle_AS<Real>(maxSize,coeff,omega,remSize));
     }
     isConvex_ = ((coeff == zero) ? true : false);
 
@@ -156,6 +159,9 @@ public:
     if ( !isConvex_ ) {
       lineSearch_ = LineSearchFactory<Real>(parlist);
     }
+
+    // Get verbosity level
+    verbosity_ = parlist.sublist("General").get("Print Verbosity", 0);
   }
 
   void initialize( Vector<Real> &x, const Vector<Real> &g, 
@@ -183,7 +189,7 @@ public:
                 BoundConstraint<Real> &con, AlgorithmState<Real> &algo_state ) { 
     Teuchos::RCP<StepState<Real> > state = Step<Real>::getState();
     first_print_ = false;                     // Print header only on first serious step
-    QPiter_ = (step_flag_ ? 0 : QPiter_);     // Reset QPiter only on serious steps
+    QPiter_ = (step_flag_==1 ? 0 : QPiter_);  // Reset QPiter only on serious steps
     Real v(0), l(0), u = T_, gd(0);           // Scalar storage
     Real zero(0), two(2), half(0.5);
     bool flag = true;
@@ -194,12 +200,26 @@ public:
       QPiter_ += bundle_->solveDual(state->searchSize,QPmaxit_,QPtol_);  // Solve QP subproblem
       bundle_->aggregate(*aggSubGradNew_,aggLinErrNew_,aggDistMeasNew_); // Compute aggregate info
       algo_state.aggregateGradientNorm = aggSubGradNew_->norm();         // Aggregate subgradient norm
+      if (verbosity_ > 0) {
+        std::cout << std::endl;
+        std::cout << "  Computation of aggregrate quantities" << std::endl;
+        std::cout << "    Aggregate subgradient norm:       " << algo_state.aggregateGradientNorm << std::endl;
+        std::cout << "    Aggregate linearization error:    " << aggLinErrNew_ << std::endl;
+        std::cout << "    Aggregate distance measure:       " << aggDistMeasNew_ << std::endl;
+      }
       /*************************************************************/
       /******** Construct Cutting Plane Solution *******************/
       /*************************************************************/
       v = -state->searchSize*std::pow(algo_state.aggregateGradientNorm,two)-aggLinErrNew_; // CP objective value
       s.set(aggSubGradNew_->dual()); s.scale(-state->searchSize);            // CP solution
       algo_state.snorm = state->searchSize*algo_state.aggregateGradientNorm; // Step norm
+      if (verbosity_ > 0) {
+        std::cout << std::endl;
+        std::cout << "  Solve cutting plan subproblem" << std::endl;
+        std::cout << "    Cutting plan objective value:     " << v << std::endl;
+        std::cout << "    Norm of computed step:            " << algo_state.snorm << std::endl;
+        std::cout << "    'Trust-region' radius:            " << state->searchSize << std::endl;
+      }
       /*************************************************************/
       /******** Decide Whether Step is Serious or Null *************/
       /*************************************************************/
@@ -211,6 +231,14 @@ public:
         algo_state.flag = true;
         break;
       }
+      else if (std::isnan(algo_state.aggregateGradientNorm)
+               || std::isnan(aggLinErrNew_)
+               || (std::isnan(aggDistMeasNew_) && !isConvex_)) {
+        s.zero(); algo_state.snorm = zero;
+        flag = false;
+        step_flag_ = 2;
+        algo_state.flag = true;
+      }
       else {
         // Current iterate is not epsilon optimal.
         y_->set(x); y_->plus(s);                       // y is the candidate iterate
@@ -223,22 +251,60 @@ public:
         gd = s.dot(state->gradientVec->dual());
         linErrNew_ = algo_state.value - (valueNew_ - gd); // Linearization error
         // Determine whether to take a serious or null step
-        bool SS1  = (valueNew_-algo_state.value <  m1_*v);
+        Real eps  = static_cast<Real>(10)*ROL_EPSILON<Real>();
+        Real del  = eps*std::max(static_cast<Real>(1),std::abs(algo_state.value));
+        Real Df   = (valueNew_ - algo_state.value) - del;
+        Real Dm   = v - del;
+        bool SS1  = false;
+        if (std::abs(Df) < eps && std::abs(Dm) < eps) {
+          SS1 = true;
+        }
+        else {
+          SS1 = (Df < m1_*Dm);
+        }
+        //bool SS1  = (valueNew_-algo_state.value <  m1_*v);
         //bool NS1  = (valueNew_-algo_state.value >= m1_*v);
         bool NS2a = (bundle_->computeAlpha(algo_state.snorm,linErrNew_) <= m3_*aggLinErrOld_);
         bool NS2b = (std::abs(algo_state.value-valueNew_) <= aggSubGradOldNorm_ + aggLinErrOld_);
+        if (verbosity_ > 0) {
+          std::cout << std::endl;
+          std::cout << "  Check for serious/null step" << std::endl;
+          std::cout << "    Serious step test SS(i):          " << SS1 << std::endl;
+          std::cout << "       -> Left hand side:             " << valueNew_-algo_state.value << std::endl;
+          std::cout << "       -> Right hand side:            " << m1_*v << std::endl;
+          std::cout << "    Null step test NS(iia):           " << NS2a << std::endl;
+          std::cout << "       -> Left hand side:             " << bundle_->computeAlpha(algo_state.snorm,linErrNew_) << std::endl;
+          std::cout << "       -> Right hand side:            " << m3_*aggLinErrOld_ << std::endl;
+          std::cout << "    Null step test NS(iib):           " << NS2b << std::endl;
+          std::cout << "       -> Left hand side:             " << std::abs(algo_state.value-valueNew_) << std::endl;
+          std::cout << "       -> Right hand side:            " << aggSubGradOldNorm_ + aggLinErrOld_ << std::endl;
+        }
         if ( isConvex_ ) {
           /************* Convex objective ****************/
           if ( SS1 ) {
             bool SS2 = (gd >= m2_*v || state->searchSize >= T_-nu_);
+            if (verbosity_ > 0) {
+              std::cout << "    Serious step test SS(iia):        " << (gd >= m2_*v) << std::endl;
+              std::cout << "       -> Left hand side:             " << gd << std::endl;
+              std::cout << "       -> Right hand side:            " << m2_*v << std::endl;
+              std::cout << "    Serious step test SS(iia):        " << (state->searchSize >= T_-nu_) << std::endl;
+              std::cout << "       -> Left hand side:             " << state->searchSize << std::endl;
+              std::cout << "       -> Right hand side:            " << T_-nu_ << std::endl;
+            }
             if ( SS2 ) { // Serious Step
               step_flag_ = 1;
               flag       = false;
+              if (verbosity_ > 0) {
+                std::cout << "  Serious step taken" << std::endl;
+              }
               break;
             }
             else { // Increase trust-region radius
               l = state->searchSize;
               state->searchSize = half*(u+l);
+              if (verbosity_ > 0) {
+                std::cout << "    Increase 'trust-region' radius:   " << state->searchSize << std::endl;
+              }
             }
           }
           else {
@@ -246,17 +312,28 @@ public:
               s.zero(); algo_state.snorm = zero;
               step_flag_ = 0;
               flag       = false;
+              if (verbosity_ > 0) {
+                std::cout << "  Null step taken" << std::endl;
+              }
               break;
             }
             else { // Decrease trust-region radius
               u = state->searchSize;
               state->searchSize = half*(u+l);
+              if (verbosity_ > 0) {
+                std::cout << "    Decrease 'trust-region' radius:   " << state->searchSize << std::endl;
+              }
             }
           }
         }
         else {
           /************* Nonconvex objective *************/
           bool NS3 = (gd - bundle_->computeAlpha(algo_state.snorm,linErrNew_) >= m2_*v);
+          if (verbosity_ > 0) {
+            std::cout << "    Null step test NS(iii):           " << NS3 << std::endl;
+            std::cout << "       -> Left hand side:             " << gd - bundle_->computeAlpha(algo_state.snorm,linErrNew_) << std::endl;
+            std::cout << "       -> Right hand side:            " << m2_*v << std::endl;
+          }
           if ( SS1 ) { // Serious step
             step_flag_ = 1;
             flag       = false;
@@ -321,14 +398,14 @@ public:
       /*************************************************************/
       /******** Update Bundle with Step Information ****************/
       /*************************************************************/
-      if ( step_flag_ ) {
+      if ( step_flag_==1 ) {
         // Serious step was taken
         x.plus(s);                        // Update iterate
         Real valueOld = algo_state.value; // Store previous objective value
         algo_state.value = valueNew_;     // Add new objective value to state
         bundle_->update(step_flag_,valueNew_-valueOld,algo_state.snorm,*(state->gradientVec),s);
       }
-      else {
+      else if ( step_flag_==0 ) {
         // Null step was taken
         bundle_->update(step_flag_,linErrNew_,algo_state.snorm,*(state->gradientVec),s);
       }
@@ -338,7 +415,7 @@ public:
     /*************************************************************/
     algo_state.iterateVec->set(x);
     algo_state.gnorm = (state->gradientVec)->norm();
-    if ( step_flag_ ) {
+    if ( step_flag_==1 ) {
       algo_state.iter++;
     }
   } // End Update
@@ -381,7 +458,7 @@ public:
       hist << std::setw(15) << std::left << algo_state.gnorm;
       hist << "\n";
     }
-    if ( step_flag_ && algo_state.iter > 0 ) {
+    if ( step_flag_==1 && algo_state.iter > 0 ) {
       if ( print_header ) {
         hist << printHeader();
       }
