@@ -232,18 +232,28 @@ private:
   */
   void updateGradient( Vector<Real> &x, Objective<Real> &obj, BoundConstraint<Real> &bnd, 
                        AlgorithmState<Real> &algo_state ) {
-    Real oem2(1.e-2), one(1), oe4(1.e4);
     Teuchos::RCP<StepState<Real> > state = Step<Real>::getState();
     if ( useInexact_[1] ) {
-      Real c = scale0_*std::max(oem2,std::min(one,oe4*algo_state.gnorm));
-      Real gtol1  = c*(state->searchSize);
-      Real gtol0  = scale1_*gtol1 + one;
-      while ( gtol0 > gtol1*scale1_ ) {
+      const Real one(1);
+      //const Real oem2(1.e-2), oe4(1.e4);
+      //Real c = scale0_*std::max(oem2,std::min(one,oe4*algo_state.gnorm));
+      //Real gtol1  = c*std::min(algo_state.gnorm,state->searchSize);
+      //Real gtol0  = scale1_*gtol1 + one;
+      //while ( gtol0 > gtol1*scale1_ ) {
+      //  obj.gradient(*(state->gradientVec),x,gtol1);
+      //  algo_state.gnorm = computeCriticalityMeasure(*(state->gradientVec),x,bnd);
+      //  gtol0 = gtol1;
+      //  c = scale0_*std::max(oem2,std::min(one,oe4*algo_state.gnorm));
+      //  gtol1 = c*std::min(algo_state.gnorm,state->searchSize);
+      //}
+      //algo_state.ngrad++;
+      Real gtol1  = scale0_*std::min(algo_state.gnorm,state->searchSize);
+      Real gtol0  = gtol1 + one;
+      while ( gtol0 > gtol1 ) {
         obj.gradient(*(state->gradientVec),x,gtol1);
         algo_state.gnorm = computeCriticalityMeasure(*(state->gradientVec),x,bnd);
         gtol0 = gtol1;
-        c = scale0_*std::max(oem2,std::min(one,oe4*algo_state.gnorm));
-        gtol1 = c*std::min(algo_state.gnorm,state->searchSize);
+        gtol1 = scale0_*std::min(algo_state.gnorm,state->searchSize);
       }
       algo_state.ngrad++;
     }
@@ -584,7 +594,7 @@ public:
     }
     // Update trust-region information;
     // Performs a hard update on the objective function
-    TRflag_   = TRUSTREGION_FLAG_SUCCESS;
+    TRflag_ = TRUSTREGION_FLAG_SUCCESS;
     state->nfval = 0;
     state->ngrad = 0;
     Real fold = algo_state.value;
@@ -654,6 +664,12 @@ public:
       // Update algorithm state
       (algo_state.iterateVec)->set(x);
     }
+    else {
+      if ( useInexact_[1] ) {
+        // Update objective function and approximate model
+        updateGradient(x,obj,bnd,algo_state);
+      }
+    }
     // Update algorithm state
     algo_state.value = fnew;
   }
