@@ -81,40 +81,46 @@ public:
     Hp_ = g.clone();
   }
 
-  void run( Vector<Real> &s, Real &snorm, Real &del, int &iflag, int &iter, const Vector<Real> &x,
-            const Vector<Real> &grad, const Real &gnorm, ProjectedObjective<Real> &pObj ) { 
-    Real tol = std::sqrt(ROL_EPSILON<Real>()), one(1), zero(0), half(0.5), p2(0.2), p8(0.8), two(2);
-
-    // Compute quasi-Newton step
-    pObj.reducedInvHessVec(*s_,grad,x,grad,x,tol);
-    s_->scale(-one);
-    Real sNnorm = s_->norm();
-    Real tmp    = s_->dot(grad.dual());
-    bool negCurv = false;
-    if ( tmp >= zero ) {
-      negCurv = true;
-    }
+  void run( Vector<Real>           &s,
+            Real                   &snorm,
+            int                    &iflag,
+            int                    &iter,
+            const Real              del,
+            TrustRegionModel<Real> &model ) {
+    Real tol = std::sqrt(ROL_EPSILON<Real>());
+    const Real one(1), zero(0), half(0.5), p2(0.2), p8(0.8), two(2);
+    // Set s to be the (projected) gradient
+    model.dualTransform(*Hp_,*model.getGradient());
+    s.set(Hp_->dual());
+    // Compute (quasi-)Newton step
+    model.invHessVec(*s_,*Hp_,s,tol);
+    Real sNnorm  = s_->norm();
+    Real tmp     = -s_->dot(s);
+    bool negCurv = (tmp > zero ? true : false);
     Real gsN = std::abs(tmp);
-
+    // Check if (quasi-)Newton step is feasible
     if ( negCurv ) {
-      cpt_->run(s,snorm,del,iflag,iter,x,grad,gnorm,pObj);
+      // Use Cauchy point
+      cpt_->run(s,snorm,iflag,iter,del,model);
       pRed_ = cpt_->getPredictedReduction();
       iflag = 2;
     }
     else {
       // Approximately solve trust region subproblem using double dogleg curve
-      if (sNnorm <= del) {        // Use the quasi-Newton step
+      if (sNnorm <= del) { // Use the (quasi-)Newton step
         s.set(*s_); 
+        s.scale(-one);
         snorm = sNnorm;
         pRed_ = half*gsN;
         iflag = 0;
       }
-      else {                      // quasi-Newton step is outside of trust region
-        pObj.reducedHessVec(*Hp_,grad.dual(),x,grad,x,tol);
+      else { // The (quasi-)Newton step is outside of trust region
+        model.hessVec(*Hp_,s,s,tol);
         Real alpha  = zero;
         Real beta   = zero;
+        Real gnorm  = s.norm();
         Real gnorm2 = gnorm*gnorm;
-        Real gBg    = grad.dot(*Hp_);
+        Real gBg    = Hp_->dot(s.dual());
         Real gamma1 = gnorm/gBg;
         Real gamma2 = gnorm/gsN;
         Real eta    = p8*gamma1*gamma2 + p2;
@@ -122,7 +128,7 @@ public:
           alpha = del/sNnorm;
           beta  = zero;
           s.set(*s_);
-          s.scale(alpha);
+          s.scale(-alpha);
           snorm = del;
           iflag = 1;
         }
@@ -130,17 +136,15 @@ public:
           if (gnorm2*gamma1 >= del) { // Cauchy Point is outside trust region
             alpha = zero;
             beta  = -del/gnorm;
-            s.set(grad.dual()); 
             s.scale(beta); 
             snorm = del;
             iflag = 2;
           }
           else {              // Find convex combination of Cauchy and Dogleg point
-            s.set(grad.dual());
             s.scale(-gamma1*gnorm);
             v_->set(s);
-            v_->scale(-one);
             v_->axpy(eta,*s_);
+            v_->scale(-one);
             Real wNorm = v_->dot(*v_);
             Real sigma = del*del-std::pow(gamma1*gnorm,two);
             Real phi   = s.dot(*v_);
@@ -155,6 +159,9 @@ public:
         pRed_ = -(alpha*(half*alpha-one)*gsN + half*beta*beta*gBg + beta*(one-alpha)*gnorm2);
       }
     }
+    model.primalTransform(*s_,s);
+    s.set(*s_);
+    snorm = s.norm();
     TrustRegion<Real>::setPredictedReduction(pRed_);
   }
 };
