@@ -38,9 +38,11 @@ namespace Kokkos {
 
 // Contiguous layout for scalar types -- equivalent to the wrapped
 // layout type
-template <typename Layout>
+template <typename Layout, unsigned Stride = 1>
 struct LayoutContiguous : public Layout {
 
+  enum { stride = Stride };
+
   //! Tag this class as a kokkos array layout
   typedef LayoutContiguous array_layout ;
 
@@ -54,6 +56,11 @@ struct LayoutContiguous : public Layout {
     size_t N0 = 0 , size_t N1 = 0 , size_t N2 = 0 , size_t N3 = 0
   , size_t N4 = 0 , size_t N5 = 0 , size_t N6 = 0 , size_t N7 = 0 )
     : Layout( N0 , N1 , N2 , N3 , N4 , N5 , N6 , N7 ) {}
+
+  KOKKOS_INLINE_FUNCTION
+  constexpr LayoutContiguous( Layout const & layout ) : Layout(layout) {}
+  KOKKOS_INLINE_FUNCTION
+  constexpr LayoutContiguous( Layout && layout ) : Layout(layout) {}
 };
 
 } // namespace Kokkos
@@ -61,13 +68,13 @@ struct LayoutContiguous : public Layout {
 // Make LayoutContiguous<Layout> equivalent to Layout
 namespace std {
 
-  template <class Layout>
-  struct is_same< Kokkos::LayoutContiguous<Layout>, Layout> {
+  template <class Layout, unsigned Stride>
+  struct is_same< Kokkos::LayoutContiguous<Layout,Stride>, Layout> {
     static const bool value = true;
   };
 
-  template <class Layout>
-  struct is_same< Layout, Kokkos::LayoutContiguous<Layout> > {
+  template <class Layout, unsigned Stride>
+  struct is_same< Layout, Kokkos::LayoutContiguous<Layout,Stride> > {
     static const bool value = true;
   };
 
@@ -80,8 +87,8 @@ namespace Experimental {
 namespace Impl {
 
 // Implement ViewOffset for LayoutContiguous
-template < class Dimension , class Layout >
-struct ViewOffset<Dimension, LayoutContiguous<Layout>, void>
+template < class Dimension , class Layout , unsigned Stride >
+struct ViewOffset<Dimension, LayoutContiguous<Layout,Stride>, void>
   : public ViewOffset<Dimension,Layout> {
 public:
 
@@ -105,6 +112,18 @@ public:
   constexpr ViewOffset(const Arg1& arg1, const Arg2& arg2) : Base(arg1,arg2) {}
 };
 
+template <typename Layout>
+struct LayoutScalarStride {
+  static const unsigned stride = 1;
+  static const bool is_unit_stride = true;
+};
+
+template <typename Layout, unsigned Stride>
+struct LayoutScalarStride< LayoutContiguous<Layout,Stride> > {
+  static const unsigned stride = Stride;
+  static const bool is_unit_stride = (Stride == 1);
+};
+
 } // namespace Impl
 } // namespace Experimental
 } // namespace Kokkos
