@@ -1987,8 +1987,8 @@ namespace Sacado {
         expr2.cache();
         const value_type_1 v1 = expr1.val();
         const value_type_2 v2 = expr2.val();
-        v = std::max(v1,v2);
         max_v1 = (v1 >= v2);
+        v = max_v1 ? v1 : v2;
       }
 
       KOKKOS_INLINE_FUNCTION
@@ -2065,8 +2065,8 @@ namespace Sacado {
         expr1.cache();
         const value_type_1 v1 = expr1.val();
         const value_type_2 v2 = expr2.val();
-        v = std::max(v1,v2);
         max_v1 = (v1 >= v2);
+        v = max_v1 ? v1 : v2;
       }
 
       KOKKOS_INLINE_FUNCTION
@@ -2143,8 +2143,8 @@ namespace Sacado {
         expr2.cache();
         const value_type_1 v1 = expr1.val();
         const value_type_2 v2 = expr2.val();
-        v = std::max(v1,v2);
         max_v1 = (v1 >= v2);
+        v = max_v1 ? v1 : v2;
       }
 
       KOKKOS_INLINE_FUNCTION
@@ -2229,8 +2229,8 @@ namespace Sacado {
         expr2.cache();
         const value_type_1 v1 = expr1.val();
         const value_type_2 v2 = expr2.val();
-        v = std::min(v1,v2);
         min_v1 = (v1 <= v2);
+        v = min_v1 ? v1 : v2;
       }
 
       KOKKOS_INLINE_FUNCTION
@@ -2307,8 +2307,8 @@ namespace Sacado {
         expr1.cache();
         const value_type_1 v1 = expr1.val();
         const value_type_2 v2 = expr2.val();
-        v = std::min(v1,v2);
         min_v1 = (v1 <= v2);
+        v = min_v1 ? v1 : v2;
       }
 
       KOKKOS_INLINE_FUNCTION
@@ -2385,8 +2385,8 @@ namespace Sacado {
         expr2.cache();
         const value_type_1 v1 = expr1.val();
         const value_type_2 v2 = expr2.val();
-        v = std::min(v1,v2);
         min_v1 = (v1 <= v2);
+        v = min_v1 ? v1 : v2;
       }
 
       KOKKOS_INLINE_FUNCTION
