@@ -51,6 +51,25 @@ TEUCHOS_UNIT_TEST(Kokkos_View_Fad, DynRankMauroDeepCopy )
   success = true;
 }
 
+// Tests assignment between ViewFad and Fad of different type
+TEUCHOS_UNIT_TEST(Kokkos_View_Fad, MixedViewFadTypes )
+{
+  const int StaticDim = 5;
+  typedef Sacado::Fad::SFad<double,StaticDim> FadType1;
+  typedef Sacado::Fad::SLFad<double,StaticDim> FadType2;
+  typedef Kokkos::View<FadType1*,Kokkos::Serial> ViewType;
+
+  const size_t num_rows = 11;
+  const size_t fad_size = StaticDim;
+  ViewType v("v", num_rows, fad_size+1);
+
+  FadType2 x = 0.0;
+  x = v(1);
+
+  const size_t sz = x.size();
+  TEUCHOS_TEST_EQUALITY(sz, fad_size, out, success);
+}
+
 int main( int argc, char* argv[] ) {
   Teuchos::GlobalMPISession mpiSession(&argc, &argv);
 
