@@ -45,9 +45,8 @@ template <typename INT> class Exo_Block : public Exo_Entity
 {
 public:
   Exo_Block();
-  Exo_Block(int exo_file_id, size_t block_id);
-  Exo_Block(int exo_file_id, size_t block_id, const char *type, size_t num_elmts,
-            size_t num_nodes_per_elmt_x);
+  Exo_Block(int file_id, size_t exo_block_id);
+  Exo_Block(int file_id, size_t id, const char *type, size_t num_e, size_t num_npe);
   ~Exo_Block() override;
 
   std::string Load_Connectivity();
