@@ -83,16 +83,17 @@ C   --   "User's Manual for GJOIN"
       include 'gj_dbvars.blk'
       include 'gj_filnum.blk'
       include 'gj_xyzrot.blk'
+      include 'argparse.inc'
 
       DIMENSION A(1), IA(1)
 C      --A - the dynamic numeric memory base array
       EQUIVALENCE (A(1),IA(1))
       character*1 c(1)
 
-      LOGICAL USESDF, NONQUD
+      LOGICAL USESDF, NONQUD, L64BIT, NC4
       LOGICAL RENNP, RENEL, REN, DELNP, DELEL, BATCH, CLOSE, MATMAT
       LOGICAL FIRST, DONE, MDEBUG
-      character*(2048) filnam, string
+      character*(2048) filnam, string, syntax, scratch
 
 C... String containing name of common element topology in model
 C    or 'MULTIPLE_TOPOLOGIES' if not common topology.
@@ -105,6 +106,9 @@ C      --INFREC - the information records
 
       include 'gj_qainfo.blk'
 
+      L64BIT = .false.
+      Nc4    = .false.
+      
       CALL STRTUP (QAINFO)
 
       CALL BANNER (0, QAINFO,
@@ -113,10 +117,6 @@ C      --INFREC - the information records
 
       call cpyrgt (0, '1988')
 
-      call exinq (netid, EXLBVR, idummy, exlibversion, name, nerr)
-      write(*,'(A,F6.3)')'ExodusII Library version ',
-     &          exlibversion
-
 C     --Open LOG file if running interactively
       IF (.NOT. BATCH()) THEN
          KLOG = 99
@@ -149,6 +149,31 @@ C      end if
 
  80   CONTINUE
 
+C .. Get filename from command line.  If not specified, emit error message
+      SYNTAX = 'Syntax is: "gjoin [-64] [-netcdf4]"'
+      NARG = argument_count()
+C ... Parse options...
+      name_len = 0
+      if (narg .ge. 1) then
+        iarg = 1
+        do
+          CALL get_argument(iarg,STRING, LNAM)
+          iarg = iarg + 1
+          if (string(:lnam) .eq. '-64') then
+            l64bit = .true.
+          else if (string(:lnam) .eq. '-netcdf4') then
+            nc4 = .true.
+          else
+            SCRATCH =
+     *        'Unrecognized command option "'//STRING(:LNAM)//'"'
+            CALL PRTERR ('FATAL', SCRATCH(:LENSTR(SCRATCH)))
+            CALL PRTERR ('CMDSPEC', SYNTAX(:LENSTR(SYNTAX)))
+            go to 150
+          end if
+          if (iarg .ge. narg) exit
+        end do
+      end if
+
       CALL INIGEN (A, FIRST,
      &   KXN, KYN, KZN, KMAPEL,
      &   KIDELB, KNELB, KNLNK, KNATR, KLINK, KATRIB,
@@ -713,7 +738,8 @@ C   --Write the QA records
      &   KIDELB, KNELB, KNLNK, KNATR, KLINK, KATRIB,
      &   KIDNS, KNNNS, KIXNNS, KLTNNS, KFACNS,
      &   KIDSS, KNESS, KNDSS, KIXESS, KIXDSS, KLTESS, KFACSS,
-     &   kltsss, NQAREC, QAREC, NINFO, INFREC, C(KNMLB), *140)
+     &   kltsss, NQAREC, QAREC, NINFO, INFREC, C(KNMLB), L64BIT, NC4,
+     &   *140)
 
       FIRST = .FALSE.
 
