@@ -153,7 +153,7 @@ C ... Parse options...
             CALL PRTERR ('FATAL', SCRATCH(:LENSTR(SCRATCH)))
             CALL PRTERR ('CMDSPEC', SYNTAX(:LENSTR(SYNTAX)))
           end if
-          if (i .gt. narg-2) exit
+          if (iarg .gt. narg-2) exit
         end do
       end if
 
@@ -420,7 +420,7 @@ C     .. Set up status arrays for element to nodal variable conversion
      &     IA(KLTESS), IA(KLTSSS), A(KFACSS),
      &     A(KXN), A(KYN), A(KZN),
      &     A(KXEXPL), A(KYEXPL), A(KZEXPL), MODBLK,
-     &     ISATRB, A(KATRSC), IA(KIXNP), IA(KMAPNN),
+     &     ISATRB, A(KATRSC), IA(KIXNP), IA(KMAPNN), IA(KMAPEL),
      &     IA(KIELBS), IA(KINPSS), IA(KIESSS),
      &     NQAREC, C(KQAREC), NINFO, c(kinfo), c(kbktyp),
      *     c(knameb), c(knamnp), c(knamss), c(knamatt),
@@ -665,6 +665,15 @@ C     --location of original numelb, isevok arrays
       
       if (renel .or. delnp) then
         CALL MDRSRV ('MSCR', KMSCR, MAX(NUMEL0, NUMNP0))
+        if (exodus) then
+C     ... Map from new var to old for mapping variables.
+          CALL MDRSRV ('MAPL', KMAPL, NUMEL0)
+          CALL MDRSRV ('MAPN', KMAPN, NUMNP0)
+          CALL MDSTAT (NERR, MEM)
+          IF (NERR .GT. 0) GOTO 40
+          CALL INIMAP(NUMEL0, IA(KMAPL))
+          CALL INIMAP(NUMNP0, IA(KMAPN))
+        end if
       end if
 
       IF (RENEL) THEN
@@ -680,14 +689,6 @@ C     old array contents into new (Only needed if EXODUS)
             CALL CPYINT (NELBLK0, IA(KNELB),  IA(KNELB0))
             CALL CPYINT (NELBLK0, IA(KIDELB2), IA(KIDELB0))
             CALL CPYINT (LIEVOK,  LA(KIEVOK), LA(KIEVOK0))
-
-C     ... Map from new var to old for mapping variables.
-            CALL MDRSRV ('MAPL', KMAPL, NUMEL0)
-            CALL MDRSRV ('MAPN', KMAPN, NUMNP0)
-            CALL MDSTAT (NERR, MEM)
-            IF (NERR .GT. 0) GOTO 40
-            CALL INIMAP(NUMEL0, IA(KMAPL))
-            CALL INIMAP(NUMNP0, IA(KMAPN))
          END IF
          
          CALL MDRSRV ('IXEL', KIXEL, NUMEL)
@@ -764,6 +765,9 @@ C     ... NUMNP modified in this call
          CALL MDSTAT (NERR, MEM)
          IF (NERR .GT. 0) GOTO 40
          CALL REMAP(NUMNP0, IA(KIXNP), IA(KMAPNN), IA(KMSCR))
+         IF (EXODUS) THEN
+            CALL REMAP (NUMNP0, IA(KIXNP), IA(KMAPN),  IA(KMSCR))
+         END IF
       END IF
 
 C     --Renumber the element map
@@ -779,12 +783,10 @@ C     --Squeeze the element map
 
       IF (DELEL) THEN
 C     ... Changes first argument
-         NSAVE = NUMEL0
-         CALL ZMMAP (NSAVE, IA(KMAPEL))
+         CALL ZMMAP (NUMEL0, IA(KMAPEL))
          CALL MDLONG ('MAPEL', KMAPEL, NUMEL)
-         NSAVE = NUMEL0
          IF (EXODUS) THEN
-            CALL ZMMAP (NSAVE, IA(KMAPL))
+            CALL ZMMAP (NUMEL0, IA(KMAPL))
             CALL MDLONG ('MAPL',  KMAPL,  NUMEL)
          END IF
       END IF
@@ -792,8 +794,7 @@ C     ... Changes first argument
 C     --Renumber the element block nodes
 
       IF (DELNP) THEN
-        NSAVE = NUMNP0
-        CALL ZMMAP(NSAVE, IA(KMAPNN))
+        CALL ZMMAP(NUMNP0, IA(KMAPNN))
         CALL MDLONG ('MAPNN', KMAPNN, NUMNP)
         CALL RENELB (NELBLK, -999, IA(KIXNP),
      &    IA(KNELB), IA(KNLNK), IA(KLINK))
@@ -803,15 +804,6 @@ C     --Renumber the nodal point set nodes
 
       IF (DELNP) THEN
          CALL RENIX (LNPSNL, -999, IA(KIXNP), IA(KLTNNS), .TRUE.)
-         NSAVE = NUMNP0
-         IF (EXODUS) THEN
-            IF (.not. DELEL) THEN
-              CALL MDRSRV ('MSCR', KMSCR, MAX(NUMEL0, NUMNP0))
-            ENDIF
-            CALL REMAP (NSAVE, IA(KIXNP), IA(KMAPN),  IA(KMSCR))
-            NSAVE = NUMNP0
-            CALL ZMMAP (NSAVE, IA(KMAPN))
-         END IF
       END IF
 
 C     --Renumber the element side set elements
@@ -865,7 +857,8 @@ C     --Squeeze the nodal point sets
 
          IF (DELNP) THEN
             CALL ZMNPS (NUMNPS, IA(KINPSS), LNPSNL, LNPSDF,
-     *       IA(KIDNS), IA(KNNNS), IA(KIXNNS), IA(KLTNNS), A(KFACNS))
+     *       IA(KIDNS), IA(KNNNS), IA(KIXNNS), IA(KLTNNS), A(KFACNS),
+     *       C(KNAMNP))
          END IF
 
 C     ... Fix up the truth table if the nodeset count changes... 
@@ -879,9 +872,9 @@ C     ... Fix up the truth table if the nodeset count changes...
            call muntt(numnps0, numnps, nvarns, 
      $       ia(knsvok0), ia(knsvok), ia(kinpss))
 
-C ... check that the sidesets that are retained contain the same number
-C     of faces that the original sidesets contain.  At the current time,
-C     can only map sideset variables if the sidesets are the same...
+C ... check that the nodesets that are retained contain the same number
+C     of nodes that the original nodesets contain.  At the current time,
+C     can only map nodeset variables if the nodesets are the same...
             i1 = 0
             do i=0,numnps0-1
                if (ia(kinpss+i) .eq.0) then
@@ -1202,8 +1195,10 @@ C     --Read the database time steps
       
 C ... NOTE: VARNP and VAREL are treated as doubly-dimensioned arrays
 C           dimensioned as (NUMEL, NVAREL)
+      iostep = 0
       do 110 istep = 1, nsteps
         if (ia(kitims+istep-1) .eq. 0) then
+          iostep = iostep + 1
            CALL DBISTE (NDBIN, '*', istep,
      &      NVARGL,
      *      NVARNP, NUMNP0,
@@ -1255,7 +1250,7 @@ C     number element blocks, and truth table.
 
            END IF
 
-           CALL DBOSTE (NDBOUT, ISTEP,
+           CALL DBOSTE (NDBOUT, IOSTEP,
      &          NVARGL, NVARNP, NUMNP, NVAREL, INOD2EL, NELBLK,
      $          IA(KNELB), LA(KIEVOK), IA(KIDELB),
      $          NVARNS, NUMNPS0, IA(KNNNS0), IA(KNSVOK0), IA(KIDNS0),
@@ -1264,13 +1259,13 @@ C     number element blocks, and truth table.
      $          A(KVARGL), A(KVARNP), A(KVAREL), A(KVARNS), A(KVARSS),
      $          A(KELMTZ))
            
-           WRITE (*, 10000) ISTEP, TIME
+           WRITE (*, 10000) IOSTEP, TIME
 10000      FORMAT (' ', I8, ' time steps processed.  Time = ',1PE10.3)
         end if
  110  continue
       
  120  CONTINUE
-      WRITE (SCRSTR, '(I9)', IOSTAT=K) NSTEPS
+      WRITE (SCRSTR, '(I9)', IOSTAT=K) IOSTEP
       CALL SQZSTR (SCRSTR, LSTR)
       WRITE (*, 10010) SCRSTR(:LSTR)
 10010 FORMAT (/, 4X, A,
