@@ -32,8 +32,8 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  */
-#define NAME_LENGTH 256 /* Maximum length of file name */
-#define LINE_LENGTH 200 /* Length of input files read at once */
+#define NAME_LENGTH 256 /**< Maximum length of file name */
+#define LINE_LENGTH 200 /**< Length of input files read at once */
 
-#define MAXDIMS 3 /* Most cuts allowed at one time */
-#define MAXSETS 8 /* 2^MAXDIMS */
+#define MAXDIMS 3 /**< Most cuts allowed at one time */
+#define MAXSETS 8 /**< 2^MAXDIMS */
