@@ -33,14 +33,36 @@
  *
  */
 
-#include "exodusII.h"     // for ex_large_model, etc
+#include "exodusII.h"     // for EX_FATAL, exerrval, ex_err, etc
 #include "exodusII_int.h" // for ex_get_counter_list, etc
-#include "netcdf.h"       // for nc_inq_varid, etc
+#include "netcdf.h"       // for NC_NOERR, nc_inq_varid, etc
 #include <assert.h>       // for assert
 #include <stddef.h>       // for size_t
-#include <stdlib.h>       // for malloc, free
+#include <stdint.h>       // for int64_t
+#include <stdio.h>        // for fprintf, stderr, snprintf
+#include <stdlib.h>       // for free, calloc, malloc
 #include <string.h>       // for strcmp, strncmp, NULL
-#include <sys/types.h>    // for int64_t
+
+#define STRINGIFY(x) #x
+#define TOSTRING(x) STRINGIFY(x)
+
+#define EXCHECK(funcall)                                                                           \
+  if ((funcall) != NC_NOERR) {                                                                     \
+    fprintf(stderr, "Error calling %s\n", TOSTRING(funcall));                                      \
+    EX_FUNC_LEAVE(EX_FATAL);                                                                       \
+  }
+
+#define EXCHECKI(funcall)                                                                          \
+  if ((funcall) != NC_NOERR) {                                                                     \
+    fprintf(stderr, "Error calling %s\n", TOSTRING(funcall));                                      \
+    return (EX_FATAL);                                                                             \
+  }
+
+#define EXCHECKF(funcall)                                                                          \
+  if ((funcall) != NC_NOERR) {                                                                     \
+    fprintf(stderr, "Error calling %s\n", TOSTRING(funcall));                                      \
+    goto err_ret;                                                                                  \
+  }
 
 /*! \cond INTERNAL */
 struct ncdim
@@ -111,7 +133,9 @@ int ex_copy(int in_exoid, int out_exoid)
   int          in_large, out_large;
   char         errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(in_exoid);
+  ex_check_valid_file_id(out_exoid);
 
   /*
    * Get exodus_large_model setting on both input and output
@@ -125,11 +149,10 @@ int ex_copy(int in_exoid, int out_exoid)
    * Currently they should both match or there will be an error.
    */
   if (ex_int64_status(in_exoid) != ex_int64_status(out_exoid)) {
-    exerrval = EX_WRONGFILETYPE;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: integer sizes do not match for input and output databases.");
-    ex_err("ex_copy", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_copy", errmsg, EX_WRONGFILETYPE);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /*
@@ -137,16 +160,16 @@ int ex_copy(int in_exoid, int out_exoid)
    * atts, and dimension id of unlimited dimension, if any
    */
 
-  (void)nc_inq(in_exoid, &ndims, &nvars, &ngatts, &recdimid);
-  (void)nc_inq_dimlen(in_exoid, recdimid, &numrec);
+  EXCHECK(nc_inq(in_exoid, &ndims, &nvars, &ngatts, &recdimid));
+  EXCHECK(nc_inq_dimlen(in_exoid, recdimid, &numrec));
 
   /* put output file into define mode */
-  (void)nc_redef(out_exoid);
+  EXCHECK(nc_redef(out_exoid));
 
   /* copy global attributes */
   for (i = 0; i < (size_t)ngatts; i++) {
 
-    (void)nc_inq_attname(in_exoid, NC_GLOBAL, i, att.name);
+    EXCHECK(nc_inq_attname(in_exoid, NC_GLOBAL, i, att.name));
 
     /* if attribute exists in output file, don't overwrite it; compute
      * word size, I/O word size etc. are global attributes stored when
@@ -162,7 +185,7 @@ int ex_copy(int in_exoid, int out_exoid)
       */
       if (strcmp(att.name, "last_written_time") != 0) {
         /* attribute doesn't exist in new file so OK to create it */
-        nc_copy_att(in_exoid, NC_GLOBAL, att.name, out_exoid, NC_GLOBAL);
+        EXCHECK(nc_copy_att(in_exoid, NC_GLOBAL, att.name, out_exoid, NC_GLOBAL));
       }
     }
   }
@@ -173,7 +196,7 @@ int ex_copy(int in_exoid, int out_exoid)
 
   for (dimid = 0; dimid < ndims; dimid++) {
 
-    (void)nc_inq_dim(in_exoid, dimid, dim_nm, &dim_sz);
+    EXCHECK(nc_inq_dim(in_exoid, dimid, dim_nm, &dim_sz));
 
     /* If the dimension isn't one we specifically don't want
      * to copy (ie, number of QA or INFO records) and it
@@ -197,11 +220,10 @@ int ex_copy(int in_exoid, int out_exoid)
           status = nc_def_dim(out_exoid, dim_nm, NC_UNLIMITED, &dim_out_id);
         } /* end else */
         if (status != NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define %s dimension in file id %d",
                    dim_nm, out_exoid);
-          ex_err("ex_copy", errmsg, exerrval);
-          return (EX_FATAL);
+          ex_err("ex_copy", errmsg, status);
+          EX_FUNC_LEAVE(EX_FATAL);
         }
       } /* end if */
     }   /* end if */
@@ -223,11 +245,10 @@ int ex_copy(int in_exoid, int out_exoid)
       /* Not found; set to default value of 32+1. */
 
       if ((status = nc_def_dim(out_exoid, DIM_STR_NAME, 33, &dim_out_id)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define string name dimension in file id %d", out_exoid);
-        ex_err("ex_copy", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_copy", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
     }
   }
@@ -241,7 +262,7 @@ int ex_copy(int in_exoid, int out_exoid)
   /* copy variable definitions and variable attributes */
   for (varid = 0; varid < nvars; varid++) {
 
-    (void)nc_inq_var(in_exoid, varid, var.name, &var.type, &var.ndims, var.dims, &var.natts);
+    EXCHECK(nc_inq_var(in_exoid, varid, var.name, &var.type, &var.ndims, var.dims, &var.natts));
 
     /* we don't want to copy some variables because there is not a
      * simple way to add to them;
@@ -278,22 +299,22 @@ int ex_copy(int in_exoid, int out_exoid)
       }
 
       /* copy the variable's attributes */
-      (void)cpy_att(in_exoid, out_exoid, varid, var_out_id);
+      cpy_att(in_exoid, out_exoid, varid, var_out_id);
     }
   }
 
   /* take the output file out of define mode */
-  if ((exerrval = nc_enddef(out_exoid)) != NC_NOERR) {
+  if ((status = nc_enddef(out_exoid)) != NC_NOERR) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to complete definition in file id %d",
              out_exoid);
-    ex_err("ex_copy", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_copy", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* output variable data */
 
   for (varid = 0; varid < nvars; varid++) {
-    (void)nc_inq_var(in_exoid, varid, var.name, &var.type, &var.ndims, var.dims, &var.natts);
+    EXCHECK(nc_inq_var(in_exoid, varid, var.name, &var.type, &var.ndims, var.dims, &var.natts));
 
     /* we don't want to copy some variable values;
      * QA records and info records shouldn't be copied because there
@@ -324,10 +345,10 @@ int ex_copy(int in_exoid, int out_exoid)
         (strncmp(var.name, "vals_elem_var", 13) != 0) && (strcmp(var.name, VAR_WHOLE_TIME) != 0)) {
 
       if (strncmp(var.name, VAR_COORD, 5) == 0) {
-        (void)cpy_coord_val(in_exoid, out_exoid, var.name, in_large, out_large);
+        cpy_coord_val(in_exoid, out_exoid, var.name, in_large, out_large);
       }
       else {
-        (void)cpy_var_val(in_exoid, out_exoid, var.name);
+        cpy_var_val(in_exoid, out_exoid, var.name);
       }
     }
   }
@@ -352,9 +373,9 @@ int ex_copy(int in_exoid, int out_exoid)
   update_internal_structs(out_exoid, EX_INQ_FACE_MAP, ex_get_counter_list(EX_FACE_MAP));
   update_internal_structs(out_exoid, EX_INQ_ELEM_MAP, ex_get_counter_list(EX_ELEM_MAP));
 
-  (void)ex_update(out_exoid);
+  ex_update(out_exoid);
 
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
 
 /*! \cond INTERNAL */
@@ -375,18 +396,18 @@ int cpy_att(int in_id, int out_id, int var_in_id, int var_out_id)
   int nbr_att;
 
   if (var_in_id == NC_GLOBAL) {
-    (void)nc_inq_natts(in_id, &nbr_att);
+    EXCHECKI(nc_inq_natts(in_id, &nbr_att));
   }
   else {
-    (void)nc_inq_varnatts(in_id, var_in_id, &nbr_att);
+    EXCHECKI(nc_inq_varnatts(in_id, var_in_id, &nbr_att));
   }
 
   /* Get the attributes names, types, lengths, and values */
   for (idx = 0; idx < nbr_att; idx++) {
     char att_nm[MAX_VAR_NAME_LENGTH];
 
-    (void)nc_inq_attname(in_id, var_in_id, idx, att_nm);
-    (void)nc_copy_att(in_id, var_in_id, att_nm, out_id, var_out_id);
+    EXCHECKI(nc_inq_attname(in_id, var_in_id, idx, att_nm));
+    EXCHECKI(nc_copy_att(in_id, var_in_id, att_nm, out_id, var_out_id));
   }
 
   return (EX_NOERR);
@@ -415,7 +436,7 @@ int cpy_coord_def(int in_id, int out_id, int rec_dim_id, char *var_nm, int in_la
 
   /* Handle easiest situation first: in_large matches out_large */
   if (in_large == out_large) {
-    return cpy_var_def(in_id, out_id, rec_dim_id, var_nm);
+    return cpy_var_def(in_id, out_id, rec_dim_id, var_nm); /* OK */
   }
 
   /* At this point, know that in_large != out_large, so some change to
@@ -435,25 +456,28 @@ int cpy_coord_def(int in_id, int out_id, int rec_dim_id, char *var_nm, int in_la
       int status3 = nc_inq_varid(out_id, VAR_COORD_Y, &var_out_idz);
 
       if (status1 == NC_NOERR && status2 == NC_NOERR && (spatial_dim == 2 || status3 == NC_NOERR)) {
-        return NC_NOERR; /* already defined in output file */
+        return NC_NOERR; /* already defined in output file */ /* OK */
       }
     }
 
     /* Get dimid of the num_nodes dimension in output file... */
-    (void)nc_inq_dimid(out_id, DIM_NUM_NODES, &dim_out_id[0]);
+    EXCHECKI(nc_inq_dimid(out_id, DIM_NUM_NODES, &dim_out_id[0]));
 
     /* Define the variables in the output file */
 
     /* Define according to the EXODUS file's IO_word_size */
     nbr_dim = 1;
-    (void)nc_def_var(out_id, VAR_COORD_X, nc_flt_code(out_id), nbr_dim, dim_out_id, &var_out_id);
+    EXCHECKI(
+        nc_def_var(out_id, VAR_COORD_X, nc_flt_code(out_id), nbr_dim, dim_out_id, &var_out_id));
     ex_compress_variable(out_id, var_out_id, 2);
     if (spatial_dim > 1) {
-      (void)nc_def_var(out_id, VAR_COORD_Y, nc_flt_code(out_id), nbr_dim, dim_out_id, &var_out_id);
+      EXCHECKI(
+          nc_def_var(out_id, VAR_COORD_Y, nc_flt_code(out_id), nbr_dim, dim_out_id, &var_out_id));
       ex_compress_variable(out_id, var_out_id, 2);
     }
     if (spatial_dim > 2) {
-      (void)nc_def_var(out_id, VAR_COORD_Z, nc_flt_code(out_id), nbr_dim, dim_out_id, &var_out_id);
+      EXCHECKI(
+          nc_def_var(out_id, VAR_COORD_Z, nc_flt_code(out_id), nbr_dim, dim_out_id, &var_out_id));
       ex_compress_variable(out_id, var_out_id, 2);
     }
   }
@@ -463,21 +487,21 @@ int cpy_coord_def(int in_id, int out_id, int rec_dim_id, char *var_nm, int in_la
        have "coord".  See if is already defined in output file. */
     status = nc_inq_varid(out_id, VAR_COORD, &var_out_id);
     if (status == NC_NOERR) {
-      return NC_NOERR; /* already defined in output file */
+      return NC_NOERR; /* already defined in output file */ /* OK */
     }
 
     /* Get dimid of the spatial dimension and num_nodes dimensions in output
      * file... */
-    (void)nc_inq_dimid(out_id, DIM_NUM_DIM, &dim_out_id[0]);
-    (void)nc_inq_dimid(out_id, DIM_NUM_NODES, &dim_out_id[1]);
+    EXCHECKI(nc_inq_dimid(out_id, DIM_NUM_DIM, &dim_out_id[0]));
+    EXCHECKI(nc_inq_dimid(out_id, DIM_NUM_NODES, &dim_out_id[1]));
 
     /* Define the variable in the output file */
 
     /* Define according to the EXODUS file's IO_word_size */
     nbr_dim = 2;
-    (void)nc_def_var(out_id, VAR_COORD, nc_flt_code(out_id), nbr_dim, dim_out_id, &var_out_id);
+    EXCHECKI(nc_def_var(out_id, VAR_COORD, nc_flt_code(out_id), nbr_dim, dim_out_id, &var_out_id));
   }
-  return var_out_id;
+  return var_out_id; /* OK */
 }
 
 /*! \internal */
@@ -496,8 +520,8 @@ int cpy_var_def(int in_id, int out_id, int rec_dim_id, char *var_nm)
 
   char errmsg[MAX_ERR_LENGTH];
   int  status;
-  int *dim_in_id;
-  int *dim_out_id;
+  int *dim_in_id  = NULL;
+  int *dim_out_id = NULL;
   int  idx;
   int  nbr_dim;
   int  var_in_id;
@@ -508,15 +532,15 @@ int cpy_var_def(int in_id, int out_id, int rec_dim_id, char *var_nm)
   /* See if the requested variable is already in the output file. */
   status = nc_inq_varid(out_id, var_nm, &var_out_id);
   if (status == NC_NOERR) {
-    return var_out_id;
+    return var_out_id; /* OK */
   }
 
   /* See if the requested variable is in the input file. */
-  (void)nc_inq_varid(in_id, var_nm, &var_in_id);
+  EXCHECKI(nc_inq_varid(in_id, var_nm, &var_in_id));
 
   /* Get the type of the variable and the number of dimensions. */
-  (void)nc_inq_vartype(in_id, var_in_id, &var_type);
-  (void)nc_inq_varndims(in_id, var_in_id, &nbr_dim);
+  EXCHECKI(nc_inq_vartype(in_id, var_in_id, &var_type));
+  EXCHECKI(nc_inq_varndims(in_id, var_in_id, &nbr_dim));
 
   /* Recall:
      1. The dimensions must be defined before the variable.
@@ -527,14 +551,14 @@ int cpy_var_def(int in_id, int out_id, int rec_dim_id, char *var_nm)
   dim_out_id = malloc(nbr_dim * sizeof(int));
 
   /* Get the dimension IDs */
-  (void)nc_inq_vardimid(in_id, var_in_id, dim_in_id);
+  EXCHECKF(nc_inq_vardimid(in_id, var_in_id, dim_in_id));
 
   /* Get the dimension sizes and names */
   for (idx = 0; idx < nbr_dim; idx++) {
     char   dim_nm[NC_MAX_NAME];
     size_t dim_sz;
 
-    (void)nc_inq_dim(in_id, dim_in_id[idx], dim_nm, &dim_sz);
+    EXCHECKF(nc_inq_dim(in_id, dim_in_id[idx], dim_nm, &dim_sz));
 
     /* See if the dimension has already been defined */
     status = nc_inq_dimid(out_id, dim_nm, &dim_out_id[idx]);
@@ -542,10 +566,10 @@ int cpy_var_def(int in_id, int out_id, int rec_dim_id, char *var_nm)
     /* If the dimension hasn't been defined, copy it */
     if (status != NC_NOERR) {
       if (dim_in_id[idx] != rec_dim_id) {
-        (void)nc_def_dim(out_id, dim_nm, dim_sz, &dim_out_id[idx]);
+        EXCHECKF(nc_def_dim(out_id, dim_nm, dim_sz, &dim_out_id[idx]));
       }
       else {
-        (void)nc_def_dim(out_id, dim_nm, NC_UNLIMITED, &dim_out_id[idx]);
+        EXCHECKF(nc_def_dim(out_id, dim_nm, NC_UNLIMITED, &dim_out_id[idx]));
       }
     }
   }
@@ -556,16 +580,15 @@ int cpy_var_def(int in_id, int out_id, int rec_dim_id, char *var_nm)
      file's IO_word_size */
 
   if ((var_type == NC_FLOAT) || (var_type == NC_DOUBLE)) {
-    (void)nc_def_var(out_id, var_nm, nc_flt_code(out_id), nbr_dim, dim_out_id, &var_out_id);
+    EXCHECKF(nc_def_var(out_id, var_nm, nc_flt_code(out_id), nbr_dim, dim_out_id, &var_out_id));
     ex_compress_variable(out_id, var_out_id, 2);
   }
   else {
     if ((status = nc_def_var(out_id, var_nm, var_type, nbr_dim, dim_out_id, &var_out_id)) !=
         NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define %s variable in file id %d", var_nm,
                out_id);
-      ex_err("ex_copy", errmsg, exerrval);
+      ex_err("ex_copy", errmsg, status);
       return (EX_FATAL);
     }
     ex_compress_variable(out_id, var_out_id, 1);
@@ -575,7 +598,13 @@ int cpy_var_def(int in_id, int out_id, int rec_dim_id, char *var_nm)
   free(dim_in_id);
   free(dim_out_id);
 
-  return var_out_id;
+  return var_out_id; /* OK */
+
+err_ret:
+  free(dim_in_id);
+  free(dim_out_id);
+  return EX_FATAL;
+
 } /* end cpy_var_def() */
 
 /*! \internal */
@@ -590,29 +619,29 @@ int cpy_var_val(int in_id, int out_id, char *var_nm)
    * to an output netCDF file.
    */
 
-  int *   dim_id_in;
-  int *   dim_id_out;
+  int *   dim_id_in  = NULL;
+  int *   dim_id_out = NULL;
   int     idx;
   int     nbr_dim;
   int     var_in_id;
   int     var_out_id;
-  size_t *dim_cnt;
-  size_t *dim_sz;
-  size_t *dim_srt;
-  size_t  var_sz = 1L;
+  size_t *dim_cnt = NULL;
+  size_t *dim_sz  = NULL;
+  size_t *dim_srt = NULL;
+  size_t  var_sz  = 1L;
   nc_type var_type_in, var_type_out;
 
   void *void_ptr = NULL;
 
   /* Get the var_id for the requested variable from both files. */
-  (void)nc_inq_varid(in_id, var_nm, &var_in_id);
-  (void)nc_inq_varid(out_id, var_nm, &var_out_id);
+  EXCHECKI(nc_inq_varid(in_id, var_nm, &var_in_id));
+  EXCHECKI(nc_inq_varid(out_id, var_nm, &var_out_id));
 
   /* Get the number of dimensions for the variable. */
-  (void)nc_inq_vartype(out_id, var_out_id, &var_type_out);
+  EXCHECKI(nc_inq_vartype(out_id, var_out_id, &var_type_out));
 
-  (void)nc_inq_vartype(in_id, var_in_id, &var_type_in);
-  (void)nc_inq_varndims(in_id, var_in_id, &nbr_dim);
+  EXCHECKI(nc_inq_vartype(in_id, var_in_id, &var_type_in));
+  EXCHECKI(nc_inq_varndims(in_id, var_in_id, &nbr_dim));
 
   /* Allocate space to hold the dimension IDs */
   dim_cnt    = calloc(nbr_dim, sizeof(size_t));
@@ -622,8 +651,8 @@ int cpy_var_val(int in_id, int out_id, char *var_nm)
   dim_srt    = calloc(nbr_dim, sizeof(size_t));
 
   /* Get the dimension IDs from the input file */
-  (void)nc_inq_vardimid(in_id, var_in_id, dim_id_in);
-  (void)nc_inq_vardimid(out_id, var_out_id, dim_id_out);
+  EXCHECKF(nc_inq_vardimid(in_id, var_in_id, dim_id_in));
+  EXCHECKF(nc_inq_vardimid(out_id, var_out_id, dim_id_out));
 
   /* Get the dimension sizes and names from the input file */
   for (idx = 0; idx < nbr_dim; idx++) {
@@ -639,8 +668,8 @@ int cpy_var_val(int in_id, int out_id, char *var_nm)
 
     /* If client is increasing any sizes, then need to make sure
        the void_ptr is large enough to hold new dimension */
-    (void)nc_inq_dimlen(in_id, dim_id_in[idx], &dim_in);
-    (void)nc_inq_dimlen(out_id, dim_id_out[idx], &dim_out);
+    EXCHECKF(nc_inq_dimlen(in_id, dim_id_in[idx], &dim_in));
+    EXCHECKF(nc_inq_dimlen(out_id, dim_id_out[idx], &dim_out));
     dim_cnt[idx] = dim_in > dim_out ? dim_in : dim_out;
 
     /* Initialize the indicial offset and stride arrays */
@@ -660,28 +689,28 @@ int cpy_var_val(int in_id, int out_id, char *var_nm)
   if (nbr_dim == 0) { /* variable is a scalar */
 
     if (var_type_in == NC_INT && var_type_out == NC_INT) {
-      nc_get_var1_int(in_id, var_in_id, 0L, void_ptr);
-      nc_put_var1_int(out_id, var_out_id, 0L, void_ptr);
+      EXCHECKF(nc_get_var1_int(in_id, var_in_id, 0L, void_ptr));
+      EXCHECKF(nc_put_var1_int(out_id, var_out_id, 0L, void_ptr));
     }
 
     else if (var_type_in == NC_INT64 && var_type_out == NC_INT64) {
-      nc_get_var1_longlong(in_id, var_in_id, 0L, void_ptr);
-      nc_put_var1_longlong(out_id, var_out_id, 0L, void_ptr);
+      EXCHECKF(nc_get_var1_longlong(in_id, var_in_id, 0L, void_ptr));
+      EXCHECKF(nc_put_var1_longlong(out_id, var_out_id, 0L, void_ptr));
     }
 
     else if (var_type_in == NC_FLOAT) {
-      nc_get_var1_float(in_id, var_in_id, 0L, void_ptr);
-      nc_put_var1_float(out_id, var_out_id, 0L, void_ptr);
+      EXCHECKF(nc_get_var1_float(in_id, var_in_id, 0L, void_ptr));
+      EXCHECKF(nc_put_var1_float(out_id, var_out_id, 0L, void_ptr));
     }
 
     else if (var_type_in == NC_DOUBLE) {
-      nc_get_var1_double(in_id, var_in_id, 0L, void_ptr);
-      nc_put_var1_double(out_id, var_out_id, 0L, void_ptr);
+      EXCHECKF(nc_get_var1_double(in_id, var_in_id, 0L, void_ptr));
+      EXCHECKF(nc_put_var1_double(out_id, var_out_id, 0L, void_ptr));
     }
 
     else if (var_type_in == NC_CHAR) {
-      nc_get_var1_text(in_id, var_in_id, 0L, void_ptr);
-      nc_put_var1_text(out_id, var_out_id, 0L, void_ptr);
+      EXCHECKF(nc_get_var1_text(in_id, var_in_id, 0L, void_ptr));
+      EXCHECKF(nc_put_var1_text(out_id, var_out_id, 0L, void_ptr));
     }
 
     else {
@@ -691,28 +720,28 @@ int cpy_var_val(int in_id, int out_id, char *var_nm)
   else { /* variable is a vector */
 
     if (var_type_in == NC_INT && var_type_out == NC_INT) {
-      (void)nc_get_var_int(in_id, var_in_id, void_ptr);
-      (void)nc_put_var_int(out_id, var_out_id, void_ptr);
+      EXCHECKF(nc_get_var_int(in_id, var_in_id, void_ptr));
+      EXCHECKF(nc_put_var_int(out_id, var_out_id, void_ptr));
     }
 
     else if (var_type_in == NC_INT64 && var_type_out == NC_INT64) {
-      (void)nc_get_var_longlong(in_id, var_in_id, void_ptr);
-      (void)nc_put_var_longlong(out_id, var_out_id, void_ptr);
+      EXCHECKF(nc_get_var_longlong(in_id, var_in_id, void_ptr));
+      EXCHECKF(nc_put_var_longlong(out_id, var_out_id, void_ptr));
     }
 
     else if (var_type_in == NC_FLOAT) {
-      (void)nc_get_var_float(in_id, var_in_id, void_ptr);
-      (void)nc_put_var_float(out_id, var_out_id, void_ptr);
+      EXCHECKF(nc_get_var_float(in_id, var_in_id, void_ptr));
+      EXCHECKF(nc_put_var_float(out_id, var_out_id, void_ptr));
     }
 
     else if (var_type_in == NC_DOUBLE) {
-      (void)nc_get_var_double(in_id, var_in_id, void_ptr);
-      (void)nc_put_var_double(out_id, var_out_id, void_ptr);
+      EXCHECKF(nc_get_var_double(in_id, var_in_id, void_ptr));
+      EXCHECKF(nc_put_var_double(out_id, var_out_id, void_ptr));
     }
 
     else if (var_type_in == NC_CHAR) {
-      (void)nc_get_var_text(in_id, var_in_id, void_ptr);
-      (void)nc_put_var_text(out_id, var_out_id, void_ptr);
+      EXCHECKF(nc_get_var_text(in_id, var_in_id, void_ptr));
+      EXCHECKF(nc_put_var_text(out_id, var_out_id, void_ptr));
     }
 
     else {
@@ -732,6 +761,28 @@ int cpy_var_val(int in_id, int out_id, char *var_nm)
 
   return (EX_NOERR);
 
+err_ret:
+  if (dim_cnt) {
+    free(dim_cnt);
+  }
+  if (dim_id_in) {
+    free(dim_id_in);
+  }
+  if (dim_id_out) {
+    free(dim_id_out);
+  }
+  if (dim_sz) {
+    free(dim_sz);
+  }
+  if (dim_srt) {
+    free(dim_srt);
+  }
+  if (void_ptr) {
+    free(void_ptr);
+  }
+
+  return (EX_FATAL);
+
 } /* end cpy_var_val() */
 
 /*! \internal */
@@ -757,7 +808,7 @@ int cpy_coord_val(int in_id, int out_id, char *var_nm, int in_large, int out_lar
 
   /* Handle easiest situation first: in_large matches out_large */
   if (in_large == out_large) {
-    return cpy_var_val(in_id, out_id, var_nm);
+    return cpy_var_val(in_id, out_id, var_nm); /* OK */
   }
 
   /* At this point, know that in_large != out_large, so will need to
@@ -770,14 +821,14 @@ int cpy_coord_val(int in_id, int out_id, char *var_nm, int in_large, int out_lar
     /* output file will have coordx, coordy, coordz (if 3d). */
     /* Get the var_id for the requested variable from both files. */
     int var_in_id, var_out_id[3];
-    (void)nc_inq_varid(in_id, VAR_COORD, &var_in_id);
+    EXCHECKI(nc_inq_varid(in_id, VAR_COORD, &var_in_id));
 
-    (void)nc_inq_varid(out_id, VAR_COORD_X, &var_out_id[0]);
-    (void)nc_inq_varid(out_id, VAR_COORD_Y, &var_out_id[1]);
-    (void)nc_inq_varid(out_id, VAR_COORD_Z, &var_out_id[2]);
+    EXCHECKI(nc_inq_varid(out_id, VAR_COORD_X, &var_out_id[0]));
+    EXCHECKI(nc_inq_varid(out_id, VAR_COORD_Y, &var_out_id[1]));
+    EXCHECKI(nc_inq_varid(out_id, VAR_COORD_Z, &var_out_id[2]));
 
-    (void)nc_inq_vartype(in_id, var_in_id, &var_type_in);
-    (void)nc_inq_vartype(out_id, var_out_id[0], &var_type_out);
+    EXCHECKI(nc_inq_vartype(in_id, var_in_id, &var_type_in));
+    EXCHECKI(nc_inq_vartype(out_id, var_out_id[0], &var_type_out));
 
     if (num_nodes > 0) {
       void_ptr = malloc(num_nodes * type_size(var_type_in));
@@ -790,13 +841,13 @@ int cpy_coord_val(int in_id, int out_id, char *var_nm, int in_large, int out_lar
       count[0] = 1;
       count[1] = num_nodes;
       if (var_type_in == NC_FLOAT) {
-        nc_get_vara_float(in_id, var_in_id, start, count, void_ptr);
-        nc_put_var_float(out_id, var_out_id[i], void_ptr);
+        EXCHECKI(nc_get_vara_float(in_id, var_in_id, start, count, void_ptr));
+        EXCHECKI(nc_put_var_float(out_id, var_out_id[i], void_ptr));
       }
       else {
         assert(var_type_in == NC_DOUBLE);
-        nc_get_vara_double(in_id, var_in_id, start, count, void_ptr);
-        nc_put_var_double(out_id, var_out_id[i], void_ptr);
+        EXCHECKI(nc_get_vara_double(in_id, var_in_id, start, count, void_ptr));
+        EXCHECKI(nc_put_var_double(out_id, var_out_id[i], void_ptr));
       }
     }
   }
@@ -805,13 +856,13 @@ int cpy_coord_val(int in_id, int out_id, char *var_nm, int in_large, int out_lar
     /* input file will have coordx, coordy, coordz (if 3d); output has only
      * "coord" */
     int var_in_id[3], var_out_id;
-    (void)nc_inq_varid(in_id, VAR_COORD_X, &var_in_id[0]);
-    (void)nc_inq_varid(in_id, VAR_COORD_Y, &var_in_id[1]);
-    (void)nc_inq_varid(in_id, VAR_COORD_Z, &var_in_id[2]);
-    (void)nc_inq_varid(out_id, VAR_COORD, &var_out_id);
+    EXCHECKI(nc_inq_varid(in_id, VAR_COORD_X, &var_in_id[0]));
+    EXCHECKI(nc_inq_varid(in_id, VAR_COORD_Y, &var_in_id[1]));
+    EXCHECKI(nc_inq_varid(in_id, VAR_COORD_Z, &var_in_id[2]));
+    EXCHECKI(nc_inq_varid(out_id, VAR_COORD, &var_out_id));
 
-    (void)nc_inq_vartype(in_id, var_in_id[0], &var_type_in);
-    (void)nc_inq_vartype(out_id, var_out_id, &var_type_out);
+    EXCHECKI(nc_inq_vartype(in_id, var_in_id[0], &var_type_in));
+    EXCHECKI(nc_inq_vartype(out_id, var_out_id, &var_type_out));
 
     if (num_nodes > 0) {
       void_ptr = malloc(num_nodes * type_size(var_type_in));
@@ -825,12 +876,12 @@ int cpy_coord_val(int in_id, int out_id, char *var_nm, int in_large, int out_lar
       count[1] = num_nodes;
 
       if (var_type_in == NC_FLOAT) {
-        nc_get_var_float(in_id, var_in_id[i], void_ptr);
-        nc_put_vara_float(out_id, var_out_id, start, count, void_ptr);
+        EXCHECKF(nc_get_var_float(in_id, var_in_id[i], void_ptr));
+        EXCHECKF(nc_put_vara_float(out_id, var_out_id, start, count, void_ptr));
       }
       else {
-        nc_get_var_double(in_id, var_in_id[i], void_ptr);
-        nc_put_vara_double(out_id, var_out_id, start, count, void_ptr);
+        EXCHECKF(nc_get_var_double(in_id, var_in_id[i], void_ptr));
+        EXCHECKF(nc_put_vara_double(out_id, var_out_id, start, count, void_ptr));
       }
     }
   }
@@ -838,6 +889,11 @@ int cpy_coord_val(int in_id, int out_id, char *var_nm, int in_large, int out_lar
   /* Free the space that held the variable */
   free(void_ptr);
   return (EX_NOERR);
+
+err_ret:
+  free(void_ptr);
+  return (EX_FATAL);
+
 } /* end cpy_coord_val() */
 
 /*! \internal */
@@ -856,22 +912,22 @@ void update_internal_structs(int out_exoid, ex_inquiry inqcode, struct list_item
 size_t type_size(nc_type type)
 {
   if (type == NC_CHAR) {
-    return sizeof(char);
+    return sizeof(char); /* OK */
   }
-  else if (type == NC_INT) {
-    return sizeof(int);
+  if (type == NC_INT) {
+    return sizeof(int); /* OK */
   }
   else if (type == NC_INT64) {
-    return sizeof(int64_t);
+    return sizeof(int64_t); /* OK */
   }
   else if (type == NC_FLOAT) {
-    return sizeof(float);
+    return sizeof(float); /* OK */
   }
   else if (type == NC_DOUBLE) {
-    return sizeof(double);
+    return sizeof(double); /* OK */
   }
   else {
-    return 0;
+    return 0; /* OK */
   }
 }
 
