@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL
 #include "netcdf.h"       // for NC_NOERR, nc_def_grp, etc
 #include <stdio.h>
@@ -45,33 +45,33 @@ int ex_create_group(int parent_id, const char *group_name)
   int exoid = -1;
   int status;
 
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(parent_id);
+
   if ((status = nc_redef(parent_id)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to put file id %d into define mode", parent_id);
-    ex_err("ex_create_group", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_create_group", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if ((status = nc_def_grp(parent_id, group_name, &exoid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: group create failed for %s in file id %d", group_name,
              parent_id);
-    ex_err("ex_create_group", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_create_group", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if ((status = nc_enddef(parent_id)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to complete definition for file id %d", exoid);
-    ex_err("ex_create", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_create", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
-  return (exoid);
+  EX_FUNC_LEAVE(exoid);
 #else
-  exerrval = NC_ENOTNC4;
+  EX_FUNC_ENTER();
   snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Group capabilities are not available in this netcdf "
                                    "version--not netcdf4");
-  ex_err("ex_create_group", errmsg, exerrval);
-  return (EX_FATAL);
+  ex_err("ex_create_group", errmsg, NC_ENOTNC4);
+  EX_FUNC_LEAVE(EX_FATAL);
 #endif
 }
