@@ -34,10 +34,11 @@
  */
 
 #include "exodusII.h" // for exoptval, MAX_ERR_LENGTH, etc
-#include "netcdf.h"   // for NC_EAXISTYPE, NC_EBADDIM, etc
-#include <stdio.h>    // for fprintf, stderr, fflush
-#include <stdlib.h>   // for exit
-#include <string.h>   // for strcpy
+#include "exodusII_int.h"
+#include "netcdf.h" // for NC_EAXISTYPE, NC_EBADDIM, etc
+#include <stdio.h>  // for fprintf, stderr, fflush
+#include <stdlib.h> // for exit
+#include <string.h> // for strcpy
 
 /*!
 \fn{void ex_err(const char *module_name, const char *message, int err_num)}
@@ -97,22 +98,43 @@ if (exoid = ex_open ("test.exo", EX_READ, &CPU_word_size,
 
 */
 
+#if defined(EXODUS_THREADSAFE)
+EX_errval_t *ex_errval = NULL;
+#define EX_PNAME ex_errval->last_pname
+#define EX_ERRMSG ex_errval->last_errmsg
+#define EX_ERR_NUM ex_errval->last_err_num
+#else
 int exerrval = 0; /* clear initial global error code value */
 
 static char last_pname[MAX_ERR_LENGTH];
 static char last_errmsg[MAX_ERR_LENGTH];
 static int  last_err_num;
 
+#define EX_PNAME last_pname
+#define EX_ERRMSG last_errmsg
+#define EX_ERR_NUM last_err_num
+#endif
+
+void ex_reset_error_status()
+{
+#if !defined(EXODUS_THREADSAFE)
+  exerrval   = 0;
+  EX_ERR_NUM = 0;
+#endif
+}
+
 void ex_err(const char *module_name, const char *message, int err_num)
 {
+  EX_FUNC_ENTER_INT();
   if (err_num == 0) { /* zero is no error, ignore and return */
-    return;
+    exerrval = err_num;
+    EX_FUNC_VOID();
   }
 
-  else if (err_num == EX_PRTLASTMSG) {
-    fprintf(stderr, "[%s] %s\n", last_pname, last_errmsg);
-    fprintf(stderr, "    exerrval = %d\n", last_err_num);
-    return;
+  if (err_num == EX_PRTLASTMSG) {
+    fprintf(stderr, "[%s] %s\n", EX_PNAME, EX_ERRMSG);
+    fprintf(stderr, "    exerrval = %d\n", EX_ERR_NUM);
+    EX_FUNC_VOID();
   }
 
   else if (err_num == EX_NULLENTITY) {
@@ -128,9 +150,14 @@ void ex_err(const char *module_name, const char *message, int err_num)
     }
   }
   /* save the error message for replays */
-  strcpy(last_errmsg, message);
-  strcpy(last_pname, module_name);
-  last_err_num = err_num;
+  strncpy(EX_ERRMSG, message, MAX_ERR_LENGTH);
+  strncpy(EX_PNAME, module_name, MAX_ERR_LENGTH);
+  EX_ERRMSG[MAX_ERR_LENGTH - 1] = '\0';
+  EX_PNAME[MAX_ERR_LENGTH - 1]  = '\0';
+  if (err_num != EX_LASTERR) {
+    exerrval   = err_num;
+    EX_ERR_NUM = err_num;
+  }
 
   fflush(stderr);
 
@@ -139,13 +166,39 @@ void ex_err(const char *module_name, const char *message, int err_num)
   if ((err_num > 0) && (exoptval & EX_ABORT)) {
     exit(err_num);
   }
+  EX_FUNC_VOID();
+}
+
+void ex_set_err(const char *module_name, const char *message, int err_num)
+{
+  EX_FUNC_ENTER_INT();
+  /* save the error message for replays */
+  strncpy(EX_ERRMSG, message, MAX_ERR_LENGTH);
+  strncpy(EX_PNAME, module_name, MAX_ERR_LENGTH);
+  EX_ERRMSG[MAX_ERR_LENGTH - 1] = '\0';
+  EX_PNAME[MAX_ERR_LENGTH - 1]  = '\0';
+  if (err_num != EX_LASTERR) {
+    /* Use last set error number, but add new function and message */
+    EX_ERR_NUM = err_num;
+  }
+  EX_FUNC_VOID();
 }
 
 void ex_get_err(const char **msg, const char **func, int *err_num)
 {
-  (*msg)     = last_errmsg;
-  (*func)    = last_pname;
-  (*err_num) = last_err_num;
+  EX_FUNC_ENTER_INT();
+  if (msg) {
+    (*msg) = EX_ERRMSG;
+  }
+
+  if (func) {
+    (*func) = EX_PNAME;
+  }
+
+  if (err_num) {
+    (*err_num) = EX_ERR_NUM;
+  }
+  EX_FUNC_VOID();
 }
 
 const char *ex_strerror(int err_num)
@@ -161,6 +214,7 @@ const char *ex_strerror(int err_num)
   case EX_INTERNAL: return "Internal logic error in exodus library.";
   case EX_NOTROOTID: return "File id is not the root id; it is a subgroup id.";
   case EX_NULLENTITY: return "Null entity found.";
+  case EX_DUPLICATEID: return "Duplicate entity id found.";
   default: return nc_strerror(err_num);
   }
 }
