@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, VAR_WHOLE_TIME, etc
 #include "netcdf.h"       // for NC_NOERR, nc_get_var_double, etc
 #include <stdio.h>
@@ -86,14 +86,14 @@ int ex_get_all_times(int exoid, void *time_values)
   int  status;
   char errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0;
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   if ((status = nc_inq_varid(exoid, VAR_WHOLE_TIME, &varid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate time variable %s in file id %d",
              VAR_WHOLE_TIME, exoid);
-    ex_err("ex_get_all_times", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_all_times", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /*read time values */
@@ -105,11 +105,10 @@ int ex_get_all_times(int exoid, void *time_values)
   }
 
   if (status != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get time values from file id %d", exoid);
-    ex_err("ex_get_all_times", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_all_times", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
