@@ -59,7 +59,7 @@
 /*****************************************************************************/
 /*****************************************************************************/
 
-#include <exodusII.h>     // for ex_err, exerrval, etc
+#include <exodusII.h>     // for ex_err, etc
 #include <exodusII_int.h> // for EX_FATAL, VAR_E_COMM_IDS, etc
 #include <inttypes.h>     // for PRId64
 #include <netcdf.h>       // for NC_NOERR, nc_inq_dimid, etc
@@ -80,7 +80,8 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
   char errmsg[MAX_ERR_LENGTH];
   /*-----------------------------Execution begins-----------------------------*/
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   /*****************************************************************************/
   /*****************************************************************************/
@@ -92,9 +93,9 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
   if (ex_get_idx(exoid, VAR_N_COMM_INFO_IDX, cmap_info_idx, processor) == -1) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find index variable, \"%s\", in file ID %d",
              VAR_N_COMM_INFO_IDX, exoid);
-    ex_err(func_name, errmsg, exerrval);
+    ex_err(func_name, errmsg, EX_LASTERR);
 
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* Get the number of nodal communications maps in the file */
@@ -102,12 +103,11 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
     /* check if I need to get the dimension of the nodal comm map */
     if (cmap_info_idx[1] == -1) {
       if ((status = nc_inq_dimlen(exoid, dimid, count)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find length of dimension \"%s\" in file ID %d", DIM_NUM_N_CMAPS,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err(func_name, errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /* set the end value for the node map */
@@ -121,12 +121,11 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
 
       /* Get the variable ID for the vector of nodal comm map IDs */
       if ((status = nc_inq_varid(exoid, VAR_N_COMM_IDS, &varid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to get variable ID for \"%s\" in file ID %d", VAR_N_COMM_IDS,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err(func_name, errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /* Get the vector of nodal communication map IDs */
@@ -140,20 +139,18 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
         }
 
         if (status != NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get variable \"%s\" from file ID %d",
                    VAR_N_COMM_IDS, exoid);
-          ex_err(func_name, errmsg, exerrval);
-          return (EX_FATAL);
+          ex_err(func_name, errmsg, status);
+          EX_FUNC_LEAVE(EX_FATAL);
         }
 
         if ((status = nc_inq_varid(exoid, VAR_N_COMM_STAT, &varid)) != NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to find variable ID for \"%s\" from file ID %d", VAR_N_COMM_STAT,
                    exoid);
-          ex_err(func_name, errmsg, exerrval);
-          return (EX_FATAL);
+          ex_err(func_name, errmsg, status);
+          EX_FUNC_LEAVE(EX_FATAL);
         }
 
         if (node_cmap_node_cnts != NULL) {
@@ -169,36 +166,33 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
             }
 
             if ((map_idx = ne_id_lkup(exoid, VAR_N_COMM_IDS, cmap_info_idx, cmap_id)) < 0) {
-              exerrval = EX_MSG;
               snprintf(errmsg, MAX_ERR_LENGTH,
                        "ERROR: failed to find nodal comm map with ID %" PRId64 " in file ID %d",
                        cmap_id, exoid);
-              ex_err(func_name, errmsg, exerrval);
-              return (EX_FATAL);
+              ex_err(func_name, errmsg, EX_LASTERR);
+              EX_FUNC_LEAVE(EX_FATAL);
             }
 
             /* Check the status of the node map */
             start[0] = map_idx;
             if ((status = nc_get_var1_int(exoid, varid, start, &nmstat)) != NC_NOERR) {
-              exerrval = status;
               snprintf(errmsg, MAX_ERR_LENGTH,
                        "ERROR: failed to get status for \"%s\" from file ID %d", VAR_N_COMM_STAT,
                        exoid);
-              ex_err(func_name, errmsg, exerrval);
-              return (EX_FATAL);
+              ex_err(func_name, errmsg, status);
+              EX_FUNC_LEAVE(EX_FATAL);
             }
 
             if (nmstat == 1) {
 
               /* get the cmap information variables index */
               if (ex_get_idx(exoid, VAR_N_COMM_DATA_IDX, cmap_data_idx, map_idx) == -1) {
-                exerrval = status;
                 snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find index variable, \"%s\", "
                                                  "in file ID %d",
                          VAR_N_COMM_DATA_IDX, exoid);
-                ex_err(func_name, errmsg, exerrval);
+                ex_err(func_name, errmsg, status);
 
-                return (EX_FATAL);
+                EX_FUNC_LEAVE(EX_FATAL);
               }
 
               if (cmap_data_idx[1] == -1) {
@@ -207,23 +201,21 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
                  * node count
                  */
                 if ((status = nc_inq_dimid(exoid, DIM_NCNT_CMAP, &dimid)) != NC_NOERR) {
-                  exerrval = status;
                   snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find dimension ID for "
                                                    "\"%s\" in file ID %d",
                            DIM_NCNT_CMAP, exoid);
-                  ex_err(func_name, errmsg, exerrval);
-                  return (EX_FATAL);
+                  ex_err(func_name, errmsg, status);
+                  EX_FUNC_LEAVE(EX_FATAL);
                 }
 
                 /* Find the value of the number of nodes in this nodal comm map
                  */
                 if ((status = nc_inq_dimlen(exoid, dimid, count)) != NC_NOERR) {
-                  exerrval = status;
                   snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find length of dimension "
                                                    "\"%s\" in file ID %d",
                            DIM_NCNT_CMAP, exoid);
-                  ex_err(func_name, errmsg, exerrval);
-                  return (EX_FATAL);
+                  ex_err(func_name, errmsg, status);
+                  EX_FUNC_LEAVE(EX_FATAL);
                 }
 
                 cmap_data_idx[1] = count[0];
@@ -256,12 +248,11 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
 
   /* get the cmap information variables index */
   if (ex_get_idx(exoid, VAR_E_COMM_INFO_IDX, cmap_info_idx, processor) == -1) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find index variable, \"%s\", in file ID %d",
              VAR_E_COMM_INFO_IDX, exoid);
-    ex_err(func_name, errmsg, exerrval);
+    ex_err(func_name, errmsg, status);
 
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* Get the number of elemental communications maps in the file */
@@ -269,12 +260,11 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
     /* check if I need to get the dimension of the nodal comm map */
     if (cmap_info_idx[1] == -1) {
       if ((status = nc_inq_dimlen(exoid, dimid, count)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find length of dimension \"%s\" in file ID %d", DIM_NUM_E_CMAPS,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err(func_name, errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /* set the end value for the node map */
@@ -288,12 +278,11 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
 
       /* Get the variable ID for the vector of nodal comm map IDs */
       if ((status = nc_inq_varid(exoid, VAR_E_COMM_IDS, &varid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to get variable ID for \"%s\" in file ID %d", VAR_E_COMM_IDS,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err(func_name, errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /* Get the vector of elemental communication map IDs */
@@ -306,20 +295,18 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
           status = nc_get_vara_int(exoid, varid, start, count, elem_cmap_ids);
         }
         if (status != NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get variable \"%s\" from file ID %d",
                    VAR_E_COMM_IDS, exoid);
-          ex_err(func_name, errmsg, exerrval);
-          return (EX_FATAL);
+          ex_err(func_name, errmsg, status);
+          EX_FUNC_LEAVE(EX_FATAL);
         }
 
         if ((status = nc_inq_varid(exoid, VAR_E_COMM_STAT, &varid)) != NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to find variable ID for \"%s\" from file ID %d", VAR_E_COMM_STAT,
                    exoid);
-          ex_err(func_name, errmsg, exerrval);
-          return (EX_FATAL);
+          ex_err(func_name, errmsg, status);
+          EX_FUNC_LEAVE(EX_FATAL);
         }
 
         if (elem_cmap_elem_cnts != NULL) {
@@ -337,36 +324,33 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
             }
 
             if ((map_idx = ne_id_lkup(exoid, VAR_E_COMM_IDS, cmap_info_idx, cmap_id)) < 0) {
-              exerrval = EX_MSG;
               snprintf(errmsg, MAX_ERR_LENGTH,
                        "ERROR: failed to find elemental comm map with ID %" PRId64 " in file ID %d",
                        cmap_id, exoid);
-              ex_err(func_name, errmsg, exerrval);
-              return (EX_FATAL);
+              ex_err(func_name, errmsg, EX_LASTERR);
+              EX_FUNC_LEAVE(EX_FATAL);
             }
 
             /* Check the status of the requested elemental map */
             start[0] = map_idx;
             if ((status = nc_get_var1_int(exoid, varid, start, &nmstat)) != NC_NOERR) {
-              exerrval = status;
               snprintf(errmsg, MAX_ERR_LENGTH,
                        "ERROR: failed to get status for \"%s\" from file ID %d", VAR_E_COMM_STAT,
                        exoid);
-              ex_err(func_name, errmsg, exerrval);
-              return (EX_FATAL);
+              ex_err(func_name, errmsg, status);
+              EX_FUNC_LEAVE(EX_FATAL);
             }
 
             if (nmstat == 1) {
 
               /* get the cmap information variables index */
               if (ex_get_idx(exoid, VAR_E_COMM_DATA_IDX, cmap_data_idx, map_idx) == -1) {
-                exerrval = status;
                 snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find index variable, \"%s\", "
                                                  "in file ID %d",
                          VAR_E_COMM_DATA_IDX, exoid);
-                ex_err(func_name, errmsg, exerrval);
+                ex_err(func_name, errmsg, status);
 
-                return (EX_FATAL);
+                EX_FUNC_LEAVE(EX_FATAL);
               }
 
               if (cmap_data_idx[1] == -1) {
@@ -375,12 +359,11 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
                  * element count
                  */
                 if ((status = nc_inq_dimid(exoid, DIM_ECNT_CMAP, &dimid)) != NC_NOERR) {
-                  exerrval = status;
                   snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find dimension ID for "
                                                    "\"%s\" in file ID %d",
                            DIM_ECNT_CMAP, exoid);
-                  ex_err(func_name, errmsg, exerrval);
-                  return (EX_FATAL);
+                  ex_err(func_name, errmsg, status);
+                  EX_FUNC_LEAVE(EX_FATAL);
                 }
 
                 /*
@@ -388,12 +371,11 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
                  * comm map
                  */
                 if ((status = nc_inq_dimlen(exoid, dimid, count)) != NC_NOERR) {
-                  exerrval = status;
                   snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find length of dimension "
                                                    "\"%s\" in file ID %d",
                            DIM_ECNT_CMAP, exoid);
-                  ex_err(func_name, errmsg, exerrval);
-                  return (EX_FATAL);
+                  ex_err(func_name, errmsg, status);
+                  EX_FUNC_LEAVE(EX_FATAL);
                 }
                 cmap_data_idx[1] = count[0];
               }
@@ -416,5 +398,5 @@ int ex_get_cmap_params(int exoid, void_int *node_cmap_ids, void_int *node_cmap_n
     }       /* "if (num_e_comm_maps > 0)" */
   }         /* End "if ((dimid = nc_inq_dimid(exoid, DIM_NUM_E_CMAPS(processor))) !=
                -1)" */
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
