@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, ex_comp_ws, etc
 #include "netcdf.h"       // for NC_NOERR, nc_inq_varid, etc
 #include <stddef.h>       // for size_t
@@ -108,36 +108,35 @@ int ex_get_coord(int exoid, void *x_coor, void *y_coor, void *z_coor)
   size_t num_nod, num_dim, start[2], count[2], i;
   char   errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0;
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   /* inquire id's of previously defined dimensions  */
 
   if (ex_get_dimension(exoid, DIM_NUM_DIM, "dimensions", &num_dim, &ndimdim, "ex_get_coord") !=
       NC_NOERR) {
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (nc_inq_dimid(exoid, DIM_NUM_NODES, &numnoddim) != NC_NOERR) {
     /* If not found, then this file is storing 0 nodes.
        Return immediately */
-    return (EX_NOERR);
+    EX_FUNC_LEAVE(EX_NOERR);
   }
 
   if ((status = nc_inq_dimlen(exoid, numnoddim, &num_nod)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of nodes in file id %d", exoid);
-    ex_err("ex_get_coord", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_coord", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* read in the coordinates  */
   if (ex_large_model(exoid) == 0) {
     if ((status = nc_inq_varid(exoid, VAR_COORD, &coordid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate nodal coordinates in file id %d",
                exoid);
-      ex_err("ex_get_coord", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_coord", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     for (i = 0; i < num_dim; i++) {
@@ -177,30 +176,27 @@ int ex_get_coord(int exoid, void *x_coor, void *y_coor, void *z_coor)
       }
 
       if (status != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get %s coord array in file id %d", which,
                  exoid);
-        ex_err("ex_get_coord", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_get_coord", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
     }
   }
   else {
     if ((status = nc_inq_varid(exoid, VAR_COORD_X, &coordidx)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate x nodal coordinates in file id %d",
                exoid);
-      ex_err("ex_get_coord", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_coord", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     if (num_dim > 1) {
       if ((status = nc_inq_varid(exoid, VAR_COORD_Y, &coordidy)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to locate y nodal coordinates in file id %d", exoid);
-        ex_err("ex_get_coord", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_get_coord", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
     }
     else {
@@ -209,11 +205,10 @@ int ex_get_coord(int exoid, void *x_coor, void *y_coor, void *z_coor)
 
     if (num_dim > 2) {
       if ((status = nc_inq_varid(exoid, VAR_COORD_Z, &coordidz)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to locate z nodal coordinates in file id %d", exoid);
-        ex_err("ex_get_coord", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_get_coord", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
     }
     else {
@@ -250,14 +245,13 @@ int ex_get_coord(int exoid, void *x_coor, void *y_coor, void *z_coor)
         }
 
         if (status != NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get %s coord array in file id %d",
                    which, exoid);
-          ex_err("ex_get_coord", errmsg, exerrval);
-          return (EX_FATAL);
+          ex_err("ex_get_coord", errmsg, status);
+          EX_FUNC_LEAVE(EX_FATAL);
         }
       }
     }
   }
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
