@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, etc
 #include "netcdf.h"       // for NC_NOERR, nc_inq_dimid, etc
 #include <stddef.h>       // for size_t
@@ -80,39 +80,37 @@ int ex_get_coord_names(int exoid, char **coord_names)
   size_t num_dim;
   char   errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0;
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   /* inquire previously defined dimensions and variables  */
 
   if ((status = nc_inq_dimid(exoid, DIM_NUM_DIM, &ndimdim)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate number of dimensions in file id %d",
              exoid);
-    ex_err("ex_get_coord_names", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_coord_names", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if ((status = nc_inq_dimlen(exoid, ndimdim, &num_dim)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of dimensions in file id %d",
              exoid);
-    ex_err("ex_get_coord_names", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_coord_names", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if ((status = nc_inq_varid(exoid, VAR_NAME_COOR, &varid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "Warning: failed to locate coordinate names in file id %d",
              exoid);
-    ex_err("ex_get_coord_names", errmsg, exerrval);
-    return (EX_WARN);
+    ex_err("ex_get_coord_names", errmsg, status);
+    EX_FUNC_LEAVE(EX_WARN);
   }
 
   /* read the coordinate names */
   status = ex_get_names_internal(exoid, varid, num_dim, coord_names, EX_COORDINATE,
                                  "ex_get_coord_names");
   if (status != NC_NOERR) {
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
