@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, EX_FILE_ID_MASK, etc
 #include "netcdf.h"       // for NC_NOERR, etc
 #include <stdio.h>
@@ -51,10 +51,8 @@
 int ex_get_group_id(int parent_id, const char *group_name, int *group_id)
 {
   char errmsg[MAX_ERR_LENGTH];
-
-  exerrval = 0; /* clear error code */
-
 #if NC_HAS_HDF5
+  EX_FUNC_ENTER();
   /* See if name contains "/" indicating it is a full path name... */
   if (group_name == NULL) {
     /* Return root */
@@ -64,32 +62,30 @@ int ex_get_group_id(int parent_id, const char *group_name, int *group_id)
     /* Local child */
     int status = nc_inq_grp_ncid(parent_id, group_name, group_id);
     if (status != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Failed to locate group with name %s as child "
                                        "group in file id %d",
                group_name, parent_id);
-      ex_err("ex_get_group_id", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_group_id", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
   else {
     /* Full path name */
     int status = nc_inq_grp_full_ncid(parent_id, group_name, group_id);
     if (status != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: Failed to locate group with full path name %s in file id %d", group_name,
                parent_id);
-      ex_err("ex_get_group_id", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_group_id", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 #else
-  exerrval = NC_ENOTNC4;
+  EX_FUNC_ENTER();
   snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Group capabilities are not available in this netcdf "
                                    "version--not netcdf4");
-  ex_err("ex_get_group_id", errmsg, exerrval);
-  return (EX_FATAL);
+  ex_err("ex_get_group_id", errmsg, NC_ENOTNC4);
+  EX_FUNC_LEAVE(EX_FATAL);
 #endif
 }
