@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, EX_NOERR
 #include "netcdf.h"       // for nc_inq_grps, NC_NOERR
 #include <stdio.h>
@@ -49,20 +49,24 @@ int ex_get_group_ids(int parent_id, int *num_groups, int *group_ids)
   char errmsg[MAX_ERR_LENGTH];
 
 #if NC_HAS_HDF5
-  int status = nc_inq_grps(parent_id, num_groups, group_ids);
+  int status;
+
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(parent_id);
+
+  status = nc_inq_grps(parent_id, num_groups, group_ids);
   if (status != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Failed to get child group ids in file id %d",
              parent_id);
-    ex_err("ex_get_group_ids", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_group_ids", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 #else
-  exerrval = NC_ENOTNC4;
+  EX_FUNC_ENTER();
   snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Group capabilities are not available in this netcdf "
                                    "version--not netcdf4");
-  ex_err("ex_get_group_ids", errmsg, exerrval);
-  return (EX_FATAL);
+  ex_err("ex_get_group_ids", errmsg, NC_ENOTNC4);
+  EX_FUNC_LEAVE(EX_FATAL);
 #endif
 }
