@@ -54,7 +54,7 @@
 /*****************************************************************************/
 /*****************************************************************************/
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, DIM_NUM_BOR_ELEMS, etc
 #include <netcdf.h>       // for NC_NOERR, nc_inq_dimid, etc
 #include <stddef.h>       // for size_t
@@ -76,6 +76,9 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
 
   char errmsg[MAX_ERR_LENGTH];
   /*-----------------------------Execution begins-----------------------------*/
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
+
   if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
     *(int64_t *)num_int_nodes  = 0;
     *(int64_t *)num_bor_nodes  = 0;
@@ -95,30 +98,26 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
     *(int *)num_elem_cmaps = 0;
   }
 
-  exerrval = 0; /* clear error code */
-
   /* Check the file version information */
   if ((dimid = ne_check_file_version(exoid)) != EX_NOERR) {
-    return (dimid);
+    EX_FUNC_LEAVE(dimid);
   }
 
   /* Get the file type */
   if (ex_get_file_type(exoid, ftype) != EX_NOERR) {
-    exerrval = EX_MSG;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: unable to find file type for file ID %d", exoid);
-    ex_err(func_name, errmsg, exerrval);
+    ex_err(func_name, errmsg, EX_LASTERR);
 
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* Get the status for this node map */
   if ((status = nc_inq_varid(exoid, VAR_INT_N_STAT, &varid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find variable ID for \"%s\" from file ID %d",
              VAR_INT_N_STAT, exoid);
-    ex_err(func_name, errmsg, exerrval);
+    ex_err(func_name, errmsg, status);
 
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (ftype[0] == 's') {
@@ -129,35 +128,32 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
   }
 
   if ((status = nc_get_var1_int(exoid, varid, start, &nmstat)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get status for \"%s\" from file ID %d",
              VAR_INT_N_STAT, exoid);
-    ex_err(func_name, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(func_name, errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (nmstat == 1) {
     if (ex_get_idx(exoid, VAR_NODE_MAP_INT_IDX, varidx, processor) == -1) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to find index variable, \"%s\", in file ID %d", VAR_NODE_MAP_INT_IDX,
                exoid);
-      ex_err(func_name, errmsg, exerrval);
+      ex_err(func_name, errmsg, status);
 
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* check if I need to get the dimension of the internal node map */
     if (varidx[1] == -1) {
       /* Get the dimension ID for the number of internal nodes */
       if ((status = nc_inq_dimid(exoid, DIM_NUM_INT_NODES, &dimid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find dimension ID for \"%s\" in file ID %d", DIM_NUM_INT_NODES,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
+        ex_err(func_name, errmsg, status);
 
-        return (EX_FATAL);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /*
@@ -165,13 +161,12 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
        * internal FEM nodes.
        */
       if ((status = nc_inq_dimlen(exoid, dimid, &nin)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find length of dimension \"%s\" in file ID %d",
                  DIM_NUM_INT_NODES, exoid);
-        ex_err(func_name, errmsg, exerrval);
+        ex_err(func_name, errmsg, status);
 
-        return (EX_FATAL);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /* set the end value for the node map */
@@ -189,12 +184,11 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
 
   /* Get the status for this node map */
   if ((status = nc_inq_varid(exoid, VAR_BOR_N_STAT, &varid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find variable ID for \"%s\" from file ID %d",
              VAR_BOR_N_STAT, exoid);
-    ex_err(func_name, errmsg, exerrval);
+    ex_err(func_name, errmsg, status);
 
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (ftype[0] == 's') {
@@ -205,35 +199,32 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
   }
 
   if ((status = nc_get_var1_int(exoid, varid, start, &nmstat)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get status for \"%s\" from file ID %d",
              VAR_BOR_N_STAT, exoid);
-    ex_err(func_name, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(func_name, errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (nmstat == 1) {
     if (ex_get_idx(exoid, VAR_NODE_MAP_BOR_IDX, varidx, processor) == -1) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to find index variable, \"%s\", in file ID %d", VAR_NODE_MAP_BOR_IDX,
                exoid);
-      ex_err(func_name, errmsg, exerrval);
+      ex_err(func_name, errmsg, status);
 
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* check if I need to get the dimension of the border node map */
     if (varidx[1] == -1) {
       /* Get the dimension ID for the number of border nodes */
       if ((status = nc_inq_dimid(exoid, DIM_NUM_BOR_NODES, &dimid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find dimension ID for \"%s\" in file ID %d", DIM_NUM_BOR_NODES,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
+        ex_err(func_name, errmsg, status);
 
-        return (EX_FATAL);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /*
@@ -241,13 +232,12 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
        * FEM nodes.
        */
       if ((status = nc_inq_dimlen(exoid, dimid, &nbn)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find length of dimension \"%s\" in file ID %d",
                  DIM_NUM_BOR_NODES, exoid);
-        ex_err(func_name, errmsg, exerrval);
+        ex_err(func_name, errmsg, status);
 
-        return (EX_FATAL);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /* set the end value for the node map */
@@ -265,12 +255,11 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
 
   /* Get the status for this node map */
   if ((status = nc_inq_varid(exoid, VAR_EXT_N_STAT, &varid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find variable ID for \"%s\" from file ID %d",
              VAR_EXT_N_STAT, exoid);
-    ex_err(func_name, errmsg, exerrval);
+    ex_err(func_name, errmsg, status);
 
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (ftype[0] == 's') {
@@ -281,35 +270,32 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
   }
 
   if ((status = nc_get_var1_int(exoid, varid, start, &nmstat)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get status for \"%s\" from file ID %d",
              VAR_EXT_N_STAT, exoid);
-    ex_err(func_name, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(func_name, errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (nmstat == 1) {
     if (ex_get_idx(exoid, VAR_NODE_MAP_EXT_IDX, varidx, processor) == -1) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to find index variable, \"%s\", in file ID %d", VAR_NODE_MAP_EXT_IDX,
                exoid);
-      ex_err(func_name, errmsg, exerrval);
+      ex_err(func_name, errmsg, status);
 
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* check if I need to get the dimension of the external node map */
     if (varidx[1] == -1) {
       /* Get the dimension ID for the number of external nodes */
       if ((status = nc_inq_dimid(exoid, DIM_NUM_EXT_NODES, &dimid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find dimension ID for \"%s\" in file ID %d", DIM_NUM_EXT_NODES,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
+        ex_err(func_name, errmsg, status);
 
-        return (EX_FATAL);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /*
@@ -317,13 +303,12 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
        * FEM nodes.
        */
       if ((status = nc_inq_dimlen(exoid, dimid, &nen)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find length of dimension \"%s\" in file ID %d",
                  DIM_NUM_EXT_NODES, exoid);
-        ex_err(func_name, errmsg, exerrval);
+        ex_err(func_name, errmsg, status);
 
-        return (EX_FATAL);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
       /* set the end value for the node map */
       varidx[1] = nen;
@@ -340,11 +325,10 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
 
   /* Get the status for this element map */
   if ((status = nc_inq_varid(exoid, VAR_INT_E_STAT, &varid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find variable ID for \"%s\" from file ID %d",
              VAR_INT_E_STAT, exoid);
-    ex_err(func_name, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(func_name, errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (ftype[0] == 's') {
@@ -355,35 +339,32 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
   }
 
   if ((status = nc_get_var1_int(exoid, varid, start, &nmstat)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get status for \"%s\" from file ID %d",
              VAR_INT_E_STAT, exoid);
-    ex_err(func_name, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(func_name, errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (nmstat == 1) {
     if (ex_get_idx(exoid, VAR_ELEM_MAP_INT_IDX, varidx, processor) == -1) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to find index variable, \"%s\", in file ID %d", VAR_ELEM_MAP_INT_IDX,
                exoid);
-      ex_err(func_name, errmsg, exerrval);
+      ex_err(func_name, errmsg, status);
 
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* check if I need to get the dimension of the internal element map */
     if (varidx[1] == -1) {
       /* Get the dimension ID for the number of internal elements */
       if ((status = nc_inq_dimid(exoid, DIM_NUM_INT_ELEMS, &dimid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find dimension ID for \"%s\" from file ID %d", DIM_NUM_INT_ELEMS,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
+        ex_err(func_name, errmsg, status);
 
-        return (EX_FATAL);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /*
@@ -391,12 +372,11 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
        * FEM elements.
        */
       if ((status = nc_inq_dimlen(exoid, dimid, &nie)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find length of dimesion \"%s\" in file ID %d", DIM_NUM_INT_ELEMS,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err(func_name, errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /* set the end value for the node map */
@@ -414,11 +394,10 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
 
   /* Get the status for this element map */
   if ((status = nc_inq_varid(exoid, VAR_BOR_E_STAT, &varid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find variable ID for \"%s\" from file ID %d",
              VAR_BOR_E_STAT, exoid);
-    ex_err(func_name, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(func_name, errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (ftype[0] == 's') {
@@ -429,35 +408,32 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
   }
 
   if ((status = nc_get_var1_int(exoid, varid, start, &nmstat)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get status for \"%s\" from file ID %d",
              VAR_BOR_E_STAT, exoid);
-    ex_err(func_name, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(func_name, errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (nmstat == 1) {
     if (ex_get_idx(exoid, VAR_ELEM_MAP_BOR_IDX, varidx, processor) == -1) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to find index variable, \"%s\", in file ID %d", VAR_ELEM_MAP_BOR_IDX,
                exoid);
-      ex_err(func_name, errmsg, exerrval);
+      ex_err(func_name, errmsg, status);
 
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* check if I need to get the dimension of the border element map */
     if (varidx[1] == -1) {
       /* Get the dimension ID for the number of border elements */
       if ((status = nc_inq_dimid(exoid, DIM_NUM_BOR_ELEMS, &dimid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find dimension ID for \"%s\" from file ID %d", DIM_NUM_BOR_ELEMS,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
+        ex_err(func_name, errmsg, status);
 
-        return (EX_FATAL);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /*
@@ -465,12 +441,11 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
        * FEM elements.
        */
       if ((status = nc_inq_dimlen(exoid, dimid, &nbe)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find length of dimesion \"%s\" in file ID %d", DIM_NUM_BOR_ELEMS,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err(func_name, errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /* set the end value for the node map */
@@ -487,12 +462,11 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
   } /* End "if (nmstat == 1)" */
 
   if (ex_get_idx(exoid, VAR_N_COMM_INFO_IDX, varidx, processor) == -1) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find index variable, \"%s\", in file ID %d",
              VAR_N_COMM_INFO_IDX, exoid);
-    ex_err(func_name, errmsg, exerrval);
+    ex_err(func_name, errmsg, status);
 
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* check if I need to get the dimension of the nodal comm map */
@@ -503,12 +477,11 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
     }
     else {
       if ((status = nc_inq_dimlen(exoid, dimid, &nncm)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find length of dimension \"%s\" in file ID %d", DIM_NUM_N_CMAPS,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err(func_name, errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
       /* set the end value for the node map */
       varidx[1] = nncm;
@@ -523,12 +496,11 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
   }
 
   if (ex_get_idx(exoid, VAR_E_COMM_INFO_IDX, varidx, processor) == -1) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to find index variable, \"%s\", in file ID %d",
              VAR_E_COMM_INFO_IDX, exoid);
-    ex_err(func_name, errmsg, exerrval);
+    ex_err(func_name, errmsg, status);
 
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* check if I need to get the dimension of the elemental comm map */
@@ -539,12 +511,11 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
     }
     else {
       if ((status = nc_inq_dimlen(exoid, dimid, &necm)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to find length of dimension \"%s\" in file ID %d", DIM_NUM_E_CMAPS,
                  exoid);
-        ex_err(func_name, errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err(func_name, errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /* set the end value for the node map */
@@ -559,5 +530,5 @@ int ex_get_loadbal_param(int exoid, void_int *num_int_nodes, void_int *num_bor_n
     *(int *)num_elem_cmaps = varidx[1] - varidx[0];
   }
 
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
