@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_NOERR, EX_FATAL, etc
 #include "netcdf.h"       // for NC_NOERR, nc_get_var_int, etc
 #include <stddef.h>       // for size_t
@@ -79,21 +79,21 @@ int ex_get_map(int exoid, void_int *elem_map)
   size_t num_elem, i;
   char   errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   /* inquire id's of previously defined dimensions and variables  */
 
   /* See if file contains any elements...*/
   if ((status = nc_inq_dimid(exoid, DIM_NUM_ELEM, &numelemdim)) != NC_NOERR) {
-    return (EX_NOERR);
+    EX_FUNC_LEAVE(EX_NOERR);
   }
 
   if ((status = nc_inq_dimlen(exoid, numelemdim, &num_elem)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of elements in file id %d",
              exoid);
-    ex_err("ex_get_map", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_map", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (nc_inq_varid(exoid, VAR_MAP, &mapid) != NC_NOERR) {
@@ -111,7 +111,7 @@ int ex_get_map(int exoid, void_int *elem_map)
       }
     }
 
-    return (EX_NOERR);
+    EX_FUNC_LEAVE(EX_NOERR);
   }
 
   /* read in the element order map  */
@@ -123,11 +123,10 @@ int ex_get_map(int exoid, void_int *elem_map)
   }
 
   if (status != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get element order map in file id %d", exoid);
-    ex_err("ex_get_map", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_map", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
