@@ -54,7 +54,7 @@
 *
 *****************************************************************************/
 
-#include "exodusII.h"     // for ex_err, exerrval, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, ex_get_dimension, etc
 #include "netcdf.h"       // for NC_NOERR, etc
 #include <inttypes.h>     // for PRId64
@@ -88,27 +88,32 @@ int ex_get_partial_attr(int exoid, ex_entity_type obj_type, ex_entity_id obj_id,
   const char *dnumobjatt;
   const char *vattrbname;
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   if (num_ent == 0) {
-    return 0;
+    EX_FUNC_LEAVE(EX_NOERR);
   }
   /* Determine index of obj_id in vobjids array */
   if (obj_type != EX_NODAL) {
     obj_id_ndx = ex_id_lkup(exoid, obj_type, obj_id);
-    if (exerrval != 0) {
-      if (exerrval == EX_NULLENTITY) {
+    if (obj_id_ndx <= 0) {
+      ex_get_err(NULL, NULL, &status);
+
+      if (status != 0) {
+        if (status == EX_NULLENTITY) {
+          snprintf(errmsg, MAX_ERR_LENGTH,
+                   "Warning: no attributes found for NULL %s %" PRId64 " in file id %d",
+                   ex_name_of_object(obj_type), obj_id, exoid);
+          ex_err("ex_get_partial_attr", errmsg, EX_NULLENTITY);
+          EX_FUNC_LEAVE(EX_WARN); /* no attributes for this object */
+        }
         snprintf(errmsg, MAX_ERR_LENGTH,
-                 "Warning: no attributes found for NULL %s %" PRId64 " in file id %d",
+                 "Warning: failed to locate %s id%" PRId64 " in id array in file id %d",
                  ex_name_of_object(obj_type), obj_id, exoid);
-        ex_err("ex_get_partial_attr", errmsg, EX_NULLENTITY);
-        return (EX_WARN); /* no attributes for this object */
+        ex_err("ex_get_partial_attr", errmsg, status);
+        EX_FUNC_LEAVE(EX_WARN);
       }
-      snprintf(errmsg, MAX_ERR_LENGTH,
-               "Warning: failed to locate %s id%" PRId64 " in id array in file id %d",
-               ex_name_of_object(obj_type), obj_id, exoid);
-      ex_err("ex_get_partial_attr", errmsg, exerrval);
-      return (EX_WARN);
     }
   }
 
@@ -159,42 +164,39 @@ int ex_get_partial_attr(int exoid, ex_entity_type obj_type, ex_entity_id obj_id,
     vattrbname = VAR_ATTRIB(obj_id_ndx);
     break;
   default:
-    exerrval = 1005;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "Internal ERROR: unrecognized object type in switch: %d in file id %d", obj_type,
              exoid);
-    ex_err("ex_get_partial_attr", errmsg, EX_MSG);
-    return (EX_FATAL); /* number of attributes not defined */
+    ex_err("ex_get_partial_attr", errmsg, EX_BADPARAM);
+    EX_FUNC_LEAVE(EX_FATAL); /* number of attributes not defined */
   }
 
   /* inquire id's of previously defined dimensions  */
   if (ex_get_dimension(exoid, dnumobjent, "entries", &num_entries_this_obj, &temp,
                        "ex_get_partial_attr") != NC_NOERR) {
-    return EX_FATAL;
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (start_num + num_ent - 1 > num_entries_this_obj) {
-    exerrval = EX_BADPARAM;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: start index (%" PRId64 ") + count (%" PRId64
              ") is larger than total number of entities (%" ST_ZU ") in file id %d",
              start_num, num_ent, num_entries_this_obj, exoid);
-    ex_err("ex_get_partial_attr", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_partial_attr", errmsg, EX_BADPARAM);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (ex_get_dimension(exoid, dnumobjatt, "attributes", &num_attr, &temp, "ex_get_partial_attr") !=
       NC_NOERR) {
-    return EX_FATAL;
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if ((status = nc_inq_varid(exoid, vattrbname, &attrid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to locate attributes for %s %" PRId64 " in file id %d",
              ex_name_of_object(obj_type), obj_id, exoid);
-    ex_err("ex_get_partial_attr", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_partial_attr", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* read in the attributes */
@@ -212,12 +214,11 @@ int ex_get_partial_attr(int exoid, ex_entity_type obj_type, ex_entity_id obj_id,
   }
 
   if (status != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to get attributes for %s %" PRId64 " in file id %d",
              ex_name_of_object(obj_type), obj_id, exoid);
-    ex_err("ex_get_partial_attr", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_partial_attr", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
