@@ -55,13 +55,12 @@
 *
 */
 #include "exodusII.h"     // for ex_err, ex_name_of_object, etc
-#include "exodusII_int.h" // for EX_FATAL, ex_id_lkup, etc
+#include "exodusII_int.h" // for ex_check_valid_file_id, etc
 #include "netcdf.h"       // for NC_NOERR, nc_get_vara_int, etc
 #include <inttypes.h>     // for PRId64
-#include <stddef.h>       // for size_t
-#include <stdio.h>
-#include <stdlib.h>    // for NULL
-#include <sys/types.h> // for int64_t
+#include <stddef.h>       // for size_t, NULL
+#include <stdint.h>       // for int64_t
+#include <stdio.h>        // for snprintf
 
 /*
  * reads the connectivity array for an element block
@@ -81,8 +80,6 @@ int ex_get_partial_conn(int exoid, ex_entity_type blk_type, ex_entity_id blk_id,
   int numedgperentdim = -1;
   int numfacperentdim = -1;
 
-  int iexit = (EX_NOERR); /* exit status */
-
   size_t num_nodes_per_entry = 0;
   size_t num_edges_per_entry = 0;
   size_t num_faces_per_entry = 0;
@@ -95,36 +92,40 @@ int ex_get_partial_conn(int exoid, ex_entity_type blk_type, ex_entity_id blk_id,
   const char *vedgeconn  = NULL;
   const char *vfaceconn  = NULL;
 
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
+
   /* The partial connectivity input function can currently only handle nodal
    * connectivity.  Print a warning if edgeconn or faceconn is non-NULL
    */
   if (edgeconn != NULL || faceconn != NULL) {
-    exerrval = 1005;
     snprintf(errmsg, MAX_ERR_LENGTH, "Warning: ex_get_partial_conn only supports nodal "
                                      "connectivity at this time. %s %" PRId64 " in file id %d",
              ex_name_of_object(blk_type), blk_id, exoid);
-    ex_err("ex_get_partial_conn", errmsg, EX_MSG);
+    ex_err("ex_get_partial_conn", errmsg, EX_BADPARAM);
   }
 
-  exerrval = 0; /* clear error code */
-
   /* Locate index of element block id in VAR_ID_EL_BLK array */
 
   blk_id_ndx = ex_id_lkup(exoid, blk_type, blk_id);
-  if (exerrval != 0) {
-    if (exerrval == EX_NULLENTITY) {
-      snprintf(errmsg, MAX_ERR_LENGTH,
-               "Warning: no connectivity array for NULL %s %" PRId64 " in file id %d",
-               ex_name_of_object(blk_type), blk_id, exoid);
-      ex_err("ex_get_partial_conn", errmsg, EX_NULLENTITY);
-      return (EX_WARN); /* no connectivity array for this element block */
-    }
+  if (blk_id_ndx <= 0) {
+    ex_get_err(NULL, NULL, &status);
 
-    snprintf(errmsg, MAX_ERR_LENGTH,
-             "ERROR: failed to locate %s id %" PRId64 " in id array in file id %d",
-             ex_name_of_object(blk_type), blk_id, exoid);
-    ex_err("ex_get_partial_conn", errmsg, exerrval);
-    return (EX_FATAL);
+    if (status != 0) {
+      if (status == EX_NULLENTITY) {
+        snprintf(errmsg, MAX_ERR_LENGTH,
+                 "Warning: no connectivity array for NULL %s %" PRId64 " in file id %d",
+                 ex_name_of_object(blk_type), blk_id, exoid);
+        ex_err("ex_get_partial_conn", errmsg, EX_NULLENTITY);
+        EX_FUNC_LEAVE(EX_WARN); /* no connectivity array for this element block */
+      }
+
+      snprintf(errmsg, MAX_ERR_LENGTH,
+               "ERROR: failed to locate %s id %" PRId64 " in id array in file id %d",
+               ex_name_of_object(blk_type), blk_id, exoid);
+      ex_err("ex_get_partial_conn", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
+    }
   }
 
   switch (blk_type) {
@@ -153,31 +154,28 @@ int ex_get_partial_conn(int exoid, ex_entity_type blk_type, ex_entity_id blk_id,
     vfaceconn  = VAR_FCONN(blk_id_ndx);
     break;
   default:
-    exerrval = 1005;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "Internal ERROR: unrecognized block type in switch: %d in file id %d", blk_type,
              exoid);
-    ex_err("ex_get_partial_conn", errmsg, EX_MSG);
-    return (EX_FATAL); /* number of attributes not defined */
+    ex_err("ex_get_partial_conn", errmsg, EX_BADPARAM);
+    EX_FUNC_LEAVE(EX_FATAL); /* number of attributes not defined */
   }
   /* inquire id's of previously defined dimensions  */
 
   if ((status = nc_inq_dimid(exoid, dnumnodent, &numnodperentdim)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to locate number of nodes/entity for %s %" PRId64 " in file id %d",
              ex_name_of_object(blk_type), blk_id, exoid);
-    ex_err("ex_get_partial_conn", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_partial_conn", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (nc_inq_dimlen(exoid, numnodperentdim, &num_nodes_per_entry) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to get number of nodes/entity for %s %" PRId64 " in file id %d",
              ex_name_of_object(blk_type), blk_id, exoid);
-    ex_err("ex_get_partial_conn", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_partial_conn", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (edgeconn && dnumedgent) {
@@ -187,12 +185,11 @@ int ex_get_partial_conn(int exoid, ex_entity_type blk_type, ex_entity_id blk_id,
     }
     else {
       if ((status = nc_inq_dimlen(exoid, numedgperentdim, &num_edges_per_entry)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to get number of edges/entry for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blk_type), blk_id, exoid);
-        ex_err("ex_get_partial_conn", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_get_partial_conn", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
     }
   }
@@ -204,44 +201,40 @@ int ex_get_partial_conn(int exoid, ex_entity_type blk_type, ex_entity_id blk_id,
     }
     else {
       if ((status = nc_inq_dimlen(exoid, numfacperentdim, &num_faces_per_entry)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to get number of faces/entry for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blk_type), blk_id, exoid);
-        ex_err("ex_get_partial_conn", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_get_partial_conn", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
     }
   }
 
   if ((status = nc_inq_varid(exoid, vnodeconn, &connid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to locate connectivity array for %s %" PRId64 " in file id %d",
              ex_name_of_object(blk_type), blk_id, exoid);
-    ex_err("ex_get_partial_conn", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_partial_conn", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   status = 0;
   if (edgeconn && (numedgperentdim > 0) &&
       ((status = nc_inq_varid(exoid, vedgeconn, &econnid)) != NC_NOERR)) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to locate edge connectivity array for %s %" PRId64 " in file id %d",
              ex_name_of_object(blk_type), blk_id, exoid);
-    ex_err("ex_get_partial_conn", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_partial_conn", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (faceconn && (numfacperentdim > 0) &&
       ((status = nc_inq_varid(exoid, vfaceconn, &fconnid)) != NC_NOERR)) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to locate face connectivity array for %s %" PRId64 " in file id %d",
              ex_name_of_object(blk_type), blk_id, exoid);
-    ex_err("ex_get_partial_conn", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_partial_conn", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* read in the connectivity array */
@@ -261,12 +254,11 @@ int ex_get_partial_conn(int exoid, ex_entity_type blk_type, ex_entity_id blk_id,
     }
 
     if (status != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to get edge connectivity array for %s %" PRId64 " in file id %d",
                ex_name_of_object(blk_type), blk_id, exoid);
-      ex_err("ex_get_partial_conn", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_partial_conn", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
 
@@ -286,12 +278,11 @@ int ex_get_partial_conn(int exoid, ex_entity_type blk_type, ex_entity_id blk_id,
     }
 
     if (status != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to get face connectivity array for %s %" PRId64 " in file id %d",
                ex_name_of_object(blk_type), blk_id, exoid);
-      ex_err("ex_get_partial_conn", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_partial_conn", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
 
@@ -311,14 +302,12 @@ int ex_get_partial_conn(int exoid, ex_entity_type blk_type, ex_entity_id blk_id,
     }
 
     if (status != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to get connectivity array for %s %" PRId64 " in file id %d",
                ex_name_of_object(blk_type), blk_id, exoid);
-      ex_err("ex_get_partial_conn", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_partial_conn", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
-
-  return iexit;
+  EX_FUNC_LEAVE(EX_NOERR);
 }
