@@ -52,7 +52,7 @@
 *
 *****************************************************************************/
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, ATT_PROP_NAME, etc
 #include "netcdf.h"       // for NC_NOERR, nc_get_att_text, etc
 #include <stdio.h>
@@ -123,7 +123,8 @@ int ex_get_prop_array(int exoid, ex_entity_type obj_type, const char *prop_name,
 
   char errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   /* open appropriate variable, depending on obj_type and prop_name */
 
@@ -144,28 +145,25 @@ int ex_get_prop_array(int exoid, ex_entity_type obj_type, const char *prop_name,
     case EX_EDGE_MAP: name   = VAR_EDM_PROP(i); break;
     case EX_NODE_MAP: name   = VAR_NM_PROP(i); break;
     default:
-      exerrval = EX_BADPARAM;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: object type %d not supported; file id %d", obj_type,
                exoid);
-      ex_err("ex_get_prop_array", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_prop_array", errmsg, EX_BADPARAM);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     if ((status = nc_inq_varid(exoid, name, &propid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate property array %s in file id %d",
                name, exoid);
-      ex_err("ex_get_prop_array", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_prop_array", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /*   compare stored attribute name with passed property name   */
     memset(tmpstr, 0, MAX_STR_LENGTH + 1);
     if ((status = nc_get_att_text(exoid, propid, ATT_PROP_NAME, tmpstr)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get property name in file id %d", exoid);
-      ex_err("ex_get_prop_array", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_prop_array", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     if (strcmp(tmpstr, prop_name) == 0) {
@@ -176,12 +174,11 @@ int ex_get_prop_array(int exoid, ex_entity_type obj_type, const char *prop_name,
 
   /* if property is not found, return warning */
   if (!found) {
-    exerrval = EX_BADPARAM;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "Warning: object type %d, property %s not defined in file id %d", obj_type, prop_name,
              exoid);
-    ex_err("ex_get_prop_array", errmsg, exerrval);
-    return (EX_WARN);
+    ex_err("ex_get_prop_array", errmsg, EX_BADPARAM);
+    EX_FUNC_LEAVE(EX_WARN);
   }
 
   /* read num_obj values from property variable */
@@ -193,13 +190,12 @@ int ex_get_prop_array(int exoid, ex_entity_type obj_type, const char *prop_name,
   }
 
   if (status != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to read values in %s property array in file id %d",
              ex_name_of_object(obj_type), exoid);
-    ex_err("ex_get_prop_array", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_prop_array", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
