@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, ex_trim_internal, etc
 #include "netcdf.h"       // for NC_NOERR, nc_get_vara_text, etc
 #include <stddef.h>       // for size_t
@@ -92,32 +92,30 @@ int ex_get_qa(int exoid, char *qa_record[][4])
 
   int rootid = exoid & EX_FILE_ID_MASK;
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   /* inquire previously defined dimensions and variables  */
   if ((status = nc_inq_dimid(rootid, DIM_NUM_QA, &dimid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "Warning: no qa records stored in file id %d", rootid);
-    ex_err("ex_get_qa", errmsg, exerrval);
-    return (EX_WARN);
+    ex_err("ex_get_qa", errmsg, status);
+    EX_FUNC_LEAVE(EX_WARN);
   }
 
   if ((status = nc_inq_dimlen(rootid, dimid, &num_qa_records)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of qa records in file id %d",
              rootid);
-    ex_err("ex_get_qa", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_qa", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* do this only if there are any QA records */
   if (num_qa_records > 0) {
     if ((status = nc_inq_varid(rootid, VAR_QA_TITLE, &varid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate qa record data in file id %d",
                rootid);
-      ex_err("ex_get_qa", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_qa", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* read the QA records */
@@ -130,16 +128,15 @@ int ex_get_qa(int exoid, char *qa_record[][4])
         start[2] = 0;
         count[2] = MAX_STR_LENGTH + 1;
         if ((status = nc_get_vara_text(rootid, varid, start, count, qa_record[i][j])) != NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get qa record data in file id %d",
                    rootid);
-          ex_err("ex_get_qa", errmsg, exerrval);
-          return (EX_FATAL);
+          ex_err("ex_get_qa", errmsg, status);
+          EX_FUNC_LEAVE(EX_FATAL);
         }
         qa_record[i][j][MAX_STR_LENGTH] = '\0';
         ex_trim_internal(qa_record[i][j]);
       }
     }
   }
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
