@@ -34,11 +34,10 @@
  */
 
 #include "exodusII.h"     // for ex_err, ex_name_of_object, etc
-#include "exodusII_int.h" // for EX_FATAL, EX_WARN, etc
+#include "exodusII_int.h" // for ex_check_valid_file_id, etc
 #include "netcdf.h"       // for NC_NOERR, nc_get_var_int, etc
 #include <inttypes.h>     // for PRId64
-#include <stdio.h>
-#include <stdlib.h> // for NULL
+#include <stdio.h>        // for snprintf, NULL
 
 /*!
  * reads the set entry list and set extra list for a single set
@@ -61,32 +60,36 @@ int ex_get_set(int exoid, ex_entity_type set_type, ex_entity_id set_id, void_int
   char *entryptr = NULL;
   char *extraptr = NULL;
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   /* first check if any sets are specified */
   if ((status = nc_inq_dimid(exoid, ex_dim_num_objects(set_type), &dimid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "Warning: no %ss stored in file id %d",
              ex_name_of_object(set_type), exoid);
-    ex_err("ex_get_set", errmsg, exerrval);
-    return (EX_WARN);
+    ex_err("ex_get_set", errmsg, status);
+    EX_FUNC_LEAVE(EX_WARN);
   }
 
   /* Lookup index of set id in VAR_*S_IDS array */
   set_id_ndx = ex_id_lkup(exoid, set_type, set_id);
-  if (exerrval != 0) {
-    if (exerrval == EX_NULLENTITY) {
-      snprintf(errmsg, MAX_ERR_LENGTH, "Warning: %s %" PRId64 " is NULL in file id %d",
-               ex_name_of_object(set_type), set_id, exoid);
-      ex_err("ex_get_set", errmsg, EX_NULLENTITY);
-      return (EX_WARN);
-    }
+  if (set_id_ndx <= 0) {
+    ex_get_err(NULL, NULL, &status);
 
-    snprintf(errmsg, MAX_ERR_LENGTH,
-             "ERROR: failed to locate %s id %" PRId64 " in VAR_*S_IDS array in file id %d",
-             ex_name_of_object(set_type), set_id, exoid);
-    ex_err("ex_get_set", errmsg, exerrval);
-    return (EX_FATAL);
+    if (status != 0) {
+      if (status == EX_NULLENTITY) {
+        snprintf(errmsg, MAX_ERR_LENGTH, "Warning: %s %" PRId64 " is NULL in file id %d",
+                 ex_name_of_object(set_type), set_id, exoid);
+        ex_err("ex_get_set", errmsg, EX_NULLENTITY);
+        EX_FUNC_LEAVE(EX_WARN);
+      }
+
+      snprintf(errmsg, MAX_ERR_LENGTH,
+               "ERROR: failed to locate %s id %" PRId64 " in VAR_*S_IDS array in file id %d",
+               ex_name_of_object(set_type), set_id, exoid);
+      ex_err("ex_get_set", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
+    }
   }
 
   /* setup more pointers based on set_type */
@@ -113,12 +116,11 @@ int ex_get_set(int exoid, ex_entity_type set_type, ex_entity_id set_id, void_int
 
   /* inquire id's of previously defined dimensions and variables */
   if ((status = nc_inq_varid(exoid, entryptr, &entry_list_id)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to locate entry list for %s %" PRId64 " in file id %d",
              ex_name_of_object(set_type), set_id, exoid);
-    ex_err("ex_get_set", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_set", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* If client doet not pass in an array to store the
@@ -127,12 +129,11 @@ int ex_get_set(int exoid, ex_entity_type set_type, ex_entity_id set_id, void_int
   /* only do extra list for edge, face and side sets */
   if (set_extra_list) {
     if ((status = nc_inq_varid(exoid, extraptr, &extra_list_id)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to locate extra list for %s %" PRId64 " in file id %d",
                ex_name_of_object(set_type), set_id, exoid);
-      ex_err("ex_get_set", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_set", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
 
@@ -146,12 +147,11 @@ int ex_get_set(int exoid, ex_entity_type set_type, ex_entity_id set_id, void_int
     }
 
     if (status != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to get entry list for %s %" PRId64 " in file id %d",
                ex_name_of_object(set_type), set_id, exoid);
-      ex_err("ex_get_set", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_set", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
 
@@ -165,13 +165,12 @@ int ex_get_set(int exoid, ex_entity_type set_type, ex_entity_id set_id, void_int
     }
 
     if (status != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to get extra list for %s %" PRId64 " in file id %d",
                ex_name_of_object(set_type), set_id, exoid);
-      ex_err("ex_get_set", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_set", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
