@@ -48,7 +48,7 @@
 *
 *****************************************************************************/
 
-#include "exodusII.h"     // for ex_err, exerrval, ex_block, etc
+#include "exodusII.h"     // for ex_err, ex_block, etc
 #include "exodusII_int.h" // for elem_blk_parm, EX_FATAL, etc
 #include <assert.h>       // for assert
 #include <ctype.h>        // for toupper
@@ -61,6 +61,7 @@
 
 int ex_get_side_set_node_count(int exoid, ex_entity_id side_set_id, int *side_set_node_cnt_list)
 {
+  int       status;
   int       ii, i, j;
   int       num_side_sets, num_elem_blks, ndim;
   size_t    tot_num_ss_elem = 0;
@@ -76,7 +77,8 @@ int ex_get_side_set_node_count(int exoid, ex_entity_id side_set_id, int *side_se
   char errmsg[MAX_ERR_LENGTH];
   int  err_stat = EX_NOERR;
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   /* first check if any side sets are specified */
   /* inquire how many side sets have been stored */
@@ -84,39 +86,43 @@ int ex_get_side_set_node_count(int exoid, ex_entity_id side_set_id, int *side_se
   if (num_side_sets < 0) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of side sets in file id %d",
              exoid);
-    ex_err("ex_get_side_set_node_count", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_side_set_node_count", errmsg, EX_LASTERR);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (num_side_sets == 0) {
     snprintf(errmsg, MAX_ERR_LENGTH, "Warning: no side sets defined in file id %d", exoid);
     ex_err("ex_get_side_set_node_count", errmsg, EX_WARN);
-    return (EX_WARN);
+    EX_FUNC_LEAVE(EX_WARN);
   }
 
   /* Lookup index of side set id in VAR_SS_IDS array */
-  ex_id_lkup(exoid, EX_SIDE_SET, side_set_id);
-  if (exerrval != 0) {
-    if (exerrval == EX_NULLENTITY) {
+  if (ex_id_lkup(exoid, EX_SIDE_SET, side_set_id) <= 0) {
+    ;
+  }
+  ex_get_err(NULL, NULL, &status);
+
+  if (status != 0) {
+    if (status == EX_NULLENTITY) {
       snprintf(errmsg, MAX_ERR_LENGTH, "Warning: side set %" PRId64 " is NULL in file id %d",
                side_set_id, exoid);
       ex_err("ex_get_side_set_node_count", errmsg, EX_NULLENTITY);
-      return (EX_WARN);
+      EX_FUNC_LEAVE(EX_WARN);
     }
 
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to locate side set %" PRId64 " in VAR_SS_IDS array in file id %d",
              side_set_id, exoid);
-    ex_err("ex_get_side_set_node_count", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_side_set_node_count", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   num_elem_blks = ex_inquire_int(exoid, EX_INQ_ELEM_BLK);
   if (num_elem_blks < 0) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of element blocks in file id %d",
              exoid);
-    ex_err("ex_get_side_set_node_count", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_side_set_node_count", errmsg, EX_LASTERR);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* get the dimensionality of the coordinates;  this is necessary to
@@ -124,8 +130,8 @@ int ex_get_side_set_node_count(int exoid, ex_entity_id side_set_id, int *side_se
   ndim = ex_inquire_int(exoid, EX_INQ_DIM);
   if (ndim < 0) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get dimensionality in file id %d", exoid);
-    ex_err("ex_get_side_set_node_count", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_side_set_node_count", errmsg, EX_LASTERR);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   int int_size = sizeof(int);
@@ -152,29 +158,27 @@ int ex_get_side_set_node_count(int exoid, ex_entity_id side_set_id, int *side_se
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to get number of elements in side set %" PRId64 " in file id %d",
              side_set_id, exoid);
-    ex_err("ex_get_side_set_node_count", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_side_set_node_count", errmsg, EX_LASTERR);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* Allocate space for the side set element list */
   {
     if (!(side_set_elem_list = malloc(tot_num_ss_elem * int_size))) {
-      exerrval = EX_MEMFAIL;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to allocate space for side set element "
                                        "list for file id %d",
                exoid);
-      ex_err("ex_get_side_set_node_count", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_side_set_node_count", errmsg, EX_MEMFAIL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* Allocate space for the side set side list */
     if (!(side_set_side_list = malloc(tot_num_ss_elem * int_size))) {
       free(side_set_elem_list);
-      exerrval = EX_MEMFAIL;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to allocate space for side set side list "
                                        "for file id %d",
                exoid);
-      ex_err("ex_get_side_set_node_count", errmsg, exerrval);
+      ex_err("ex_get_side_set_node_count", errmsg, EX_MEMFAIL);
       err_stat = EX_FATAL;
       goto cleanup;
     }
@@ -182,18 +186,17 @@ int ex_get_side_set_node_count(int exoid, ex_entity_id side_set_id, int *side_se
     if (ex_get_set(exoid, EX_SIDE_SET, side_set_id, side_set_elem_list, side_set_side_list) == -1) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get side set %" PRId64 " in file id %d",
                side_set_id, exoid);
-      ex_err("ex_get_side_set_node_count", errmsg, exerrval);
+      ex_err("ex_get_side_set_node_count", errmsg, EX_LASTERR);
       err_stat = EX_FATAL;
       goto cleanup;
     }
 
     /* Allocate space for the ss element index array */
     if (!(ss_elem_ndx = malloc(tot_num_ss_elem * int_size))) {
-      exerrval = EX_MEMFAIL;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to allocate space for side set elem sort "
                                        "array for file id %d",
                exoid);
-      ex_err("ex_get_side_set_node_count", errmsg, exerrval);
+      ex_err("ex_get_side_set_node_count", errmsg, EX_MEMFAIL);
       err_stat = EX_FATAL;
       goto cleanup;
     }
@@ -224,11 +227,10 @@ int ex_get_side_set_node_count(int exoid, ex_entity_id side_set_id, int *side_se
     }
 
     if (!(elem_blk_ids = malloc(num_elem_blks * int_size))) {
-      exerrval = EX_MEMFAIL;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to allocate space for element block ids "
                                        "for file id %d",
                exoid);
-      ex_err("ex_get_side_set_node_count", errmsg, exerrval);
+      ex_err("ex_get_side_set_node_count", errmsg, EX_MEMFAIL);
       err_stat = EX_FATAL;
       goto cleanup;
     }
@@ -244,11 +246,10 @@ int ex_get_side_set_node_count(int exoid, ex_entity_id side_set_id, int *side_se
 
   /* Allocate space for the element block params */
   if (!(elem_blk_parms = malloc(num_elem_blks * sizeof(struct elem_blk_parm)))) {
-    exerrval = EX_MEMFAIL;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to allocate space for element block params "
                                      "for file id %d",
              exoid);
-    ex_err("ex_get_side_set_node_count", errmsg, exerrval);
+    ex_err("ex_get_side_set_node_count", errmsg, EX_MEMFAIL);
     err_stat = EX_FATAL;
     goto cleanup;
   }
@@ -307,11 +308,10 @@ int ex_get_side_set_node_count(int exoid, ex_entity_id side_set_id, int *side_se
       side_set_node_cnt_list[i] = elem_blk_parms[j].num_nodes_per_side[side];
     }
     else {
-      exerrval = EX_BADPARAM;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: Invalid element number %" PRId64 " found in side set %" PRId64 " in file %d",
                elem, side_set_id, exoid);
-      ex_err("ex_get_side_set_node_count", errmsg, EX_MSG);
+      ex_err("ex_get_side_set_node_count", errmsg, EX_BADPARAM);
       err_stat = EX_FATAL;
       goto cleanup;
     }
@@ -328,5 +328,5 @@ cleanup:
   free(side_set_side_list);
   free(side_set_elem_list);
 
-  return (err_stat);
+  EX_FUNC_LEAVE(err_stat);
 }
