@@ -49,7 +49,7 @@
 *
 *****************************************************************************/
 
-#include "exodusII.h"     // for ex_err, exerrval, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for elem_blk_parm, EX_FATAL, etc
 #include "netcdf.h"       // for NC_NOERR
 #include <ctype.h>        // for toupper
@@ -90,7 +90,8 @@ int ex_get_side_set_node_list_len(int exoid, ex_entity_id side_set_id,
 
   char errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
     *(int64_t *)side_set_node_list_len = 0; /* default value */
@@ -108,38 +109,38 @@ int ex_get_side_set_node_list_len(int exoid, ex_entity_id side_set_id,
   ndim = ex_inquire_int(exoid, EX_INQ_DIM);
   if (ndim < 0) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get dimensionality in file id %d", exoid);
-    ex_err("ex_get_side_set_node_list_len", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_side_set_node_list_len", errmsg, EX_LASTERR);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   tot_num_elem = ex_inquire_int(exoid, EX_INQ_ELEM);
   if (tot_num_elem < 0) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get total number of elements in file id %d",
              exoid);
-    ex_err("ex_get_side_set_node_list_len", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_side_set_node_list_len", errmsg, EX_LASTERR);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   num_elem_blks = ex_inquire_int(exoid, EX_INQ_ELEM_BLK);
   if (num_elem_blks < 0) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of element blocks in file id %d",
              exoid);
-    ex_err("ex_get_side_set_node_list_len", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_side_set_node_list_len", errmsg, EX_LASTERR);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   num_side_sets = ex_inquire_int(exoid, EX_INQ_SIDE_SETS);
   if (num_side_sets < 0) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of side sets in file id %d",
              exoid);
-    ex_err("ex_get_side_set_node_list_len", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_side_set_node_list_len", errmsg, EX_LASTERR);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (num_side_sets == 0) {
     snprintf(errmsg, MAX_ERR_LENGTH, "Warning: no side sets defined in file id %d", exoid);
     ex_err("ex_get_side_set_node_list_len", errmsg, EX_WARN);
-    return (EX_WARN);
+    EX_FUNC_LEAVE(EX_WARN);
   }
 
   /* First determine the  # of elements in the side set*/
@@ -158,12 +159,12 @@ int ex_get_side_set_node_list_len(int exoid, ex_entity_id side_set_id,
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to get number of elements in side set %" PRId64 " in file id %d",
              side_set_id, exoid);
-    ex_err("ex_get_side_set_node_list_len", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_side_set_node_list_len", errmsg, EX_LASTERR);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (tot_num_ss_elem == 0) { /* NULL side set? */
-    return (EX_NOERR);        /* return zero */
+    EX_FUNC_LEAVE(EX_NOERR);
   }
 
   /* Minor optimization/kluge -- If num_df is nonzero, or 1 per face
@@ -175,7 +176,7 @@ int ex_get_side_set_node_list_len(int exoid, ex_entity_id side_set_id,
     else {
       *(int *)side_set_node_list_len = num_df;
     }
-    return (EX_NOERR);
+    EX_FUNC_LEAVE(EX_NOERR);
   }
 
   /* Allocate space for the side set element list */
@@ -185,21 +186,19 @@ int ex_get_side_set_node_list_len(int exoid, ex_entity_id side_set_id,
       int_size = sizeof(int64_t);
     }
     if (!(side_set_elem_list = malloc(tot_num_ss_elem * int_size))) {
-      exerrval = EX_MEMFAIL;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to allocate space for side set element "
                                        "list for file id %d",
                exoid);
-      ex_err("ex_get_side_set_node_list_len", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_side_set_node_list_len", errmsg, EX_MEMFAIL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* Allocate space for the side set side list */
     if (!(side_set_side_list = malloc(tot_num_ss_elem * int_size))) {
-      exerrval = EX_MEMFAIL;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to allocate space for side set side list "
                                        "for file id %d",
                exoid);
-      ex_err("ex_get_side_set_node_list_len", errmsg, exerrval);
+      ex_err("ex_get_side_set_node_list_len", errmsg, EX_MEMFAIL);
       err_stat = EX_FATAL;
       goto cleanup;
     }
@@ -208,7 +207,7 @@ int ex_get_side_set_node_list_len(int exoid, ex_entity_id side_set_id,
         NC_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get side set %" PRId64 " in file id %d",
                side_set_id, exoid);
-      ex_err("ex_get_side_set_node_list_len", errmsg, exerrval);
+      ex_err("ex_get_side_set_node_list_len", errmsg, EX_LASTERR);
       err_stat = EX_FATAL;
       goto cleanup;
     }
@@ -222,11 +221,10 @@ int ex_get_side_set_node_list_len(int exoid, ex_entity_id side_set_id,
     }
 
     if (ss_elem_ndx_64 == NULL && ss_elem_ndx == NULL) {
-      exerrval = EX_MEMFAIL;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to allocate space for side set elem sort "
                                        "array for file id %d",
                exoid);
-      ex_err("ex_get_side_set_node_list_len", errmsg, exerrval);
+      ex_err("ex_get_side_set_node_list_len", errmsg, EX_MEMFAIL);
       err_stat = EX_FATAL;
       goto cleanup;
     }
@@ -254,11 +252,10 @@ int ex_get_side_set_node_list_len(int exoid, ex_entity_id side_set_id,
     }
 
     if (!(elem_blk_ids = malloc(num_elem_blks * int_size))) {
-      exerrval = EX_MEMFAIL;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to allocate space for element block ids "
                                        "for file id %d",
                exoid);
-      ex_err("ex_get_side_set_node_list_len", errmsg, exerrval);
+      ex_err("ex_get_side_set_node_list_len", errmsg, EX_MEMFAIL);
       err_stat = EX_FATAL;
       goto cleanup;
     }
@@ -273,11 +270,10 @@ int ex_get_side_set_node_list_len(int exoid, ex_entity_id side_set_id,
 
   /* Allocate space for the element block params */
   if (!(elem_blk_parms = malloc(num_elem_blks * sizeof(struct elem_blk_parm)))) {
-    exerrval = EX_MEMFAIL;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to allocate space for element block params "
                                      "for file id %d",
              exoid);
-    ex_err("ex_get_side_set_node_list_len", errmsg, exerrval);
+    ex_err("ex_get_side_set_node_list_len", errmsg, EX_MEMFAIL);
     err_stat = EX_FATAL;
     goto cleanup;
   }
@@ -324,7 +320,6 @@ int ex_get_side_set_node_list_len(int exoid, ex_entity_id side_set_id,
       }
     }
     if (j >= num_elem_blks) {
-      exerrval = EX_BADPARAM;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: Invalid element number %" ST_ZU " found in side set %" PRId64 " in file %d",
                elem, side_set_id, exoid);
@@ -352,5 +347,5 @@ cleanup:
   free(side_set_side_list);
   free(side_set_elem_list);
 
-  return (err_stat);
+  EX_FUNC_LEAVE(err_stat);
 }
