@@ -34,12 +34,12 @@
  */
 
 #include "exodusII.h"     // for ex_err, ex_name_of_object, etc
-#include "exodusII_int.h" // for EX_FATAL, ex_comp_ws, etc
+#include "exodusII_int.h" // for ex_check_valid_file_id, etc
 #include "netcdf.h"       // for NC_NOERR, etc
 #include <inttypes.h>     // for PRId64
 #include <stddef.h>       // for size_t
-#include <stdio.h>
-#include <sys/types.h> // for int64_t
+#include <stdint.h>       // for int64_t
+#include <stdio.h>        // for snprintf
 
 /*!
 \ingroup ResultsData
@@ -105,44 +105,50 @@ int ex_get_var(int exoid, int time_step, ex_entity_type var_type, int var_index,
   size_t start[2], count[2];
   char   errmsg[MAX_ERR_LENGTH];
 
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
+
   if (var_type == EX_NODAL) {
     /* FIXME: Special case: ignore obj_id, possible large_file complications,
      * etc. */
-    return ex_get_nodal_var_int(exoid, time_step, var_index, num_entry_this_obj, var_vals);
+    status = ex_get_nodal_var_int(exoid, time_step, var_index, num_entry_this_obj, var_vals);
+    EX_FUNC_LEAVE(status);
   }
   if (var_type == EX_GLOBAL) {
     /* FIXME: Special case: all vars stored in 2-D single array. */
-    return ex_get_glob_vars_int(exoid, time_step, num_entry_this_obj, var_vals);
+    status = ex_get_glob_vars_int(exoid, time_step, num_entry_this_obj, var_vals);
+    EX_FUNC_LEAVE(status);
   }
 
-  exerrval = 0; /* clear error code */
-
   /* Determine index of obj_id in VAR_ID_EL_BLK array */
   obj_id_ndx = ex_id_lkup(exoid, var_type, obj_id);
-  if (exerrval != 0) {
-    if (exerrval == EX_NULLENTITY) {
+  if (obj_id_ndx <= 0) {
+    ex_get_err(NULL, NULL, &status);
+
+    if (status != 0) {
+      if (status == EX_NULLENTITY) {
+        snprintf(errmsg, MAX_ERR_LENGTH,
+                 "Warning: no %s variables for NULL block %" PRId64 " in file id %d",
+                 ex_name_of_object(var_type), obj_id, exoid);
+        ex_err("ex_get_var", errmsg, EX_NULLENTITY);
+        EX_FUNC_LEAVE(EX_WARN);
+      }
       snprintf(errmsg, MAX_ERR_LENGTH,
-               "Warning: no %s variables for NULL block %" PRId64 " in file id %d",
+               "ERROR: failed to locate %s id %" PRId64 " in id variable in file id %d",
                ex_name_of_object(var_type), obj_id, exoid);
-      ex_err("ex_get_var", errmsg, EX_NULLENTITY);
-      return (EX_WARN);
+      ex_err("ex_get_var", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
-    snprintf(errmsg, MAX_ERR_LENGTH,
-             "ERROR: failed to locate %s id %" PRId64 " in id variable in file id %d",
-             ex_name_of_object(var_type), obj_id, exoid);
-    ex_err("ex_get_var", errmsg, exerrval);
-    return (EX_FATAL);
   }
 
   /* inquire previously defined variable */
 
   if ((status = nc_inq_varid(exoid, ex_name_var_of_object(var_type, var_index, obj_id_ndx),
                              &varid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate %s %" PRId64 " var %d in file id %d",
              ex_name_of_object(var_type), obj_id, var_index, exoid);
-    ex_err("ex_get_var", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_var", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
 /* Verify that time_step is within bounds */
@@ -154,7 +160,7 @@ int ex_get_var(int exoid, int time_step, ex_entity_type var_type, int var_index,
                                        "range is 1 to %d in file id %d",
                time_step, num_time_steps, exoid);
       ex_err("ex_get_var", errmsg, EX_BADPARAM);
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
 #endif
@@ -174,12 +180,11 @@ int ex_get_var(int exoid, int time_step, ex_entity_type var_type, int var_index,
   }
 
   if (status != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to get %s %" PRId64 " variable %d in file id %d",
              ex_name_of_object(var_type), obj_id, var_index, exoid);
-    ex_err("ex_get_var", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_get_var", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
