@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_WARN, etc
 #include "netcdf.h"       // for NC_NOERR, nc_inq_varid
 #include <stdio.h>
@@ -99,7 +99,8 @@ int ex_get_variable_names(int exoid, ex_entity_type obj_type, int num_vars, char
   char        errmsg[MAX_ERR_LENGTH];
   const char *vvarname;
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   switch (obj_type) {
   case EX_NODAL: vvarname      = VAR_NAME_NOD_VAR; break;
@@ -113,27 +114,25 @@ int ex_get_variable_names(int exoid, ex_entity_type obj_type, int num_vars, char
   case EX_ELEM_SET: vvarname   = VAR_NAME_ELSET_VAR; break;
   case EX_GLOBAL: vvarname     = VAR_NAME_GLO_VAR; break;
   default:
-    exerrval = EX_BADPARAM;
     snprintf(errmsg, MAX_ERR_LENGTH, "Warning: invalid variable type %d requested from file id %d",
              obj_type, exoid);
-    ex_err("ex_get_variable_names", errmsg, exerrval);
-    return (EX_WARN);
+    ex_err("ex_get_variable_names", errmsg, EX_BADPARAM);
+    EX_FUNC_LEAVE(EX_WARN);
   }
 
   /* inquire previously defined variables  */
   if ((status = nc_inq_varid(exoid, vvarname, &varid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "Warning: no %s variables names stored in file id %d",
              ex_name_of_object(obj_type), exoid);
-    ex_err("ex_get_variable_names", errmsg, exerrval);
-    return (EX_WARN);
+    ex_err("ex_get_variable_names", errmsg, status);
+    EX_FUNC_LEAVE(EX_WARN);
   }
 
   /* read the variable names */
   status =
       ex_get_names_internal(exoid, varid, num_vars, var_names, obj_type, "ex_get_variable_names");
   if (status != NC_NOERR) {
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
