@@ -55,7 +55,7 @@
 #include "exodusII.h"
 #if defined(PARALLEL_AWARE_EXODUS)
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, etc
 #include <mpi.h>          // for MPI_Comm, MPI_Info, etc
 #include <stddef.h>       // for size_t
@@ -146,7 +146,7 @@ int ex_open_par_int(const char *path, int mode, int *comp_ws, int *io_ws, float
 
   char errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
 
   /* set error handling mode to no messages, non-fatal errors */
   ex_opts(exoptval); /* call required to set ncopts first time through */
@@ -165,10 +165,9 @@ int ex_open_par_int(const char *path, int mode, int *comp_ws, int *io_ws, float
   }
 
   if ((mode & EX_READ) && (mode & EX_WRITE)) {
-    exerrval = EX_BADFILEMODE;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Cannot specify both EX_READ and EX_WRITE");
-    ex_err("ex_open_par", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_open_par", errmsg, EX_BADFILEMODE);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* Check parallel io mode.  Valid is NC_MPIPOSIX or NC_MPIIO or NC_PNETCDF
@@ -233,18 +232,16 @@ int ex_open_par_int(const char *path, int mode, int *comp_ws, int *io_ws, float
                 path);
 #endif
       }
-      exerrval = status;
 
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to open %s read only", path);
-      ex_err("ex_open_par", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_open_par", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
   else /* (mode & EX_WRITE) READ/WRITE */
   {
     if ((status = nc_open_par(path, NC_WRITE | NC_SHARE | pariomode, comm, info, &exoid)) !=
         NC_NOERR) {
-      exerrval = status;
 #if defined(NC_HAVE_META_H)
 #if (NC_HAS_PARALLEL == 0) && (NC_HAS_PNETCDF == 0)
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: The underyling netcdf library was not compiled "
@@ -252,22 +249,25 @@ int ex_open_par_int(const char *path, int mode, int *comp_ws, int *io_ws, float
 #endif
 #endif
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to open %s write only", path);
-      ex_err("ex_open_par", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_open_par", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* turn off automatic filling of netCDF variables */
     if ((status = nc_set_fill(exoid, NC_NOFILL, &old_fill)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to set nofill mode in file id %d", exoid);
-      ex_err("ex_open_par", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_open_par", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     stat_att = nc_inq_att(exoid, NC_GLOBAL, ATT_MAX_NAME_LENGTH, &att_type, &att_len);
     stat_dim = nc_inq_dimid(exoid, DIM_STR_NAME, &dim_str_name);
     if (stat_att != NC_NOERR || stat_dim != NC_NOERR) {
-      nc_redef(exoid);
+      if ((status = nc_redef(exoid)) != NC_NOERR) {
+        snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to put file id %d into define mode", exoid);
+        ex_err("ex_open_par", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
+      }
       if (stat_att != NC_NOERR) {
         int max_so_far = 32;
         nc_put_att_int(exoid, NC_GLOBAL, ATT_MAX_NAME_LENGTH, NC_INT, 1, &max_so_far);
@@ -280,7 +280,12 @@ int ex_open_par_int(const char *path, int mode, int *comp_ws, int *io_ws, float
         int max_name = ex_default_max_name_length < 32 ? 32 : ex_default_max_name_length;
         nc_def_dim(exoid, DIM_STR_NAME, max_name + 1, &dim_str_name);
       }
-      nc_enddef(exoid);
+      if ((status = nc_enddef(exoid)) != NC_NOERR) {
+        snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to complete definition in file id %d",
+                 exoid);
+        ex_err("ex_open_par", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
+      }
     }
   }
 
@@ -289,30 +294,28 @@ int ex_open_par_int(const char *path, int mode, int *comp_ws, int *io_ws, float
    */
 
   if ((status = nc_get_att_float(exoid, NC_GLOBAL, ATT_VERSION, version)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get database version for file id: %d",
              exoid);
-    ex_err("ex_open_par", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_open_par", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* check ExodusII file version - old version 1.x files are not supported */
   if (*version < 2.0) {
-    exerrval = EX_FATAL;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Unsupported file version %.2f in file id: %d",
              *version, exoid);
-    ex_err("ex_open_par", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_open_par", errmsg, EX_BADPARAM);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if (nc_get_att_int(exoid, NC_GLOBAL, ATT_FLT_WORDSIZE, &file_wordsize) !=
       NC_NOERR) { /* try old (prior to db version 2.02) attribute name */
-    if (nc_get_att_int(exoid, NC_GLOBAL, ATT_FLT_WORDSIZE_BLANK, &file_wordsize) != NC_NOERR) {
-      exerrval = EX_FATAL;
+    if ((status = nc_get_att_int(exoid, NC_GLOBAL, ATT_FLT_WORDSIZE_BLANK, &file_wordsize)) !=
+        NC_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get file wordsize from file id: %d",
                exoid);
-      ex_err("ex_open_par", errmsg, exerrval);
-      return (exerrval);
+      ex_err("ex_open_par", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
 
@@ -338,28 +341,26 @@ int ex_open_par_int(const char *path, int mode, int *comp_ws, int *io_ws, float
   */
   if (ex_find_file_item(exoid) != NULL) {
     char errmsg[MAX_ERR_LENGTH];
-    exerrval = EX_BADFILEID;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: There is an existing file already using the file "
                                      "id %d which was also assigned to file %s.\n\tWas "
                                      "nc_close() called instead of ex_close() on an open Exodus "
                                      "file?\n",
              exoid, path);
-    ex_err("ex_open_par", errmsg, exerrval);
+    ex_err("ex_open_par", errmsg, EX_BADFILEID);
     nc_close(exoid);
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* initialize floating point and integer size conversion. */
   if (ex_conv_ini(exoid, comp_ws, io_ws, file_wordsize, int64_status, 1, is_mpiio, is_pnetcdf) !=
       EX_NOERR) {
-    exerrval = EX_FATAL;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to initialize conversion routines in file id %d", exoid);
-    ex_err("ex_open_par", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_open_par", errmsg, EX_LASTERR);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
-  return (exoid);
+  EX_FUNC_LEAVE(exoid);
 }
 #else
 /*
