@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for ex_block, ex_err, exerrval, etc
+#include "exodusII.h"     // for ex_block, ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, etc
 #include "netcdf.h"       // for NC_NOERR, nc_def_var, etc
 #include <inttypes.h>     // for PRId64
@@ -85,8 +85,12 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
   const char *dnnpe       = NULL;
   const char *dnepe       = NULL;
   const char *dnfpe       = NULL;
+#if NC_HAS_HDF5
+  int fill = NC_FILL_CHAR;
+#endif
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   blocks_to_define = malloc(block_count * sizeof(int));
 
@@ -108,13 +112,12 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       vblksta = VAR_STAT_EL_BLK;
       break;
     default:
-      exerrval = EX_BADPARAM;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: Bad block type (%d) specified for entry %d file id %d", blocks[i].type,
                (int)i, exoid);
-      ex_err("ex_put_block_params", errmsg, exerrval);
+      ex_err("ex_put_block_params", errmsg, EX_BADPARAM);
       free(blocks_to_define);
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* first check if any blocks of that type are specified */
@@ -122,9 +125,9 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
                                    &dimid, "ex_put_block_params")) != NC_NOERR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: No %ss defined in file id %d",
                ex_name_of_object(blocks[i].type), exoid);
-      ex_err("ex_put_block_params", errmsg, exerrval);
+      ex_err("ex_put_block_params", errmsg, EX_LASTERR);
       free(blocks_to_define);
-      return EX_FATAL;
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* Next: Make sure that there are not any duplicate block ids by
@@ -135,23 +138,20 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     */
 
     if ((status = nc_inq_varid(exoid, vblkids, &varid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate %s ids in file id %d",
                ex_name_of_object(blocks[i].type), exoid);
-      ex_err("ex_put_block_params", errmsg, exerrval);
+      ex_err("ex_put_block_params", errmsg, status);
       free(blocks_to_define);
-      return EX_FATAL;
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
-    ex_id_lkup(exoid, blocks[i].type,
-               blocks[i].id);        /* Error value used, but don't need return value */
-    if (exerrval != EX_LOOKUPFAIL) { /* found the element block id */
-      exerrval = EX_FATAL;
+    status = ex_id_lkup(exoid, blocks[i].type, blocks[i].id);
+    if (-status != EX_LOOKUPFAIL) { /* found the element block id */
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: %s id %" PRId64 " already exists in file id %d",
                ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-      ex_err("ex_put_block_params", errmsg, exerrval);
+      ex_err("ex_put_block_params", errmsg, EX_DUPLICATEID);
       free(blocks_to_define);
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /* Keep track of the total number of element blocks defined using a counter
@@ -161,12 +161,11 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     */
     cur_num_blk = ex_get_file_item(exoid, ex_get_counter_list(blocks[i].type));
     if (cur_num_blk >= (int)num_blk) {
-      exerrval = EX_FATAL;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: exceeded number of %ss (%d) defined in file id %d",
                ex_name_of_object(blocks[i].type), (int)num_blk, exoid);
-      ex_err("ex_put_block_params", errmsg, exerrval);
+      ex_err("ex_put_block_params", errmsg, EX_BADPARAM);
       free(blocks_to_define);
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /*   NOTE: ex_inc_file_item  is a function that finds the number of element
@@ -178,12 +177,11 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     status = nc_put_var1_longlong(exoid, varid, start, (long long *)&blocks[i].id);
 
     if (status != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store %s id to file id %d",
                ex_name_of_object(blocks[i].type), exoid);
-      ex_err("ex_put_block_params", errmsg, exerrval);
+      ex_err("ex_put_block_params", errmsg, status);
       free(blocks_to_define);
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     blocks_to_define[i] = start[0] + 1; /* element id index into vblkids array*/
@@ -196,32 +194,29 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     }
 
     if ((status = nc_inq_varid(exoid, vblksta, &varid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate %s status in file id %d",
                ex_name_of_object(blocks[i].type), exoid);
-      ex_err("ex_put_block_params", errmsg, exerrval);
+      ex_err("ex_put_block_params", errmsg, status);
       free(blocks_to_define);
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     if ((status = nc_put_var1_int(exoid, varid, start, &blk_stat)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to store %s id %" PRId64 " status to file id %d",
                ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-      ex_err("ex_put_block_params", errmsg, exerrval);
+      ex_err("ex_put_block_params", errmsg, status);
       free(blocks_to_define);
-      return (EX_FATAL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
 
   /* put netcdf file into define mode  */
   if ((status = nc_redef(exoid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to place file id %d into define mode", exoid);
-    ex_err("ex_put_block_params", errmsg, exerrval);
+    ex_err("ex_put_block_params", errmsg, status);
     free(blocks_to_define);
-    return (EX_FATAL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   for (i = 0; i < block_count; i++) {
@@ -276,17 +271,15 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     /* define some dimensions and variables*/
     if ((status = nc_def_dim(exoid, dneblk, blocks[i].num_entry, &numblkdim)) != NC_NOERR) {
       if (status == NC_ENAMEINUSE) { /* duplicate entry */
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: %s %" PRId64 " already defined in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
       }
       else {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define number of entities/block for %s %" PRId64 " file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
       }
       goto error_ret; /* exit define mode and return */
     }
@@ -295,11 +288,10 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       /* A nfaced block would not have any nodes defined... */
       if ((status = nc_def_dim(exoid, dnnpe, blocks[i].num_nodes_per_entry, &nnodperentdim)) !=
           NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define number of nodes/entity for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
     }
@@ -307,11 +299,10 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     if (dnepe && blocks[i].num_edges_per_entry > 0) {
       if ((status = nc_def_dim(exoid, dnepe, blocks[i].num_edges_per_entry, &nedgperentdim)) !=
           NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define number of edges/entity for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
     }
@@ -319,11 +310,10 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     if (dnfpe && blocks[i].num_faces_per_entry > 0) {
       if ((status = nc_def_dim(exoid, dnfpe, blocks[i].num_faces_per_entry, &nfacperentdim)) !=
           NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define number of faces/entity for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
     }
@@ -332,11 +322,10 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     if (blocks[i].num_attribute > 0) {
 
       if ((status = nc_def_dim(exoid, dnape, blocks[i].num_attribute, &numattrdim)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define number of attributes in %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
 
@@ -344,20 +333,18 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       dims[1] = numattrdim;
 
       if ((status = nc_def_var(exoid, vblkatt, nc_flt_code(exoid), 2, dims, &varid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR:  failed to define attributes for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
       ex_compress_variable(exoid, varid, 2);
 
       /* inquire previously defined dimensions  */
       if ((status = nc_inq_dimid(exoid, DIM_STR_NAME, &strdim)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get string length in file id %d", exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret;
       }
 
@@ -366,13 +353,15 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       dims[1] = strdim;
 
       if ((status = nc_def_var(exoid, vattnam, NC_CHAR, 2, dims, &att_name_varid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define %s attribute name array in file id %d",
                  ex_name_of_object(blocks[i].type), exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
+#if NC_HAS_HDF5
+      nc_def_var_fill(exoid, att_name_varid, 0, &fill);
+#endif
     }
 
     conn_int_type = NC_INT;
@@ -400,11 +389,10 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     /* element connectivity array */
     if (arbitrary_polyhedra > 0) {
       if (blocks[i].type != EX_FACE_BLOCK && blocks[i].type != EX_ELEM_BLOCK) {
-        exerrval = EX_BADPARAM;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: Bad block type (%d) for nsided/nfaced block in file id %d", blocks[i].type,
                  exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, EX_BADPARAM);
         goto error_ret;
       }
 
@@ -433,11 +421,10 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       }
 
       if ((status = nc_def_var(exoid, vconn, conn_int_type, 1, dims, &connid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to create connectivity array for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
 
@@ -445,32 +432,29 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       dims[0] = numblkdim;
 
       if ((status = nc_def_var(exoid, vnpecnt, conn_int_type, 1, dims, &npeid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to create face- or node- per-entity "
                                          "count array for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
 
       if ((status = nc_put_att_text(exoid, npeid, "entity_type1", strlen(entity_type1) + 1,
                                     entity_type1)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to store entity type attribute text for %s %" PRId64
                  " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
       if ((status = nc_put_att_text(exoid, npeid, "entity_type2", strlen(entity_type2) + 1,
                                     entity_type2)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to store entity type attribute text for %s %" PRId64
                  " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
     }
@@ -480,11 +464,10 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
       dims[1] = nnodperentdim;
 
       if ((status = nc_def_var(exoid, vnodcon, conn_int_type, 2, dims, &connid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to create connectivity array for %s %" PRId64 " in file id %d",
                  ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-        ex_err("ex_put_block_params", errmsg, exerrval);
+        ex_err("ex_put_block_params", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
       ex_compress_variable(exoid, connid, 1);
@@ -492,10 +475,9 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     /* store element type as attribute of connectivity variable */
     if ((status = nc_put_att_text(exoid, connid, ATT_NAME_ELB, strlen(blocks[i].topology) + 1,
                                   blocks[i].topology)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store %s type name %s in file id %d",
                ex_name_of_object(blocks[i].type), blocks[i].topology, exoid);
-      ex_err("ex_put_block_params", errmsg, exerrval);
+      ex_err("ex_put_block_params", errmsg, status);
       goto error_ret; /* exit define mode and return */
     }
 
@@ -505,12 +487,11 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
         dims[1] = nedgperentdim;
 
         if ((status = nc_def_var(exoid, vedgcon, conn_int_type, 2, dims, &varid)) != NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to create edge connectivity array for %s %" PRId64
                    " in file id %d",
                    ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-          ex_err("ex_put_block_params", errmsg, exerrval);
+          ex_err("ex_put_block_params", errmsg, status);
           goto error_ret; /* exit define mode and return */
         }
       }
@@ -520,12 +501,11 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
         dims[1] = nfacperentdim;
 
         if ((status = nc_def_var(exoid, vfaccon, conn_int_type, 2, dims, &varid)) != NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to create face connectivity array for %s %" PRId64
                    " in file id %d",
                    ex_name_of_object(blocks[i].type), blocks[i].id, exoid);
-          ex_err("ex_put_block_params", errmsg, exerrval);
+          ex_err("ex_put_block_params", errmsg, status);
           goto error_ret; /* exit define mode and return */
         }
       }
@@ -535,11 +515,11 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
   free(blocks_to_define);
 
   /* leave define mode  */
-  if ((exerrval = nc_enddef(exoid)) != NC_NOERR) {
+  if ((status = nc_enddef(exoid)) != NC_NOERR) {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to complete %s definition in file id %d",
              ex_name_of_object(blocks[i].type), exoid);
-    ex_err("ex_put_block_params", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_block_params", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   for (i = 0; i < block_count; i++) {
@@ -548,7 +528,7 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     case EX_FACE_BLOCK: vblkids = VAR_ID_FA_BLK; break;
     case EX_ELEM_BLOCK: vblkids = VAR_ID_EL_BLK; break;
     default:
-      return (EX_FATAL); /* should have been handled earlier; quiet compiler here */
+      EX_FUNC_LEAVE(EX_FATAL); /* should have been handled earlier; quiet compiler here */
     }
 
     nc_inq_varid(exoid, vblkids, &att_name_varid);
@@ -572,15 +552,15 @@ int ex_put_block_params(int exoid, size_t block_count, const struct ex_block *bl
     }
   }
 
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 
 /* Fatal error: exit definition mode and return */
 error_ret:
   free(blocks_to_define);
 
-  if (nc_enddef(exoid) != NC_NOERR) { /* exit define mode */
+  if ((status = nc_enddef(exoid)) != NC_NOERR) { /* exit define mode */
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to complete definition for file id %d", exoid);
-    ex_err("ex_put_block_params", errmsg, exerrval);
+    ex_err("ex_put_block_params", errmsg, status);
   }
-  return (EX_FATAL);
+  EX_FUNC_LEAVE(EX_FATAL);
 }
