@@ -50,7 +50,7 @@
 *
 *****************************************************************************/
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, ex_comp_ws, etc
 #include "netcdf.h"       // for NC_NOERR, nc_inq_varid, etc
 #include <stddef.h>       // for size_t
@@ -124,48 +124,45 @@ int ex_put_coord(int exoid, const void *x_coor, const void *y_coor, const void *
   size_t num_nod, num_dim, start[2], count[2], i;
   char   errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   /* inquire id's of previously defined dimensions  */
 
   if ((status = nc_inq_dimid(exoid, DIM_NUM_NODES, &numnoddim)) != NC_NOERR) {
     /* If not found, then this file is storing 0 nodes.
        Return immediately */
-    return (EX_NOERR);
+    EX_FUNC_LEAVE(EX_NOERR);
   }
 
   if ((status = nc_inq_dimlen(exoid, numnoddim, &num_nod)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: inquire failed to return number of nodes in file id %d", exoid);
-    ex_err("ex_put_coord", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_coord", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if ((status = nc_inq_dimid(exoid, DIM_NUM_DIM, &ndimdim)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate number of dimensions in file id %d",
              exoid);
-    ex_err("ex_put_coord", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_coord", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if ((status = nc_inq_dimlen(exoid, ndimdim, &num_dim)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of dimensions in file id %d",
              exoid);
-    ex_err("ex_put_coord", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_coord", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* write out the coordinates  */
   if (ex_large_model(exoid) == 0) {
     if ((status = nc_inq_varid(exoid, VAR_COORD, &coordid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate nodal coordinates in file id %d",
                exoid);
-      ex_err("ex_put_coord", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_put_coord", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     for (i = 0; i < num_dim; i++) {
@@ -205,30 +202,27 @@ int ex_put_coord(int exoid, const void *x_coor, const void *y_coor, const void *
       }
 
       if (status != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to put %s coord array in file id %d", which,
                  exoid);
-        ex_err("ex_put_coord", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_put_coord", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
     }
   }
   else {
     if ((status = nc_inq_varid(exoid, VAR_COORD_X, &coordidx)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate x nodal coordinates in file id %d",
                exoid);
-      ex_err("ex_put_coord", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_put_coord", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     if (num_dim > 1) {
       if ((status = nc_inq_varid(exoid, VAR_COORD_Y, &coordidy)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to locate y nodal coordinates in file id %d", exoid);
-        ex_err("ex_put_coord", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_put_coord", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
     }
     else {
@@ -236,11 +230,10 @@ int ex_put_coord(int exoid, const void *x_coor, const void *y_coor, const void *
     }
     if (num_dim > 2) {
       if ((status = nc_inq_varid(exoid, VAR_COORD_Z, &coordidz)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to locate z nodal coordinates in file id %d", exoid);
-        ex_err("ex_put_coord", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_put_coord", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
     }
     else {
@@ -277,14 +270,13 @@ int ex_put_coord(int exoid, const void *x_coor, const void *y_coor, const void *
         }
 
         if (status != NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to put %s coord array in file id %d",
                    which, exoid);
-          ex_err("ex_put_coord", errmsg, exerrval);
-          return (EX_FATAL);
+          ex_err("ex_put_coord", errmsg, status);
+          EX_FUNC_LEAVE(EX_FATAL);
         }
       }
     }
   }
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
