@@ -50,12 +50,12 @@
 *****************************************************************************/
 
 #include "exodusII.h"     // for ex_init_params, ex_err, etc
-#include "exodusII_int.h" // for nc_flt_code, EX_FATAL, etc
+#include "exodusII_int.h" // for nc_flt_code, etc
 #include "netcdf.h"       // for NC_NOERR, nc_def_dim, etc
-#include <stddef.h>       // for size_t
-#include <stdio.h>
-#include <stdlib.h> // for NULL, free, malloc
-#include <string.h> // for strlen
+#include <stddef.h>       // for size_t, NULL
+#include <stdio.h>        // for snprintf
+#include <stdlib.h>       // for free, malloc
+#include <string.h>       // for strlen
 
 static void write_dummy_names(int exoid, ex_entity_type obj_type)
 {
@@ -87,20 +87,25 @@ static int ex_write_object_names(int exoid, const char *type, const char *dimens
   int  status;
   int  varid;
   char errmsg[MAX_ERR_LENGTH];
+#if NC_HAS_HDF5
+  int fill = NC_FILL_CHAR;
+#endif
 
   if (count > 0) {
     dim[0] = dimension_var;
     dim[1] = string_dimension;
 
     if ((status = nc_def_var(exoid, dimension_name, NC_CHAR, 2, dim, &varid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define %s name array in file id %d", type,
                exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
-      return status; /* exit define mode and return */
+      ex_err("ex_put_init_ext", errmsg, status);
+      return (status); /* exit define mode and return */
     }
+#if NC_HAS_HDF5
+    nc_def_var_fill(exoid, varid, 0, &fill);
+#endif
   }
-  return NC_NOERR;
+  return (NC_NOERR);
 }
 
 static int ex_write_object_params(int exoid, const char *type, const char *dimension_name,
@@ -116,21 +121,19 @@ static int ex_write_object_params(int exoid, const char *type, const char *dimen
   /* Can have nonzero model->num_elem_blk even if model->num_elem == 0 */
   if (count > 0) {
     if ((status = nc_def_dim(exoid, dimension_name, count, dimension)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define number of %ss in file id %d", type,
                exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
-      return status; /* exit define mode and return */
+      ex_err("ex_put_init_ext", errmsg, status);
+      return (status); /* exit define mode and return */
     }
     /* ...and some variables */
     /* element block id status array */
     dim[0] = *dimension;
     if ((status = nc_def_var(exoid, status_dim_name, NC_INT, 1, dim, &varid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define %s status array in file id %d",
                type, exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
-      return status; /* exit define mode and return */
+      ex_err("ex_put_init_ext", errmsg, status);
+      return (status); /* exit define mode and return */
     }
 
     /* type id array */
@@ -139,23 +142,21 @@ static int ex_write_object_params(int exoid, const char *type, const char *dimen
       int_type = NC_INT64;
     }
     if ((status = nc_def_var(exoid, id_array_dim_name, int_type, 1, dim, &varid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define %s id array in file id %d", type,
                exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
-      return status; /* exit define mode and return */
+      ex_err("ex_put_init_ext", errmsg, status);
+      return (status); /* exit define mode and return */
     }
 
     /*   store property name as attribute of property array variable */
     if ((status = nc_put_att_text(exoid, varid, ATT_PROP_NAME, 3, "ID")) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store %s property name %s in file id %d",
                type, "ID", exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
-      return status;
+      ex_err("ex_put_init_ext", errmsg, status);
+      return (status);
     }
   }
-  return NC_NOERR;
+  return (NC_NOERR);
 }
 
 static int ex_write_map_params(int exoid, const char *map_name, const char *map_dim_name,
@@ -174,34 +175,31 @@ static int ex_write_map_params(int exoid, const char *map_name, const char *map_
   /* Can have nonzero model->num_XXXX_map even if model->num_XXXX == 0 */
   if ((map_count) > 0) {
     if ((status = nc_def_dim(exoid, map_dim_name, map_count, map_dimension)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define number of %ss in file id %d",
                map_name, exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
-      return status; /* exit define mode and return */
+      ex_err("ex_put_init_ext", errmsg, status);
+      return (status); /* exit define mode and return */
     }
 
     dim[0] = *map_dimension;
 
     /* map_name id array */
     if ((status = nc_def_var(exoid, map_id_name, int_type, 1, dim, &varid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define %s id array in file id %d",
                map_name, exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
-      return status; /* exit define mode and return */
+      ex_err("ex_put_init_ext", errmsg, status);
+      return (status); /* exit define mode and return */
     }
 
     /*   store property name as attribute of property array variable */
     if ((status = nc_put_att_text(exoid, varid, ATT_PROP_NAME, 3, "ID")) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store %s property name %s in file id %d",
                map_name, "ID", exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
+      ex_err("ex_put_init_ext", errmsg, status);
       return (EX_FATAL);
     }
   }
-  return NC_NOERR;
+  return (NC_NOERR);
 }
 
 static void invalidate_id_status(int exoid, const char *var_stat, const char *var_id, int count,
@@ -249,33 +247,31 @@ int ex_put_init_ext(int exoid, const ex_init_params *model)
 #endif
   char errmsg[MAX_ERR_LENGTH];
 
+  EX_FUNC_ENTER();
   int rootid = exoid & EX_FILE_ID_MASK;
 
-  exerrval = 0; /* clear error code */
+  ex_check_valid_file_id(exoid);
 
   if (rootid == exoid && nc_inq_dimid(exoid, DIM_NUM_DIM, &temp) == NC_NOERR) {
-    exerrval = EX_MSG;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: initialization already done for file id %d", exoid);
-    ex_err("ex_put_init_ext", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_init_ext", errmsg, EX_MSG);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* put file into define mode */
   if ((status = nc_redef(exoid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to put file id %d into define mode", exoid);
-    ex_err("ex_put_init_ext", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_init_ext", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* define some attributes... */
   title_len = strlen(model->title) < MAX_LINE_LENGTH ? strlen(model->title) : MAX_LINE_LENGTH;
   if ((status = nc_put_att_text(rootid, NC_GLOBAL, (const char *)ATT_TITLE, title_len + 1,
                                 model->title)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define model->title attribute to file id %d",
              rootid);
-    ex_err("ex_put_init_ext", errmsg, exerrval);
+    ex_err("ex_put_init_ext", errmsg, status);
     goto error_ret; /* exit define mode and return */
   }
 
@@ -289,36 +285,32 @@ int ex_put_init_ext(int exoid, const ex_init_params *model)
     }
 
     if ((status = nc_def_dim(rootid, DIM_STR_NAME, max_name + 1, &dim_str_name)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define name string length in file id %d",
                rootid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
+      ex_err("ex_put_init_ext", errmsg, status);
       goto error_ret;
     }
   }
 
   if ((status = nc_def_dim(exoid, DIM_TIME, NC_UNLIMITED, &timedim)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define time dimension in file id %d", exoid);
-    ex_err("ex_put_init_ext", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_init_ext", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   dim[0] = timedim;
   if ((status = nc_def_var(exoid, VAR_WHOLE_TIME, nc_flt_code(exoid), 1, dim, &temp)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to define whole time step variable in file id %d", exoid);
-    ex_err("ex_put_init_ext", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_init_ext", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
   ex_compress_variable(exoid, temp, 2);
 
   if ((status = nc_def_dim(exoid, DIM_NUM_DIM, model->num_dim, &numdimdim)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define number of dimensions in file id %d",
              exoid);
-    ex_err("ex_put_init_ext", errmsg, exerrval);
+    ex_err("ex_put_init_ext", errmsg, status);
     goto error_ret; /* exit define mode and return */
   }
 
@@ -332,67 +324,60 @@ int ex_put_init_ext(int exoid, const ex_init_params *model)
 
   if (model->num_nodes > 0) {
     if ((status = nc_def_dim(exoid, DIM_NUM_NODES, model->num_nodes, &numnoddim)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define number of nodes in file id %d",
                exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
+      ex_err("ex_put_init_ext", errmsg, status);
       goto error_ret; /* exit define mode and return */
     }
   }
 
   if (model->num_elem > 0) {
     if (model->num_nodes <= 0) {
-      exerrval = EX_MSG;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Cannot have non-zero element count if node count "
                                        "is zero.in file id %d",
                exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
+      ex_err("ex_put_init_ext", errmsg, EX_BADPARAM);
       goto error_ret; /* exit define mode and return */
     }
 
     if ((status = nc_def_dim(exoid, DIM_NUM_ELEM, model->num_elem, &temp)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define number of elements in file id %d",
                exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
+      ex_err("ex_put_init_ext", errmsg, status);
       goto error_ret; /* exit define mode and return */
     }
   }
 
   if (model->num_edge > 0) {
     if (model->num_nodes <= 0) {
-      exerrval = EX_MSG;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Cannot have non-zero edge count if node count is "
                                        "zero.in file id %d",
                exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
+      ex_err("ex_put_init_ext", errmsg, EX_BADPARAM);
       goto error_ret; /* exit define mode and return */
     }
 
     if ((status = nc_def_dim(exoid, DIM_NUM_EDGE, model->num_edge, &temp)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define number of edges in file id %d",
                exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
+      ex_err("ex_put_init_ext", errmsg, status);
       goto error_ret; /* exit define mode and return */
     }
   }
 
   if (model->num_face > 0) {
     if (model->num_nodes <= 0) {
-      exerrval = EX_MSG;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Cannot have non-zero face count if node count is "
                                        "zero.in file id %d",
                exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
+      ex_err("ex_put_init_ext", errmsg, EX_BADPARAM);
       goto error_ret; /* exit define mode and return */
     }
 
     if ((status = nc_def_dim(exoid, DIM_NUM_FACE, model->num_face, &temp)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to define number of faces in file id %d",
                exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
+      ex_err("ex_put_init_ext", errmsg, status);
       goto error_ret; /* exit define mode and return */
     }
   }
@@ -471,10 +456,9 @@ int ex_put_init_ext(int exoid, const ex_init_params *model)
       if (model->num_dim > 0) {
         if ((status = nc_def_var(exoid, VAR_COORD_X, nc_flt_code(exoid), 1, dim, &temp)) !=
             NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to define node x coordinate array in file id %d", exoid);
-          ex_err("ex_put_init_ext", errmsg, exerrval);
+          ex_err("ex_put_init_ext", errmsg, status);
           goto error_ret; /* exit define mode and return */
         }
         ex_compress_variable(exoid, temp, 2);
@@ -483,10 +467,9 @@ int ex_put_init_ext(int exoid, const ex_init_params *model)
       if (model->num_dim > 1) {
         if ((status = nc_def_var(exoid, VAR_COORD_Y, nc_flt_code(exoid), 1, dim, &temp)) !=
             NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to define node y coordinate array in file id %d", exoid);
-          ex_err("ex_put_init_ext", errmsg, exerrval);
+          ex_err("ex_put_init_ext", errmsg, status);
           goto error_ret; /* exit define mode and return */
         }
         ex_compress_variable(exoid, temp, 2);
@@ -495,10 +478,9 @@ int ex_put_init_ext(int exoid, const ex_init_params *model)
       if (model->num_dim > 2) {
         if ((status = nc_def_var(exoid, VAR_COORD_Z, nc_flt_code(exoid), 1, dim, &temp)) !=
             NC_NOERR) {
-          exerrval = status;
           snprintf(errmsg, MAX_ERR_LENGTH,
                    "ERROR: failed to define node z coordinate array in file id %d", exoid);
-          ex_err("ex_put_init_ext", errmsg, exerrval);
+          ex_err("ex_put_init_ext", errmsg, status);
           goto error_ret; /* exit define mode and return */
         }
         ex_compress_variable(exoid, temp, 2);
@@ -510,10 +492,9 @@ int ex_put_init_ext(int exoid, const ex_init_params *model)
       dim[0] = numdimdim;
       dim[1] = numnoddim;
       if ((status = nc_def_var(exoid, VAR_COORD, nc_flt_code(exoid), 2, dim, &temp)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to define node coordinate array in file id %d", exoid);
-        ex_err("ex_put_init_ext", errmsg, exerrval);
+        ex_err("ex_put_init_ext", errmsg, status);
         goto error_ret; /* exit define mode and return */
       }
     }
@@ -574,11 +555,10 @@ int ex_put_init_ext(int exoid, const ex_init_params *model)
 
   /* leave define mode */
   if ((status = nc_enddef(exoid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to complete variable definitions in file id %d",
              exoid);
-    ex_err("ex_put_init_ext", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_init_ext", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* Fill the id and status arrays with EX_INVALID_ID */
@@ -621,11 +601,10 @@ int ex_put_init_ext(int exoid, const ex_init_params *model)
 
     /* allocate space for id/status array */
     if (!(invalid_ids = malloc(maxset * sizeof(int)))) {
-      exerrval = EX_MEMFAIL;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to allocate memory for id/status array for file id %d", exoid);
-      ex_err("ex_put_init_ext", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_put_init_ext", errmsg, EX_MEMFAIL);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     invalidate_id_status(exoid, VAR_STAT_EL_BLK, VAR_ID_EL_BLK, model->num_elem_blk, invalid_ids);
@@ -687,14 +666,14 @@ int ex_put_init_ext(int exoid, const ex_init_params *model)
     write_dummy_names(exoid, EX_ELEM_MAP);
   }
 
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 
 /* Fatal error: exit definition mode and return */
 error_ret:
-  if (nc_enddef(exoid) != NC_NOERR) /* exit define mode */
+  if ((status = nc_enddef(exoid)) != NC_NOERR) /* exit define mode */
   {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to complete definition for file id %d", exoid);
-    ex_err("ex_put_init_ext", errmsg, exerrval);
+    ex_err("ex_put_init_ext", errmsg, status);
   }
-  return (EX_FATAL);
+  EX_FUNC_LEAVE(EX_FATAL);
 }
