@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for ex_err, exerrval, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, ex_id_lkup, etc
 #include "netcdf.h"       // for NC_NOERR, nc_set_fill, etc
 #include <inttypes.h>     // for PRId64
@@ -124,7 +124,8 @@ int ex_put_prop(int exoid, ex_entity_type obj_type, ex_entity_id obj_id, const c
 
   char errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   /* check if property has already been created */
 
@@ -147,28 +148,25 @@ int ex_put_prop(int exoid, ex_entity_type obj_type, ex_entity_id obj_id, const c
       case EX_EDGE_MAP: name   = VAR_EDM_PROP(i); break;
       case EX_NODE_MAP: name   = VAR_NM_PROP(i); break;
       default:
-        exerrval = EX_BADPARAM;
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: object type %d not supported; file id %d",
                  obj_type, exoid);
-        ex_err("ex_put_prop", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_put_prop", errmsg, EX_BADPARAM);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       if ((status = nc_inq_varid(exoid, name, &propid)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get property array id in file id %d",
                  exoid);
-        ex_err("ex_put_prop", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_put_prop", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       /*   compare stored attribute name with passed property name   */
       memset(tmpstr, 0, MAX_STR_LENGTH + 1);
       if ((status = nc_get_att_text(exoid, propid, ATT_PROP_NAME, tmpstr)) != NC_NOERR) {
-        exerrval = status;
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get property name in file id %d", exoid);
-        ex_err("ex_put_prop", errmsg, exerrval);
-        return (EX_FATAL);
+        ex_err("ex_put_prop", errmsg, status);
+        EX_FUNC_LEAVE(EX_FATAL);
       }
 
       if (strcmp(tmpstr, prop_name) == 0) {
@@ -185,10 +183,9 @@ int ex_put_prop(int exoid, ex_entity_type obj_type, ex_entity_id obj_id, const c
 
     /* put netcdf file into define mode  */
     if ((status = nc_redef(exoid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to place file id %d into define mode", exoid);
-      ex_err("ex_put_prop", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_put_prop", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     /*   create a variable with a name xx_prop#, where # is the new number   */
@@ -244,19 +241,17 @@ int ex_put_prop(int exoid, ex_entity_type obj_type, ex_entity_id obj_id, const c
       dim_name = DIM_NUM_NM;
       break;
     default:
-      exerrval = EX_BADPARAM;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: object type %d not supported; file id %d", obj_type,
                exoid);
-      ex_err("ex_put_prop", errmsg, exerrval);
+      ex_err("ex_put_prop", errmsg, EX_BADPARAM);
       goto error_ret; /* Exit define mode and return */
     }
 
     /*   inquire id of previously defined dimension (number of objects) */
     if ((status = nc_inq_dimid(exoid, dim_name, &dimid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate number of objects in file id %d",
                exoid);
-      ex_err("ex_put_prop", errmsg, exerrval);
+      ex_err("ex_put_prop", errmsg, status);
       goto error_ret; /* Exit define mode and return */
     }
 
@@ -269,10 +264,9 @@ int ex_put_prop(int exoid, ex_entity_type obj_type, ex_entity_id obj_id, const c
     }
 
     if ((status = nc_def_var(exoid, name, int_type, 1, dims, &propid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to create property array variable in file id %d", exoid);
-      ex_err("ex_put_prop", errmsg, exerrval);
+      ex_err("ex_put_prop", errmsg, status);
       goto error_ret; /* Exit define mode and return */
     }
 
@@ -280,10 +274,9 @@ int ex_put_prop(int exoid, ex_entity_type obj_type, ex_entity_id obj_id, const c
     /*   create attribute to cause variable to fill with zeros per routine spec
      */
     if ((status = nc_put_att_longlong(exoid, propid, _FillValue, int_type, 1, vals)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to create property name fill attribute in file id %d", exoid);
-      ex_err("ex_put_prop", errmsg, exerrval);
+      ex_err("ex_put_prop", errmsg, status);
       goto error_ret; /* Exit define mode and return */
     }
 
@@ -299,10 +292,9 @@ int ex_put_prop(int exoid, ex_entity_type obj_type, ex_entity_id obj_id, const c
     /*   store property name as attribute of property array variable */
     if ((status = nc_put_att_text(exoid, propid, ATT_PROP_NAME, prop_name_len,
                                   (void *)prop_name)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store property name %s in file id %d",
                prop_name, exoid);
-      ex_err("ex_put_prop", errmsg, exerrval);
+      ex_err("ex_put_prop", errmsg, status);
       goto error_ret; /* Exit define mode and return */
     }
 
@@ -310,10 +302,9 @@ int ex_put_prop(int exoid, ex_entity_type obj_type, ex_entity_id obj_id, const c
 
     /* leave define mode  */
     if ((status = nc_enddef(exoid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to leave define mode in file id %d", exoid);
-      ex_err("ex_put_prop", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_put_prop", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     nc_set_fill(exoid, oldfill, &temp); /* default: nofill */
@@ -325,56 +316,58 @@ int ex_put_prop(int exoid, ex_entity_type obj_type, ex_entity_id obj_id, const c
 
   /* special case: property name ID - check for duplicate ID assignment */
   if (strcmp("ID", prop_name) == 0) {
-    start[0] = ex_id_lkup(exoid, obj_type, value);
-    if (exerrval != EX_LOOKUPFAIL) /* found the id */
-    {
-      exerrval = EX_BADPARAM;
+    int indx = ex_id_lkup(exoid, obj_type, value);
+    if (indx != -EX_LOOKUPFAIL) { /* found the id */
       snprintf(errmsg, MAX_ERR_LENGTH,
                "Warning: attempt to assign duplicate %s ID %" PRId64 " in file id %d",
                ex_name_of_object(obj_type), value, exoid);
-      ex_err("ex_put_prop", errmsg, exerrval);
-      return (EX_WARN);
+      ex_err("ex_put_prop", errmsg, EX_DUPLICATEID);
+      EX_FUNC_LEAVE(EX_WARN);
     }
   }
 
-  start[0] = ex_id_lkup(exoid, obj_type, obj_id);
-  if (exerrval != 0) {
-    if (exerrval == EX_NULLENTITY) {
+  status = ex_id_lkup(exoid, obj_type, obj_id);
+  if (status > 0) {
+    start[0] = status - 1;
+  }
+  else {
+    ex_get_err(NULL, NULL, &status);
+
+    if (status != 0) {
+      if (status == EX_NULLENTITY) {
+        snprintf(errmsg, MAX_ERR_LENGTH,
+                 "Warning: no properties allowed for NULL %s id %" PRId64 " in file id %d",
+                 ex_name_of_object(obj_type), obj_id, exoid);
+        ex_err("ex_put_prop", errmsg, EX_NULLENTITY);
+        EX_FUNC_LEAVE(EX_WARN);
+      }
       snprintf(errmsg, MAX_ERR_LENGTH,
-               "Warning: no properties allowed for NULL %s id %" PRId64 " in file id %d",
-               ex_name_of_object(obj_type), obj_id, exoid);
-      ex_err("ex_put_prop", errmsg, EX_NULLENTITY);
-      return (EX_WARN);
+               "ERROR: failed to find value %" PRId64 " in %s property array in file id %d", obj_id,
+               ex_name_of_object(obj_type), exoid);
+      ex_err("ex_put_prop", errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
-    snprintf(errmsg, MAX_ERR_LENGTH,
-             "ERROR: failed to find value %" PRId64 " in %s property array in file id %d", obj_id,
-             ex_name_of_object(obj_type), exoid);
-    ex_err("ex_put_prop", errmsg, exerrval);
-    return (EX_FATAL);
   }
 
-  start[0] = start[0] - 1;
-
   /* value is of type 'ex_entity_id' which is a typedef to int64_t or long long
    */
   status = nc_put_var1_longlong(exoid, propid, start, (long long *)&value);
 
   if (status != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store property value in file id %d", exoid);
-    ex_err("ex_put_prop", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_prop", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 
 /* Fatal error: exit definition mode and return */
 error_ret:
   nc_set_fill(exoid, oldfill, &temp); /* default: nofill */
 
-  if (nc_enddef(exoid) != NC_NOERR) { /* exit define mode */
+  if ((status = nc_enddef(exoid)) != NC_NOERR) { /* exit define mode */
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to complete definition for file id %d", exoid);
-    ex_err("ex_put_prop", errmsg, exerrval);
+    ex_err("ex_put_prop", errmsg, status);
   }
-  return (EX_FATAL);
+  EX_FUNC_LEAVE(EX_FATAL);
 }
