@@ -33,7 +33,7 @@
  *
  */
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, ex_comp_ws, etc
 #include "netcdf.h"       // for NC_NOERR, nc_inq_varid, etc
 #include <stddef.h>       // for size_t
@@ -84,14 +84,15 @@ int ex_put_time(int exoid, int time_step, const void *time_value)
   size_t start[1];
   char   errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+
+  ex_check_valid_file_id(exoid);
 
   /* inquire previously defined variable */
   if ((status = nc_inq_varid(exoid, VAR_WHOLE_TIME, &varid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate time variable in file id %d", exoid);
-    ex_err("ex_put_time", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_time", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* store time value */
@@ -105,11 +106,10 @@ int ex_put_time(int exoid, int time_step, const void *time_value)
   }
 
   if (status != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store time value in file id %d", exoid);
-    ex_err("ex_put_time", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_time", errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 }
