@@ -51,7 +51,7 @@
 *
 *****************************************************************************/
 
-#include "exodusII.h"     // for ex_err, exerrval, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for ex_get_dimension, EX_FATAL, etc
 #include "netcdf.h"       // for nc_inq_varid, NC_NOERR, etc
 #include <stddef.h>       // for size_t
@@ -96,7 +96,10 @@ int ex_put_truth_table(int exoid, ex_entity_type obj_type, int num_blk, int num_
   const char *ent_type = NULL;
   const char *var_name = NULL;
   const char *ent_size = NULL;
-  exerrval             = 0; /* clear error code */
+
+  EX_FUNC_ENTER();
+
+  ex_check_valid_file_id(exoid);
 
   ex_get_dimension(exoid, ex_dim_num_objects(obj_type), ex_name_of_object(obj_type), &num_entity,
                    &numelblkdim, routine);
@@ -175,38 +178,34 @@ int ex_put_truth_table(int exoid, ex_entity_type obj_type, int num_blk, int num_
   }
 
   else { /* invalid variable type */
-    exerrval = EX_BADPARAM;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Invalid variable type %d specified in file id %d",
              obj_type, exoid);
-    ex_err(routine, errmsg, exerrval);
-    return (EX_WARN);
+    ex_err(routine, errmsg, EX_BADPARAM);
+    EX_FUNC_LEAVE(EX_WARN);
   }
 
   if ((int)num_entity != num_blk) {
-    exerrval = EX_FATAL;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: # of %s doesn't match those defined in file id %d",
              ex_name_of_object(obj_type), exoid);
-    ex_err(routine, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(routine, errmsg, EX_BADPARAM);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   if ((int)num_var_db != num_var) {
-    exerrval = EX_FATAL;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: # of %s variables doesn't match those defined in file id %d",
              ex_name_of_object(obj_type), exoid);
-    ex_err(routine, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(routine, errmsg, EX_BADPARAM);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* Get status array for later use */
   if (!(stat_vals = malloc(num_blk * sizeof(int)))) {
-    exerrval = EX_MEMFAIL;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to allocate memory for %s status array for file id %d",
              ex_name_of_object(obj_type), exoid);
-    ex_err(routine, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(routine, errmsg, EX_MEMFAIL);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   status = nc_inq_varid(exoid, sta_type, &varid);
@@ -217,12 +216,11 @@ int ex_put_truth_table(int exoid, ex_entity_type obj_type, int num_blk, int num_
        object exists to be backward compatible */
 
     if ((status = nc_get_var_int(exoid, varid, stat_vals)) != NC_NOERR) {
-      exerrval = status;
       free(stat_vals);
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get %s status array from file id %d",
                ex_name_of_object(obj_type), exoid);
-      ex_err(routine, errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err(routine, errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
   }
   else {
@@ -235,18 +233,16 @@ int ex_put_truth_table(int exoid, ex_entity_type obj_type, int num_blk, int num_
   /* put netcdf file into define mode  */
   if ((status = nc_redef(exoid)) != NC_NOERR) {
     free(stat_vals);
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to put file id %d into define mode", exoid);
-    ex_err(routine, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(routine, errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* inquire previously defined dimensions */
   if ((status = nc_inq_dimid(exoid, DIM_TIME, &timedim)) != NC_NOERR) {
-    exerrval = status;
     free(stat_vals);
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate time variable in file id %d", exoid);
-    ex_err(routine, errmsg, exerrval);
+    ex_err(routine, errmsg, status);
     goto error_ret; /* exit define mode and return */
   }
 
@@ -271,12 +267,11 @@ int ex_put_truth_table(int exoid, ex_entity_type obj_type, int num_blk, int num_
 
           /* Determine number of entities in block */
           if ((status = nc_inq_dimid(exoid, ex_catstr(ent_size, (i + 1)), &dims[1])) != NC_NOERR) {
-            exerrval = status;
             free(stat_vals);
             snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate number of entities in "
                                              "%d'th %s in file id %d",
                      i + 1, ex_name_of_object(obj_type), exoid);
-            ex_err(routine, errmsg, exerrval);
+            ex_err(routine, errmsg, status);
             goto error_ret; /* exit define mode and return */
           }
 
@@ -290,12 +285,11 @@ int ex_put_truth_table(int exoid, ex_entity_type obj_type, int num_blk, int num_
           if ((status = nc_def_var(exoid, ex_catstr2(var_name, j, ent_type, i + 1),
                                    nc_flt_code(exoid), 2, dims, &varid)) != NC_NOERR) {
             if (status != NC_ENAMEINUSE) {
-              exerrval = status;
               free(stat_vals);
               snprintf(errmsg, MAX_ERR_LENGTH,
                        "ERROR: failed to define variable for %d'th %s in file id %d", i + 1,
                        ex_name_of_object(obj_type), exoid);
-              ex_err(routine, errmsg, exerrval);
+              ex_err(routine, errmsg, status);
               goto error_ret; /* exit define mode and return */
             }
             ex_compress_variable(exoid, varid, 2);
@@ -316,41 +310,38 @@ int ex_put_truth_table(int exoid, ex_entity_type obj_type, int num_blk, int num_
   status  = nc_def_var(exoid, tab_type, NC_INT, 2, dims, &varid);
 
   if (status != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to define %s variable truth table in file id %d",
              ex_name_of_object(obj_type), exoid);
-    ex_err(routine, errmsg, exerrval);
+    ex_err(routine, errmsg, status);
     goto error_ret; /* exit define mode and return */
   }
 
   /* leave define mode  */
   if ((status = nc_enddef(exoid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to complete definitions in file id %d", exoid);
-    ex_err(routine, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(routine, errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* write out the element variable truth table */
   status = nc_put_var_int(exoid, varid, var_tab);
 
   if (status != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store variable truth table in file id %d",
              exoid);
-    ex_err(routine, errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err(routine, errmsg, status);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
-  return (EX_NOERR);
+  EX_FUNC_LEAVE(EX_NOERR);
 
 /* Fatal error: exit definition mode and return */
 error_ret:
-  if (nc_enddef(exoid) != NC_NOERR) /* exit define mode */
+  if ((status = nc_enddef(exoid)) != NC_NOERR) /* exit define mode */
   {
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to complete definition for file id %d", exoid);
-    ex_err(routine, errmsg, exerrval);
+    ex_err(routine, errmsg, status);
   }
-  return (EX_FATAL);
+  EX_FUNC_LEAVE(EX_FATAL);
 }
