@@ -50,7 +50,7 @@
 *
 *****************************************************************************/
 
-#include "exodusII.h"     // for exerrval, ex_err, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_WARN, etc
 #include "netcdf.h"       // for nc_inq_varid, NC_NOERR
 #include <stdio.h>
@@ -72,7 +72,9 @@ int ex_put_variable_name(int exoid, ex_entity_type obj_type, int var_num, const
   char        errmsg[MAX_ERR_LENGTH];
   const char *vname;
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+
+  ex_check_valid_file_id(exoid);
 
   /* inquire previously defined variables  */
   switch (obj_type) {
@@ -87,24 +89,22 @@ int ex_put_variable_name(int exoid, ex_entity_type obj_type, int var_num, const
   case EX_SIDE_SET: vname   = VAR_NAME_SSET_VAR; break;
   case EX_ELEM_SET: vname   = VAR_NAME_ELSET_VAR; break;
   default:
-    exerrval = EX_BADPARAM;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Invalid variable type (%d) given for file id %d",
              obj_type, exoid);
-    ex_err("ex_put_variable_name", errmsg, exerrval);
-    return (EX_WARN);
+    ex_err("ex_put_variable_name", errmsg, EX_BADPARAM);
+    EX_FUNC_LEAVE(EX_WARN);
   }
 
   if ((status = nc_inq_varid(exoid, vname, &varid)) != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "Warning: no %s variables names stored in file id %d",
              ex_name_of_object(obj_type), exoid);
-    ex_err("ex_put_variable_name", errmsg, exerrval);
-    return (EX_WARN);
+    ex_err("ex_put_variable_name", errmsg, status);
+    EX_FUNC_LEAVE(EX_WARN);
   }
 
   /* write EXODUS variable name */
   status = ex_put_name_internal(exoid, varid, var_num - 1, var_name, obj_type, "variable",
                                 "ex_put_variable_name");
 
-  return (status);
+  EX_FUNC_LEAVE(status);
 }
