@@ -50,7 +50,7 @@
 *
 *****************************************************************************/
 
-#include "exodusII.h"     // for ex_err, exerrval, etc
+#include "exodusII.h"     // for ex_err, etc
 #include "exodusII_int.h" // for EX_FATAL, etc
 #include "netcdf.h"       // for NC_NOERR, nc_inq_dimid, etc
 #include <stdio.h>
@@ -61,38 +61,34 @@ static int ex_put_var_names_int(int exoid, char *tname, char *dnumvar, char *vna
   int  dimid;
   char errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0; /* clear error code */
-
   if ((status = nc_inq_dimid(exoid, dnumvar, &dimid)) != NC_NOERR) {
-    exerrval = status;
     if (status == NC_EBADDIM) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: no %s variables defined in file id %d", tname,
                exoid);
-      ex_err("ex_put_variable_names", errmsg, exerrval);
+      ex_err("ex_put_variable_names", errmsg, status);
     }
     else {
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to locate number of %s variables in file id %d", tname, exoid);
-      ex_err("ex_put_variable_names", errmsg, exerrval);
+      ex_err("ex_put_variable_names", errmsg, status);
     }
-    return EX_FATAL;
+    return (EX_FATAL);
   }
 
   if ((status = nc_inq_varid(exoid, vnames, varid)) != NC_NOERR) {
-    exerrval = status;
     if (status == NC_ENOTVAR) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: no %s variable names defined in file id %d", tname,
                exoid);
-      ex_err("ex_put_variable_names", errmsg, exerrval);
+      ex_err("ex_put_variable_names", errmsg, status);
     }
     else {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: %s name variable names not found in file id %d",
                tname, exoid);
-      ex_err("ex_put_variable_names", errmsg, exerrval);
+      ex_err("ex_put_variable_names", errmsg, status);
     }
-    return EX_FATAL;
+    return (EX_FATAL);
   }
-  return EX_NOERR;
+  return (EX_NOERR);
 }
 
 /*!
@@ -159,7 +155,8 @@ int ex_put_variable_names(int exoid, ex_entity_type obj_type, int num_vars, char
   int  varid, status;
   char errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0; /* clear error code */
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
 
   switch (obj_type) {
   case EX_GLOBAL:
@@ -193,16 +190,15 @@ int ex_put_variable_names(int exoid, ex_entity_type obj_type, int num_vars, char
     ex_put_var_names_int(exoid, "element set", DIM_NUM_ELSET_VAR, VAR_NAME_ELSET_VAR, &varid);
     break;
   default:
-    exerrval = EX_BADPARAM;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Invalid variable type %d specified in file id %d",
              obj_type, exoid);
-    ex_err("ex_put_variable_names", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_put_variable_names", errmsg, EX_BADPARAM);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
 
   /* write EXODUS variable names */
   status = ex_put_names_internal(exoid, varid, num_vars, var_names, obj_type, "variable",
                                  "ex_put_variable_names");
 
-  return (status);
+  EX_FUNC_LEAVE(status);
 }
