@@ -95,6 +95,7 @@ Type is set to:
 #define MAGIC_NUMBER_LEN 4
 
   char magic[MAGIC_NUMBER_LEN];
+  EX_FUNC_ENTER();
 
   *type = 0;
 
@@ -104,12 +105,12 @@ Type is set to:
     int   i;
 
     if (!(fp = fopen(path, "r"))) {
-      return errno;
+      EX_FUNC_LEAVE(errno);
     }
     i = fread(magic, MAGIC_NUMBER_LEN, 1, fp);
     fclose(fp);
     if (i != 1) {
-      return errno;
+      EX_FUNC_LEAVE(errno);
     }
   }
 
@@ -125,29 +126,30 @@ Type is set to:
       *type = 2;
     }
   }
-  return EX_NOERR;
+  EX_FUNC_LEAVE(EX_NOERR);
 }
 
 int ex_set_max_name_length(int exoid, int length)
 {
   char errmsg[MAX_ERR_LENGTH];
+
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
   if (length <= 0) {
-    exerrval = NC_EMAXNAME;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: Max name length must be positive.");
-    ex_err("ex_set_max_name_length", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_set_max_name_length", errmsg, NC_EMAXNAME);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
   if (length > NC_MAX_NAME) {
-    exerrval = NC_EMAXNAME;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: Max name length (%d) exceeds netcdf max name size (%d).", length, NC_MAX_NAME);
-    ex_err("ex_set_max_name_length", errmsg, exerrval);
-    return (EX_FATAL);
+    ex_err("ex_set_max_name_length", errmsg, NC_EMAXNAME);
+    EX_FUNC_LEAVE(EX_FATAL);
   }
-  else {
-    ex_set_option(exoid, EX_OPT_MAX_NAME_LENGTH, length);
-  }
-  return EX_NOERR;
+
+  ex_set_option(exoid, EX_OPT_MAX_NAME_LENGTH, length);
+
+  EX_FUNC_LEAVE(EX_NOERR);
 }
 
 void ex_update_max_name_length(int exoid, int length)
@@ -156,20 +158,24 @@ void ex_update_max_name_length(int exoid, int length)
   int db_length = 0;
   int rootid    = exoid & EX_FILE_ID_MASK;
 
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
+
   /* Get current value of the maximum_name_length attribute... */
   if ((status = nc_get_att_int(rootid, NC_GLOBAL, ATT_MAX_NAME_LENGTH, &db_length)) != NC_NOERR) {
     char errmsg[MAX_ERR_LENGTH];
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: failed to update 'max_name_length' attribute in file id %d", exoid);
-    ex_err("ex_update_max_name_length", errmsg, exerrval);
+    ex_err("ex_update_max_name_length", errmsg, status);
   }
 
   if (length > db_length) {
     /* Update with new value... */
+    ex_set_max_name_length(exoid, length);
     nc_put_att_int(rootid, NC_GLOBAL, ATT_MAX_NAME_LENGTH, NC_INT, 1, &length);
     nc_sync(rootid);
   }
+  EX_FUNC_VOID();
 }
 
 int ex_put_names_internal(int exoid, int varid, size_t num_entity, char **names,
@@ -177,56 +183,56 @@ int ex_put_names_internal(int exoid, int varid, size_t num_entity, char **names,
 {
   size_t i;
   int    status;
-  size_t start[2], count[2];
   char   errmsg[MAX_ERR_LENGTH];
   int    max_name_len = 0;
   size_t name_length;
+  size_t length;
+  char * int_names  = NULL;
+  size_t idx        = 0;
+  int    found_name = 0;
 
+  EX_FUNC_ENTER();
+  ex_check_valid_file_id(exoid);
   /* inquire previously defined dimensions  */
   name_length = ex_inquire_int(exoid, EX_INQ_DB_MAX_ALLOWED_NAME_LENGTH) + 1;
 
+  int_names = calloc(num_entity * name_length, 1);
+
   for (i = 0; i < num_entity; i++) {
     if (names[i] != '\0') {
-      int too_long = 0;
-      start[0]     = i;
-      start[1]     = 0;
-
-      count[0] = 1;
-      count[1] = strlen(names[i]) + 1;
-
-      if (count[1] > name_length) {
+      found_name = 1;
+      strncpy(&int_names[idx], names[i], name_length - 1);
+      int_names[idx + name_length - 1] = '\0';
+      length                           = strlen(names[i]) + 1;
+      if (length > name_length) {
         fprintf(stderr, "Warning: The %s %s name '%s' is too long.\n\tIt will "
                         "be truncated from %d to %d characters\n",
-                ex_name_of_object(obj_type), subtype, names[i], (int)strlen(names[i]),
+                ex_name_of_object(obj_type), subtype, names[i], (int)length - 1,
                 (int)name_length - 1);
-        count[1] = name_length;
-        too_long = 1;
+        length = name_length;
       }
 
-      if (count[1] > max_name_len) {
-        max_name_len = count[1];
-      }
-
-      if ((status = nc_put_vara_text(exoid, varid, start, count, names[i])) != NC_NOERR) {
-        exerrval = status;
-        snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store %s names in file id %d",
-                 ex_name_of_object(obj_type), exoid);
-        ex_err(routine, errmsg, exerrval);
-        return (EX_FATAL);
-      }
-
-      /* Add the trailing null if the variable name was too long */
-      if (too_long) {
-        start[1] = name_length - 1;
-        nc_put_var1_text(exoid, varid, start, "\0");
+      if (length > max_name_len) {
+        max_name_len = length;
       }
     }
+    idx += name_length;
   }
 
-  /* Update the maximum_name_length attribute on the file. */
-  ex_update_max_name_length(exoid, max_name_len - 1);
+  if (found_name) {
+    if ((status = nc_put_var_text(exoid, varid, int_names)) != NC_NOERR) {
+      snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store %s names in file id %d",
+               ex_name_of_object(obj_type), exoid);
+      ex_err(routine, errmsg, status);
+      EX_FUNC_LEAVE(EX_FATAL);
+    }
 
-  return (EX_NOERR);
+    /* Update the maximum_name_length attribute on the file. */
+    ex_update_max_name_length(exoid, max_name_len - 1);
+  }
+  free(int_names);
+
+  EX_FUNC_LEAVE(EX_NOERR);
 }
 
 int ex_put_name_internal(int exoid, int varid, size_t index, const char *name,
@@ -237,6 +243,8 @@ int ex_put_name_internal(int exoid, int varid, size_t index, const char *name,
   char   errmsg[MAX_ERR_LENGTH];
   size_t name_length;
 
+  ex_check_valid_file_id(exoid);
+
   /* inquire previously defined dimensions  */
   name_length = ex_inquire_int(exoid, EX_INQ_DB_MAX_ALLOWED_NAME_LENGTH) + 1;
 
@@ -257,10 +265,9 @@ int ex_put_name_internal(int exoid, int varid, size_t index, const char *name,
     }
 
     if ((status = nc_put_vara_text(exoid, varid, start, count, name)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to store %s name in file id %d",
                ex_name_of_object(obj_type), exoid);
-      ex_err(routine, errmsg, exerrval);
+      ex_err(routine, errmsg, status);
       return (EX_FATAL);
     }
 
@@ -273,7 +280,6 @@ int ex_put_name_internal(int exoid, int varid, size_t index, const char *name,
     /* Update the maximum_name_length attribute on the file. */
     ex_update_max_name_length(exoid, count[1] - 1);
   }
-
   return (EX_NOERR);
 }
 
@@ -293,10 +299,10 @@ int ex_get_names_internal(int exoid, int varid, size_t num_entity, char **names,
   for (i = 0; i < num_entity; i++) {
     status = ex_get_name_internal(exoid, varid, i, names[i], name_size, obj_type, routine);
     if (status != NC_NOERR) {
-      return status;
+      return (status);
     }
   }
-  return EX_NOERR;
+  return (EX_NOERR);
 }
 
 int ex_get_name_internal(int exoid, int varid, size_t index, char *name, int name_size,
@@ -305,7 +311,9 @@ int ex_get_name_internal(int exoid, int varid, size_t index, char *name, int nam
   size_t start[2], count[2];
   int    status;
   char   errmsg[MAX_ERR_LENGTH];
-  int    api_name_size = ex_inquire_int(exoid, EX_INQ_MAX_READ_NAME_LENGTH);
+  int    api_name_size = 0;
+
+  api_name_size = ex_inquire_int(exoid, EX_INQ_MAX_READ_NAME_LENGTH);
 
   /* read the name */
   start[0] = index;
@@ -315,21 +323,21 @@ int ex_get_name_internal(int exoid, int varid, size_t index, char *name, int nam
 
   status = nc_get_vara_text(exoid, varid, start, count, name);
   if (status != NC_NOERR) {
-    exerrval = status;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get %s name at index %d from file id %d",
              ex_name_of_object(obj_type), (int)index, exoid);
-    ex_err(routine, errmsg, exerrval);
+    ex_err(routine, errmsg, status);
     return (EX_FATAL);
   }
 
   name[api_name_size] = '\0';
 
   ex_trim_internal(name);
-  return EX_NOERR;
+  return (EX_NOERR);
 }
 
 void ex_trim_internal(char *name)
 {
+  /* Thread-safe, reentrant */
   /* Trim trailing spaces... */
   size_t size;
   char * end;
@@ -355,6 +363,7 @@ void ex_trim_internal(char *name)
  */
 char *ex_catstr(const char *string, int num)
 {
+  /* Only called from an already locked function */
   char *tmp_string = cur_string;
   cur_string += sprintf(cur_string, "%s%d", string, num) + 1;
   if (cur_string - ret_string > 9 * (MAX_VAR_NAME_LENGTH + 1)) {
@@ -366,6 +375,7 @@ char *ex_catstr(const char *string, int num)
 /** ex_catstr2 - concatenate  string1num1string2num2   */
 char *ex_catstr2(const char *string1, int num1, const char *string2, int num2)
 {
+  /* Only called from an already locked function */
   char *tmp_string = cur_string;
   cur_string += sprintf(cur_string, "%s%d%s%d", string1, num1, string2, num2) + 1;
   if (cur_string - ret_string > 9 * (MAX_VAR_NAME_LENGTH + 1)) {
@@ -376,6 +386,7 @@ char *ex_catstr2(const char *string1, int num1, const char *string2, int num2)
 
 char *ex_name_of_object(ex_entity_type obj_type)
 {
+  /* Thread-safe and reentrant */
   switch (obj_type) {
   case EX_COORDINATE: /* kluge so some wrapper functions work */ return "coordinate";
   case EX_NODAL: return "nodal";
@@ -398,11 +409,12 @@ char *ex_name_of_object(ex_entity_type obj_type)
 
 ex_entity_type ex_var_type_to_ex_entity_type(char var_type)
 {
+  /* Thread-safe and reentrant */
   char var_lower = tolower(var_type);
   if (var_lower == 'n') {
     return EX_NODAL;
   }
-  else if (var_lower == 'l') {
+  if (var_lower == 'l') {
     return EX_EDGE_BLOCK;
   }
   else if (var_lower == 'f') {
@@ -436,7 +448,6 @@ ex_entity_type ex_var_type_to_ex_entity_type(char var_type)
 
 char *ex_dim_num_objects(ex_entity_type obj_type)
 {
-  exerrval = 0; /* clear error code */
   switch (obj_type) {
   case EX_NODAL: return DIM_NUM_NODES;
   case EX_ELEM_BLOCK: return DIM_NUM_EL_BLK;
@@ -453,10 +464,9 @@ char *ex_dim_num_objects(ex_entity_type obj_type)
   case EX_NODE_MAP: return DIM_NUM_NM;
   default: {
     char errmsg[MAX_ERR_LENGTH];
-    exerrval = EX_BADPARAM;
     snprintf(errmsg, MAX_ERR_LENGTH,
              "ERROR: object type %d not supported in call to ex_dim_num_objects", obj_type);
-    ex_err("ex_dim_num_objects", errmsg, exerrval);
+    ex_err("ex_dim_num_objects", errmsg, EX_BADPARAM);
     return (NULL);
   }
   }
@@ -514,7 +524,7 @@ char *ex_name_of_map(ex_entity_type map_type, int map_index)
 *       ex_entity_type id_type           id type name:
 *                                         elem_ss
 *                                         node_ns
-*                                         side_ss
+2*                                         side_ss
 *       int     num                     id value
 *
 * exit conditions -
@@ -524,7 +534,6 @@ char *ex_name_of_map(ex_entity_type map_type, int map_index)
 
 int ex_id_lkup(int exoid, ex_entity_type id_type, ex_entity_id num)
 {
-
   char *   id_table;
   char *   id_dim;
   char *   stat_table;
@@ -538,11 +547,9 @@ int ex_id_lkup(int exoid, ex_entity_type id_type, ex_entity_id num)
   int               status;
   char              errmsg[MAX_ERR_LENGTH];
 
-  exerrval = 0; /* clear error code */
-
   switch (id_type) {
-  case EX_NODAL: return 0;
-  case EX_GLOBAL: return 0;
+  case EX_NODAL: return (0);
+  case EX_GLOBAL: return (0);
   case EX_ELEM_BLOCK:
     id_table   = VAR_ID_EL_BLK;   /* id array name */
     id_dim     = DIM_NUM_EL_BLK;  /* id array dimension name*/
@@ -616,10 +623,9 @@ int ex_id_lkup(int exoid, ex_entity_type id_type, ex_entity_id num)
     tmp_stats  = ex_get_stat_ptr(exoid, &exoII_em);
     break;
   default:
-    exerrval = EX_BADPARAM;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: unsupported id array type %d for file id %d", id_type,
              exoid);
-    ex_err("ex_id_lkup", errmsg, exerrval);
+    ex_err("ex_id_lkup", errmsg, EX_BADPARAM);
     return (EX_FATAL);
   }
 
@@ -631,38 +637,34 @@ int ex_id_lkup(int exoid, ex_entity_type id_type, ex_entity_id num)
 
     /* First get dimension id of id array */
     if ((status = nc_inq_dimid(exoid, id_dim, &dimid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate id array dimension in file id %d",
                exoid);
-      ex_err("ex_id_lkup", errmsg, exerrval);
+      ex_err("ex_id_lkup", errmsg, status);
       return (EX_FATAL);
     }
 
     /* Next get value of dimension */
     if ((status = nc_inq_dimlen(exoid, dimid, &dim_len)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate %s array length in file id %d",
                id_table, exoid);
-      ex_err("ex_id_lkup", errmsg, exerrval);
+      ex_err("ex_id_lkup", errmsg, status);
       return (EX_FATAL);
     }
 
     /* get variable id of id array */
     if ((status = nc_inq_varid(exoid, id_table, &varid)) != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate %s array in file id %d", id_table,
                exoid);
-      ex_err("ex_id_lkup", errmsg, exerrval);
+      ex_err("ex_id_lkup", errmsg, status);
       return (EX_FATAL);
     }
 
     /* allocate space for id array and initialize to zero to ensure
        that the higher bits don't contain garbage while copy from ints */
     if (!(id_vals = calloc(dim_len, sizeof(int64_t)))) {
-      exerrval = EX_MEMFAIL;
       snprintf(errmsg, MAX_ERR_LENGTH,
                "ERROR: failed to allocate memory for %s array for file id %d", id_table, exoid);
-      ex_err("ex_id_lkup", errmsg, exerrval);
+      ex_err("ex_id_lkup", errmsg, EX_MEMFAIL);
       return (EX_FATAL);
     }
 
@@ -672,11 +674,10 @@ int ex_id_lkup(int exoid, ex_entity_type id_type, ex_entity_id num)
     else {
       int *id_vals_int;
       if (!(id_vals_int = malloc(dim_len * sizeof(int)))) {
-        exerrval = EX_MEMFAIL;
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to allocate memory for temporary array "
                                          "id_vals_int for file id %d",
                  exoid);
-        ex_err("ex_id_lkup", errmsg, exerrval);
+        ex_err("ex_id_lkup", errmsg, EX_MEMFAIL);
         free(id_vals);
         return (EX_FATAL);
       }
@@ -690,10 +691,9 @@ int ex_id_lkup(int exoid, ex_entity_type id_type, ex_entity_id num)
     }
 
     if (status != NC_NOERR) {
-      exerrval = status;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get %s array from file id %d", id_table,
                exoid);
-      ex_err("ex_id_lkup", errmsg, exerrval);
+      ex_err("ex_id_lkup", errmsg, status);
       free(id_vals);
       return (EX_FATAL);
     }
@@ -731,8 +731,10 @@ int ex_id_lkup(int exoid, ex_entity_type id_type, ex_entity_id num)
     if (!(tmp_stats->valid_ids)) {
       free(id_vals);
     }
-    exerrval = EX_LOOKUPFAIL;
-    return (EX_LOOKUPFAIL); /*if we got here, the id array value doesn't exist */
+    snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate id %" PRId64 " for file id %d", num,
+             exoid);
+    ex_set_err("ex_id_lkup", errmsg, EX_LOOKUPFAIL);
+    return (-EX_LOOKUPFAIL); /*if we got here, the id array value doesn't exist */
   }
 
   /* Now check status array to see if object is null */
@@ -748,21 +750,19 @@ int ex_id_lkup(int exoid, ex_entity_type id_type, ex_entity_id num)
       /* allocate space for new status array */
 
       if (!(stat_vals = malloc(dim_len * sizeof(int)))) {
-        exerrval = EX_MEMFAIL;
         free(id_vals);
         snprintf(errmsg, MAX_ERR_LENGTH,
                  "ERROR: failed to allocate memory for %s array for file id %d", id_table, exoid);
-        ex_err("ex_id_lkup", errmsg, exerrval);
+        ex_err("ex_id_lkup", errmsg, EX_MEMFAIL);
         return (EX_FATAL);
       }
 
       if ((status = nc_get_var_int(exoid, varid, stat_vals)) != NC_NOERR) {
-        exerrval = status;
         free(id_vals);
         free(stat_vals);
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get %s array from file id %d",
                  stat_table, exoid);
-        ex_err("ex_id_lkup", errmsg, exerrval);
+        ex_err("ex_id_lkup", errmsg, status);
         return (EX_FATAL);
       }
 
@@ -777,7 +777,7 @@ int ex_id_lkup(int exoid, ex_entity_type id_type, ex_entity_id num)
     }
 
     if (stat_vals[i] == 0) /* is this object null? */ {
-      exerrval = EX_NULLENTITY;
+      ex_err("ex_id_lkup", "", EX_NULLENTITY);
       if (!(tmp_stats->valid_stat)) {
         free(stat_vals);
       }
@@ -806,7 +806,6 @@ int ex_id_lkup(int exoid, ex_entity_type id_type, ex_entity_id num)
  */
 
 struct obj_stats *ex_get_stat_ptr(int exoid, struct obj_stats **obj_ptr)
-
 {
   struct obj_stats *tmp_ptr;
 
@@ -830,8 +829,7 @@ struct obj_stats *ex_get_stat_ptr(int exoid, struct obj_stats **obj_ptr)
     tmp_ptr->valid_stat = 0;
     *obj_ptr            = tmp_ptr;
   }
-
-  return (tmp_ptr);
+  return tmp_ptr;
 }
 
 /******************************************************************************
@@ -847,7 +845,6 @@ struct obj_stats *ex_get_stat_ptr(int exoid, struct obj_stats **obj_ptr)
  */
 
 void ex_rm_stat_ptr(int exoid, struct obj_stats **obj_ptr)
-
 {
   struct obj_stats *last_head_list_ptr, *tmp_ptr;
 
@@ -892,6 +889,8 @@ static struct list_item *em_ctr_list  = 0; /* element maps */
 
 struct list_item **ex_get_counter_list(ex_entity_type obj_type)
 {
+  /* Thread-safe, but is dealing with globals */
+  /* Only called from a routine which will be using locks */
   switch (obj_type) {
   case EX_ELEM_BLOCK: return &eb_ctr_list;
   case EX_NODE_SET: return &ns_ctr_list;
@@ -938,7 +937,6 @@ struct list_item **ex_get_counter_list(ex_entity_type obj_type)
 
 int ex_inc_file_item(int                exoid,    /* file id */
                      struct list_item **list_ptr) /* ptr to ptr to list_item */
-
 {
   struct list_item *tlist_ptr = *list_ptr; /* use temp list ptr to walk linked list */
   while (tlist_ptr) {                      /* Walk linked list of file ids/vals */
@@ -987,8 +985,11 @@ int ex_inc_file_item(int                exoid,    /* file id */
 
 int ex_get_file_item(int                exoid,    /* file id */
                      struct list_item **list_ptr) /* ptr to ptr to list_item */
-
 {
+  /* Not thread-safe: list_ptr passed in is a global
+   * Would probably work ok with multiple threads since read-only,
+   * but possible that list_ptr will be modified while being used
+   */
   struct list_item *tlist_ptr = *list_ptr; /* use temp list ptr to walk linked list */
   while (tlist_ptr) {                      /* Walk linked list of file ids/vals */
     if (exoid == tlist_ptr->exo_id) {      /* linear search for exodus file id */
@@ -1062,6 +1063,7 @@ int ex_get_num_props(int exoid, ex_entity_type obj_type)
   char *var_name;
   char  errmsg[MAX_ERR_LENGTH];
 
+  EX_FUNC_ENTER();
   cntr = 0;
 
   /* loop until there is not a property variable defined; the name of */
@@ -1081,17 +1083,16 @@ int ex_get_num_props(int exoid, ex_entity_type obj_type)
     case EX_EDGE_MAP: var_name   = VAR_EDM_PROP(cntr + 1); break;
     case EX_NODE_MAP: var_name   = VAR_NM_PROP(cntr + 1); break;
     default:
-      exerrval = EX_BADPARAM;
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: object type %d not supported; file id %d", obj_type,
                exoid);
-      ex_err("ex_get_prop_names", errmsg, exerrval);
-      return (EX_FATAL);
+      ex_err("ex_get_prop_names", errmsg, EX_BADPARAM);
+      EX_FUNC_LEAVE(EX_FATAL);
     }
 
     if (nc_inq_varid(exoid, var_name, &varid) != NC_NOERR) {
       /*   no variable with this name; return cntr which is now the number of */
       /*   properties for this type of entity */
-      return (cntr);
+      EX_FUNC_LEAVE(cntr);
     }
     cntr++;
   }
@@ -1102,6 +1103,7 @@ int ex_get_cpu_ws(void) { return (sizeof(float)); }
 /* swap - interchange v[i] and v[j] */
 static void ex_swap(int v[], int i, int j)
 {
+  /* Thread-safe, reentrant */
   int temp;
 
   temp = v[i];
@@ -1111,6 +1113,7 @@ static void ex_swap(int v[], int i, int j)
 
 static void ex_swap64(int64_t v[], int64_t i, int64_t j)
 {
+  /* Thread-safe, reentrant */
   int64_t temp;
 
   temp = v[i];
@@ -1140,6 +1143,7 @@ static void ex_swap64(int64_t v[], int64_t i, int64_t j)
 
 static int ex_int_median3(int v[], int iv[], int64_t left, int64_t right)
 {
+  /* Thread-safe, reentrant */
   int64_t center;
   center = (left + right) / 2;
 
@@ -1159,6 +1163,7 @@ static int ex_int_median3(int v[], int iv[], int64_t left, int64_t right)
 
 static int64_t ex_int_median3_64(int64_t v[], int64_t iv[], int64_t left, int64_t right)
 {
+  /* Thread-safe, reentrant */
   int64_t center;
   center = (left + right) / 2;
 
@@ -1178,6 +1183,7 @@ static int64_t ex_int_median3_64(int64_t v[], int64_t iv[], int64_t left, int64_
 
 static void ex_int_iqsort(int v[], int iv[], int left, int right)
 {
+  /* Thread-safe, reentrant */
   int pivot;
   int i, j;
 
@@ -1209,6 +1215,7 @@ static void ex_int_iqsort(int v[], int iv[], int left, int right)
 
 static void ex_int_iqsort64(int64_t v[], int64_t iv[], int64_t left, int64_t right)
 {
+  /* Thread-safe, reentrant */
   int64_t pivot;
   int64_t i, j;
 
@@ -1240,6 +1247,7 @@ static void ex_int_iqsort64(int64_t v[], int64_t iv[], int64_t left, int64_t rig
 
 static void ex_int_iisort(int v[], int iv[], int N)
 {
+  /* Thread-safe, reentrant */
   int i, j;
   int ndx = 0;
   int small;
@@ -1266,6 +1274,7 @@ static void ex_int_iisort(int v[], int iv[], int N)
 
 static void ex_int_iisort64(int64_t v[], int64_t iv[], int64_t N)
 {
+  /* Thread-safe, reentrant */
   int64_t i, j;
   int64_t ndx = 0;
   int64_t small;
@@ -1292,6 +1301,7 @@ static void ex_int_iisort64(int64_t v[], int64_t iv[], int64_t N)
 
 void ex_iqsort(int v[], int iv[], int N)
 {
+  /* Thread-safe, reentrant */
   ex_int_iqsort(v, iv, 0, N - 1);
   ex_int_iisort(v, iv, N);
 
@@ -1306,6 +1316,7 @@ void ex_iqsort(int v[], int iv[], int N)
 
 void ex_iqsort64(int64_t v[], int64_t iv[], int64_t N)
 {
+  /* Thread-safe, reentrant */
   ex_int_iqsort64(v, iv, 0, N - 1);
   ex_int_iisort64(v, iv, N);
 
@@ -1328,6 +1339,7 @@ void ex_iqsort64(int64_t v[], int64_t iv[], int64_t N)
 int ex_large_model(int exoid)
 {
   static int message_output = EX_FALSE;
+  EX_FUNC_ENTER();
   if (exoid < 0) {
     /* If exoid not specified, then query is to see if user specified
      * the large model via an environment variable
@@ -1340,18 +1352,17 @@ int ex_large_model(int exoid)
                           "EXODUS_LARGE_MODEL environment variable\n");
           message_output = EX_TRUE;
         }
-        return 0;
+        EX_FUNC_LEAVE(0);
       }
       if (!message_output) {
         fprintf(stderr, "EXODUSII: Large model size selected via "
                         "EXODUS_LARGE_MODEL environment variable\n");
         message_output = EX_TRUE;
       }
-      return 1;
-    }
-    else {
-      return EXODUS_DEFAULT_SIZE; /* Specified in exodusII_int.h */
+      EX_FUNC_LEAVE(1);
     }
+
+    EX_FUNC_LEAVE(EXODUS_DEFAULT_SIZE); /* Specified in exodusII_int.h */
   }
   else {
     /* See if the ATT_FILESIZE attribute is defined in the file */
@@ -1360,7 +1371,7 @@ int ex_large_model(int exoid)
       /* Variable not found; default is 0 */
       file_size = 0;
     }
-    return file_size;
+    EX_FUNC_LEAVE(file_size);
   }
 }
 
@@ -1374,31 +1385,29 @@ int ex_get_dimension(int exoid, const char *DIMENSION, const char *label, size_t
   *dimid = -1;
 
   if ((status = nc_inq_dimid(exoid, DIMENSION, dimid)) != NC_NOERR) {
-    exerrval = status;
     if (routine != NULL) {
       if (status == NC_EBADDIM) {
         snprintf(errmsg, MAX_ERR_LENGTH, "Warning: no %s defined in file id %d", label, exoid);
-        ex_err(routine, errmsg, exerrval);
+        ex_err(routine, errmsg, status);
       }
       else {
         snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to locate number of %s in file id %d",
                  label, exoid);
-        ex_err(routine, errmsg, exerrval);
+        ex_err(routine, errmsg, status);
       }
     }
-    return status;
+    return (status);
   }
 
   if ((status = nc_inq_dimlen(exoid, *dimid, count)) != NC_NOERR) {
-    exerrval = status;
     if (routine != NULL) {
       snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to get number of %s in file id %d", label,
                exoid);
-      ex_err(routine, errmsg, exerrval);
+      ex_err(routine, errmsg, status);
       return -1;
     }
   }
-  return status;
+  return (status);
 }
 
 /* Deprecated. do not use */
@@ -1413,10 +1422,9 @@ void ex_compress_variable(int exoid, int varid, int type)
 
   if (!file) {
     char errmsg[MAX_ERR_LENGTH];
-    exerrval = EX_BADFILEID;
     snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: unknown file id %d for ex_compress_variable().",
              exoid);
-    ex_err("ex_compress_variable", errmsg, exerrval);
+    ex_err("ex_compress_variable", errmsg, EX_BADFILEID);
   }
   else {
     int deflate_level = file->compression_level;
