@@ -265,7 +265,7 @@ int main(int argc, char **argv)
     num_nodes_per_elem = (int *)calloc(num_elem_blk, sizeof(int));
     num_attr           = (int *)calloc(num_elem_blk, sizeof(int));
 
-    error = ex_get_elem_blk_ids(exoid, ids);
+    error = ex_get_ids(exoid, EX_ELEM_BLOCK, ids);
     printf("\nafter ex_get_elem_blk_ids, error = %3d\n", error);
 
     for (i = 0; i < num_elem_blk; i++) {
@@ -280,8 +280,8 @@ int main(int argc, char **argv)
       if (strcmp(name, block_names[i]) != 0) {
         printf("error in ex_get_name for block id %d\n", ids[i]);
       }
-      error = ex_get_elem_block(exoid, ids[i], elem_type, &(num_elem_in_block[i]),
-                                &(num_nodes_per_elem[i]), &(num_attr[i]));
+      error = ex_get_block(exoid, EX_ELEM_BLOCK, ids[i], elem_type, &(num_elem_in_block[i]),
+                           &(num_nodes_per_elem[i]), 0, 0, &(num_attr[i]));
       printf("\nafter ex_get_elem_block, error = %d\n", error);
 
       printf("element block id = %2d\n", ids[i]);
@@ -327,7 +327,7 @@ int main(int argc, char **argv)
     if (num_elem_in_block[i] > 0) {
       connect = (int *)calloc((num_nodes_per_elem[i] * num_elem_in_block[i]), sizeof(int));
 
-      error = ex_get_elem_conn(exoid, ids[i], connect);
+      error = ex_get_conn(exoid, EX_ELEM_BLOCK, ids[i], connect, NULL, NULL);
       printf("\nafter ex_get_elem_conn, error = %d\n", error);
 
       printf("connect array for elem block %2d\n", ids[i]);
@@ -335,33 +335,22 @@ int main(int argc, char **argv)
       for (j = 0; j < num_nodes_per_elem[i]; j++) {
         printf("%3d\n", connect[j]);
       }
-      /*
-        error = ex_get_1_elem_conn (exoid, 1, ids[i], connect);
-        printf ("\nafter ex_get_elem_conn, error = %d\n", error);
-
-        printf ("node list for first element of element block %d \n ", ids[i]);
-        for (j=0; j<num_nodes_per_elem[i]; j++)
-        {
-        printf ("%d \n", connect[j]);
-        }
-      */
       free(connect);
     }
   }
 
   /* read element block attributes */
-
   for (i = 0; i < num_elem_blk; i++) {
     if (num_elem_in_block[i] > 0) {
       for (j            = 0; j < num_attr[i]; j++)
         attrib_names[j] = (char *)calloc((MAX_STR_LENGTH + 1), sizeof(char));
 
       attrib = (float *)calloc(num_attr[i] * num_elem_in_block[i], sizeof(float));
-      error  = ex_get_elem_attr(exoid, ids[i], attrib);
+      error  = ex_get_attr(exoid, EX_ELEM_BLOCK, ids[i], attrib);
       printf("\n after ex_get_elem_attr, error = %d\n", error);
 
       if (error == 0) {
-        error = ex_get_elem_attr_names(exoid, ids[i], attrib_names);
+        error = ex_get_attr_names(exoid, EX_ELEM_BLOCK, ids[i], attrib_names);
         printf(" after ex_get_elem_attr_names, error = %d\n", error);
 
         if (error == 0) {
@@ -384,7 +373,7 @@ int main(int argc, char **argv)
   if (num_node_sets > 0) {
     ids = (int *)calloc(num_node_sets, sizeof(int));
 
-    error = ex_get_node_set_ids(exoid, ids);
+    error = ex_get_ids(exoid, EX_NODE_SET, ids);
     printf("\nafter ex_get_node_set_ids, error = %3d\n", error);
 
     for (i = 0; i < num_node_sets; i++) {
@@ -400,7 +389,7 @@ int main(int argc, char **argv)
         printf("error in ex_get_name for nodeset id %d\n", ids[i]);
       }
 
-      error = ex_get_node_set_param(exoid, ids[i], &num_nodes_in_set, &num_df_in_set);
+      error = ex_get_set_param(exoid, EX_NODE_SET, ids[i], &num_nodes_in_set, &num_df_in_set);
       printf("\nafter ex_get_node_set_param, error = %3d\n", error);
 
       printf("\nnode set %2d parameters: \n", ids[i]);
@@ -410,11 +399,11 @@ int main(int argc, char **argv)
       node_list = (int *)calloc(num_nodes_in_set, sizeof(int));
       dist_fact = (float *)calloc(num_nodes_in_set, sizeof(float));
 
-      error = ex_get_node_set(exoid, ids[i], node_list);
+      error = ex_get_set(exoid, EX_NODE_SET, ids[i], node_list, NULL);
       printf("\nafter ex_get_node_set, error = %3d\n", error);
 
       if (num_df_in_set > 0) {
-        error = ex_get_node_set_dist_fact(exoid, ids[i], dist_fact);
+        error = ex_get_set_dist_fact(exoid, EX_NODE_SET, ids[i], dist_fact);
         printf("\nafter ex_get_node_set_dist_fact, error = %3d\n", error);
       }
 
@@ -514,8 +503,20 @@ int main(int argc, char **argv)
     printf("\nafter ex_inquire: EX_INQ_NS_DF_LEN = %d, error = %3d\n", list_len, error);
     dist_fact = (float *)calloc(list_len, sizeof(float));
 
-    error = ex_get_concat_node_sets(exoid, ids, num_nodes_per_set, num_df_per_set, node_ind, df_ind,
-                                    node_list, dist_fact);
+    {
+      struct ex_set_specs set_specs;
+
+      set_specs.sets_ids            = ids;
+      set_specs.num_entries_per_set = num_nodes_per_set;
+      set_specs.num_dist_per_set    = num_df_per_set;
+      set_specs.sets_entry_index    = node_ind;
+      set_specs.sets_dist_index     = df_ind;
+      set_specs.sets_entry_list     = node_list;
+      set_specs.sets_extra_list     = NULL;
+      set_specs.sets_dist_fact      = dist_fact;
+
+      error = ex_get_concat_sets(exoid, EX_NODE_SET, &set_specs);
+    }
     printf("\nafter ex_get_concat_node_sets, error = %3d\n", error);
 
     printf("\nconcatenated node set info\n");
@@ -553,7 +554,7 @@ int main(int argc, char **argv)
   if (num_side_sets > 0) {
     ids = (int *)calloc(num_side_sets, sizeof(int));
 
-    error = ex_get_side_set_ids(exoid, ids);
+    error = ex_get_ids(exoid, EX_SIDE_SET, ids);
     printf("\nafter ex_get_side_set_ids, error = %3d\n", error);
 
     for (i = 0; i < num_side_sets; i++) {
@@ -569,7 +570,7 @@ int main(int argc, char **argv)
         printf("error in ex_get_name for sideset id %d\n", ids[i]);
       }
 
-      error = ex_get_side_set_param(exoid, ids[i], &num_sides_in_set, &num_df_in_set);
+      error = ex_get_set_param(exoid, EX_SIDE_SET, ids[i], &num_sides_in_set, &num_df_in_set);
       printf("\nafter ex_get_side_set_param, error = %3d\n", error);
 
       printf("side set %2d parameters:\n", ids[i]);
@@ -586,14 +587,14 @@ int main(int argc, char **argv)
       node_list       = (int *)calloc(num_elem_in_set * 21, sizeof(int));
       dist_fact       = (float *)calloc(num_df_in_set, sizeof(float));
 
-      error = ex_get_side_set(exoid, ids[i], elem_list, side_list);
+      error = ex_get_set(exoid, EX_SIDE_SET, ids[i], elem_list, side_list);
       printf("\nafter ex_get_side_set, error = %3d\n", error);
 
       error = ex_get_side_set_node_list(exoid, ids[i], node_ctr_list, node_list);
       printf("\nafter ex_get_side_set_node_list, error = %3d\n", error);
 
       if (num_df_in_set > 0) {
-        error = ex_get_side_set_dist_fact(exoid, ids[i], dist_fact);
+        error = ex_get_set_dist_fact(exoid, EX_SIDE_SET, ids[i], dist_fact);
         printf("\nafter ex_get_side_set_dist_fact, error = %3d\n", error);
       }
 
@@ -680,6 +681,8 @@ int main(int argc, char **argv)
     /* concatenated side set read */
 
     if (num_side_sets > 0) {
+      struct ex_set_specs set_specs;
+
       ids              = (int *)calloc(num_side_sets, sizeof(int));
       num_elem_per_set = (int *)calloc(num_side_sets, sizeof(int));
       num_df_per_set   = (int *)calloc(num_side_sets, sizeof(int));
@@ -689,8 +692,16 @@ int main(int argc, char **argv)
       side_list        = (int *)calloc(elem_list_len, sizeof(int));
       dist_fact        = (float *)calloc(df_list_len, sizeof(float));
 
-      error = ex_get_concat_side_sets(exoid, ids, num_elem_per_set, num_df_per_set, elem_ind,
-                                      df_ind, elem_list, side_list, dist_fact);
+      set_specs.sets_ids            = ids;
+      set_specs.num_entries_per_set = num_elem_per_set;
+      set_specs.num_dist_per_set    = num_df_per_set;
+      set_specs.sets_entry_index    = elem_ind;
+      set_specs.sets_dist_index     = df_ind;
+      set_specs.sets_entry_list     = elem_list;
+      set_specs.sets_extra_list     = side_list;
+      set_specs.sets_dist_fact      = dist_fact;
+
+      error = ex_get_concat_sets(exoid, EX_SIDE_SET, &set_specs);
       printf("\nafter ex_get_concat_side_sets, error = %3d\n", error);
 
       printf("concatenated side set info\n");
@@ -779,15 +790,15 @@ int main(int argc, char **argv)
 
   /* read global variables parameters and names */
 
-  error = ex_get_var_param(exoid, "g", &num_glo_vars);
-  printf("\nafter ex_get_var_param, error = %3d\n", error);
+  error = ex_get_variable_param(exoid, EX_GLOBAL, &num_glo_vars);
+  printf("\nafter ex_get_variable_param, error = %3d\n", error);
 
   for (i = 0; i < num_glo_vars; i++) {
     var_names[i] = (char *)calloc((MAX_STR_LENGTH + 1), sizeof(char));
   }
 
-  error = ex_get_var_names(exoid, "g", num_glo_vars, var_names);
-  printf("\nafter ex_get_var_names, error = %3d\n", error);
+  error = ex_get_variable_names(exoid, EX_GLOBAL, num_glo_vars, var_names);
+  printf("\nafter ex_get_variable_names, error = %3d\n", error);
 
   printf("There are %2d global variables; their names are :\n", num_glo_vars);
   for (i = 0; i < num_glo_vars; i++) {
@@ -798,15 +809,15 @@ int main(int argc, char **argv)
   /* read nodal variables parameters and names */
   num_nod_vars = 0;
   if (num_nodes > 0) {
-    error = ex_get_var_param(exoid, "n", &num_nod_vars);
-    printf("\nafter ex_get_var_param, error = %3d\n", error);
+    error = ex_get_variable_param(exoid, EX_NODAL, &num_nod_vars);
+    printf("\nafter ex_get_variable_param, error = %3d\n", error);
 
     for (i = 0; i < num_nod_vars; i++) {
       var_names[i] = (char *)calloc((MAX_STR_LENGTH + 1), sizeof(char));
     }
 
-    error = ex_get_var_names(exoid, "n", num_nod_vars, var_names);
-    printf("\nafter ex_get_var_names, error = %3d\n", error);
+    error = ex_get_variable_names(exoid, EX_NODAL, num_nod_vars, var_names);
+    printf("\nafter ex_get_variable_names, error = %3d\n", error);
 
     printf("There are %2d nodal variables; their names are :\n", num_nod_vars);
     for (i = 0; i < num_nod_vars; i++) {
@@ -819,15 +830,15 @@ int main(int argc, char **argv)
 
   num_ele_vars = 0;
   if (num_elem > 0) {
-    error = ex_get_var_param(exoid, "e", &num_ele_vars);
-    printf("\nafter ex_get_var_param, error = %3d\n", error);
+    error = ex_get_variable_param(exoid, EX_ELEM_BLOCK, &num_ele_vars);
+    printf("\nafter ex_get_variable_param, error = %3d\n", error);
 
     for (i = 0; i < num_ele_vars; i++) {
       var_names[i] = (char *)calloc((MAX_STR_LENGTH + 1), sizeof(char));
     }
 
-    error = ex_get_var_names(exoid, "e", num_ele_vars, var_names);
-    printf("\nafter ex_get_var_names, error = %3d\n", error);
+    error = ex_get_variable_names(exoid, EX_ELEM_BLOCK, num_ele_vars, var_names);
+    printf("\nafter ex_get_variable_names, error = %3d\n", error);
 
     printf("There are %2d element variables; their names are :\n", num_ele_vars);
     for (i = 0; i < num_ele_vars; i++) {
@@ -840,7 +851,7 @@ int main(int argc, char **argv)
     if (num_ele_vars > 0) {
       truth_tab = (int *)calloc((num_elem_blk * num_ele_vars), sizeof(int));
 
-      error = ex_get_elem_var_tab(exoid, num_elem_blk, num_ele_vars, truth_tab);
+      error = ex_get_truth_table(exoid, EX_ELEM_BLOCK, num_elem_blk, num_ele_vars, truth_tab);
       printf("\nafter ex_get_elem_var_tab, error = %3d\n", error);
 
       printf("This is the element variable truth table:\n");
@@ -857,16 +868,16 @@ int main(int argc, char **argv)
 
   num_nset_vars = 0;
   if (num_node_sets > 0) {
-    error = ex_get_var_param(exoid, "m", &num_nset_vars);
-    printf("\nafter ex_get_var_param, error = %3d\n", error);
+    error = ex_get_variable_param(exoid, EX_NODE_SET, &num_nset_vars);
+    printf("\nafter ex_get_variable_param, error = %3d\n", error);
 
     if (num_nset_vars > 0) {
       for (i = 0; i < num_nset_vars; i++) {
         var_names[i] = (char *)calloc((MAX_STR_LENGTH + 1), sizeof(char));
       }
 
-      error = ex_get_var_names(exoid, "m", num_nset_vars, var_names);
-      printf("\nafter ex_get_var_names, error = %3d\n", error);
+      error = ex_get_variable_names(exoid, EX_NODE_SET, num_nset_vars, var_names);
+      printf("\nafter ex_get_variable_names, error = %3d\n", error);
 
       printf("There are %2d nodeset variables; their names are :\n", num_nset_vars);
       for (i = 0; i < num_nset_vars; i++) {
@@ -879,7 +890,7 @@ int main(int argc, char **argv)
       if (num_nset_vars > 0) {
         truth_tab = (int *)calloc((num_node_sets * num_nset_vars), sizeof(int));
 
-        error = ex_get_nset_var_tab(exoid, num_node_sets, num_nset_vars, truth_tab);
+        error = ex_get_truth_table(exoid, EX_NODE_SET, num_node_sets, num_nset_vars, truth_tab);
         printf("\nafter ex_get_nset_var_tab, error = %3d\n", error);
 
         printf("This is the nodeset variable truth table:\n");
@@ -897,16 +908,16 @@ int main(int argc, char **argv)
 
   num_sset_vars = 0;
   if (num_side_sets > 0) {
-    error = ex_get_var_param(exoid, "s", &num_sset_vars);
-    printf("\nafter ex_get_var_param, error = %3d\n", error);
+    error = ex_get_variable_param(exoid, EX_SIDE_SET, &num_sset_vars);
+    printf("\nafter ex_get_variable_param, error = %3d\n", error);
 
     if (num_sset_vars > 0) {
       for (i = 0; i < num_sset_vars; i++) {
         var_names[i] = (char *)calloc((MAX_STR_LENGTH + 1), sizeof(char));
       }
 
-      error = ex_get_var_names(exoid, "s", num_sset_vars, var_names);
-      printf("\nafter ex_get_var_names, error = %3d\n", error);
+      error = ex_get_variable_names(exoid, EX_SIDE_SET, num_sset_vars, var_names);
+      printf("\nafter ex_get_variable_names, error = %3d\n", error);
 
       printf("There are %2d sideset variables; their names are :\n", num_sset_vars);
       for (i = 0; i < num_sset_vars; i++) {
@@ -919,7 +930,7 @@ int main(int argc, char **argv)
       if (num_sset_vars > 0) {
         truth_tab = (int *)calloc((num_side_sets * num_sset_vars), sizeof(int));
 
-        error = ex_get_sset_var_tab(exoid, num_side_sets, num_sset_vars, truth_tab);
+        error = ex_get_truth_table(exoid, EX_SIDE_SET, num_side_sets, num_sset_vars, truth_tab);
         printf("\nafter ex_get_sset_var_tab, error = %3d\n", error);
 
         printf("This is the sideset variable truth table:\n");
@@ -964,7 +975,7 @@ int main(int argc, char **argv)
 
   var_values = (float *)calloc(num_glo_vars, sizeof(float));
 
-  error = ex_get_glob_vars(exoid, time_step, num_glo_vars, var_values);
+  error = ex_get_var(exoid, time_step, EX_GLOBAL, 1, 1, num_glo_vars, var_values);
   printf("\nafter ex_get_glob_vars, error = %3d\n", error);
 
   printf("global variable values at time step %2d\n", time_step);
@@ -981,7 +992,7 @@ int main(int argc, char **argv)
 
   var_values = (float *)calloc(num_time_steps, sizeof(float));
 
-  error = ex_get_glob_var_time(exoid, var_index, beg_time, end_time, var_values);
+  error = ex_get_var_time(exoid, EX_GLOBAL, var_index, 1, beg_time, end_time, var_values);
   printf("\nafter ex_get_glob_var_time, error = %3d\n", error);
 
   printf("global variable %2d values through time:\n", var_index);
@@ -995,7 +1006,7 @@ int main(int argc, char **argv)
   if (num_nodes > 0) {
     var_values = (float *)calloc(num_nodes, sizeof(float));
 
-    error = ex_get_nodal_var(exoid, time_step, var_index, num_nodes, var_values);
+    error = ex_get_var(exoid, time_step, EX_NODAL, var_index, 1, num_nodes, var_values);
     printf("\nafter ex_get_nodal_var, error = %3d\n", error);
 
     printf("nodal variable %2d values at time step %2d\n", var_index, time_step);
@@ -1009,7 +1020,7 @@ int main(int argc, char **argv)
     var_values = (float *)calloc(num_time_steps, sizeof(float));
 
     node_num = 1;
-    error    = ex_get_nodal_var_time(exoid, var_index, node_num, beg_time, end_time, var_values);
+    error = ex_get_var_time(exoid, EX_NODAL, var_index, node_num, beg_time, end_time, var_values);
     printf("\nafter ex_get_nodal_var_time, error = %3d\n", error);
 
     printf("nodal variable %2d values for node %2d through time:\n", var_index, node_num);
@@ -1023,15 +1034,15 @@ int main(int argc, char **argv)
   if (num_elem_blk > 0) {
     ids = (int *)calloc(num_elem_blk, sizeof(int));
 
-    error = ex_get_elem_blk_ids(exoid, ids);
+    error = ex_get_ids(exoid, EX_ELEM_BLOCK, ids);
     printf("\n after ex_get_elem_blk_ids, error = %3d\n", error);
 
     for (i = 0; i < num_elem_blk; i++) {
       if (num_elem_in_block[i] > 0) {
         var_values = (float *)calloc(num_elem_in_block[i], sizeof(float));
 
-        error =
-            ex_get_elem_var(exoid, time_step, var_index, ids[i], num_elem_in_block[i], var_values);
+        error = ex_get_var(exoid, time_step, EX_ELEM_BLOCK, var_index, ids[i], num_elem_in_block[i],
+                           var_values);
         printf("\nafter ex_get_elem_var, error = %3d\n", error);
 
         if (!error) {
@@ -1054,7 +1065,8 @@ int main(int argc, char **argv)
 
     var_index = 2;
     elem_num  = 2;
-    error     = ex_get_elem_var_time(exoid, var_index, elem_num, beg_time, end_time, var_values);
+    error =
+        ex_get_var_time(exoid, EX_ELEM_BLOCK, var_index, elem_num, beg_time, end_time, var_values);
     printf("\nafter ex_get_elem_var_time, error = %3d\n", error);
 
     printf("element variable %2d values for element %2d through time:\n", var_index, elem_num);
@@ -1069,13 +1081,14 @@ int main(int argc, char **argv)
   if (num_sset_vars > 0) {
     ids = (int *)calloc(num_side_sets, sizeof(int));
 
-    error = ex_get_side_set_ids(exoid, ids);
+    error = ex_get_ids(exoid, EX_SIDE_SET, ids);
     printf("\n after ex_get_side_set_ids, error = %3d\n", error);
 
     for (i = 0; i < num_side_sets; i++) {
       var_values = (float *)calloc(num_elem_per_set[i], sizeof(float));
 
-      error = ex_get_sset_var(exoid, time_step, var_index, ids[i], num_elem_per_set[i], var_values);
+      error = ex_get_var(exoid, time_step, EX_SIDE_SET, var_index, ids[i], num_elem_per_set[i],
+                         var_values);
       printf("\nafter ex_get_sset_var, error = %3d\n", error);
 
       if (!error) {
@@ -1096,14 +1109,14 @@ int main(int argc, char **argv)
   if (num_nset_vars > 0) {
     ids = (int *)calloc(num_node_sets, sizeof(int));
 
-    error = ex_get_node_set_ids(exoid, ids);
+    error = ex_get_ids(exoid, EX_NODE_SET, ids);
     printf("\n after ex_get_node_set_ids, error = %3d\n", error);
 
     for (i = 0; i < num_node_sets; i++) {
       var_values = (float *)calloc(num_nodes_per_set[i], sizeof(float));
 
-      error =
-          ex_get_nset_var(exoid, time_step, var_index, ids[i], num_nodes_per_set[i], var_values);
+      error = ex_get_var(exoid, time_step, EX_NODE_SET, var_index, ids[i], num_nodes_per_set[i],
+                         var_values);
       printf("\nafter ex_get_nset_var, error = %3d\n", error);
 
       if (!error) {
