@@ -461,7 +461,7 @@ int main(int argc, char **argv)
   connect[2] = 3;
   connect[3] = 4;
 
-  error = ex_put_elem_conn(exoid, blocks[0].id, connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, blocks[0].id, connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
   if (error) {
     ex_close(exoid);
@@ -473,7 +473,7 @@ int main(int argc, char **argv)
   connect[2] = 7;
   connect[3] = 8;
 
-  error = ex_put_elem_conn(exoid, blocks[1].id, connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, blocks[1].id, connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -490,7 +490,7 @@ int main(int argc, char **argv)
   connect[6] = 15;
   connect[7] = 16;
 
-  error = ex_put_elem_conn(exoid, blocks[2].id, connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, blocks[2].id, connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -503,7 +503,7 @@ int main(int argc, char **argv)
   connect[2] = 19;
   connect[3] = 20;
 
-  error = ex_put_elem_conn(exoid, blocks[3].id, connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, blocks[3].id, connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -518,7 +518,7 @@ int main(int argc, char **argv)
   connect[4] = 25;
   connect[5] = 26;
 
-  error = ex_put_elem_conn(exoid, blocks[4].id, connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, blocks[4].id, connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -535,7 +535,7 @@ int main(int argc, char **argv)
   connect[6] = 30;
   connect[7] = 29;
 
-  error = ex_put_elem_conn(exoid, blocks[5].id, connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, blocks[5].id, connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -547,7 +547,7 @@ int main(int argc, char **argv)
   connect[1] = 32;
   connect[2] = 33;
 
-  error = ex_put_elem_conn(exoid, blocks[6].id, connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, blocks[6].id, connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -566,15 +566,8 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, blocks[0].id, attrib);
-  printf("after ex_put_elem_attr, error = %d\n", error);
-  if (error) {
-    ex_close(exoid);
-    exit(-1);
-  }
-
   attrib[0] = 6.14159;
-  error     = ex_put_elem_attr(exoid, blocks[1].id, attrib);
+  error     = ex_put_attr(exoid, EX_ELEM_BLOCK, blocks[1].id, attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -582,7 +575,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, blocks[2].id, attrib);
+  error = ex_put_attr(exoid, EX_ELEM_BLOCK, blocks[2].id, attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -590,7 +583,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, blocks[3].id, attrib);
+  error = ex_put_attr(exoid, EX_ELEM_BLOCK, blocks[3].id, attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -598,7 +591,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, blocks[4].id, attrib);
+  error = ex_put_attr(exoid, EX_ELEM_BLOCK, blocks[4].id, attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -606,7 +599,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, blocks[5].id, attrib);
+  error = ex_put_attr(exoid, EX_ELEM_BLOCK, blocks[5].id, attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -614,7 +607,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, blocks[6].id, attrib);
+  error = ex_put_attr(exoid, EX_ELEM_BLOCK, blocks[6].id, attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -624,7 +617,7 @@ int main(int argc, char **argv)
 
   attrib_names[0] = "THICKNESS";
   for (i = 0; i < num_elem_blk; i++) {
-    error = ex_put_elem_attr_names(exoid, blocks[i].id, attrib_names);
+    error = ex_put_attr_names(exoid, EX_ELEM_BLOCK, blocks[i].id, attrib_names);
     printf("after ex_put_elem_attr_names, error = %d\n", error);
     if (error) {
       ex_close(exoid);
@@ -640,7 +633,7 @@ int main(int argc, char **argv)
   nsids[0] = 20;
   nsids[1] = 21;
 
-  error = ex_put_node_set_param(exoid, nsids[0], 5, 5);
+  error = ex_put_set_param(exoid, EX_NODE_SET, nsids[0], 5, 5);
   printf("after ex_put_node_set_param, error = %d\n", error);
 
   if (error) {
@@ -660,21 +653,21 @@ int main(int argc, char **argv)
   dist_fact[3] = 4.0;
   dist_fact[4] = 5.0;
 
-  error = ex_put_node_set(exoid, nsids[0], node_list);
+  error = ex_put_set(exoid, EX_NODE_SET, nsids[0], node_list, NULL);
   printf("after ex_put_node_set, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_node_set_dist_fact(exoid, nsids[0], dist_fact);
+  error = ex_put_set_dist_fact(exoid, EX_NODE_SET, nsids[0], dist_fact);
   printf("after ex_put_node_set_dist_fact, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_node_set_param(exoid, nsids[1], 3, 3);
+  error = ex_put_set_param(exoid, EX_NODE_SET, nsids[1], 3, 3);
   printf("after ex_put_node_set_param, error = %d\n", error);
 
   if (error) {
@@ -690,14 +683,14 @@ int main(int argc, char **argv)
   dist_fact[1] = 2.1;
   dist_fact[2] = 3.1;
 
-  error = ex_put_node_set(exoid, nsids[1], node_list);
+  error = ex_put_set(exoid, EX_NODE_SET, nsids[1], node_list, NULL);
   printf("after ex_put_node_set, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_node_set_dist_fact(exoid, nsids[1], dist_fact);
+  error = ex_put_set_dist_fact(exoid, EX_NODE_SET, nsids[1], dist_fact);
   printf("after ex_put_node_set_dist_fact, error = %d\n", error);
   if (error) {
     ex_close(exoid);
@@ -780,7 +773,7 @@ int main(int argc, char **argv)
 
   /* side set #1  - quad */
 
-  error = ex_put_side_set_param(exoid, ssids[0], 2, 4);
+  error = ex_put_set_param(exoid, EX_SIDE_SET, ssids[0], 2, 4);
   printf("after ex_put_side_set_param, error = %d\n", error);
 
   if (error) {
@@ -799,7 +792,7 @@ int main(int argc, char **argv)
   dist_fact[2] = 30.2;
   dist_fact[3] = 30.3;
 
-  error = ex_put_side_set(exoid, 30, elem_list, side_list);
+  error = ex_put_set(exoid, EX_SIDE_SET, 30, elem_list, side_list);
   printf("after ex_put_side_set, error = %d\n", error);
 
   if (error) {
@@ -807,7 +800,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_side_set_dist_fact(exoid, 30, dist_fact);
+  error = ex_put_set_dist_fact(exoid, EX_SIDE_SET, 30, dist_fact);
   printf("after ex_put_side_set_dist_fact, error = %d\n", error);
 
   if (error) {
@@ -817,7 +810,7 @@ int main(int argc, char **argv)
 
   /* side set #2  - quad, spanning 2 elements  */
 
-  error = ex_put_side_set_param(exoid, 31, 2, 4);
+  error = ex_put_set_param(exoid, EX_SIDE_SET, 31, 2, 4);
   printf("after ex_put_side_set_param, error = %d\n", error);
 
   if (error) {
@@ -836,7 +829,7 @@ int main(int argc, char **argv)
   dist_fact[2] = 31.2;
   dist_fact[3] = 31.3;
 
-  error = ex_put_side_set(exoid, 31, elem_list, side_list);
+  error = ex_put_set(exoid, EX_SIDE_SET, 31, elem_list, side_list);
   printf("after ex_put_side_set, error = %d\n", error);
 
   if (error) {
@@ -844,7 +837,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_side_set_dist_fact(exoid, 31, dist_fact);
+  error = ex_put_set_dist_fact(exoid, EX_SIDE_SET, 31, dist_fact);
   printf("after ex_put_side_set_dist_fact, error = %d\n", error);
 
   if (error) {
@@ -854,7 +847,7 @@ int main(int argc, char **argv)
 
   /* side set #3  - hex */
 
-  error = ex_put_side_set_param(exoid, 32, 7, 0);
+  error = ex_put_set_param(exoid, EX_SIDE_SET, 32, 7, 0);
   printf("after ex_put_side_set_param, error = %d\n", error);
 
   if (error) {
@@ -878,7 +871,7 @@ int main(int argc, char **argv)
   side_list[5] = 1;
   side_list[6] = 6;
 
-  error = ex_put_side_set(exoid, 32, elem_list, side_list);
+  error = ex_put_set(exoid, EX_SIDE_SET, 32, elem_list, side_list);
   printf("after ex_put_side_set, error = %d\n", error);
 
   if (error) {
@@ -888,7 +881,7 @@ int main(int argc, char **argv)
 
   /* side set #4  - tetras */
 
-  error = ex_put_side_set_param(exoid, 33, 8, 0);
+  error = ex_put_set_param(exoid, EX_SIDE_SET, 33, 8, 0);
   printf("after ex_put_side_set_param, error = %d\n", error);
 
   if (error) {
@@ -914,7 +907,7 @@ int main(int argc, char **argv)
   side_list[6] = 3;
   side_list[7] = 4;
 
-  error = ex_put_side_set(exoid, 33, elem_list, side_list);
+  error = ex_put_set(exoid, EX_SIDE_SET, 33, elem_list, side_list);
   printf("after ex_put_side_set, error = %d\n", error);
 
   if (error) {
@@ -924,7 +917,7 @@ int main(int argc, char **argv)
 
   /* side set #5  - wedges and tris */
 
-  error = ex_put_side_set_param(exoid, 34, 10, 0);
+  error = ex_put_set_param(exoid, EX_SIDE_SET, 34, 10, 0);
   printf("after ex_put_side_set_param, error = %d\n", error);
 
   if (error) {
@@ -954,7 +947,7 @@ int main(int argc, char **argv)
   side_list[8] = 4;
   side_list[9] = 5;
 
-  error = ex_put_side_set(exoid, 34, elem_list, side_list);
+  error = ex_put_set(exoid, EX_SIDE_SET, 34, elem_list, side_list);
   printf("after ex_put_side_set, error = %d\n", error);
 
   if (error) {
@@ -1036,15 +1029,15 @@ int main(int argc, char **argv)
 
   var_names[0] = "glo_vars";
 
-  error = ex_put_var_param(exoid, "g", num_glo_vars);
-  printf("after ex_put_var_param, error = %d\n", error);
+  error = ex_put_variable_param(exoid, EX_GLOBAL, num_glo_vars);
+  printf("after ex_put_variable_param, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_var_names(exoid, "g", num_glo_vars, var_names);
-  printf("after ex_put_var_names, error = %d\n", error);
+  error = ex_put_variable_names(exoid, EX_GLOBAL, num_glo_vars, var_names);
+  printf("after ex_put_variable_names, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
@@ -1055,15 +1048,15 @@ int main(int argc, char **argv)
   var_names[0] = "node_variable_a_very_long_name_0";
   var_names[1] = "nod_var1";
 
-  error = ex_put_var_param(exoid, "n", num_nod_vars);
-  printf("after ex_put_var_param, error = %d\n", error);
+  error = ex_put_variable_param(exoid, EX_NODAL, num_nod_vars);
+  printf("after ex_put_variable_param, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_var_names(exoid, "n", num_nod_vars, var_names);
-  printf("after ex_put_var_names, error = %d\n", error);
+  error = ex_put_variable_names(exoid, EX_NODAL, num_nod_vars, var_names);
+  printf("after ex_put_variable_names, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
@@ -1076,15 +1069,15 @@ int main(int argc, char **argv)
   var_names[1] = "this_variable_name_is_just_right";
   var_names[2] = "this_variable_name_is_ok";
 
-  error = ex_put_var_param(exoid, "e", num_ele_vars);
-  printf("after ex_put_var_param, error = %d\n", error);
+  error = ex_put_variable_param(exoid, EX_ELEM_BLOCK, num_ele_vars);
+  printf("after ex_put_variable_param, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_var_names(exoid, "e", num_ele_vars, var_names);
-  printf("after ex_put_var_names, error = %d\n", error);
+  error = ex_put_variable_names(exoid, EX_ELEM_BLOCK, num_ele_vars, var_names);
+  printf("after ex_put_variable_names, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
@@ -1097,15 +1090,15 @@ int main(int argc, char **argv)
     var_names[1] = "ns_var1";
     var_names[2] = "ns_var2";
 
-    error = ex_put_var_param(exoid, "m", num_nset_vars);
-    printf("after ex_put_var_param, error = %d\n", error);
+    error = ex_put_variable_param(exoid, EX_NODE_SET, num_nset_vars);
+    printf("after ex_put_variable_param, error = %d\n", error);
     if (error) {
       ex_close(exoid);
       exit(-1);
     }
 
-    error = ex_put_var_names(exoid, "m", num_nset_vars, var_names);
-    printf("after ex_put_var_names, error = %d\n", error);
+    error = ex_put_variable_names(exoid, EX_NODE_SET, num_nset_vars, var_names);
+    printf("after ex_put_variable_names, error = %d\n", error);
     if (error) {
       ex_close(exoid);
       exit(-1);
@@ -1119,15 +1112,15 @@ int main(int argc, char **argv)
     var_names[1] = "ss_var1";
     var_names[2] = "ss_var2";
 
-    error = ex_put_var_param(exoid, "s", num_sset_vars);
-    printf("after ex_put_var_param, error = %d\n", error);
+    error = ex_put_variable_param(exoid, EX_SIDE_SET, num_sset_vars);
+    printf("after ex_put_variable_param, error = %d\n", error);
     if (error) {
       ex_close(exoid);
       exit(-1);
     }
 
-    error = ex_put_var_names(exoid, "s", num_sset_vars, var_names);
-    printf("after ex_put_var_names, error = %d\n", error);
+    error = ex_put_variable_names(exoid, EX_SIDE_SET, num_sset_vars, var_names);
+    printf("after ex_put_variable_names, error = %d\n", error);
     if (error) {
       ex_close(exoid);
       exit(-1);
@@ -1145,7 +1138,7 @@ int main(int argc, char **argv)
     }
   }
 
-  error = ex_put_elem_var_tab(exoid, num_elem_blk, num_ele_vars, truth_tab);
+  error = ex_put_truth_table(exoid, EX_ELEM_BLOCK, num_elem_blk, num_ele_vars, truth_tab);
   printf("after ex_put_elem_var_tab, error = %d\n", error);
 
   if (error) {
@@ -1189,7 +1182,7 @@ int main(int argc, char **argv)
       glob_var_vals[j] = (float)(j + 2) * time_value;
     }
 
-    error = ex_put_glob_vars(exoid, whole_time_step, num_glo_vars, glob_var_vals);
+    error = ex_put_var(exoid, whole_time_step, EX_GLOBAL, 1, 0, num_glo_vars, glob_var_vals);
     printf("after ex_put_glob_vars, error = %d\n", error);
 
     if (error) {
@@ -1204,7 +1197,7 @@ int main(int argc, char **argv)
         nodal_var_vals[j] = (float)k + ((float)(j + 1) * time_value);
       }
 
-      error = ex_put_nodal_var(exoid, whole_time_step, k, num_nodes, nodal_var_vals);
+      error = ex_put_var(exoid, whole_time_step, EX_NODAL, k, 1, num_nodes, nodal_var_vals);
       printf("after ex_put_nodal_var, error = %d\n", error);
       if (error) {
         ex_close(exoid);
@@ -1220,8 +1213,8 @@ int main(int argc, char **argv)
           elem_var_vals[m] = (float)(k + 1) + (float)(j + 2) + ((float)(m + 1) * time_value);
           /* printf("elem_var_vals[%d]: %f\n",m,elem_var_vals[m]); */
         }
-        error = ex_put_elem_var(exoid, whole_time_step, k, blocks[j].id, blocks[j].num_entry,
-                                elem_var_vals);
+        error = ex_put_var(exoid, whole_time_step, EX_ELEM_BLOCK, k, blocks[j].id,
+                           blocks[j].num_entry, elem_var_vals);
         printf("after ex_put_elem_var, error = %d\n", error);
         if (error) {
           ex_close(exoid);
@@ -1238,8 +1231,8 @@ int main(int argc, char **argv)
           sset_var_vals[m] = (float)(k + 2) + (float)(j + 3) + ((float)(m + 1) * time_value);
           /* printf("sset_var_vals[%d]: %f\n",m,sset_var_vals[m]); */
         }
-        error = ex_put_sset_var(exoid, whole_time_step, k, ssids[j], num_face_in_sset[j],
-                                sset_var_vals);
+        error = ex_put_var(exoid, whole_time_step, EX_SIDE_SET, k, ssids[j], num_face_in_sset[j],
+                           sset_var_vals);
         printf("after ex_put_sset_var, error = %d\n", error);
         if (error) {
           ex_close(exoid);
@@ -1256,8 +1249,8 @@ int main(int argc, char **argv)
           nset_var_vals[m] = (float)(k + 3) + (float)(j + 4) + ((float)(m + 1) * time_value);
           /* printf("nset_var_vals[%d]: %f\n",m,nset_var_vals[m]); */
         }
-        error = ex_put_nset_var(exoid, whole_time_step, k, nsids[j], num_nodes_in_nset[j],
-                                nset_var_vals);
+        error = ex_put_var(exoid, whole_time_step, EX_NODE_SET, k, nsids[j], num_nodes_in_nset[j],
+                           nset_var_vals);
         printf("after ex_put_nset_var, error = %d\n", error);
         if (error) {
           ex_close(exoid);
