@@ -343,8 +343,8 @@ int main(int argc, char **argv)
   ebids[5] = 15;
   ebids[6] = 16;
 
-  error =
-      ex_put_elem_block(exoid, ebids[0], "quad", num_elem_in_block[0], num_nodes_per_elem[0], 1);
+  error = ex_put_block(exoid, EX_ELEM_BLOCK, ebids[0], "quad", num_elem_in_block[0],
+                       num_nodes_per_elem[0], 0, 0, 1);
   printf("after ex_put_elem_block, error = %d\n", error);
 
   if (error) {
@@ -352,8 +352,8 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error =
-      ex_put_elem_block(exoid, ebids[1], "quad", num_elem_in_block[1], num_nodes_per_elem[1], 1);
+  error = ex_put_block(exoid, EX_ELEM_BLOCK, ebids[1], "quad", num_elem_in_block[1],
+                       num_nodes_per_elem[1], 0, 0, 1);
   printf("after ex_put_elem_block, error = %d\n", error);
 
   if (error) {
@@ -361,7 +361,8 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_block(exoid, ebids[2], "hex", num_elem_in_block[2], num_nodes_per_elem[2], 1);
+  error = ex_put_block(exoid, EX_ELEM_BLOCK, ebids[2], "hex", num_elem_in_block[2],
+                       num_nodes_per_elem[2], 0, 0, 1);
   printf("after ex_put_elem_block, error = %d\n", error);
 
   if (error) {
@@ -369,8 +370,8 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error =
-      ex_put_elem_block(exoid, ebids[3], "tetra", num_elem_in_block[3], num_nodes_per_elem[3], 1);
+  error = ex_put_block(exoid, EX_ELEM_BLOCK, ebids[3], "tetra", num_elem_in_block[3],
+                       num_nodes_per_elem[3], 0, 0, 1);
   printf("after ex_put_elem_block, error = %d\n", error);
 
   if (error) {
@@ -378,8 +379,8 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error =
-      ex_put_elem_block(exoid, ebids[4], "wedge", num_elem_in_block[4], num_nodes_per_elem[4], 1);
+  error = ex_put_block(exoid, EX_ELEM_BLOCK, ebids[4], "wedge", num_elem_in_block[4],
+                       num_nodes_per_elem[4], 0, 0, 1);
   printf("after ex_put_elem_block, error = %d\n", error);
 
   if (error) {
@@ -387,8 +388,8 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error =
-      ex_put_elem_block(exoid, ebids[5], "tetra", num_elem_in_block[5], num_nodes_per_elem[5], 1);
+  error = ex_put_block(exoid, EX_ELEM_BLOCK, ebids[5], "tetra", num_elem_in_block[5],
+                       num_nodes_per_elem[5], 0, 0, 1);
   printf("after ex_put_elem_block, error = %d\n", error);
 
   if (error) {
@@ -396,7 +397,8 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_block(exoid, ebids[6], "tri", num_elem_in_block[6], num_nodes_per_elem[6], 1);
+  error = ex_put_block(exoid, EX_ELEM_BLOCK, ebids[6], "tri", num_elem_in_block[6],
+                       num_nodes_per_elem[6], 0, 0, 1);
   printf("after ex_put_elem_block, error = %d\n", error);
 
   if (error) {
@@ -483,7 +485,7 @@ int main(int argc, char **argv)
   connect[2] = 3;
   connect[3] = 4;
 
-  error = ex_put_elem_conn(exoid, ebids[0], connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, ebids[0], connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
   if (error) {
     ex_close(exoid);
@@ -495,7 +497,7 @@ int main(int argc, char **argv)
   connect[2] = 7;
   connect[3] = 8;
 
-  error = ex_put_elem_conn(exoid, ebids[1], connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, ebids[1], connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -512,7 +514,7 @@ int main(int argc, char **argv)
   connect[6] = 15;
   connect[7] = 16;
 
-  error = ex_put_elem_conn(exoid, ebids[2], connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, ebids[2], connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -525,7 +527,7 @@ int main(int argc, char **argv)
   connect[2] = 19;
   connect[3] = 20;
 
-  error = ex_put_elem_conn(exoid, ebids[3], connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, ebids[3], connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -540,7 +542,7 @@ int main(int argc, char **argv)
   connect[4] = 25;
   connect[5] = 26;
 
-  error = ex_put_elem_conn(exoid, ebids[4], connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, ebids[4], connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -557,7 +559,7 @@ int main(int argc, char **argv)
   connect[6] = 30;
   connect[7] = 29;
 
-  error = ex_put_elem_conn(exoid, ebids[5], connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, ebids[5], connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -569,7 +571,7 @@ int main(int argc, char **argv)
   connect[1] = 32;
   connect[2] = 33;
 
-  error = ex_put_elem_conn(exoid, ebids[6], connect);
+  error = ex_put_conn(exoid, EX_ELEM_BLOCK, ebids[6], connect, NULL, NULL);
   printf("after ex_put_elem_conn, error = %d\n", error);
 
   if (error) {
@@ -582,14 +584,14 @@ int main(int argc, char **argv)
   /* write element block attributes */
 
   attrib[0] = 3.14159;
-  error     = ex_put_elem_attr(exoid, ebids[0], attrib);
+  error     = ex_put_attr(exoid, EX_ELEM_BLOCK, ebids[0], attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, ebids[0], attrib);
+  error = ex_put_attr(exoid, EX_ELEM_BLOCK, ebids[0], attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
   if (error) {
     ex_close(exoid);
@@ -597,7 +599,7 @@ int main(int argc, char **argv)
   }
 
   attrib[0] = 6.14159;
-  error     = ex_put_elem_attr(exoid, ebids[1], attrib);
+  error     = ex_put_attr(exoid, EX_ELEM_BLOCK, ebids[1], attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -605,7 +607,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, ebids[2], attrib);
+  error = ex_put_attr(exoid, EX_ELEM_BLOCK, ebids[2], attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -613,7 +615,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, ebids[3], attrib);
+  error = ex_put_attr(exoid, EX_ELEM_BLOCK, ebids[3], attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -621,7 +623,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, ebids[4], attrib);
+  error = ex_put_attr(exoid, EX_ELEM_BLOCK, ebids[4], attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -629,7 +631,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, ebids[5], attrib);
+  error = ex_put_attr(exoid, EX_ELEM_BLOCK, ebids[5], attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -637,7 +639,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_elem_attr(exoid, ebids[6], attrib);
+  error = ex_put_attr(exoid, EX_ELEM_BLOCK, ebids[6], attrib);
   printf("after ex_put_elem_attr, error = %d\n", error);
 
   if (error) {
@@ -647,7 +649,7 @@ int main(int argc, char **argv)
 
   attrib_names[0] = "THICKNESS";
   for (i = 0; i < 7; i++) {
-    error = ex_put_elem_attr_names(exoid, ebids[i], attrib_names);
+    error = ex_put_attr_names(exoid, EX_ELEM_BLOCK, ebids[i], attrib_names);
     printf("after ex_put_elem_attr_names, error = %d\n", error);
     if (error) {
       ex_close(exoid);
@@ -663,7 +665,7 @@ int main(int argc, char **argv)
   nsids[0] = 20;
   nsids[1] = 21;
 
-  error = ex_put_node_set_param(exoid, nsids[0], 5, 5);
+  error = ex_put_set_param(exoid, EX_NODE_SET, nsids[0], 5, 5);
   printf("after ex_put_node_set_param, error = %d\n", error);
 
   if (error) {
@@ -683,21 +685,21 @@ int main(int argc, char **argv)
   dist_fact[3] = 4.0;
   dist_fact[4] = 5.0;
 
-  error = ex_put_node_set(exoid, nsids[0], node_list);
+  error = ex_put_set(exoid, EX_NODE_SET, nsids[0], node_list, NULL);
   printf("after ex_put_node_set, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_node_set_dist_fact(exoid, nsids[0], dist_fact);
+  error = ex_put_set_dist_fact(exoid, EX_NODE_SET, nsids[0], dist_fact);
   printf("after ex_put_node_set_dist_fact, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_node_set_param(exoid, nsids[1], 3, 3);
+  error = ex_put_set_param(exoid, EX_NODE_SET, nsids[1], 3, 3);
   printf("after ex_put_node_set_param, error = %d\n", error);
 
   if (error) {
@@ -713,14 +715,14 @@ int main(int argc, char **argv)
   dist_fact[1] = 2.1;
   dist_fact[2] = 3.1;
 
-  error = ex_put_node_set(exoid, nsids[1], node_list);
+  error = ex_put_set(exoid, EX_NODE_SET, nsids[1], node_list, NULL);
   printf("after ex_put_node_set, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_node_set_dist_fact(exoid, nsids[1], dist_fact);
+  error = ex_put_set_dist_fact(exoid, EX_NODE_SET, nsids[1], dist_fact);
   printf("after ex_put_node_set_dist_fact, error = %d\n", error);
   if (error) {
     ex_close(exoid);
@@ -803,7 +805,7 @@ int main(int argc, char **argv)
 
   /* side set #1  - quad */
 
-  error = ex_put_side_set_param(exoid, ssids[0], 2, 4);
+  error = ex_put_set_param(exoid, EX_SIDE_SET, ssids[0], 2, 4);
   printf("after ex_put_side_set_param, error = %d\n", error);
 
   if (error) {
@@ -822,7 +824,7 @@ int main(int argc, char **argv)
   dist_fact[2] = 30.2;
   dist_fact[3] = 30.3;
 
-  error = ex_put_side_set(exoid, 30, elem_list, side_list);
+  error = ex_put_set(exoid, EX_SIDE_SET, 30, elem_list, side_list);
   printf("after ex_put_side_set, error = %d\n", error);
 
   if (error) {
@@ -830,7 +832,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_side_set_dist_fact(exoid, 30, dist_fact);
+  error = ex_put_set_dist_fact(exoid, EX_SIDE_SET, 30, dist_fact);
   printf("after ex_put_side_set_dist_fact, error = %d\n", error);
 
   if (error) {
@@ -840,7 +842,7 @@ int main(int argc, char **argv)
 
   /* side set #2  - quad, spanning 2 elements  */
 
-  error = ex_put_side_set_param(exoid, 31, 2, 4);
+  error = ex_put_set_param(exoid, EX_SIDE_SET, 31, 2, 4);
   printf("after ex_put_side_set_param, error = %d\n", error);
 
   if (error) {
@@ -859,7 +861,7 @@ int main(int argc, char **argv)
   dist_fact[2] = 31.2;
   dist_fact[3] = 31.3;
 
-  error = ex_put_side_set(exoid, 31, elem_list, side_list);
+  error = ex_put_set(exoid, EX_SIDE_SET, 31, elem_list, side_list);
   printf("after ex_put_side_set, error = %d\n", error);
 
   if (error) {
@@ -867,7 +869,7 @@ int main(int argc, char **argv)
     exit(-1);
   }
 
-  error = ex_put_side_set_dist_fact(exoid, 31, dist_fact);
+  error = ex_put_set_dist_fact(exoid, EX_SIDE_SET, 31, dist_fact);
   printf("after ex_put_side_set_dist_fact, error = %d\n", error);
 
   if (error) {
@@ -877,7 +879,7 @@ int main(int argc, char **argv)
 
   /* side set #3  - hex */
 
-  error = ex_put_side_set_param(exoid, 32, 7, 0);
+  error = ex_put_set_param(exoid, EX_SIDE_SET, 32, 7, 0);
   printf("after ex_put_side_set_param, error = %d\n", error);
 
   if (error) {
@@ -901,7 +903,7 @@ int main(int argc, char **argv)
   side_list[5] = 1;
   side_list[6] = 6;
 
-  error = ex_put_side_set(exoid, 32, elem_list, side_list);
+  error = ex_put_set(exoid, EX_SIDE_SET, 32, elem_list, side_list);
   printf("after ex_put_side_set, error = %d\n", error);
 
   if (error) {
@@ -911,7 +913,7 @@ int main(int argc, char **argv)
 
   /* side set #4  - tetras */
 
-  error = ex_put_side_set_param(exoid, 33, 8, 0);
+  error = ex_put_set_param(exoid, EX_SIDE_SET, 33, 8, 0);
   printf("after ex_put_side_set_param, error = %d\n", error);
 
   if (error) {
@@ -937,7 +939,7 @@ int main(int argc, char **argv)
   side_list[6] = 3;
   side_list[7] = 4;
 
-  error = ex_put_side_set(exoid, 33, elem_list, side_list);
+  error = ex_put_set(exoid, EX_SIDE_SET, 33, elem_list, side_list);
   printf("after ex_put_side_set, error = %d\n", error);
 
   if (error) {
@@ -947,7 +949,7 @@ int main(int argc, char **argv)
 
   /* side set #5  - wedges and tris */
 
-  error = ex_put_side_set_param(exoid, 34, 10, 0);
+  error = ex_put_set_param(exoid, EX_SIDE_SET, 34, 10, 0);
   printf("after ex_put_side_set_param, error = %d\n", error);
 
   if (error) {
@@ -977,7 +979,7 @@ int main(int argc, char **argv)
   side_list[8] = 4;
   side_list[9] = 5;
 
-  error = ex_put_side_set(exoid, 34, elem_list, side_list);
+  error = ex_put_set(exoid, EX_SIDE_SET, 34, elem_list, side_list);
   printf("after ex_put_side_set, error = %d\n", error);
 
   if (error) {
@@ -1059,15 +1061,15 @@ int main(int argc, char **argv)
 
   var_names[0] = "glo_vars";
 
-  error = ex_put_var_param(exoid, "g", num_glo_vars);
-  printf("after ex_put_var_param, error = %d\n", error);
+  error = ex_put_variable_param(exoid, EX_GLOBAL, num_glo_vars);
+  printf("after ex_put_variable_param, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_var_names(exoid, "g", num_glo_vars, var_names);
-  printf("after ex_put_var_names, error = %d\n", error);
+  error = ex_put_variable_names(exoid, EX_GLOBAL, num_glo_vars, var_names);
+  printf("after ex_put_variable_names, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
@@ -1078,15 +1080,15 @@ int main(int argc, char **argv)
   var_names[0] = "node_variable_a_very_long_name_0";
   var_names[1] = "nod_var1";
 
-  error = ex_put_var_param(exoid, "n", num_nod_vars);
-  printf("after ex_put_var_param, error = %d\n", error);
+  error = ex_put_variable_param(exoid, EX_NODAL, num_nod_vars);
+  printf("after ex_put_variable_param, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_var_names(exoid, "n", num_nod_vars, var_names);
-  printf("after ex_put_var_names, error = %d\n", error);
+  error = ex_put_variable_names(exoid, EX_NODAL, num_nod_vars, var_names);
+  printf("after ex_put_variable_names, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
@@ -1100,15 +1102,15 @@ int main(int argc, char **argv)
   var_names[1] = "this_variable_name_is_just_right";
   var_names[2] = "this_variable_name_is_tooooo_long";
 
-  error = ex_put_var_param(exoid, "e", num_ele_vars);
-  printf("after ex_put_var_param, error = %d\n", error);
+  error = ex_put_variable_param(exoid, EX_ELEM_BLOCK, num_ele_vars);
+  printf("after ex_put_variable_param, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
   }
 
-  error = ex_put_var_names(exoid, "e", num_ele_vars, var_names);
-  printf("after ex_put_var_names, error = %d\n", error);
+  error = ex_put_variable_names(exoid, EX_ELEM_BLOCK, num_ele_vars, var_names);
+  printf("after ex_put_variable_names, error = %d\n", error);
   if (error) {
     ex_close(exoid);
     exit(-1);
@@ -1121,15 +1123,15 @@ int main(int argc, char **argv)
     var_names[1] = "ns_var1";
     var_names[2] = "ns_var2";
 
-    error = ex_put_var_param(exoid, "m", num_nset_vars);
-    printf("after ex_put_var_param, error = %d\n", error);
+    error = ex_put_variable_param(exoid, EX_NODE_SET, num_nset_vars);
+    printf("after ex_put_variable_param, error = %d\n", error);
     if (error) {
       ex_close(exoid);
       exit(-1);
     }
 
-    error = ex_put_var_names(exoid, "m", num_nset_vars, var_names);
-    printf("after ex_put_var_names, error = %d\n", error);
+    error = ex_put_variable_names(exoid, EX_NODE_SET, num_nset_vars, var_names);
+    printf("after ex_put_variable_names, error = %d\n", error);
     if (error) {
       ex_close(exoid);
       exit(-1);
@@ -1143,15 +1145,15 @@ int main(int argc, char **argv)
     var_names[1] = "ss_var1";
     var_names[2] = "ss_var2";
 
-    error = ex_put_var_param(exoid, "s", num_sset_vars);
-    printf("after ex_put_var_param, error = %d\n", error);
+    error = ex_put_variable_param(exoid, EX_SIDE_SET, num_sset_vars);
+    printf("after ex_put_variable_param, error = %d\n", error);
     if (error) {
       ex_close(exoid);
       exit(-1);
     }
 
-    error = ex_put_var_names(exoid, "s", num_sset_vars, var_names);
-    printf("after ex_put_var_names, error = %d\n", error);
+    error = ex_put_variable_names(exoid, EX_SIDE_SET, num_sset_vars, var_names);
+    printf("after ex_put_variable_names, error = %d\n", error);
     if (error) {
       ex_close(exoid);
       exit(-1);
@@ -1169,7 +1171,7 @@ int main(int argc, char **argv)
     }
   }
 
-  error = ex_put_elem_var_tab(exoid, num_elem_blk, num_ele_vars, truth_tab);
+  error = ex_put_truth_table(exoid, EX_ELEM_BLOCK, num_elem_blk, num_ele_vars, truth_tab);
   printf("after ex_put_elem_var_tab, error = %d\n", error);
 
   if (error) {
@@ -1213,7 +1215,7 @@ int main(int argc, char **argv)
       glob_var_vals[j] = (float)(j + 2) * time_value;
     }
 
-    error = ex_put_glob_vars(exoid, whole_time_step, num_glo_vars, glob_var_vals);
+    error = ex_put_var(exoid, whole_time_step, EX_GLOBAL, 1, 1, num_glo_vars, glob_var_vals);
     printf("after ex_put_glob_vars, error = %d\n", error);
 
     if (error) {
@@ -1228,7 +1230,7 @@ int main(int argc, char **argv)
         nodal_var_vals[j] = (float)k + ((float)(j + 1) * time_value);
       }
 
-      error = ex_put_nodal_var(exoid, whole_time_step, k, num_nodes, nodal_var_vals);
+      error = ex_put_var(exoid, whole_time_step, EX_NODAL, k, 1, num_nodes, nodal_var_vals);
       printf("after ex_put_nodal_var, error = %d\n", error);
       if (error) {
         ex_close(exoid);
@@ -1244,8 +1246,8 @@ int main(int argc, char **argv)
           elem_var_vals[m] = (float)(k + 1) + (float)(j + 2) + ((float)(m + 1) * time_value);
           /* printf("elem_var_vals[%d]: %f\n",m,elem_var_vals[m]); */
         }
-        error = ex_put_elem_var(exoid, whole_time_step, k, ebids[j], num_elem_in_block[j],
-                                elem_var_vals);
+        error = ex_put_var(exoid, whole_time_step, EX_ELEM_BLOCK, k, ebids[j], num_elem_in_block[j],
+                           elem_var_vals);
         printf("after ex_put_elem_var, error = %d\n", error);
         if (error) {
           ex_close(exoid);
@@ -1262,8 +1264,8 @@ int main(int argc, char **argv)
           sset_var_vals[m] = (float)(k + 2) + (float)(j + 3) + ((float)(m + 1) * time_value);
           /* printf("sset_var_vals[%d]: %f\n",m,sset_var_vals[m]); */
         }
-        error = ex_put_sset_var(exoid, whole_time_step, k, ssids[j], num_face_in_sset[j],
-                                sset_var_vals);
+        error = ex_put_var(exoid, whole_time_step, EX_SIDE_SET, k, ssids[j], num_face_in_sset[j],
+                           sset_var_vals);
         printf("after ex_put_sset_var, error = %d\n", error);
         if (error) {
           ex_close(exoid);
@@ -1280,8 +1282,8 @@ int main(int argc, char **argv)
           nset_var_vals[m] = (float)(k + 3) + (float)(j + 4) + ((float)(m + 1) * time_value);
           /* printf("nset_var_vals[%d]: %f\n",m,nset_var_vals[m]); */
         }
-        error = ex_put_nset_var(exoid, whole_time_step, k, nsids[j], num_nodes_in_nset[j],
-                                nset_var_vals);
+        error = ex_put_var(exoid, whole_time_step, EX_NODE_SET, k, nsids[j], num_nodes_in_nset[j],
+                           nset_var_vals);
         printf("after ex_put_nset_var, error = %d\n", error);
         if (error) {
           ex_close(exoid);
