@@ -33,8 +33,8 @@
 #ifndef IOSS_Ioss_CoordinateFrame_h
 #define IOSS_Ioss_CoordinateFrame_h
 
-#include <stdint.h> // for int64_t
-#include <vector>   // for vector
+#include <cstdint> // for int64_t
+#include <vector>  // for vector
 
 namespace Ioss {
   class DatabaseIO;
@@ -56,5 +56,5 @@ namespace Ioss {
     std::vector<double> pointList_;
     char                tag_;
   };
-}
+} // namespace Ioss
 #endif
