@@ -35,11 +35,12 @@
 #ifndef IOSS_DECOMPOSITON_H
 #define IOSS_DECOMPOSITON_H
 
+#include <Ioss_CodeTypes.h>
 #include <Ioss_Map.h>
+#include <Ioss_ParallelUtils.h>
 #include <Ioss_PropertyManager.h>
 #include <algorithm>
 #include <assert.h>
-#include <mpi.h>
 #include <string>
 #include <vector>
 
@@ -197,11 +198,21 @@ namespace Ioss {
       return I->second;
     }
 
+    void show_progress(const std::string &message) const
+    {
+      if (m_showProgress) {
+        // Use the output below for debugging...
+        // std::cerr << "[" << m_processor << "].... " << message << "\n";
+        Ioss::ParallelUtils pu(m_comm);
+        pu.progress(message);
+      }
+    }
+
     void decompose_model(
 #if !defined(NO_ZOLTAN_SUPPORT)
         Zoltan &zz,
 #endif
-        std::vector<BlockDecompositionData> &el_blocks);
+        std::vector<BlockDecompositionData> &element_blocks);
 
     void simple_decompose();
 
@@ -247,8 +258,8 @@ namespace Ioss {
     void communicate_node_data(T *file_data, T *ioss_data, size_t comp_count) const;
 
     MPI_Comm    m_comm;
-    int         m_processor;
-    int         m_processorCount;
+    int         m_processor{};
+    int         m_processorCount{};
     std::string m_method;
 
     // Values for the file decomposition
@@ -264,6 +275,8 @@ namespace Ioss {
     size_t m_importPreLocalNodeIndex;
 
     bool m_retainFreeNodes;
+    bool m_showProgress;
+    bool m_showHWM;
 
     std::vector<double> m_centroids;
     std::vector<INT>    m_pointer;   // Index into adjacency, processor list for each element...
