@@ -42,11 +42,11 @@
 
 namespace Ioss {
   class VariableType;
-}
+} // namespace Ioss
 
 namespace Ioss {
-  typedef std::map<std::string, VariableType *, std::less<std::string>> VariableTypeMap;
-  typedef VariableTypeMap::value_type VTM_ValuePair;
+  using VariableTypeMap = std::map<std::string, VariableType *, std::less<std::string>>;
+  using VTM_ValuePair   = VariableTypeMap::value_type;
 
   class Registry
   {
@@ -67,12 +67,12 @@ namespace Ioss {
 #define MAX_SUFFIX 8
   struct Suffix
   {
-    Suffix(const char new_data[MAX_SUFFIX])
+    explicit Suffix(const char new_data[MAX_SUFFIX])
     {
       std::strncpy(data, new_data, MAX_SUFFIX);
       data[MAX_SUFFIX] = '\0';
     }
-    Suffix(const std::string &new_data)
+    explicit Suffix(const std::string &new_data)
     {
       std::strncpy(data, new_data.c_str(), MAX_SUFFIX);
       data[MAX_SUFFIX] = '\0';
@@ -110,9 +110,8 @@ namespace Ioss {
     std::string name() const;
 
     static std::string numeric_label(int which, int ncomp, const std::string &name);
-    virtual std::string label(int which, const char suffix_sep = '_') const = 0;
-    virtual std::string label_name(const std::string &base, int which,
-                                   const char suffix_sep = '_') const;
+    virtual std::string label(int which, char suffix_sep = '_') const = 0;
+    virtual std::string label_name(const std::string &base, int which, char suffix_sep = '_') const;
     virtual bool match(const std::vector<Suffix> &suffices) const;
 
     static const VariableType *factory(const std::string &raw_name, int copies = 1);
@@ -131,7 +130,7 @@ namespace Ioss {
 
     static bool build_variable_type(const std::string &raw_type);
   };
-}
+} // namespace Ioss
 inline std::string Ioss::VariableType::name() const { return name_; }
 
 inline int Ioss::VariableType::component_count() const { return componentCount; }
