@@ -35,8 +35,6 @@
 #ifndef IOCGNS_DECOMPOSITONDATA_H
 #define IOCGNS_DECOMPOSITONDATA_H
 
-#include <mpi.h>
-
 #include <string>
 #include <unordered_map>
 #include <vector>
@@ -108,6 +106,11 @@ namespace Iocgns {
 
     void get_block_connectivity(int filePtr, void *data, int blk_seq) const;
 
+    void get_element_field(int filePtr, int solution_index, int blk_seq, int field_index,
+                           double *data) const;
+
+    void get_node_field(int filePtr, int solution_index, int field_index, double *data) const;
+
     void get_node_entity_proc_data(void *entity_proc, const Ioss::MapContainer &node_map,
                                    bool do_map) const;
 
@@ -173,8 +176,8 @@ namespace Iocgns {
       m_decomposition.communicate_node_data(file_data, ioss_data, comp_count);
     }
 
-    template <typename T>
-    void communicate_block_data(cgsize_t *file_data, T *ioss_data,
+    template <typename U, typename T>
+    void communicate_block_data(U *file_data, T *ioss_data,
                                 const Ioss::BlockDecompositionData &block, size_t comp_count) const
     {
       m_decomposition.communicate_block_data(file_data, ioss_data, block, comp_count);
@@ -182,6 +185,11 @@ namespace Iocgns {
 
     void get_block_connectivity(int filePtr, INT *data, int blk_seq) const;
 
+    void get_element_field(int filePtr, int solution_index, int blk_seq, int field_index,
+                           double *data) const;
+
+    void get_node_field(int filePtr, int solution_index, int field_index, double *data) const;
+
     size_t get_commset_node_size() const { return m_decomposition.m_nodeCommMap.size() / 2; }
 
     void get_sideset_element_side(int filePtr, const Ioss::SetDecompositionData &sset,
@@ -240,7 +248,8 @@ namespace Iocgns {
     void get_file_node_coordinates(int filePtr, int direction, double *ioss_data) const;
     void get_node_coordinates(int filePtr, double *ioss_data, const Ioss::Field &field) const;
 
-    double m_loadBalanceThreshold;
+    double      m_loadBalanceThreshold;
+    std::string m_preferentialOrdinals;
 
   public:
     Ioss::Decomposition<INT> m_decomposition;
