@@ -80,10 +80,6 @@
 
 #include "info_interface.h"
 
-#ifdef HAVE_MPI
-#include <mpi.h>
-#endif
-
 #ifndef NO_XDMF_SUPPORT
 #include <xdmf/Ioxf_Initializer.h>
 #endif
