@@ -52,7 +52,7 @@ namespace Iotr {
 
   private:
     Tensor_Factory();
-    Ioss::Transform *make(const std::string &type) const;
+    Ioss::Transform *make(const std::string &type) const override;
   };
 
   class Tensor : public Ioss::Transform
@@ -71,13 +71,13 @@ namespace Iotr {
     };
 
   public:
-    const Ioss::VariableType *output_storage(const Ioss::VariableType *in) const;
-    int output_count(int in) const;
+    const Ioss::VariableType *output_storage(const Ioss::VariableType *in) const override;
+    int output_count(int in) const override;
 
   protected:
     explicit Tensor(const std::string &type);
 
-    bool internal_execute(const Ioss::Field &field, void *data);
+    bool internal_execute(const Ioss::Field &field, void *data) override;
 
   private:
     TranType type_;
