@@ -81,9 +81,6 @@
 #define MAXCHAR 80
 #define WORDLEN 8 /* Note that we *FORCE* the Fortran string */
                   /* length be 8 for the strings hard and soft. */
-#define HARD hardname
-#define SOFT softname
-
 #if defined(ADDC_)
 void exparm_(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FTNINT *idau,
              FTNINT hlen, FTNINT slen)
@@ -104,11 +101,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
 
   uname(&SysInfo);
 
-  sprintf(hardname, "SGI-%4s", SysInfo.machine);
-  sprintf(softname, "%8s", SysInfo.release);
+  sprintf(hardname, "SGI-%.4s", SysInfo.machine);
+  sprintf(softname, "%.8s", SysInfo.release);
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 #endif /* Silicon Graphics */
 /********************************************************************/
@@ -124,11 +121,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
 
   uname(&SysInfo);
 
-  sprintf(hardname, "IBM %4s", SysInfo.machine);
-  sprintf(softname, "%03s %4s", SysInfo.sysname, SysInfo.release);
+  sprintf(hardname, "IBM %.4s", SysInfo.machine);
+  sprintf(softname, "%03s %.4s", SysInfo.sysname, SysInfo.release);
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 #endif /* IBM */
 /********************************************************************/
@@ -144,11 +141,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
 
   uname(&SysInfo);
 
-  sprintf(hardname, "HP  %4s", SysInfo.machine);
-  sprintf(softname, "HP-UX%3s", SysInfo.release);
+  sprintf(hardname, "HP  %.4s", SysInfo.machine);
+  sprintf(softname, "HP-UX%.3s", SysInfo.release);
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 #endif /* HPUX */
 /********************************************************************/
@@ -164,11 +161,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
 
   uname(&SysInfo);
 
-  sprintf(hardname, "%8s", "i860 GP ");
-  sprintf(softname, "OSF %2s.%1s", SysInfo.version, SysInfo.release);
+  sprintf(hardname, "i860 GP ");
+  sprintf(softname, "OSF %.2s.%.1s", SysInfo.version, SysInfo.release);
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 #endif
 /********************************************************************/
@@ -182,11 +179,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
   *kcsu = sizeof(FTNREAL); /* 860 has 32 bit words */
   *knsu = 1;
 
-  sprintf(hardname, "%8s", "i860 GP ");
-  sprintf(softname, "SUNMOS ");
+  sprintf(hardname, "i860 GP ");
+  sprintf(softname, "SUNMOS  ");
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 #endif
 /********************************************************************/
@@ -200,11 +197,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
   *kcsu = sizeof(FTNREAL); /* P6 has 32 bit words */
   *knsu = 1;
 
-  sprintf(hardname, "%8s", "P6      ");
+  sprintf(hardname, "P6      ");
   sprintf(softname, "Solari  ");
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 #endif
 /********************************************************************/
 #if defined(cougar)
@@ -217,11 +214,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
   *kcsu = sizeof(FTNREAL); /* p6 has 32 bit words */
   *knsu = 1;
 
-  sprintf(hardname, "%8s", "PentPro ");
+  sprintf(hardname, "PentPro ");
   sprintf(softname, "COUGAR  ");
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 #endif
 /********************************************************************/
@@ -237,11 +234,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
 
   uname(&SysInfo);
 
-  sprintf(hardname, "%8s", SysInfo.machine);
-  sprintf(softname, "%4s%4s", SysInfo.sysname, SysInfo.release);
+  sprintf(hardname, "%.8s", SysInfo.machine);
+  sprintf(softname, "%.4s%.4s", SysInfo.sysname, SysInfo.release);
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 #endif
 /********************************************************************/
@@ -258,11 +255,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
 
   uname(&SysInfo);
 
-  sprintf(hardname, "%8s", SysInfo.machine);
-  sprintf(softname, "SunOS%3s", SysInfo.release);
+  sprintf(hardname, "%.8s", SysInfo.machine);
+  sprintf(softname, "SunOS%.3s", SysInfo.release);
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 #else
 
@@ -282,8 +279,8 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
 #endif /* sparc */
 
   if ((darg = (char *)fgets(
-           SOFT, MAXCHAR, pipe = popen("/usr/ucb/strings /vmunix|/usr/bin/fgrep Release", "r"))) ==
-      (char *)NULL) {
+           softname, MAXCHAR,
+           pipe = popen("/usr/ucb/strings /vmunix|/usr/bin/fgrep Release", "r"))) == (char *)NULL) {
     perror("exparm: bad read from pipe");
     exit(1);
   }
@@ -299,7 +296,7 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
   /* This occurs due to the wait() */
   /* function call in pclose(). */
 
-  sscanf(SOFT, "%*s%*s%6s", soft + 2);
+  sscanf(softname, "%*s%*s%6s", soft + 2);
 
   strncat(hard, "    ", strlen("    ")); /* Another case of hardwiring the length of hard. */
   soft[0] = 'O';
@@ -335,8 +332,8 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
   else {
     sprintf(softname, "Unknown OS");
   }
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 /* cygwin native */
 /********************************************************************/
@@ -351,11 +348,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
 
   uname(&SysInfo);
 
-  sprintf(hardname, "%8s", SysInfo.machine);
-  sprintf(softname, "CW%6s", SysInfo.release);
+  sprintf(hardname, "%.8s", SysInfo.machine);
+  sprintf(softname, "CW%.6s", SysInfo.release);
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 #endif
 /********************************************************************/
@@ -370,11 +367,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
 
   uname(&SysInfo);
 
-  sprintf(hardname, "%8s", "PowerMac");
-  sprintf(softname, "Darw %3s", SysInfo.release);
+  sprintf(hardname, "%.8s", SysInfo.machine);
+  sprintf(softname, "OSX%.5s", SysInfo.release);
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 #endif /* Darwin (Power Macintosh)*/
 
@@ -390,11 +387,11 @@ void exparm(char *hard, char *soft, FTNINT *mode, FTNINT *kcsu, FTNINT *knsu, FT
 
   uname(&SysInfo);
 
-  sprintf(hardname, "%8s", SysInfo.machine);
-  sprintf(softname, "Lx%6s", SysInfo.release);
+  sprintf(hardname, "%.8s", SysInfo.machine);
+  sprintf(softname, "Lx%.6s", SysInfo.release);
 
-  strncpy(hard, HARD, WORDLEN);
-  strncpy(soft, SOFT, WORDLEN);
+  strncpy(hard, hardname, WORDLEN);
+  strncpy(soft, softname, WORDLEN);
 
 #endif /* Linux, Interix */
   /********************************************************************/
