@@ -561,7 +561,7 @@ void cesc1_(f_integer *funcid, f_integer *ldr, char *data, f_integer *drec_size)
 /*      cqid - inquire device identification                                  */
 /*                                                                            */
 /******************************************************************************/
-void cqid_(f_integer *maxchr, f_integer *vstat, f_integer *dclass, char *devid[4])
+void cqid_(f_integer *maxchr, f_integer *vstat, f_integer *dclass, char *devid)
 {
   short     dev;       /* which device to look at now */
   short     dev_found; /* which device was it found on */
@@ -1614,7 +1614,7 @@ void cqfl_(f_integer *vstat, f_integer *npdefb, f_integer *nsetb, f_integer *max
 /*      cqc - inquire colour capabilities                                     */
 /*                                                                            */
 /******************************************************************************/
-void cqc_(f_integer *vstat, f_integer *nsimul, f_integer *navail, f_integer *nint[3],
+void cqc_(f_integer *vstat, f_integer *nsimul, f_integer *navail, f_integer *nint,
           f_integer *cmode, f_integer *dynmod, f_integer *overit, f_integer *monoc)
 {
   short     dev;       /* which device to look at now */
