@@ -74,20 +74,20 @@ namespace BaskerNS
     BASKER_INLINE
     void init_token(const Int size)
     {
-      printf("token size: %d \n", size);
+      printf("token size: %ld \n", (long)size);
       token = (Int **)malloc(size*sizeof(Int*));
       for(Int i = 0; i < size; i++)
-	{
-	  token[i] = (Int *)malloc(8*sizeof(Int));
-	  token[i][0] = 0;
-	  token[i][1] = 0;
-	  token[i][2] = 0;
-	  token[i][3] = 0;
-	  token[i][4] = 0;
-	  token[i][5] = 0;
-	  token[i][6] = 0;
-	  token[i][7] = 0;
-	}
+      {
+        token[i] = (Int *)malloc(8*sizeof(Int));
+        token[i][0] = 0;
+        token[i][1] = 0;
+        token[i][2] = 0;
+        token[i][3] = 0;
+        token[i][4] = 0;
+        token[i][5] = 0;
+        token[i][6] = 0;
+        token[i][7] = 0;
+      }
     }
 
 
@@ -95,16 +95,12 @@ namespace BaskerNS
 
     void init_ops()
     {
-      for(Int i=0; i < 10; i++)
-	{
-	  for(Int j = 0; j < 10; j++)
-	    {
-	      ops_counts[i][j] = 0;
-	    }
-	}
-     
+      for(Int i=0; i < 10; i++) {
+        for(Int j = 0; j < 10; j++) {
+          ops_counts[i][j] = 0;
+        }
+      }
     }
-   
 
   };
 
@@ -131,32 +127,37 @@ namespace BaskerNS
     {
       //printf("basker_tree Finalize todo \n");
       if(nroots > 0)
-        {
-          FREE_INT_1DARRAY(roots);
-        }
+      {
+        FREE_INT_1DARRAY(roots);
+      }
       if(nblks > 0)
-        {
-          FREE_INT_1DARRAY(permtab);
-          FREE_INT_1DARRAY(ipermtab);
-          FREE_INT_1DARRAY(row_tabs);
-          FREE_INT_1DARRAY(col_tabs);
-          FREE_INT_1DARRAY(lvlset);
-          FREE_INT_1DARRAY(treetab);
-          FREE_INT_1DARRAY(lvltreetabs);
-          FREE_INT_1DARRAY(treeptr);
-          FREE_INT_1DARRAY(rowptr);
-          FREE_INT_1DARRAY(child);
-          FREE_INT_1DARRAY(sibling);
-        }
+      {
+        FREE_INT_1DARRAY(permtab);
+        FREE_INT_1DARRAY(ipermtab);
+        FREE_INT_1DARRAY(row_tabs);
+        FREE_INT_1DARRAY(col_tabs);
+        FREE_INT_1DARRAY(lvlset);
+        FREE_INT_1DARRAY(treetab);
+        FREE_INT_1DARRAY(lvltreetabs);
+        FREE_INT_1DARRAY(treeptr);
+        FREE_INT_1DARRAY(rowptr);
+        FREE_INT_1DARRAY(child);
+        FREE_INT_1DARRAY(sibling);
+      }
     }//end Finalize();
 
     BASKER_INLINE
-    void basic_convert(Int _m, Int *_perm, Int _nblks,
-		       Int _parts, 
-		       Int *_row_tabs, Int *_col_tabs,
-		       Int *_treetab)
+    void basic_convert
+    (
+     Int _m, 
+     Int *_perm, 
+     Int _nblks,
+     Int _parts, 
+     Int *_row_tabs, 
+     Int *_col_tabs,
+     Int *_treetab
+    )
     {
-          
       nblks = _nblks;
       //For now defaulting parts to 2
       //nparts = _parts;
@@ -166,19 +167,19 @@ namespace BaskerNS
       BASKER_ASSERT((nblks+1)>0, "struct basic convert");
       MALLOC_INT_1DARRAY(row_tabs, nblks+1);
       for(Int i =0; i < nblks+1; i++)
-	{
-	  row_tabs[i] = _row_tabs[i];
-	}
+      {
+        row_tabs[i] = _row_tabs[i];
+      }
       MALLOC_INT_1DARRAY(col_tabs, nblks+1);
       for(Int i=0; i < nblks+1; i++)
-	{
-	  col_tabs[i] = _col_tabs[i];
-	}
+      {
+        col_tabs[i] = _col_tabs[i];
+      }
       MALLOC_INT_1DARRAY(treetab, nblks+1);
       for(Int i=0; i < nblks+1; i++)
-	{
-	  treetab[i] = _treetab[i];
-	}
+      {
+        treetab[i] = _treetab[i];
+      }
     }//end basic_convert
 
     BASKER_INLINE
@@ -252,7 +253,6 @@ namespace BaskerNS
       U_col_counts_flg = 0;
       S_col_counts_flg = 0;
       S_row_counts_flg = 0;
-
     }
 
     ~basker_symbolic_tree()
@@ -266,111 +266,114 @@ namespace BaskerNS
       //This can be removed to use only in sfactor stage than delete
       //printf("basker_symbolic_tree finalize todo \n");
       if(parent_flg > 0)
-        {
-          FREE_INT_1DARRAY(parent);
-        }
+      {
+        FREE_INT_1DARRAY(parent);
+      }
       if(post_flg > 0)
-        {
-          FREE_INT_1DARRAY(post);
-        }
+      {
+        FREE_INT_1DARRAY(post);
+      }
       if(col_ptr_flg > 0)
-        {
-          FREE_INT_1DARRAY(col_ptr);
-        }
+      {
+        FREE_INT_1DARRAY(col_ptr);
+      }
       if(left_most_flg > 0)
-        {
-          FREE_INT_1DARRAY(left_most);
-        }
+      {
+        FREE_INT_1DARRAY(left_most);
+      }
       if(row_counts_flg > 0)
-        {
-          FREE_INT_1DARRAY(row_counts);
-        }
+      {
+        FREE_INT_1DARRAY(row_counts);
+      }
       if(col_counts_flg > 0)
-        {
-          FREE_INT_1DARRAY(col_counts);
-        }
+      {
+        FREE_INT_1DARRAY(col_counts);
+      }
       if(WS_flg > 0)
-        {
-          FREE_INT_1DARRAY(WS);
-        }
+      {
+        FREE_INT_1DARRAY(WS);
+      }
       if(S_col_flg > 0)
-        {
-          FREE_INT_1DARRAY(S_col);
-        }
+      {
+        FREE_INT_1DARRAY(S_col);
+      }
       if(S_row_flg > 0)
-        {
-          FREE_INT_1DARRAY(S_row);
-        }
+      {
+        FREE_INT_1DARRAY(S_row);
+      }
       if(L_row_counts_flg > 0)
-        {
-          FREE_INT_1DARRAY(L_row_counts);
-        }
+      {
+        FREE_INT_1DARRAY(L_row_counts);
+      }
       if(L_col_counts_flg > 0)
-        {
-          FREE_INT_1DARRAY(L_col_counts);
-        }
+      {
+        FREE_INT_1DARRAY(L_col_counts);
+      }
       if(U_row_counts_flg > 0)
-        {
-          FREE_INT_1DARRAY(U_row_counts);
-        }
+      {
+        FREE_INT_1DARRAY(U_row_counts);
+      }
       if(U_col_counts_flg > 0)
-        {
-          FREE_INT_1DARRAY(U_col_counts);
-        }
+      {
+        FREE_INT_1DARRAY(U_col_counts);
+      }
       if(S_col_counts_flg > 0)
-        {
-          FREE_INT_1DARRAY(S_col_counts);
-        }
+      {
+        FREE_INT_1DARRAY(S_col_counts);
+      }
       if(S_row_counts_flg > 0)
-        {
-          FREE_INT_1DARRAY(S_row_counts);
-        }
- 
+      {
+        FREE_INT_1DARRAY(S_row_counts);
+      }
+
     }//end Finalize()
     
     BASKER_INLINE
     void init_parent(Int size)
     {
       if(size <=0)
-	//{return;} JDB: Changed because of kokkos
-	{size = 1;}
+        //{return;} JDB: Changed because of kokkos
+      {size = 1;} //defaul to 1
       if(parent_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "struct parent size");
-	  MALLOC_INT_1DARRAY(parent, size);
-	  parent_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct parent size");
+        MALLOC_INT_1DARRAY(parent, size);
+        parent_flg =size;
+      }
       else if(size > parent_flg)
-	{
-	  BASKER_ASSERT(size > 0, "struct parent size2");
-	  REALLOC_1DARRAY(parent, parent_flg, size);
-	  parent_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct parent size2");
+        REALLOC_1DARRAY(parent, parent_flg, size);
+        parent_flg = size;
+      }
       //BV::init_value(parent, parent_flg, 0);
       for(Int j = 0; j < parent_flg; j++)
-	{
-	  parent(j) = (Int) 0;
-	}
+      {
+        parent(j) = (Int) 0;
+      }
 
     }//end init_parent
 
     BASKER_INLINE
     void init_post(Int size)
     {
-       if(size <=0)
-	{return;}
+      if(size <=0)
+      {
+        std::cout << " init_post: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(post_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "struct post size");
-	  MALLOC_INT_1DARRAY(post, size);
-	  post_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct post size");
+        MALLOC_INT_1DARRAY(post, size);
+        post_flg =size;
+      }
       else if(size > parent_flg)
-	{
-	  BASKER_ASSERT(size > 0, "struct post size2");
-	  REALLOC_1DARRAY(post, post_flg, size);
-	  post_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct post size2");
+        REALLOC_1DARRAY(post, post_flg, size);
+        post_flg = size;
+      }
       BV::init_value(post, post_flg, 0);
     }//end init_post
 
@@ -378,20 +381,23 @@ namespace BaskerNS
     BASKER_INLINE
     void init_col_ptr(Int size)
     {
-       if(size <=0)
-	{return;}
+      if(size <=0)
+      {
+        std::cout << " init_col_ptr: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(col_ptr_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "structs col size");
-	  MALLOC_INT_1DARRAY(col_ptr, size);
-	  col_ptr_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "structs col size");
+        MALLOC_INT_1DARRAY(col_ptr, size);
+        col_ptr_flg =size;
+      }
       else if(size > parent_flg)
-	{
-	  BASKER_ASSERT(size > 0, "structs col size2");
-	  REALLOC_1DARRAY(col_ptr, col_ptr_flg, size);
-	  col_ptr_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "structs col size2");
+        REALLOC_1DARRAY(col_ptr, col_ptr_flg, size);
+        col_ptr_flg = size;
+      }
       BV::init_value(col_ptr, col_ptr_flg, 0);
     }//end init_col_ptr
 
@@ -399,20 +405,23 @@ namespace BaskerNS
     BASKER_INLINE
     void init_left_most(Int size)
     {
-       if(size <=0)
-	{return;}
+      if(size <=0)
+      {
+        std::cout << " init_left_most: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(left_most_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "struct left size");
-	  MALLOC_INT_1DARRAY(left_most, size);
-	  left_most_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct left size");
+        MALLOC_INT_1DARRAY(left_most, size);
+        left_most_flg =size;
+      }
       else if(size > left_most_flg)
-	{
-	  BASKER_ASSERT(size > 0, "struct left size2");
-	  REALLOC_1DARRAY(left_most, left_most_flg, size);
-	  left_most_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct left size2");
+        REALLOC_1DARRAY(left_most, left_most_flg, size);
+        left_most_flg = size;
+      }
       BV::init_value(left_most, left_most_flg, 0);
     }//end init_left_most
 
@@ -420,20 +429,23 @@ namespace BaskerNS
     BASKER_INLINE
     void init_row_counts(Int size)
     {
-       if(size <=0)
-	{return;}
+      if(size <=0)
+      {
+        std::cout << " init_row_counts: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(row_counts_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "struct row size");
-	  MALLOC_INT_1DARRAY(row_counts, size);
-	  row_counts_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct row size");
+        MALLOC_INT_1DARRAY(row_counts, size);
+        row_counts_flg =size;
+      }
       else if(size > row_counts_flg)
-	{
-	  BASKER_ASSERT(size > 0, "struct row size2");
-	  REALLOC_1DARRAY(row_counts, row_counts_flg, size);
-	  row_counts_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct row size2");
+        REALLOC_1DARRAY(row_counts, row_counts_flg, size);
+        row_counts_flg = size;
+      }
       BV::init_value(row_counts, row_counts_flg, 0);
 
     }//end init_row_counts
@@ -442,24 +454,27 @@ namespace BaskerNS
     BASKER_INLINE
     void init_col_counts(Int size)
     {
-       if(size <=0)
-	{return;}
+      if(size <=0)
+      {
+        std::cout << " init_col_counts: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(col_counts_flg == 0)
-	{
-	  //printf("first call init_col_counts\n");
-	  BASKER_ASSERT(size > 0, "struct col count size");
-	  MALLOC_INT_1DARRAY(col_counts, size);
-	  col_counts_flg =size;
-	}
+      {
+        //printf("first call init_col_counts\n");
+        BASKER_ASSERT(size > 0, "struct col count size");
+        MALLOC_INT_1DARRAY(col_counts, size);
+        col_counts_flg =size;
+      }
       else if(size > col_counts_flg)
-	{
-	  printf("realloc call init_col_counts\n");
-	  printf("oldsize: %d newsize: %d \n",
-		 col_counts_flg, size);
-	  BASKER_ASSERT(size > 0, "struct col count size2");
-	  REALLOC_1DARRAY(col_counts, col_counts_flg, size);
-	  col_counts_flg = size;
-	}
+      {
+        printf("realloc call init_col_counts\n");
+        printf("oldsize: %ld newsize: %ld \n",
+            (long)col_counts_flg, (long)size);
+        BASKER_ASSERT(size > 0, "struct col count size2");
+        REALLOC_1DARRAY(col_counts, col_counts_flg, size);
+        col_counts_flg = size;
+      }
       //printf("zero out col_counts\n");
       BV::init_value(col_counts, col_counts_flg, 0);
     }//end init_col_counts
@@ -469,19 +484,22 @@ namespace BaskerNS
     void init_WS(Int size)
     {
       if(size <=0)
-	{return;}
+      {
+        std::cout << " init_WS: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(WS_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "struct WS size");
-	  MALLOC_INT_1DARRAY(WS, size);
-	  WS_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct WS size");
+        MALLOC_INT_1DARRAY(WS, size);
+        WS_flg =size;
+      }
       else if(size > WS_flg)
-	{
-	  BASKER_ASSERT(size > 0, "struct WS size2");
-	  REALLOC_1DARRAY(WS, WS_flg, size);
-	  WS_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct WS size2");
+        REALLOC_1DARRAY(WS, WS_flg, size);
+        WS_flg = size;
+      }
       BV::init_value(WS, WS_flg, 0);
     }//end init_WS()
 
@@ -490,19 +508,22 @@ namespace BaskerNS
     void init_S_col(Int size)
     {
       if(size <=0)
-	{return;}
+      {
+        std::cout << " init_S_col: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(S_col_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "struct scol size");
-	  MALLOC_INT_1DARRAY(S_col, size);
-	  S_col_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct scol size");
+        MALLOC_INT_1DARRAY(S_col, size);
+        S_col_flg =size;
+      }
       else if(size > S_col_flg)
-	{
-	  BASKER_ASSERT(size > 0, "struct scol size2");
-	  REALLOC_1DARRAY(WS, S_col_flg, size);
-	  S_col_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct scol size2");
+        REALLOC_1DARRAY(WS, S_col_flg, size);
+        S_col_flg = size;
+      }
       BV::init_value(WS, S_col_flg, 0);
     }//end init_S_col()
     
@@ -511,19 +532,22 @@ namespace BaskerNS
     void init_S_row(Int size)
     {
       if(size <=0)
-	{return;}
+      {
+        std::cout << " init_S_row: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(S_row_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "struct s row size");
-	  MALLOC_INT_1DARRAY(S_row, size);
-	  S_row_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct s row size");
+        MALLOC_INT_1DARRAY(S_row, size);
+        S_row_flg =size;
+      }
       else if(size > S_row_flg)
-	{
-	  BASKER_ASSERT(size > 0, "struct s row size2");
-	  REALLOC_1DARRAY(S_row, S_row_flg, size);
-	  S_row_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct s row size2");
+        REALLOC_1DARRAY(S_row, S_row_flg, size);
+        S_row_flg = size;
+      }
       BV::init_value(S_row, S_row_flg, 0);
     }//end init_S_row()
 
@@ -532,83 +556,94 @@ namespace BaskerNS
     void init_L_row_counts(Int size)
     {
       if(size <=0)
-	{return;}
+      {
+        std::cout << " init_L_row_counts: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(L_row_counts_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "struct lrowcount size");
-	  MALLOC_INT_1DARRAY(L_row_counts, size);
-	  L_row_counts_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct lrowcount size");
+        MALLOC_INT_1DARRAY(L_row_counts, size);
+        L_row_counts_flg =size;
+      }
       else if(size > L_row_counts_flg)
-	{
-	  BASKER_ASSERT(size > 0, "struct lrowcount size2");
-	  REALLOC_1DARRAY(L_row_counts, L_row_counts_flg, size);
-	  L_row_counts_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct lrowcount size2");
+        REALLOC_1DARRAY(L_row_counts, L_row_counts_flg, size);
+        L_row_counts_flg = size;
+      }
       BV::init_value(L_row_counts, L_row_counts_flg, 0);
-      
+
     }//end init_L_row_counts
 
     BASKER_INLINE
     void init_L_col_counts(Int size)
     {
       if(size <=0)
-	{return;}
+      {
+        std::cout << " init_L_col_counts: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(L_col_counts_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "strcut lcolcountsize");
-	  MALLOC_INT_1DARRAY(L_col_counts, size);
-	  L_col_counts_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "strcut lcolcountsize");
+        MALLOC_INT_1DARRAY(L_col_counts, size);
+        L_col_counts_flg =size;
+      }
       else if(size > L_col_counts_flg)
-	{
-	  BASKER_ASSERT(size > 0, "strcut lcolcountsize2");
-	  REALLOC_1DARRAY(L_col_counts, L_col_counts_flg, size);
-	  L_col_counts_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "strcut lcolcountsize2");
+        REALLOC_1DARRAY(L_col_counts, L_col_counts_flg, size);
+        L_col_counts_flg = size;
+      }
       BV::init_value(L_col_counts, L_col_counts_flg, 0);
-    
+
     }//end init_L_col_counts
 
     BASKER_INLINE
     void init_U_row_counts(Int size)
     {
       if(size <=0)
-	{return;}
+      {
+        std::cout << " init_U_row_counts: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(U_row_counts_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "struct urowcount size");
-	  MALLOC_INT_1DARRAY(U_row_counts, size);
-	  U_row_counts_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct urowcount size");
+        MALLOC_INT_1DARRAY(U_row_counts, size);
+        U_row_counts_flg =size;
+      }
       else if(size > U_row_counts_flg)
-	{
-	  BASKER_ASSERT(size > 0, "strcut urowcount size2");
-	  REALLOC_1DARRAY(U_row_counts, U_row_counts_flg, size);
-	  U_row_counts_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "strcut urowcount size2");
+        REALLOC_1DARRAY(U_row_counts, U_row_counts_flg, size);
+        U_row_counts_flg = size;
+      }
       BV::init_value(U_row_counts, U_row_counts_flg, 0);
-      
+
     }//end init_U_row_counts
 
     BASKER_INLINE
     void init_U_col_counts(Int size)
     {
-
       if(size <=0)
-	{return;}
+      {
+        std::cout << " init_U_col_counts: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(U_col_counts_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "strcut ucolcount size");
-	  MALLOC_INT_1DARRAY(U_col_counts, size);
-	  U_col_counts_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "strcut ucolcount size");
+        MALLOC_INT_1DARRAY(U_col_counts, size);
+        U_col_counts_flg =size;
+      }
       else if(size > U_col_counts_flg)
-	{
-	  BASKER_ASSERT(size > 0, "struct ucolcont size2");
-	  REALLOC_1DARRAY(U_col_counts, U_col_counts_flg, size);
-	  U_col_counts_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct ucolcont size2");
+        REALLOC_1DARRAY(U_col_counts, U_col_counts_flg, size);
+        U_col_counts_flg = size;
+      }
       BV::init_value(U_col_counts, U_col_counts_flg, 0);
 
     }//end init_U_col_counts
@@ -617,19 +652,22 @@ namespace BaskerNS
     void init_S_row_counts(Int size)
     {
       if(size <=0)
-	{return;}
+      {
+        std::cout << " init_S_row_counts: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(S_row_counts_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "struct srowcount size");
-	  MALLOC_INT_1DARRAY(S_row_counts, size);
-	  S_row_counts_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct srowcount size");
+        MALLOC_INT_1DARRAY(S_row_counts, size);
+        S_row_counts_flg =size;
+      }
       else if(size > S_row_counts_flg)
-	{
-	  BASKER_ASSERT(size > 0, "struct srowcount size2");
-	  REALLOC_1DARRAY(S_row_counts, S_row_counts_flg, size);
-	  S_row_counts_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "struct srowcount size2");
+        REALLOC_1DARRAY(S_row_counts, S_row_counts_flg, size);
+        S_row_counts_flg = size;
+      }
       BV::init_value(S_row_counts, S_row_counts_flg, 0);
 
     }//end init_S_row_count
@@ -638,19 +676,22 @@ namespace BaskerNS
     void init_S_col_counts(Int size)
     {
       if(size <=0)
-	{return;}
+      {
+        std::cout << " init_S_col_counts: size <= 0 no alloc " << std::endl;
+        return;  //NDE - info of failure to allocate should be returned...
+      }
       if(S_col_counts_flg == 0)
-	{
-	  BASKER_ASSERT(size > 0, "strcut scolcount size");
-	  MALLOC_INT_1DARRAY(S_col_counts, size);
-	  S_col_counts_flg =size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "strcut scolcount size");
+        MALLOC_INT_1DARRAY(S_col_counts, size);
+        S_col_counts_flg =size;
+      }
       else if(size > S_col_counts_flg)
-	{
-	  BASKER_ASSERT(size > 0, "strcut scolcount size2");
-	  REALLOC_1DARRAY(S_col_counts, S_col_counts_flg, size);
-	  S_col_counts_flg = size;
-	}
+      {
+        BASKER_ASSERT(size > 0, "strcut scolcount size2");
+        REALLOC_1DARRAY(S_col_counts, S_col_counts_flg, size);
+        S_col_counts_flg = size;
+      }
       BV::init_value(S_col_counts, S_col_counts_flg, 0);
 
     }//end init_S_col_counts
@@ -684,7 +725,6 @@ namespace BaskerNS
     {
 
       //Operation Options
-
       same_pattern = BASKER_FALSE;
 
       //Note verbose will not give debug
@@ -731,7 +771,8 @@ namespace BaskerNS
       //incomplete_type = BASKER_INCOMPLETE_RLVL_LIMITED;
       inc_lvl    = BASKER_INC_LVL_VALUE;
       inc_tol    = BASKER_INC_TOL_VALUE;
-      user_fill  = (Entry)BASKER_FILL_USER;
+      //user_fill  = (Entry)BASKER_FILL_USER;
+      user_fill  = (double)BASKER_FILL_USER;
  
     }
 
@@ -746,7 +787,6 @@ namespace BaskerNS
     BASKER_BOOL  realloc;
     BASKER_BOOL  transpose;
     
-
     //Symmetric Options
     BASKER_BOOL  symmetric;
     
@@ -780,49 +820,12 @@ namespace BaskerNS
     BASKER_INT   incomplete_type;
     BASKER_INT   inc_lvl;
     BASKER_ENTRY inc_tol;    //Not Used
-    BASKER_ENTRY user_fill;
-    
+    //BASKER_ENTRY user_fill;
+    double user_fill;
     
     /* ---- todo add more ----*/
   }; // end bask_options
 
 }//end namespace Basker
 
-
-
-#ifndef KOKKOS_USING_EXPERIMENTAL_VIEW
-
-namespace Kokkos
-{
-namespace Impl
-{
-//----------Specialization for Basker_thread---------------//
-  template <class ExecSpace, class Int, class Entry>
-  struct ViewDefaultConstruct<ExecSpace, BaskerNS::basker_thread<Int,Entry,ExecSpace>, true>
-  {
-    typedef BaskerNS::basker_thread<Int,Entry,ExecSpace> type;
-    type * const m_ptr;
-     
-    KOKKOS_FORCEINLINE_FUNCTION
-    void operator()(const typename ExecSpace::size_type& i) const
-    {
-      new(m_ptr+i) type();
-    }
-
-    ViewDefaultConstruct( type * pointer, size_t capacity )
-      :m_ptr( pointer )
-    {
-
-      Kokkos::RangePolicy<ExecSpace> range(0, capacity);
-      parallel_for(range, *this);
-      ExecSpace::fence();
-
-    }//end constructor
-  };//end ViewDefault Construct BaskerMatrix
-
-}//end namespace imp
-}//end namepace kokkos
-
-#endif //ifndef Kokkos_using_experimental_view
-
 #endif //end ifdef basker_structs.hpp
