@@ -100,7 +100,7 @@ enum BASKER_INCOMPLETE_CODE
 #define BASKER_ASSERT(a,s)       \
   {                              \
     if(!(a))                     \
-      {printf("\n\n%s\n\n", s);} \
+      {printf("\n\n%s \nLINE: %d \nFILE: %s\n\n", s, __LINE__, __FILE__);} \
     ASSERT(a);                   \
     assert(a);			 \
     if(!(a))                     \
@@ -143,88 +143,97 @@ enum BASKER_INCOMPLETE_CODE
 #define MATRIX_VIEW_2DARRAY       Kokkos::View<MATRIX_VIEW_1DARRAY*, BASKER_EXE_SPACE>
 #define THREAD_1DARRAY            Kokkos::View<BASKER_THREAD*,       BASKER_EXE_SPACE>
 #define THREAD_2DARRAY            Kokkos::View<THREAD_1DARRAY*,      BASKER_EXE_SPACE>
+
+#define INT_1DARRAY_PAIRS        Kokkos::View<std::pair<Int,Int>*,  BASKER_EXE_SPACE>
 //Macro Memory Calls
 //MALLOC
+#define MALLOC_INT_1DARRAY_PAIRS(a,s)   \
+  { \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC malloc_pairs_1d: size to alloc > 0 fails"); \
+    a = INT_1DARRAY_PAIRS(KOKKOS_NOINIT("pairs_1d"),s); \
+    if(a.data() == NULL)           \
+      throw std::bad_alloc();	   \
+  }
 #define MALLOC_INT_1DARRAY(a,s)   \
   { \
-    BASKER_ASSERT(s>0, "init_1d"); \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC int_1d: size to alloc > 0 fails"); \
     a = INT_1DARRAY(KOKKOS_NOINIT("int_1d"),s); \
     if(a.data() == NULL)           \
       throw std::bad_alloc();	   \
   }
 #define MALLOC_INT_2DARRAY(a,s) \
   { \
-    BASKER_ASSERT(s>0,"int_2d"); \
+    BASKER_ASSERT(s>0,"BASKER ASSERT MALLOC int_2d: size to alloc > 0 fails"); \
     a = INT_2DARRAY("int_2d",s); \
     if(a.data() == NULL)         \
       throw std::bad_alloc();    \
   }
 #define MALLOC_ENTRY_1DARRAY(a,s) \
   { \
-    BASKER_ASSERT(s>0, "entry_1d"); \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC entry_1d: size to alloc > 0 fails"); \
     a = ENTRY_1DARRAY(KOKKOS_NOINIT("entry_1d"),s); \
     if(a.data() == NULL)           \
       throw std::bad_alloc();      \
   }
 #define MALLOC_ENTRY_2DARRAY(a,s) \
   { \
-    BASKER_ASSERT(s>0, "entry_2d"); \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC entry_2d: size to alloc > 0 fails"); \
     a = ENTRY_2DARRAY("entry_2d",s); \
     if(a.data() == NULL)             \
       throw std::bad_alloc();        \
   }
 #define MALLOC_BOOL_1DARRAY(a,s) \
   { \
-    BASKER_ASSERT(s>0, "bool_1d"); \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC bool_1d: size to alloc > 0 fails"); \
     a = BOOL_1DARRAY(KOKKOS_NOINIT("bool_1d"), s); \
     if(a.data() == NULL)           \
       throw std::bad_alloc();      \
   }
 #define MALLOC_BOOL_2DARRAY(a,s) \
   { \
-    BASKER_ASSERT(s>0, "bool_2d"); \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC bool_2d: size to alloc > 0 fails"); \
     a = BOOL_2DARRAY("bool_2d", s); \
     if(a.data() == NULL)            \
       throw std::bad_alloc();       \
   }
 #define MALLOC_MATRIX_1DARRAY(a,s) \
   { \
-    BASKER_ASSERT(s>0, "matrix_1d"); \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC matrix_1d: size to alloc > 0 fails"); \
     a = MATRIX_1DARRAY("matrix_1d",s); \
     if(a.data() == NULL)              \
       throw std::bad_alloc();         \
   }
 #define MALLOC_MATRIX_2DARRAY(a,s) \
   { \
-    BASKER_ASSERT(s>0, "matrix_2d"); \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC matrix_2d: size to alloc > 0 fails"); \
     a = MATRIX_2DARRAY("matrix_2d",s); \
     if(a.data() == NULL)              \
       throw std::bad_alloc();         \
   }
 #define MALLOC_MATRIX_VIEW_1DARRAY(a,s) \
   { \
-    BASKER_ASSERT(s>0, "matrix_view_1d"); \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC matrix_view_1d: size to alloc > 0 fails"); \
     a = MATRIX_VIEW_1DARRAY("matrix_view_1d",s); \
     if(a.data() == NULL)                 \
       throw std::bad_alloc();            \
   }
 #define MALLOC_MATRIX_VIEW_2DARRAY(a,s) \
   { \
-    BASKER_ASSERT(s>0, "matrix_view_2d"); \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC matrix_view_2d: size to alloc > 0 fails"); \
     a = MATRIX_VIEW_2DARRAY("matrix_view_2d",s); \
     if(a.data() == NULL)                 \
       throw std::bad_alloc();            \
   }
 #define MALLOC_THREAD_1DARRAY(a,s) \
   { \
-    BASKER_ASSERT(s>0, "thread_1d"); \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC thread_1d: size to alloc > 0 fails"); \
     a = THREAD_1DARRAY("thread_1d",s); \
     if(a.data() == NULL)              \
       throw std::bad_alloc();         \
   }
 #define MALLOC_THREAD_2DARRAY(a,s) \
   { \
-    BASKER_ASSERT(s>0, "thread_2d"); \
+    BASKER_ASSERT(s>0, "BASKER ASSERT MALLOC thread_2d: size to alloc > 0 fails"); \
     a = THREAD_2DARRAY("thread_2d",s); \
     if(a.data() == NULL)             \
       throw std::bakd_alloc();       \
@@ -263,6 +272,11 @@ enum BASKER_INCOMPLETE_CODE
 
 #define FREE(a)                        BASKER_NO_OP
 
+#define FREE_INT_1DARRAY_PAIRS(a)      \
+  { \
+    a = INT_1DARRAY_PAIRS(); \
+  }
+
 #define FREE_INT_1DARRAY(a)      \
   { \
     a = INT_1DARRAY(); \
@@ -465,7 +479,8 @@ enum BASKER_INCOMPLETE_CODE
 //Time Macro
 #ifdef BASKER_TIME
 #ifdef BASKER_KOKKOS
-#define BASKER_KOKKOS_TIME
+#define BASKER_TIMER
+#define BASKER_TIMER_FINE
 #else
 #define BASKER_OMP_TIME
 #endif
