@@ -525,7 +525,7 @@ namespace stk_classic
           msg << "Unable to resolve symbols in expression: " << name;
           throw new std::runtime_error(msg.str());
         }
-      if (DOPRINT) std::cout << " end resolve: "<<std::endl;;
+      if (DOPRINT) std::cout << " end resolve: "<<std::endl;
 
       return;
     }
