@@ -55,12 +55,12 @@ namespace
 
     // Add some parameters to write and read...
     stk::util::ParameterList params;
-    params.set_param("PI", 3.14159);  // Double 
-    params.set_param("Answer", 42);   // Integer
+    params.set_param("PI", 3.14159);   // Double 
+    params.set_param("Answer", 42);    // Integer
 
     std::vector<double> my_vector = { 2.78, 5.30, 6.21 };
     params.set_param("doubles", my_vector); // Vector of doubles...
-    
+
     std::vector<int> ages = { 55, 49, 21, 19};
     params.set_param("Ages", ages);   // Vector of integers...
 
@@ -119,10 +119,10 @@ namespace
       // ============================================================
       //+ VALIDATION
       stk::util::ParameterList gold_params; // To compare values read
-      gold_params.set_param("PI", 3.14159);  // Double 
-      gold_params.set_param("Answer", 42);   // Integer
-      gold_params.set_param("doubles", my_vector);
-      gold_params.set_param("Ages", ages);   // Vector of integers...
+      gold_params.set_param("PI", 3.14159);        // Double 
+      gold_params.set_param("Answer", 42);         // Integer
+      gold_params.set_param("doubles", my_vector); // Vector of doubles
+      gold_params.set_param("Ages", ages);         // Vector of integers...
 
       size_t param_count = 0;
       for (i = params.begin(); i != ie; ++i) {
