@@ -69,8 +69,9 @@ public:
    *
    * @param expr		a <b>std::string</b> const reference to the
    *				expression to be parsed.
+   *
    */
-  Eval(VariableMap::Resolver &resolver = VariableMap::getDefaultResolver(), const std::string &expr = "");
+  Eval(VariableMap::Resolver &resolver = VariableMap::getDefaultResolver(), const std::string &expr = "", const Variable::ArrayOffset arrayOffsetType = Variable::ZERO_BASED_INDEX);
 
 private:
   explicit Eval(const Eval &);
@@ -150,23 +151,11 @@ public:
     return m_parseStatus;
   }
 
-  /**
-   * @brief Member function <b>setValue</b> assigns a variables value in the
-   * variable map.
-   *
-   * @param name		a <b>std::string</b> const reference of the name of the
-   *				variable.
-   *
-   * @param value		a <b>double</b> value to be assigned to the
-   *				variable.
-   *
-   * @return			an <b>Eval</b> reference to this expression
-   *				evaluator.
-   */
-  inline Eval &setValue(const std::string &name, double value) {
+  inline Eval &setValue(const std::string &name, double* value, int definedLength) {
     VariableMap::iterator it = m_variableMap.find(name);
-    if (it != m_variableMap.end())
-      *(*it).second = value;
+    if (it != m_variableMap.end()) {
+      (*it).second->bind(*value, definedLength);
+    }
     return *this;
   }
 
@@ -200,20 +189,19 @@ public:
   /**
    * @brief Member function <b>bindVariable</b> binds the variable to the address of
    * the specified value.  This address must remain in scope during the lifetime of the
-   * variable are until rebound to a new address.
+   * variable or until the variable is rebound to a new address.
    *
-   * @param name		a <b>std::string</b> const reference to the variable's
-   *				name.
+   * @param name		a <b>std::string</b> const reference to the variable's name.
    *
    * @param value_ref		a <b>double</b> reference to be used for this variable.
    *
-   * @return			an <b>Eval</b> reference to this expression
-   *				evaluator.
+   * @return			an <b>Eval</b> reference to this expression evaluator.
    */
-  inline Eval &bindVariable(const std::string &name, double &value_ref) {
+  inline Eval &bindVariable(const std::string &name, double &value_ref, int definedLength=std::numeric_limits<int>::max()) {
     VariableMap::iterator it = m_variableMap.find(name);
-    if (it != m_variableMap.end())
-      (*it).second->bind(value_ref);
+    if (it != m_variableMap.end()) {
+      (*it).second->bind(value_ref, definedLength);
+    }
     return *this;
   }
 
@@ -251,7 +239,6 @@ public:
   /**
    * @brief Member function <b>syntax</b> performs a syntax check on the current
    * expression.  If successful, the syntax status is set to true.
-   *
    */
   void syntax();
 
@@ -259,8 +246,7 @@ public:
    * @brief Member function <b>parse</b> parses the expression.  If successful, the
    * parse status is set to true.
    *
-   * @param expr		a <b>std::string</b> const reference to the
-   *				expression to parse.
+   * @param expr		a <b>std::string</b> const reference to the expression to parse.
    *
    */
   inline void parse(const std::string &expr) {
@@ -298,6 +284,8 @@ public:
    */
   bool undefinedFunction() const;
 
+  Variable::ArrayOffset getArrayOffsetType() {return m_arrayOffsetType;}
+
 private:
   VariableMap		m_variableMap;		///< Variable map
   UndefinedFunctionSet	m_undefinedFunctionSet;	///< Vector of undefined functions
@@ -308,6 +296,7 @@ private:
 
   Node *		m_headNode;		///< Head of compiled expression
   std::vector<Node *>   m_nodes;                ///< Allocated nodes
+  Variable::ArrayOffset m_arrayOffsetType;      ///< Zero or one based array indexing
 };
 
 } // namespace expreval
