@@ -48,7 +48,7 @@
 #include <stk_util/parallel/ParallelReduce.hpp>  // for Reduce, ReduceSum, etc
 #include <gtest/gtest.h>
 #include <string>                       // for string, basic_string, etc
-#include <unit_tests/Setup8Quad4ProcMesh.hpp>
+#include <stk_unit_tests/stk_mesh/Setup8Quad4ProcMesh.hpp>
 #include <stk_unit_test_utils/getOption.h>
 #include <utility>                      // for pair
 #include <vector>                       // for vector, etc
