@@ -324,7 +324,7 @@ namespace stk_example_io {
     // NOTE: 'out_region' owns 'dbo' pointer at this time...
     Ioss::Region out_region(dbo, "results_output");
 
-    stk::io::define_output_db(out_region, bulk_data, &in_region);
+    stk::io::define_output_db(out_region, bulk_data, {}, &in_region);
     stk::io::write_output_db(out_region,  bulk_data);
 
     // ------------------------------------------------------------------------
@@ -430,10 +430,8 @@ namespace stk_example_io {
   // ========================================================================
   void process_elementblocks(Ioss::Region &region, stk::mesh::MetaData &meta)
   {
-    const stk::mesh::EntityRank element_rank = stk::topology::ELEMENT_RANK;
-
     const Ioss::ElementBlockContainer& elem_blocks = region.get_element_blocks();
-    stk::io::default_part_processing(elem_blocks, meta, element_rank);
+    stk::io::default_part_processing(elem_blocks, meta);
 
     // Parts were created above, now handle element block specific
     // information (topology, attributes, ...);
@@ -471,7 +469,7 @@ namespace stk_example_io {
   void process_nodesets(Ioss::Region &region, stk::mesh::MetaData &meta)
   {
     const Ioss::NodeSetContainer& node_sets = region.get_nodesets();
-    stk::io::default_part_processing(node_sets, meta, stk::topology::NODE_RANK);
+    stk::io::default_part_processing(node_sets, meta);
 
     /** \todo REFACTOR should "distribution_factor" be a default field
      * that is automatically declared on all objects that it exists
@@ -515,7 +513,7 @@ namespace stk_example_io {
     Ioss::SideSet *fs = dynamic_cast<Ioss::SideSet *>(sset);
     assert(fs != NULL);
     const Ioss::SideBlockContainer& blocks = fs->get_side_blocks();
-    stk::io::default_part_processing(blocks, meta, sset_rank);
+    stk::io::default_part_processing(blocks, meta);
 
     stk::mesh::Part* const fs_part = meta.get_part(sset->name());
     STKIORequire(fs_part != NULL);
@@ -565,7 +563,7 @@ namespace stk_example_io {
     const stk::mesh::EntityRank side_rank = meta.side_rank();
 
     const Ioss::SideSetContainer& side_sets = region.get_sidesets();
-    stk::io::default_part_processing(side_sets, meta, side_rank);
+    stk::io::default_part_processing(side_sets, meta);
 
     for(Ioss::SideSetContainer::const_iterator it = side_sets.begin();
 	it != side_sets.end(); ++it) {
@@ -655,7 +653,7 @@ namespace stk_example_io {
         for (Ioss::NameList::const_iterator I = names.begin(); I != names.end(); ++I) {
           if (*I == "attribute" && names.size() > 1)
             continue;
-          stk::mesh::FieldBase *field = meta.get_field<stk::mesh::FieldBase>(stk::topology::ELEMENT_RANK, *I);
+          stk::mesh::FieldBase *field = meta.get_field(stk::topology::ELEMENT_RANK, *I);
           stk::io::field_data_from_ioss(bulk, field, elements, entity, *I);
 
         }
@@ -688,7 +686,7 @@ namespace stk_example_io {
         for(int i=0; i<node_count; ++i) {
           nodes[i] = bulk.get_entity( stk::topology::NODE_RANK, node_ids[i] );
           if (bulk.is_valid(nodes[i])) {
-            bulk.declare_entity(stk::topology::NODE_RANK, node_ids[i], add_parts );
+            bulk.declare_node(node_ids[i], add_parts );
           }
         }
 
@@ -745,13 +743,13 @@ namespace stk_example_io {
             int side_ordinal = elem_side[is*2+1] - 1 ;
 
             stk::mesh::Entity side = stk::mesh::Entity();
-	    int64_t side_id = ten * elem_side[is*2+0] + elem_side[is*2+1];
             if (side_rank == 2) {
-              side = stk::mesh::declare_element_side(bulk, side_id, elem, side_ordinal);
+              side = bulk.declare_element_side(elem, side_ordinal, add_parts);
             } else {
+              int64_t side_id = ten * elem_side[is*2+0] + elem_side[is*2+1];
               side = stk::mesh::declare_element_edge(bulk, side_id, elem, side_ordinal);
+              bulk.change_entity_parts( side, add_parts );
             }
-            bulk.change_entity_parts( side, add_parts );
             sides[is] = side;
           } else {
             sides[is] = stk::mesh::Entity();
