@@ -216,6 +216,11 @@ namespace stk {
       m_region->field_describe(Ioss::Field::TRANSIENT, &names);
     }
 
+    FieldNameToPartVector InputFile::get_var_names(Ioss::EntityType type, stk::mesh::MetaData& meta)
+    {
+        return stk::io::get_var_names(*m_region.get(), type, meta);
+    }
+
     void InputFile::add_all_mesh_fields_as_input_fields(stk::mesh::MetaData &meta, MeshField::TimeMatchOption tmo)
     {
       stk::io::define_input_fields(*m_region.get(),  meta);
@@ -587,5 +592,73 @@ namespace stk {
       return time_read;
     }
 
+
+    double InputFile::read_defined_input_fields_at_step(int step,
+                                                std::vector<stk::io::MeshField> *missingFields,
+                                                stk::mesh::BulkData &bulk)
+    {
+        ThrowErrorMsgIf(step <= 0,
+                        "ERROR: Invalid step (" << step << ") requested. Value must be greater than zero.");
+
+        ThrowErrorMsgIf (Teuchos::is_null(m_region),
+                         "There is no Input mesh/restart region associated with this Mesh Data.");
+
+        Ioss::Region *region = m_region.get();
+
+        int step_count = region->get_property("state_count").get_int();
+
+        ThrowErrorMsgIf(step_count == 0,
+                        "ERROR: Input database '" << region->get_database()->get_filename()
+                        << "' has no transient data.");
+
+        ThrowErrorMsgIf(step > step_count,
+                        "ERROR: Input database '" << region->get_database()->get_filename()
+                        << "'. Step " << step << " was specified, but database only has "
+                        << step_count << " steps.");
+
+        // Sort fields to ensure they are iterated in the same order on all processors.
+        std::sort(m_fields.begin(), m_fields.end(), meshFieldSort);
+
+        bool ignore_missing_fields = (missingFields != NULL);
+
+        if (!m_fieldsInitialized) {
+            std::vector<stk::io::MeshField>::iterator I = m_fields.begin();
+            while (I != m_fields.end()) {
+                (*I).set_inactive(); ++I;
+            }
+
+            build_field_part_associations(bulk, missingFields);
+
+            m_fieldsInitialized = true;
+        }
+
+        double time  = region->get_state_time(step);
+        if (time < m_startTime || time > m_stopTime)
+            return 0.0;
+
+        std::vector<stk::io::MeshField>::iterator I = m_fields.begin();
+        double time_read = -1.0;
+        while (I != m_fields.end()) {
+            // NOTE: If the fields being restored have different settings, the time
+            // value can be different for each field and this will return the value
+            // of the last field.  For example, if one field is CLOSEST, one is SPECFIED,
+            // and one is TIME_INTERPOLATION, then the time value to return is
+            // ambiguous.  Also an issue if some of the fields are inactive.
+            double time_t = (*I).restore_field_data_at_step(region, bulk, step, ignore_missing_fields);
+            if ((*I).is_active()) {
+                time_read = time_t > time_read ? time_t : time_read;
+            }
+            ++I;
+        }
+
+        int current_step = region->get_current_state();
+        if (current_step != -1 && current_step != static_cast<int>(step))
+            region->end_state(current_step);
+        if (current_step != static_cast<int>(step))
+            region->begin_state(step);
+
+        return time_read;
+    }
+
   }
 }
