@@ -71,6 +71,14 @@ namespace stk {
     
     static std::string CoordinateFieldName("coordinates");
 
+    struct QaRecord
+    {
+        std::string name;
+        std::string version;
+        std::string date;
+        std::string time;
+    };
+
     // ------------------------------------------------------------------------
     struct GlobalAnyVariable {
       GlobalAnyVariable(const std::string &name, const boost::any *value, stk::util::ParameterType::Type type)
@@ -91,6 +99,7 @@ namespace impl
 		 Ioss::PropertyManager& property_manager, const Ioss::Region *input_region, char const* type = "exodus")
         : m_current_output_step(-1), m_use_nodeset_for_part_nodes_fields(false),
           m_mesh_defined(false), m_fields_defined(false), m_non_any_global_variables_defined(false),
+          m_appending_to_mesh(false),
 	  m_db_purpose(db_type), m_input_region(input_region), m_subset_selector(NULL)
       {
 	setup_output_file(filename, communicator, property_manager, type);
@@ -100,6 +109,7 @@ namespace impl
 		 DatabasePurpose db_type, const Ioss::Region *input_region)
         : m_current_output_step(-1), m_use_nodeset_for_part_nodes_fields(false),
           m_mesh_defined(false), m_fields_defined(false), m_non_any_global_variables_defined(false),
+          m_appending_to_mesh(false),
 	  m_db_purpose(db_type), m_input_region(input_region), m_subset_selector(NULL)
       {
 	m_region = ioss_output_region;
@@ -113,10 +123,10 @@ namespace impl
 	stk::io::delete_selector_property(*m_region);
       }
 
-      void write_output_mesh(const stk::mesh::BulkData& bulk_data);
+      void write_output_mesh(const stk::mesh::BulkData& bulk_data, const std::vector<std::vector<int>> &attributeOrdering);
       void flush_output() const;
       void add_field(stk::mesh::FieldBase &field, const std::string &alternate_name);
-
+      bool has_global(const std::string &globalVarName) const;
       void add_global(const std::string &variableName, const boost::any &value, stk::util::ParameterType::Type type);
       void add_global_ref(const std::string &variableName, const boost::any *value, stk::util::ParameterType::Type type);
       void add_global(const std::string &variableName, Ioss::Field::BasicType dataType);
@@ -130,11 +140,11 @@ namespace impl
       void write_global(const std::string &variableName, std::vector<double>& globalVarData);
       void write_global(const std::string &variableName, std::vector<int>& globalVarData);
 
-      void begin_output_step(double time, const stk::mesh::BulkData& bulk_data);
+      void begin_output_step(double time, const stk::mesh::BulkData& bulk_data, const std::vector<std::vector<int>> &attributeOrdering);
       void end_output_step();
 
       int write_defined_output_fields(const stk::mesh::BulkData& bulk_data);
-      int process_output_request(double time, const stk::mesh::BulkData& bulk_data);
+      int process_output_request(double time, const stk::mesh::BulkData& bulk_data, const std::vector<std::vector<int>> &attributeOrdering);
 
       void set_subset_selector(Teuchos::RCP<stk::mesh::Selector> my_selector);
 
@@ -142,7 +152,7 @@ namespace impl
       void use_nodeset_for_part_nodes_fields(bool true_false);
       
     private:
-      void define_output_fields(const stk::mesh::BulkData& bulk_data);
+      void define_output_fields(const stk::mesh::BulkData& bulk_data, const std::vector<std::vector<int>> &attributeOrdering);
       void setup_output_file(const std::string &filename, MPI_Comm communicator,
 			     Ioss::PropertyManager &property_manager,
                              char const* type = "exodus");
@@ -152,6 +162,7 @@ namespace impl
       bool m_mesh_defined;
       bool m_fields_defined;
       bool m_non_any_global_variables_defined;
+      bool m_appending_to_mesh;
       DatabasePurpose m_db_purpose;
       const Ioss::Region* m_input_region;
       Teuchos::RCP<stk::mesh::Selector> m_subset_selector;
@@ -412,6 +423,11 @@ namespace impl
       // the above-declared 'populate_mesh()' method.
       void populate_field_data();
 
+      FieldNameToPartVector get_nodal_var_names();
+      FieldNameToPartVector get_elem_var_names();
+      FieldNameToPartVector get_nodeset_var_names();
+      FieldNameToPartVector get_sideset_var_names();
+
       // For all transient fields on the mesh database:
       // - declare a stk_field of the same name,
       // - add the field as in input field for the mesh 
@@ -433,7 +449,8 @@ namespace impl
       // not found.
       double read_defined_input_fields(int step,
 				       std::vector<stk::io::MeshField> *missing=NULL);
-
+      double read_defined_input_fields_at_step(int step,
+                                       std::vector<stk::io::MeshField> *missing=NULL);
       // For all transient input fields defined, read the data at the
       // specified database time 'time' and populate the stk data
       // structures with those values.  
@@ -457,6 +474,8 @@ namespace impl
       bool read_input_field(stk::io::MeshField &mf);
       
       void get_global_variable_names(std::vector<std::string> &names);
+      size_t get_global_variable_length(const std::string& name);
+
       bool get_global(const std::string &variableName,
 		      boost::any &value,
 		      stk::util::ParameterType::Type type,
@@ -522,7 +541,8 @@ namespace impl
       void add_field(size_t output_file_index,
 		     stk::mesh::FieldBase &field,
 		     const std::string &db_name);
-
+      bool has_global(size_t output_file_index,
+                      const std::string &globalVarName) const;
       void add_global_ref(size_t output_file_index,
 			  const std::string &variableName,
 			  const boost::any *value,
@@ -638,6 +658,17 @@ namespace impl
       void set_option_to_not_collapse_sequenced_fields();
       int get_num_time_steps();
       double get_max_time();
+      std::vector<double> get_time_steps();
+      void set_max_num_steps_before_overwrite(size_t outputFileIndex, int maxNumStepsInFile);
+
+      void set_name_and_version_for_qa_record(size_t outputFileIndex, const std::string &codeName, const std::string &codeVersion);
+      void add_qa_records(size_t outputFileIndex, const std::vector<QaRecord> &qaRecords);
+      void add_info_records(size_t outputFileIndex, const std::vector<std::string> &infoRecords);
+      std::vector<QaRecord> get_qa_records();
+      std::vector<std::string> get_info_records();
+      stk::mesh::FieldVector get_ordered_attribute_fields(const stk::mesh::Part *blockPart) const;
+      const std::vector<std::vector<int>> & get_attribute_field_ordering_stored_by_part_ordinal() const;
+      void set_attribute_field_ordering_stored_by_part_ordinal(const std::vector<std::vector<int>> &ordering);
 
       //-END
     protected:
@@ -683,17 +714,22 @@ namespace impl
       Teuchos::RCP<stk::mesh::MetaData>  m_meta_data;
       Teuchos::RCP<stk::mesh::BulkData>  m_bulk_data;
 
+
       Teuchos::RCP<stk::mesh::Selector> m_deprecated_selector;
 
       const stk::mesh::ConnectivityMap* m_connectivity_map;
-
+    protected:
+      std::vector<std::vector<int>> attributeFieldOrderingByPartOrdinal;
       std::vector<Teuchos::RCP<impl::OutputFile> > m_output_files;
+    private:
       std::vector<Teuchos::RCP<impl::Heartbeat> > m_heartbeat;
     protected:
       std::vector<Teuchos::RCP<InputFile> > m_input_files;
     private:
       StkMeshIoBroker(const StkMeshIoBroker&); // Do not implement
       StkMeshIoBroker& operator=(const StkMeshIoBroker&); // Do not implement
+    void store_attribute_field_ordering();
+
     protected:
       size_t m_active_mesh_index;
       SideSetFaceCreationBehavior m_sideset_face_creation_behavior;
