@@ -8,41 +8,6 @@
 namespace stk {
 namespace mesh {
 
-
-///////////////////////////////////////////////////////////////////////////////
-// The following get_connectivity API is designed for *internal* STK_Mesh usage
-// to support algorithms that must always be able to get connectivity even
-// when it is disabled in the connectivity map. These functions are designed
-// to support connectivity-retrieval callsites that need to work regardless of
-// the connectivity map. The scratch vectors will be used for allocation when it
-// is needed; otherwise, they are ignored. The overloads are provided for the
-// common cases where not all connectivity data is needed.
-///////////////////////////////////////////////////////////////////////////////
-
-size_t get_connectivity( const BulkData & mesh,
-                         Entity entity,
-                         EntityRank to_rank,
-                         EntityVector & entity_scratch_storage );
-
-size_t get_connectivity( const BulkData & mesh,
-                         Entity entity, EntityRank to_rank,
-                         EntityVector & entity_scratch_storage,
-                         std::vector<ConnectivityOrdinal> & ordinal_scratch_storage );
-
-size_t get_connectivity( const BulkData & mesh,
-                         Entity entity,
-                         EntityRank to_rank,
-                         EntityVector & entity_scratch_storage,
-                         std::vector<Permutation> & permutation_scratch_storage );
-
-size_t get_connectivity( const BulkData & mesh,
-                         Entity entity,
-                         EntityRank to_rank,
-                         EntityVector & entity_scratch_storage,
-                         std::vector<ConnectivityOrdinal> & ordinal_scratch_storage,
-                         std::vector<Permutation> & permutation_scratch_storage );
-
-
  /** \brief  Comparator functor for entities compares the entities' keys */
 #ifdef SIERRA_MIGRATION
 inline
