@@ -53,7 +53,7 @@ namespace stk {
 namespace mesh {
 
 typedef std::set<Entity , EntityLess> EntitySet;
-typedef std::set<EntityKeyProc> EntityProcSet;
+typedef std::set<EntityKeyProc> EntityKeyProcSet;
 
 namespace {
 
@@ -94,16 +94,12 @@ void find_local_closure (const BulkData& mesh, std::set<Entity,EntityLess> & clo
   }
 }
 
-void construct_communication_set( const BulkData & bulk, const std::set<Entity,EntityLess> & closure, EntityProcSet & communication_set)
+void construct_communication_set( const BulkData & bulk, const std::set<Entity,EntityLess> & closure, EntityKeyProcSet & communication_set)
 {
   if (bulk.parallel_size() < 2) return;
 
   std::vector<int> commProcs;
-  for ( std::set<Entity,EntityLess>::const_iterator
-        i = closure.begin(); i != closure.end(); ++i) {
-
-    Entity entity = *i;
-
+  for ( Entity entity : closure ) {
     const bool owned = bulk.parallel_rank() == bulk.parallel_owner_rank(entity);
     const bool shared = bulk.bucket(entity).shared();
 
@@ -120,33 +116,19 @@ void construct_communication_set( const BulkData & bulk, const std::set<Entity,E
   }
 }
 
-//size_t count_ghost_entities( const BulkData & bulk, const EntityVector & entities)
-//{
-//  size_t num_ghost_entities = 0;
-//
-//  for ( EntityVector::const_iterator
-//        i = entities.begin(); i != entities.end(); ++i ) {
-//    if ( ! bulk.owned_closure(*i) ) {
-//      ++num_ghost_entities;
-//    }
-//  }
-//
-//  return num_ghost_entities;
-//}
-
 }
 
 
 
 void find_closure( const BulkData & bulk,
-    const std::vector< Entity> & entities,
-    std::vector< Entity> & entities_closure)
+    const EntityVector& entities,
+    EntityVector& entities_closure)
 {
 
   entities_closure.clear();
 
 
-  EntityProcSet send_list;
+  EntityKeyProcSet send_list;
   EntityLess entless(bulk);
   std::set<Entity,EntityLess>     temp_entities_closure(entless);
 
@@ -160,18 +142,16 @@ void find_closure( const BulkData & bulk,
   CommSparse commSparse( bulk.parallel() );
 
   //pack send_list for sizing
-  for ( EntityProcSet::const_iterator
-      ep = send_list.begin() ; ep != send_list.end() ; ++ep ) {
-    commSparse.send_buffer( ep->second).pack<EntityKey>(ep->first);
+  for ( const EntityKeyProc& ep : send_list ) {
+    commSparse.send_buffer( ep.second).pack<EntityKey>(ep.first);
   }
 
 
   commSparse.allocate_buffers();
 
   //pack send_list
-  for ( EntityProcSet::const_iterator
-      ep = send_list.begin() ; ep != send_list.end() ; ++ep ) {
-    commSparse.send_buffer( ep->second).pack<EntityKey>(ep->first);
+  for ( const EntityKeyProc& ep : send_list ) {
+    commSparse.send_buffer( ep.second).pack<EntityKey>(ep.first);
   }
 
   commSparse.communicate();
