@@ -2,6 +2,7 @@
 #include <stddef.h>                     // for size_t, nullptr
 #include <string>                       // for string
 #include <stk_util/parallel/ParallelReduceBool.hpp>
+#include <stk_util/parallel/DebugTool.hpp>
 #include <map>
 #include <string>
 #include "BulkData.hpp"
@@ -15,7 +16,6 @@
 #include "stk_mesh/baseImpl/MeshImplUtils.hpp"
 #include "stk_mesh/baseImpl/elementGraph/BulkDataIdMapper.hpp"
 #include "stk_mesh/baseImpl/elementGraph/ElemGraphCoincidentElems.hpp"
-#include "stk_util/parallel/DebugTool.hpp"
 
 namespace stk { namespace mesh {
 
@@ -48,10 +48,10 @@ void fill_split_coincident_connections(const stk::mesh::BulkData & bulk, const i
     }
 }
 
-SideNodeToReceivedElementDataMap get_element_sides_from_other_procs(stk::mesh::BulkData & bulkData, SideIdPool & sideIdPool)
+SideNodeToReceivedElementDataMap get_element_sides_from_other_procs(stk::mesh::BulkData & bulkData)
 {
     impl::ElemSideToProcAndFaceId elementSideIdsToSend = impl::gather_element_side_ids_to_send(bulkData);
-    impl::fill_suggested_side_ids(sideIdPool, elementSideIdsToSend);
+    impl::fill_suggested_side_ids(bulkData, elementSideIdsToSend);
     SharedSidesCommunication sharedSidesCommunication(bulkData, elementSideIdsToSend);
     return sharedSidesCommunication.get_received_element_sides();
 }
@@ -63,6 +63,7 @@ SplitCoincidentInfo get_split_coincident_elements_from_received_element_sides(st
     impl::ParallelElementDataVector localElementsAttachedToReceivedNodes;
     for (SideNodeToReceivedElementDataMap::value_type & receivedElementData: elementSidesReceived)
     {
+        localElementsAttachedToReceivedNodes.clear();
         stk::mesh::impl::ParallelElementDataVector &parallelElementDatas = receivedElementData.second;
         impl::get_elements_connected_via_sidenodes<impl::ParallelElementData>(bulkData,
                                                                               parallelElementDatas[0].get_element_identifier(),
@@ -77,13 +78,7 @@ SplitCoincidentInfo get_split_coincident_elements_from_received_element_sides(st
 
 SplitCoincidentInfo get_split_coincident_elements(stk::mesh::BulkData& bulkData)
 {
-    SideIdPool sideIdPool(bulkData);
-    const int maxNumSidesPerElement = 6;
-    const int numSidesNeededIfCoincident = maxNumSidesPerElement + 2;
-    unsigned numSideIdsNeeded = numSidesNeededIfCoincident * stk::mesh::count_selected_entities(bulkData.mesh_meta_data().locally_owned_part(), bulkData.buckets(stk::topology::ELEM_RANK));
-    sideIdPool.generate_initial_ids(numSideIdsNeeded);
-
-    SideNodeToReceivedElementDataMap elementSidesReceived = get_element_sides_from_other_procs(bulkData, sideIdPool);
+    SideNodeToReceivedElementDataMap elementSidesReceived = get_element_sides_from_other_procs(bulkData);
 
     impl::ElementLocalIdMapper localIdMapper;
     localIdMapper.initialize(bulkData);
