@@ -300,7 +300,6 @@ void get_entities_through_relations(
  */
 void induced_part_membership(const BulkData& mesh,
                              const Entity entity ,
-                             const OrdinalVector & omit ,
                              OrdinalVector & induced_parts);
 
 //----------------------------------------------------------------------
@@ -361,7 +360,6 @@ inline
 RelationType
 back_relation_type(const RelationType relType)
 {
-  /* %TRACE[NONE]% */  /* %TRACE% */
   switch(relType) {
   case RelationType::USES:
     return RelationType::USED_BY;
@@ -441,6 +439,9 @@ void Relation::setMeshObj(Entity object, EntityRank object_rank )
   m_target_entity = object;
 }
 
+// Find relation from mesh_obj to an Entity of certain rank by relation ordinal
+stk::mesh::Entity find_by_ordinal(stk::mesh::Entity mesh_obj, stk::mesh::EntityRank rank, size_t ordinal, const stk::mesh::BulkData& mesh);
+
 #endif
 
 } // namespace mesh
