@@ -76,14 +76,21 @@ public:
    */
   const BucketVector & buckets( EntityRank rank ) const
   {
-    ThrowAssertMsg( rank < m_buckets.size(), "Invalid entity rank " << rank );
+    static const BucketVector emptyBucketVector;
 
-    if (m_need_sync_from_partitions[rank])
+    if( rank < m_buckets.size() )
     {
-      const_cast<BucketRepository *>(this)->sync_from_partitions(rank);
-    }
+      if (m_need_sync_from_partitions[rank])
+      {
+        const_cast<BucketRepository *>(this)->sync_from_partitions(rank);
+      }
 
-    return m_buckets[ rank ];
+      return m_buckets[ rank ];
+    }
+    else
+    {
+      return emptyBucketVector;
+    }
   }
 
   BulkData& mesh() const { return m_mesh; }
@@ -155,6 +162,8 @@ private:
 
   void sync_bucket_ids(EntityRank entity_rank);
 
+  void ensure_data_structures_sized();
+
   BulkData & m_mesh ; // Associated Bulk Data Aggregate
 
   // Vector of bucket pointers by rank.  This is now a cache and no longer the primary
