@@ -48,11 +48,9 @@ void runTwoSpheresTest(stk::search::SearchMethod searchMethod, const double dist
     MPI_Comm comm = MPI_COMM_WORLD;
     int procId = stk::parallel_machine_rank(comm);
 
-    std::vector< std::pair<Sphere,Ident> > boxVector1;
-    boxVector1.push_back(generateBoundingVolume<Sphere>(0, 0, 0, radius, 1, procId));
+    std::vector< std::pair<Sphere,Ident> > boxVector1 = { generateBoundingVolume<Sphere>(0, 0, 0, radius, 1, procId) };
 
-    std::vector< std::pair<Sphere,Ident> > boxVector2;
-    boxVector2.push_back(generateBoundingVolume<Sphere>(distanceBetweenSphereCenters, 0, 0, radius, 2, procId));
+    std::vector< std::pair<Sphere,Ident> > boxVector2 = { generateBoundingVolume<Sphere>(distanceBetweenSphereCenters, 0, 0, radius, 2, procId) };
 
     stk::search::coarse_search(boxVector1, boxVector2, searchMethod, comm, boxIdPairResults);
 }
@@ -91,6 +89,19 @@ TEST(Verification, OverlappingSpheres_OCTREE)
     ASSERT_EQ(1u, boxIdPairResults.size());
 }
 
+TEST(Verification, OverlappingSpheres_KDTREE)
+{
+    if (numProcessors() > 1) {
+        return;
+    }
+
+    double distanceBetweenSphereCenters = 0.5;
+    std::vector< std::pair<Ident, Ident> > boxIdPairResults;
+    runTwoSpheresTest(stk::search::KDTREE, distanceBetweenSphereCenters, radiusOfOneHalf, boxIdPairResults);
+
+    ASSERT_EQ(1u, boxIdPairResults.size());
+}
+
 TEST(Verification, NonOverlappingSpheres_BOOST_RTREE)
 {
     double distanceBetweenSphereCenters = 2.0;
@@ -109,6 +120,15 @@ TEST(Verification, NonOverlappingSpheres_OCTREE)
     ASSERT_EQ(0u, boxIdPairResults.size());
 }
 
+TEST(Verification, NonOverlappingSpheres_KDTREE)
+{
+    double distanceBetweenSphereCenters = 2.0;
+    std::vector< std::pair<Ident, Ident> > boxIdPairResults;
+    runTwoSpheresTest(stk::search::KDTREE, distanceBetweenSphereCenters, radiusOfOneHalf, boxIdPairResults);
+
+    ASSERT_EQ(0u, boxIdPairResults.size());
+}
+
 TEST(Verification, JustEdgeOverlappingSpheres_BOOST_RTREE)
 {
     if (numProcessors() > 1) {
@@ -135,6 +155,19 @@ TEST(Verification, JustEdgeOverlappingSpheres_OCTREE)
     ASSERT_EQ(1u, boxIdPairResults.size());
 }
 
+TEST(Verification, JustEdgeOverlappingSpheres_KDTREE)
+{
+    if (numProcessors() > 1) {
+        return;
+    }
+
+    double distanceBetweenSphereCenters = 0.999999999;
+    std::vector< std::pair<Ident, Ident> > boxIdPairResults;
+    runTwoSpheresTest(stk::search::KDTREE, distanceBetweenSphereCenters, radiusOfOneHalf, boxIdPairResults);
+
+    ASSERT_EQ(1u, boxIdPairResults.size());
+}
+
 TEST(Verification, NotQuiteEdgeOverlappingSpheres_BOOST_RTREE)
 {
     double distanceBetweenSphereCenters = 1.0000000001;
@@ -153,6 +186,15 @@ TEST(Verification, NotQuiteEdgeOverlappingSpheres_OCTREE)
     ASSERT_EQ(0u, boxIdPairResults.size());
 }
 
+TEST(Verification, NotQuiteEdgeOverlappingSpheres_KDTREE)
+{
+    double distanceBetweenSphereCenters = 1.0000000001;
+    std::vector< std::pair<Ident, Ident> > boxIdPairResults;
+    runTwoSpheresTest(stk::search::KDTREE, distanceBetweenSphereCenters, radiusOfOneHalf, boxIdPairResults);
+
+    ASSERT_EQ(0u, boxIdPairResults.size());
+}
+
 template<class InnerBoundingBoxType, class OuterBoundingBoxType>
 void runBoxOverlappingEightSurroundingBoxes(stk::search::SearchMethod searchMethod, const double radius, const unsigned numExpectedResults)
 {
@@ -209,6 +251,12 @@ TEST(Verification, SphereOverlappingEightSurroundingSpheres_OCTREE)
     const unsigned numExpectedResults = 8;
     runBoxOverlappingEightSurroundingBoxes<Sphere,Sphere>(stk::search::OCTREE, radius, numExpectedResults);
 }
+TEST(Verification, SphereOverlappingEightSurroundingSpheres_KDTREE)
+{
+    const double radius = 0.708;
+    const unsigned numExpectedResults = 8;
+    runBoxOverlappingEightSurroundingBoxes<Sphere,Sphere>(stk::search::KDTREE, radius, numExpectedResults);
+}
 
 TEST(Verification, SphereOverlappingNoSurroundingPoints_BOOST_RTREE)
 {
@@ -252,6 +300,27 @@ TEST(Verification, SphereOverlappingEightSurroundingPoints_OCTREE)
     runBoxOverlappingEightSurroundingBoxes<Sphere,Point>(stk::search::OCTREE, radius, numExpectedResults);
 }
 
+TEST(Verification, SphereOverlappingNoSurroundingPoints_KDTREE)
+{
+    const double radius = 0.99;
+    const unsigned numExpectedResults = 0;
+    runBoxOverlappingEightSurroundingBoxes<Sphere,Point>(stk::search::KDTREE, radius, numExpectedResults);
+}
+
+TEST(Verification, SphereOverlappingFourSurroundingPoints_KDTREE)
+{
+    const double radius = 1.41;
+    const unsigned numExpectedResults = 4;
+    runBoxOverlappingEightSurroundingBoxes<Sphere,Point>(stk::search::KDTREE, radius, numExpectedResults);
+}
+
+TEST(Verification, SphereOverlappingEightSurroundingPoints_KDTREE)
+{
+    const double radius = 1.42;
+    const unsigned numExpectedResults = 8;
+    runBoxOverlappingEightSurroundingBoxes<Sphere,Point>(stk::search::KDTREE, radius, numExpectedResults);
+}
+
 TEST(Verification, SphereOverlappingFourOfEightSurroundingSpheres_BOOST_RTREE)
 {
     const double radius = 0.706;
@@ -266,6 +335,13 @@ TEST(Verification, SphereOverlappingFourOfEightSurroundingSpheres_OCTREE)
     runBoxOverlappingEightSurroundingBoxes<Sphere,Sphere>(stk::search::OCTREE, radius, numExpectedResults);
 }
 
+TEST(Verification, SphereOverlappingFourOfEightSurroundingSpheres_KDTREE)
+{
+    const double radius = 0.706;
+    const unsigned numExpectedResults = 4;
+    runBoxOverlappingEightSurroundingBoxes<Sphere,Sphere>(stk::search::KDTREE, radius, numExpectedResults);
+}
+
 TEST(Verification, BoxOverlappingNoSurroundingPoints_BOOST_RTREE)
 {
     const double radius = 0.99;
@@ -280,6 +356,13 @@ TEST(Verification, BoxOverlappingNoSurroundingPoints_OCTREE)
     runBoxOverlappingEightSurroundingBoxes<StkBox,Point>(stk::search::OCTREE, radius, numExpectedResults);
 }
 
+TEST(Verification, BoxOverlappingNoSurroundingPoints_KDTREE)
+{
+    const double radius = 0.99;
+    const unsigned numExpectedResults = 0;
+    runBoxOverlappingEightSurroundingBoxes<StkBox,Point>(stk::search::KDTREE, radius, numExpectedResults);
+}
+
 TEST(Verification, BoxOverlappingEightSurroundingPoints_BOOST_RTREE)
 {
     const double radius = 1.01;
@@ -294,6 +377,13 @@ TEST(Verification, BoxOverlappingEightSurroundingPoints_OCTREE)
     runBoxOverlappingEightSurroundingBoxes<StkBox,Point>(stk::search::OCTREE, radius, numExpectedResults);
 }
 
+TEST(Verification, BoxOverlappingEightSurroundingPoints_KDTREE)
+{
+    const double radius = 1.01;
+    const unsigned numExpectedResults = 8;
+    runBoxOverlappingEightSurroundingBoxes<StkBox,Point>(stk::search::KDTREE, radius, numExpectedResults);
+}
+
 TEST(Verification, PointOverlappingNoSurroundingBoxes_BOOST_RTREE)
 {
     const double radius = 0.99;
@@ -322,6 +412,20 @@ TEST(Verification, PointOverlappingEightSurroundingBoxes_OCTREE)
     runBoxOverlappingEightSurroundingBoxes<Point,StkBox>(stk::search::OCTREE, radius, numExpectedResults);
 }
 
+TEST(Verification, PointOverlappingNoSurroundingBoxes_KDTREE)
+{
+    const double radius = 0.99;
+    const unsigned numExpectedResults = 0;
+    runBoxOverlappingEightSurroundingBoxes<Point,StkBox>(stk::search::KDTREE, radius, numExpectedResults);
+}
+
+TEST(Verification, PointOverlappingEightSurroundingBoxes_KDTREE)
+{
+    const double radius = 1.01;
+    const unsigned numExpectedResults = 8;
+    runBoxOverlappingEightSurroundingBoxes<Point,StkBox>(stk::search::KDTREE, radius, numExpectedResults);
+}
+
 enum Axis
 {
     xDim, yDim, zDim
@@ -398,6 +502,11 @@ TEST(Verification, LineOfSpheres_OCTREE)
     runLineOfBoundingBoxes<Sphere>(stk::search::OCTREE, xDim);
 }
 
+TEST(Verification, LineOfSpheres_KDTREE)
+{
+    runLineOfBoundingBoxes<Sphere>(stk::search::KDTREE, xDim);
+}
+
 TEST(Verification, LineOfBoxes_BOOST_RTREE)
 {
     runLineOfBoundingBoxes<StkBox>(stk::search::BOOST_RTREE, yDim);
@@ -408,6 +517,11 @@ TEST(Verification, LineOfBoxes_OCTREE)
     runLineOfBoundingBoxes<StkBox>(stk::search::OCTREE, yDim);
 }
 
+TEST(Verification, LineOfBoxes_KDTREE)
+{
+    runLineOfBoundingBoxes<StkBox>(stk::search::KDTREE, yDim);
+}
+
 TEST(Verification, LineOfSpheresZDimension_BOOST_RTREE)
 {
     runLineOfBoundingBoxes<Sphere>(stk::search::BOOST_RTREE, zDim);
@@ -418,4 +532,9 @@ TEST(Verification, LineOfSpheresZDimension_OCTREE)
     runLineOfBoundingBoxes<Sphere>(stk::search::OCTREE, zDim);
 }
 
+TEST(Verification, LineOfSpheresZDimension_KDTREE)
+{
+    runLineOfBoundingBoxes<Sphere>(stk::search::KDTREE, zDim);
+}
+
 }
