@@ -219,7 +219,7 @@ void testCoarseSearchForAlgorithmUsingFloatAABoxes(NewSearchMethod algorithm, MP
   int num_procs = stk::parallel_machine_size(comm);
   int proc_id   = stk::parallel_machine_rank(comm);
 
-  FlaotBoxVector local_domain, local_range;
+  FloatBoxVector local_domain, local_range;
   // what if identifier is NOT unique
 
   FloatBox box;
@@ -253,12 +253,14 @@ TEST(stk_search, coarse_search_noIdentProc_boost_rtree)
   testCoarseSearchForAlgorithm_IntsForIdents(stk::search::BOOST_RTREE, MPI_COMM_WORLD);
 }
 
-#if 0
-TEST(stk_search, basic_coarse_search_octree)
-{
-  testCoarseSearchForAlgorithm_IntsForIdents(stk::search::OCTREE, MPI_COMM_WORLD);
-}
-#endif
+//  
+//  rdjamis, Dec 12, 2016: Added this test w/ KDTREE and the unit test failed,
+//  needs to be addressed. Leaving it off for the time being
+//
+// TEST(stk_search, coarse_search_noIdentProc_kdtree)
+// {
+//   testCoarseSearchForAlgorithm_IntsForIdents(stk::search::KDTREE, MPI_COMM_WORLD);
+// }
 
 TEST(stk_search, coarse_search_boost_rtree)
 {
@@ -287,7 +289,7 @@ TEST(stk_search, coarse_search_octree_using_float_aa_boxes)
 
 TEST(stk_search, coarse_search_kdtree_using_float_aa_boxes)
 {
-    testCoarseSearchForAlgorithmUsingFloatAABoxes(GTK, MPI_COMM_WORLD);
+    testCoarseSearchForAlgorithmUsingFloatAABoxes(KDTREE, MPI_COMM_WORLD);
 }
 
 void testIdentProcWithSearch(stk::search::SearchMethod searchMethod)
@@ -305,7 +307,7 @@ void testIdentProcWithSearch(stk::search::SearchMethod searchMethod)
         Ident id1(1, 0);
         Ident id2(1, 1);
 
-        FlaotBoxVector boxes;
+        FloatBoxVector boxes;
         if ( procId == 0 )
         {
           boxes.push_back(std::make_pair(box1, id1));
@@ -356,6 +358,11 @@ TEST(stk_search, coarse_search_octree_ident_proc_switch)
     testIdentProcWithSearch(stk::search::OCTREE);
 }
 
+TEST(stk_search, coarse_search_kdtree_ident_proc_switch)
+{
+    testIdentProcWithSearch(stk::search::KDTREE);
+}
+
 void testCoarseSearchOnePoint(stk::search::SearchMethod searchMethod)
 {
     typedef stk::search::IdentProc<uint64_t, unsigned> Ident;
@@ -423,10 +430,11 @@ TEST(stk_search, coarse_search_one_point_KDTREE)
     testCoarseSearchOnePoint(stk::search::KDTREE);
 }
 
-void testCoarseSearchForDeterminingSharing(stk::search::SearchMethod searchMethod)
+void testCoarseSearchForDeterminingSharingAllAllCase(stk::search::SearchMethod searchMethod)
 {
     const stk::ParallelMachine comm = MPI_COMM_WORLD;
     const int p_rank = stk::parallel_machine_rank(comm);
+    const int p_size = stk::parallel_machine_size(comm);
 
     typedef std::vector< std::pair<Sphere,Ident> > SphereVector;
 
@@ -435,15 +443,23 @@ void testCoarseSearchForDeterminingSharing(stk::search::SearchMethod searchMetho
     Point coords(1.0, 1.0, 1.0);
     double radius = 1.0e-6;
     Sphere node(coords, radius);
-    uint64_t global_id = 1000;
+    uint64_t global_id = 1000 + p_rank;
     Ident id = Ident(global_id, p_rank);
 
     source_bbox_vector.push_back(std::make_pair(node, id));
 
-    SearchResults searchResults;
-    stk::search::coarse_search(source_bbox_vector, source_bbox_vector, searchMethod, comm, searchResults);
+    const bool communicateRangeBoxInfo = true;
+    const bool dontCommunicateRangeBoxInfo = false;
 
-    EXPECT_GE(static_cast<int>(searchResults.size()), p_rank + 1);
+    SearchResults searchResults;
+    stk::search::coarse_search(source_bbox_vector, source_bbox_vector, searchMethod, comm, searchResults,
+                               communicateRangeBoxInfo);
+    EXPECT_EQ(2*p_size - 1, static_cast<int>(searchResults.size()));
+
+    searchResults.clear();
+    stk::search::coarse_search(source_bbox_vector, source_bbox_vector, searchMethod, comm, searchResults,
+                               dontCommunicateRangeBoxInfo);
+    EXPECT_EQ(p_size, static_cast<int>(searchResults.size()));
 
     std::set<int> procs;
 
@@ -463,15 +479,127 @@ void testCoarseSearchForDeterminingSharing(stk::search::SearchMethod searchMetho
     }
 }
 
-TEST(CoarseSearch, forDeterminingSharing_BOOST_RTREE)
+TEST(CoarseSearch, forDeterminingSharingAllAllCase_BOOST_RTREE)
 {
-  testCoarseSearchForDeterminingSharing(stk::search::BOOST_RTREE);
+  testCoarseSearchForDeterminingSharingAllAllCase(stk::search::BOOST_RTREE);
 }
 
-TEST(CoarseSearch, forDeterminingSharing_KDTREE)
+TEST(CoarseSearch, forDeterminingSharingAllAllCase_KDTREE)
 {
-  testCoarseSearchForDeterminingSharing(stk::search::KDTREE);
+  testCoarseSearchForDeterminingSharingAllAllCase(stk::search::KDTREE);
 }
 
 
+void testCoarseSearchForDeterminingSharingLinearAdjacentCase(stk::search::SearchMethod searchMethod,
+                                                             int numLoops = 1)
+{
+    const stk::ParallelMachine comm = MPI_COMM_WORLD;
+    const int p_rank = stk::parallel_machine_rank(comm);
+    const int p_size = stk::parallel_machine_size(comm);
+
+    typedef std::vector< std::pair<Sphere,Ident> > SphereVector;
+
+    SphereVector source_bbox_vector;
+
+    Point coords(1.0 + p_rank, 1.0, 1.0);
+    double radius = 0.6;
+    Sphere node(coords, radius);
+    uint64_t global_id = 1000 + p_rank;
+    Ident id = Ident(global_id, p_rank);
+
+    source_bbox_vector.push_back(std::make_pair(node, id));
+
+    const bool communicateRangeBoxInfo = true;
+    const bool dontCommunicateRangeBoxInfo = false;
+
+    SearchResults searchResults;
+
+    double markTime, elapsedTime, totalTime;
+    markTime = elapsedTime = totalTime = 0.0;
+
+    for (int count = 0; count < numLoops; ++count) {
+
+      const bool lastLoop = (count + 1 == numLoops);
+
+      searchResults.clear();
+      markTime = stk::wall_time();
+      stk::search::coarse_search(source_bbox_vector, source_bbox_vector, searchMethod, comm, searchResults,
+                                 communicateRangeBoxInfo);
+      totalTime += stk::wall_time() - markTime;
+
+      if (lastLoop) {
+        if (p_size == 1) {
+          EXPECT_EQ(1, static_cast<int>(searchResults.size()));
+        }
+        else {
+          const int expectedSize = ((p_rank == 0) || (p_rank == p_size - 1) ? 3 : 5);
+          EXPECT_EQ(expectedSize, static_cast<int>(searchResults.size()));
+        }
+      }
+
+      searchResults.clear();
+      markTime = stk::wall_time();
+      stk::search::coarse_search(source_bbox_vector, source_bbox_vector, searchMethod, comm, searchResults,
+                                 dontCommunicateRangeBoxInfo);
+      totalTime += stk::wall_time() - markTime;
+
+      if (lastLoop) {
+        if (p_size == 1) {
+          EXPECT_EQ(1, static_cast<int>(searchResults.size()));
+        }
+        else {
+          const int expectedSize = ((p_rank == 0) || (p_rank == p_size - 1) ? 2 : 3);
+          EXPECT_EQ(expectedSize, static_cast<int>(searchResults.size()));
+        }
+      }
+    }
+
+    if (p_rank == 0) {
+      double avgTime =  totalTime / numLoops;
+      std::cout << "Average search time measured on rank 0 of " << p_size << " ranks is " << avgTime << " through " << numLoops << " loops" << std::endl;
+    }
+
+    // Do more correctness checking after the last loop.
+    std::set<int> procs;
+    for(size_t i=0;i<searchResults.size();++i)
+    {
+      procs.insert(searchResults[i].second.proc());
+      procs.insert(searchResults[i].first.proc());
+    }
+    std::set<int>::iterator iter = procs.begin();
+
+    int minNeighbor = p_rank - 1;
+    int maxNeighbor = p_rank + 1;
+
+    int procCounter = 0;
+    for (;iter!=procs.end();++iter)
+    {
+      EXPECT_LE(minNeighbor, *iter);
+      EXPECT_GE(maxNeighbor, *iter);
+      ++procCounter;
+    }
+    if (p_size == 1) {
+      EXPECT_EQ(1, procCounter);
+    }
+    else {
+      const int expectedCount = ((p_rank == 0) || (p_rank == p_size - 1) ? 2 : 3);
+      EXPECT_EQ(expectedCount, static_cast<int>(procCounter));
+    }
+}
+
+TEST(CoarseSearch, forDeterminingSharingLinearAdjacentCase_BOOST_RTREE)
+{
+  testCoarseSearchForDeterminingSharingLinearAdjacentCase(stk::search::BOOST_RTREE);
+}
+
+TEST(CoarseSearch, forDeterminingSharingLinearAdjacentCase_KDTREE)
+{
+  testCoarseSearchForDeterminingSharingLinearAdjacentCase(stk::search::KDTREE);
+}
+
+TEST(CoarseSearchScaling, forDeterminingSharingLinearAdjacentCase_KDTREE)
+{
+  testCoarseSearchForDeterminingSharingLinearAdjacentCase(stk::search::KDTREE, 1000);
+}
+
 } //namespace
