@@ -171,7 +171,7 @@ void verbose_print_topology(std::ostream &out, topology t)
 
   out << std::boolalpha;
 
-  out << t << std::endl;;
+  out << t << std::endl;
   out << std::setw(shiftwidth) << "is valid: " << t.is_valid() << std::endl;
   out << std::setw(shiftwidth) << "base: " << t.base() << std::endl;
   out << std::setw(shiftwidth) << "is shell: " << t.is_shell() << std::endl;
