@@ -38,20 +38,13 @@
 
 #include <boost/utility.hpp>
 
-//
-// Set some default values GPU support
-//
-#  ifndef BOOST_GPU_ENABLED
-#  define BOOST_GPU_ENABLED
-#  endif
-
 namespace stk { namespace topology_detail {
 
 #ifdef __CUDACC__
 #pragma hd_warning_disable
 #endif
 template <typename Topology, typename NodeArrayA, typename NodeArrayB, typename Node>
-BOOST_GPU_ENABLED inline
+inline
 typename boost::enable_if_c< (Topology::num_permutations > 0u), std::pair<bool,unsigned> >::type
 equivalent_helper(Topology, const NodeArrayA &a, const NodeArrayB &b, Node)
 {
@@ -70,7 +63,7 @@ equivalent_helper(Topology, const NodeArrayA &a, const NodeArrayB &b, Node)
 #pragma hd_warning_disable
 #endif
 template <typename Topology, typename NodeArrayA, typename NodeArrayB, typename Node>
-BOOST_GPU_ENABLED inline
+inline
 typename boost::enable_if_c< (Topology::num_permutations == 0u), std::pair<bool,unsigned> >::type
 equivalent_helper(Topology, const NodeArrayA &a, const NodeArrayB &b, Node)
 {
@@ -83,7 +76,7 @@ equivalent_helper(Topology, const NodeArrayA &a, const NodeArrayB &b, Node)
 #pragma hd_warning_disable
 #endif
 template <typename Topology, typename NodeArray, typename Node>
-BOOST_GPU_ENABLED inline
+inline
 typename boost::enable_if_c< (Topology::num_permutations > 0u), unsigned >::type
 lexicographical_smallest_permutation_helper(Topology, const NodeArray &nodes, bool only_positive_permutations, Node)
 {
@@ -130,7 +123,7 @@ lexicographical_smallest_permutation_helper(Topology, const NodeArray &nodes, bo
 #pragma hd_warning_disable
 #endif
 template <typename Topology, typename NodeArray, typename Node>
-BOOST_GPU_ENABLED inline
+inline
 typename boost::enable_if_c< (Topology::num_permutations > 0u), unsigned >::type
 lexicographical_smallest_permutation_preserve_polarity_helper(Topology, const NodeArray &nodes, const NodeArray &element_nodes, Node)
 {
@@ -185,7 +178,7 @@ lexicographical_smallest_permutation_preserve_polarity_helper(Topology, const No
 #pragma hd_warning_disable
 #endif
 template <typename Topology, typename NodeArray, typename Node>
-BOOST_GPU_ENABLED inline
+inline
 typename boost::enable_if_c< (Topology::num_permutations == 0u), unsigned >::type
 lexicographical_smallest_permutation_preserve_polarity_helper(Topology, const NodeArray &, const NodeArray &, Node)
 { return 0; }
@@ -194,7 +187,7 @@ lexicographical_smallest_permutation_preserve_polarity_helper(Topology, const No
 #pragma hd_warning_disable
 #endif
 template <typename Topology, typename NodeArray, typename Node>
-BOOST_GPU_ENABLED inline
+inline
 typename boost::enable_if_c< (Topology::num_permutations == 0u), unsigned >::type
 lexicographical_smallest_permutation_helper(Topology, const NodeArray &, bool , Node)
 { return 0; }
