@@ -39,11 +39,11 @@ public:
 
 protected:
     PerformanceTester(MPI_Comm comm) :
+            duration(0.0),
             enabledTimerSet(CHILDMASK1),
             rootTimer(createRootTimer("totalTestRuntime", enabledTimerSet)),
             childTimer("timed algorithm", CHILDMASK1, rootTimer),
-            communicator(comm),
-            duration(0.0)
+            communicator(comm)
     {
         rootTimer.start();
     }
@@ -56,16 +56,15 @@ protected:
     virtual void run_algorithm_to_time() = 0;
     virtual size_t get_value_to_output_as_iteration_count() = 0;
 
-protected:
+    double duration;
+
+private:
     const int CHILDMASK1 = 1;
     stk::diag::TimerSet enabledTimerSet;
     stk::diag::Timer rootTimer;
     stk::diag::Timer childTimer;
     MPI_Comm communicator;
 
-    double duration;
-
-private:
     void time_algorithm()
     {
         stk::diag::TimeBlockSynchronized timerStartSynchronizedAcrossProcessors(childTimer, communicator);
