@@ -35,7 +35,7 @@
 #include <stddef.h>                     // for size_t
 #include <ostream>                      // for basic_ostream::operator<<
 #include <stk_mesh/base/BulkData.hpp>   // for BulkData, etc
-#include <stk_mesh/fixtures/RingFixture.hpp>  // for RingFixture
+#include <stk_unit_tests/stk_mesh_fixtures/RingFixture.hpp>  // for RingFixture
 #include <stk_util/parallel/Parallel.hpp>  // for parallel_machine_rank, etc
 #include <vector>                       // for vector
 #include "mpi.h"                        // for MPI_Barrier, MPI_COMM_WORLD, etc
@@ -99,7 +99,7 @@ void testDestroy_nodes(stk::mesh::BulkData::AutomaticAuraOption autoAuraOption)
 
   ASSERT_TRUE( bulk.modification_begin() );
   for ( unsigned i = id_begin ; i < id_end ; ++i ) {
-    bulk.declare_entity( stk::topology::NODE_RANK , ids[i] , no_parts );
+    bulk.declare_node(ids[i] , no_parts );
   }
   ASSERT_TRUE( bulk.modification_end() );
 
