@@ -40,7 +40,7 @@
 #include <stk_mesh/base/Selector.hpp>   // for Selector, operator&, etc
 #include <stk_mesh/base/Types.hpp>      // for PartOrdinal, BucketVector, etc
 #include <stk_mesh/baseImpl/Partition.hpp>  // for Partition
-#include <stk_mesh/fixtures/SelectorFixture.hpp>  // for SelectorFixture
+#include <stk_unit_tests/stk_mesh_fixtures/SelectorFixture.hpp>  // for SelectorFixture
 #include <gtest/gtest.h>
 #include <vector>                       // for vector, vector<>::iterator, etc
 #include "stk_mesh/base/BulkData.hpp"   // for BulkData
@@ -103,9 +103,7 @@ addEntitiesToFixture(SelectorFixture& fixture, stk::mesh::EntityId start_id, siz
   stk::mesh::EntityId ent_id = start_id;
   for (size_t i = 0; i < num_to_add; ++i)
   {
-    stk::mesh::Entity ent =
-      fixture.m_bulk_data.declare_entity(stk::topology::NODE_RANK,
-                                         ent_id, partMembership);
+    stk::mesh::Entity ent = fixture.m_bulk_data.declare_node(ent_id, partMembership);
     collector.push_back(ent);
     ++ent_id;
   }
@@ -479,7 +477,7 @@ TEST( UnitTestPartition, Partition_testSort)
   {
     stk::mesh::impl::Partition &partition = *partitions[i];
     // check_test_partition_invariant(fix, partition);
-    partition.sort(true);
+    partition.sort(stk::mesh::impl::GlobalIdEntitySorter());
     check_test_partition_invariant(fix, partition);
   }
 
@@ -528,7 +526,7 @@ TEST( UnitTestPartition, Partition_testRemove)
     ++num_removed;
 
     // Need to sort before checking whether the invariant holds.
-    partition.sort();
+    partition.default_sort_if_needed();
 
     EXPECT_EQ(old_size,  partition.size() + num_removed);
     check_test_partition_invariant(fix, partition);
@@ -600,7 +598,7 @@ TEST( UnitTestPartition, Partition_testAdd)
   {
     size_t dst_partition_idx = (i + 1) % num_partitions;
     stk::mesh::impl::Partition &dst_partition = *partitions[dst_partition_idx];
-    stk::mesh::Entity entity = first_entities[i];;
+    stk::mesh::Entity entity = first_entities[i];
     dst_partition.add(entity);
     stk::mesh::Bucket &bkt = mesh.bucket(entity);
     double *field_data = stk::mesh::field_data(fix.m_fieldABC, bkt, 0);
@@ -615,7 +613,7 @@ TEST( UnitTestPartition, Partition_testAdd)
   for (size_t i = 0; i < num_partitions; ++i)
   {
     stk::mesh::impl::Partition &partition = *partitions[i];
-    partition.sort();
+    partition.default_sort_if_needed();
     EXPECT_EQ(old_sizes[i], partition.size());
     check_test_partition_invariant(fix, partition);
   }
@@ -672,7 +670,7 @@ TEST( UnitTestPartition, Partition_testMoveTo)
   for (size_t i = 0; i < num_data_partitions; ++i)
   {
     stk::mesh::impl::Partition &partition = *data_partitions[i];
-    partition.sort();
+    partition.default_sort_if_needed();
 
     EXPECT_EQ(old_sizes[i], partition.size());
     check_test_partition_invariant(fix, partition);
@@ -788,7 +786,7 @@ TEST( UnitTestPartition, Partition_testMoveToBetter)
   for (size_t i = 0; i < num_data_partitions; ++i)
   {
     stk::mesh::impl::Partition &partition = *data_partitions[i];
-    partition.sort();
+    partition.default_sort_if_needed();
 
     EXPECT_EQ(partition.size(), old_sizes[i]);
 
