@@ -37,9 +37,9 @@
 #include <stk_mesh/base/BulkData.hpp>   // for BulkData
 #include <stk_mesh/base/GetEntities.hpp>  // for count_selected_entities
 #include <stk_mesh/base/SkinMesh.hpp>   // for skin_mesh
-#include <stk_mesh/fixtures/HexFixture.hpp>  // for HexFixture
-#include <stk_mesh/fixtures/QuadFixture.hpp>  // for QuadFixture
-#include <stk_mesh/fixtures/TetFixture.hpp>  // for QuadFixture
+#include <stk_unit_tests/stk_mesh_fixtures/HexFixture.hpp>  // for HexFixture
+#include <stk_unit_tests/stk_mesh_fixtures/QuadFixture.hpp>  // for QuadFixture
+#include <stk_unit_tests/stk_mesh_fixtures/TetFixture.hpp>  // for QuadFixture
 #include <stk_util/parallel/ParallelReduce.hpp>  // for all_reduce_sum
 #include "gtest/gtest.h"                // for AssertHelper, EXPECT_EQ, etc
 #include "stk_mesh/base/MetaData.hpp"   // for MetaData
@@ -53,49 +53,49 @@
 #include <stk_io/StkMeshIoBroker.hpp>   // for StkMeshIoBroker
 #include <stk_mesh/baseImpl/MeshImplUtils.hpp>
 
-void put_all_faces_in_io_part(stk::mesh::BulkData &mesh, stk::mesh::Selector locally_owned, stk::mesh::Part& face_output_part)
-{
-    mesh.modification_begin();
-    stk::mesh::PartVector part_vector;
-    part_vector.push_back(&face_output_part);
-    stk::mesh::EntityVector stk_faces;
-    stk::mesh::get_entities(mesh, stk::topology::FACE_RANK, stk_faces);
-    for(size_t count = 0; count < stk_faces.size(); ++count)
-    {
-        if(locally_owned(mesh.bucket(stk_faces[count])))
-        {
-            mesh.change_entity_parts(stk_faces[count], part_vector);
-        }
-    }
-    mesh.modification_end();
-}
+//void put_all_faces_in_io_part(stk::mesh::BulkData &mesh, stk::mesh::Selector locally_owned, stk::mesh::Part& face_output_part)
+//{
+//    mesh.modification_begin();
+//    stk::mesh::PartVector part_vector;
+//    part_vector.push_back(&face_output_part);
+//    stk::mesh::EntityVector stk_faces;
+//    stk::mesh::get_entities(mesh, stk::topology::FACE_RANK, stk_faces);
+//    for(size_t count = 0; count < stk_faces.size(); ++count)
+//    {
+//        if(locally_owned(mesh.bucket(stk_faces[count])))
+//        {
+//            mesh.change_entity_parts(stk_faces[count], part_vector);
+//        }
+//    }
+//    mesh.modification_end();
+//}
 
-void put_all_elements_in_io_part(stk::mesh::BulkData &mesh, stk::mesh::Selector locally_owned, stk::mesh::Part& element_output_part)
-{
-    mesh.modification_begin();
-    stk::mesh::PartVector part_vector;
-    part_vector.push_back(&element_output_part);
-    stk::mesh::EntityVector stk_elements;
-    stk::mesh::get_entities(mesh, stk::topology::ELEMENT_RANK, stk_elements);
-    for(size_t count = 0; count < stk_elements.size(); ++count)
-    {
-        if(locally_owned(mesh.bucket(stk_elements[count])))
-        {
-            mesh.change_entity_parts(stk_elements[count], part_vector);
-        }
-    }
-    mesh.modification_end();
-}
+//void put_all_elements_in_io_part(stk::mesh::BulkData &mesh, stk::mesh::Selector locally_owned, stk::mesh::Part& element_output_part)
+//{
+//    mesh.modification_begin();
+//    stk::mesh::PartVector part_vector;
+//    part_vector.push_back(&element_output_part);
+//    stk::mesh::EntityVector stk_elements;
+//    stk::mesh::get_entities(mesh, stk::topology::ELEMENT_RANK, stk_elements);
+//    for(size_t count = 0; count < stk_elements.size(); ++count)
+//    {
+//        if(locally_owned(mesh.bucket(stk_elements[count])))
+//        {
+//            mesh.change_entity_parts(stk_elements[count], part_vector);
+//        }
+//    }
+//    mesh.modification_end();
+//}
 
-void writeStkDebuggingFile(stk::io::StkMeshIoBroker &stkMeshIoBroker, stk::mesh::BulkData &mesh, const std::string &output_name)
-{
-    stk::mesh::Part & face_output_part = mesh.mesh_meta_data().declare_part_with_topology("output_face_name", stk::topology::TRI_3);
-    stk::io::put_io_part_attribute(face_output_part);
-    put_all_faces_in_io_part(mesh, mesh.mesh_meta_data().locally_owned_part(), face_output_part);
-
-    size_t resultFileIndex = stkMeshIoBroker.create_output_mesh(output_name, stk::io::WRITE_RESULTS);
-    stkMeshIoBroker.write_output_mesh(resultFileIndex);
-}
+//void writeStkDebuggingFile(stk::io::StkMeshIoBroker &stkMeshIoBroker, stk::mesh::BulkData &mesh, const std::string &output_name)
+//{
+//    stk::mesh::Part & face_output_part = mesh.mesh_meta_data().declare_part_with_topology("output_face_name", stk::topology::TRI_3);
+//    stk::io::put_io_part_attribute(face_output_part);
+//    put_all_faces_in_io_part(mesh, mesh.mesh_meta_data().locally_owned_part(), face_output_part);
+//
+//    size_t resultFileIndex = stkMeshIoBroker.create_output_mesh(output_name, stk::io::WRITE_RESULTS);
+//    stkMeshIoBroker.write_output_mesh(resultFileIndex);
+//}
 
 template <std::size_t SIZE>
 bool check_if_one_owned_face_with_these_nodes_exists(const std::array <uint64_t, SIZE> &nodes, stk::mesh::BulkData &mesh)
@@ -170,7 +170,7 @@ void test_skin_mesh_with_hexes(stk::mesh::BulkData::AutomaticAuraOption autoAura
 
   stk::mesh::BulkData mesh(meta, MPI_COMM_WORLD, autoAuraOption);
   // node ordering for generated mesh is different than hand-crafted meshes for other unit tests below
-  stk::unit_test_util::fill_mesh_using_stk_io("generated:1x1x2", mesh);
+  stk::io::fill_mesh("generated:1x1x2", mesh);
   const int p_rank = mesh.parallel_rank();
 
   ASSERT_EQ( 0u, stk::mesh::count_selected_entities( skin_part, mesh.buckets(stk::topology::NODE_RANK)) );
@@ -890,7 +890,7 @@ void test_2_hex_2_block(stk::mesh::BulkData::AutomaticAuraOption autoAuraOption)
         stk::mesh::Part & block_2 = meta.declare_part("block_2", stk::topology::FACE_RANK);
 
         stk::mesh::BulkData mesh(meta, MPI_COMM_WORLD, autoAuraOption);
-        stk::unit_test_util::fill_mesh_using_stk_io("generated:1x1x2", mesh);
+        stk::io::fill_mesh("generated:1x1x2", mesh);
 
         ASSERT_EQ( 0u, stk::mesh::count_selected_entities( skin_part, mesh.buckets(stk::topology::NODE_RANK)) );
         ASSERT_EQ( 0u, stk::mesh::count_selected_entities( skin_part, mesh.buckets(side_rank)) );
@@ -945,7 +945,7 @@ void test_2_hex_2_block_with_second_selector(stk::mesh::BulkData::AutomaticAuraO
         stk::mesh::Part & block_2 = meta.declare_part("block_2", stk::topology::FACE_RANK);
 
         stk::mesh::BulkData mesh(meta, MPI_COMM_WORLD, autoAuraOption);
-        stk::unit_test_util::fill_mesh_using_stk_io("generated:1x1x2", mesh);
+        stk::io::fill_mesh("generated:1x1x2", mesh);
 
         ASSERT_EQ( 0u, stk::mesh::count_selected_entities( skin_part, mesh.buckets(stk::topology::NODE_RANK)) );
         ASSERT_EQ( 0u, stk::mesh::count_selected_entities( skin_part, mesh.buckets(side_rank)) );
