@@ -31,7 +31,7 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 // 
 
-#include <stk_mesh/fixtures/SelectorFixture.hpp>
+#include <stk_unit_tests/stk_mesh_fixtures/SelectorFixture.hpp>
 #include <sstream>                      // for ostringstream, etc
 #include <string>                       // for string
 #include "mpi.h"                        // for MPI_COMM_WORLD
@@ -83,32 +83,32 @@ void SelectorFixture::generate_mesh()
   // Entity1 is contained in PartA
   partMembership.clear();
   partMembership.push_back( & m_partA );
-  m_entity1 = m_bulk_data.declare_entity(stk::topology::NODE_RANK, ent_id, partMembership);
+  m_entity1 = m_bulk_data.declare_node(ent_id, partMembership);
   ++ent_id;
 
   // Entity2 is contained in PartA and PartB
   partMembership.clear();
   partMembership.push_back( & m_partA );
   partMembership.push_back( & m_partB );
-  m_entity2 = m_bulk_data.declare_entity(stk::topology::NODE_RANK, ent_id, partMembership);
+  m_entity2 = m_bulk_data.declare_node(ent_id, partMembership);
   ++ent_id;
 
   // Entity3 is contained in PartB and PartC
   partMembership.clear();
   partMembership.push_back( & m_partB );
   partMembership.push_back( & m_partC );
-  m_entity3 = m_bulk_data.declare_entity(stk::topology::NODE_RANK, ent_id, partMembership);
+  m_entity3 = m_bulk_data.declare_node(ent_id, partMembership);
   ++ent_id;
 
   // Entity4 is contained in PartC
   partMembership.clear();
   partMembership.push_back( & m_partC );
-  m_entity4 = m_bulk_data.declare_entity(stk::topology::NODE_RANK, ent_id, partMembership);
+  m_entity4 = m_bulk_data.declare_node(ent_id, partMembership);
   ++ent_id;
 
   // Entity5 is not contained in any Part
   partMembership.clear();
-  m_entity5 = m_bulk_data.declare_entity(stk::topology::NODE_RANK, ent_id, partMembership);
+  m_entity5 = m_bulk_data.declare_node(ent_id, partMembership);
 }
 
 //--------------------------------------------------------------------------
@@ -145,7 +145,7 @@ VariableSelectorFixture::VariableSelectorFixture(int NumParts)
   for (int part_i = 0 ; part_i < NumParts ; ++part_i) {
     std::vector<stk::mesh::Part*> partMembership;
     partMembership.push_back(m_declared_part_vector[part_i]);
-    stk::mesh::Entity e = m_BulkData.declare_entity(stk::topology::NODE_RANK, ent_id, partMembership);
+    stk::mesh::Entity e = m_BulkData.declare_node(ent_id, partMembership);
     m_entities.push_back( e );
     ++ent_id;
   }
