@@ -80,11 +80,6 @@
 #include <sys/time.h>
 #include <sys/resource.h>
 
-#elif defined(__SUNPRO_CC)
-#include <sys/resource.h>
-#include <sys/time.h>
-#include <sys/utsname.h>
-#include <netdb.h>
 #endif
 
 #if defined(__PUMAGON__)
@@ -93,10 +88,6 @@ extern "C" {
 #include <sys/param.h>
 }
 
-#elif defined(__sgi)
-#include <sys/time.h>
-#include <sys/resource.h>
-
 #elif defined(__JVN)
 #include <sys/param.h>
 #include <sys/utsname.h>
@@ -187,22 +178,6 @@ get_heap_info(
 #endif // defined(SIERRA_HEAP_INFO)
 }
 
-
-size_t get_available_memory()
-{
-  // The value returned for _SC_AVPHYS_PAGES is the amount of memory
-  // the application can use without hindering any other process
-  // (given that no other process increases its memory usage).
-#if !defined(__APPLE__) && !defined(__FreeBSD__)
-  static size_t pagesize = getpagesize();
-  size_t avail = sysconf(_SC_AVPHYS_PAGES);
-  return avail * pagesize;
-#else
-  // _SC_AVPHYS_PAGES does not exist on FreeBSD/Apple
-  return 0;
-#endif
-}
-
 void
 get_memory_info(
   size_t &		memory_usage,
@@ -305,48 +280,33 @@ username()
 std::string
 hardware()
 {
-#ifndef __sgi
   struct utsname	uts_name;
 
   uname(&uts_name);
 
   return uts_name.machine;
-#else
-  std::string s;
-  return s;
-#endif
 }
 
 
 std::string
 osname()
 {
-#ifndef __sgi
   struct utsname	uts_name;
 
   uname(&uts_name);
 
   return uts_name.sysname;
-#else
-  std::string s;
-  return s;
-#endif
 }
 
 
 std::string
 osversion()
 {
-#ifndef __sgi
   struct utsname	uts_name;
 
   uname(&uts_name);
 
   return uts_name.release;
-#else
-  std::string s;
-  return s;
-#endif
 }
 
 
@@ -381,7 +341,6 @@ path_exists(
   return path_access(name, F_OK);
 }
 
-
 bool
 path_read_access(
   const std::string &	name)
@@ -389,15 +348,6 @@ path_read_access(
   return path_access(name, R_OK);
 }
 
-
-bool
-path_write_access(
-  const std::string &	name)
-{
-  return path_access(name, W_OK);
-}
-
-
 namespace {
 
 struct flock *
@@ -405,7 +355,6 @@ file_lock(
   short	type,
   short	whence)
 {
-//  /* %TRACE[SPEC]% */ Tracespec trace__("sierra::Fmwk::<unnamed>::file_lock( short type, short whence)"); /* %TRACE% */
   static struct flock ret;
   ret.l_type = type;
   ret.l_start = 0;
@@ -422,8 +371,6 @@ write_lock(
   int		fd)
 {
   int i =::fcntl(fd, F_SETLK, file_lock(F_WRLCK, SEEK_SET));
-//   if (i == -1)
-//     fmwkout << "Write lock failed " << errno << dendl;
 
   return i != -1;
 }
@@ -434,9 +381,6 @@ release_lock(
   int		fd)
 {
   int i =::fcntl(fd, F_SETLK, file_lock(F_UNLCK, SEEK_SET));
-//   if (i == -1)
-//     fmwkout << "Release lock failed " << errno << dendl;
-
   return i != -1;
 }
 
