@@ -316,6 +316,17 @@ void handle_invalid_arg(const char* expr,
 #define ThrowInvalidArgMsgIf(expr, message) ThrowGenericCond( !(expr), message, handle_invalid_arg)
 #define ThrowInvalidArgIf(expr)             ThrowInvalidArgMsgIf(expr, "")
 
+/**
+ * @ingroup Exception
+ * @brief Macro WarnTrace makes a pretty warning message with file and line number.
+ */
+#define WarnTrace std::string(std::string("  warning at ") + stk::source_relative_path(STK_STR_TRACE))
+
+/**
+ * @ingroup Exception
+ * @brief Macro ErrorTrace makes a pretty error message with file and line number.
+ */
+#define ErrorTrace std::string(std::string("  error thrown from ") + stk::source_relative_path(STK_STR_TRACE))
 
 ///
 /// @}
