@@ -40,7 +40,7 @@
 #include <exception>                    // for uncaught_exception
 #include <map>                          // for map, map<>::value_compare
 #include <ostream>                      // for ostream
-#include <stk_util/util/Writer_fwd.hpp>  // for LogMask::LOG_TRACE, etc
+#include <stk_util/util/Writer_fwd.hpp> // for LogMask::LOG_TRACE, etc
 #include <string>                       // for string
 #include <vector>                       // for vector, vector<>::iterator
 namespace stk { namespace diag { class Writer; } }
@@ -92,20 +92,6 @@ public:
    */
   std::string getFunctionName() const;
 
-  /**
-   * @brief Member function <b>getFunctionName</b> returns the function's name.
-   *
-   * @return      a <b>char</b> const pointer to the function's name.
-   */
-  std::string getFunctionClass() const;
-
-  /**
-   * @brief Member function <b>getFunctionName</b> returns the function's name.
-   *
-   * @return      a <b>char</b> const pointer to the function's name.
-   */
-  std::string getFunctionNamespace() const;
-
 protected:
   const char *      m_functionSpec;    ///< The member function specification
 };
@@ -129,7 +115,6 @@ public:
    * <LI>RUNNING - No throws are in progress.
    * <LI>THROWING - A throw is in progress.
    * </UL>
-   *
    */
   enum TracebackState{RUNNING, THROWING};
 
@@ -144,7 +129,6 @@ public:
    * NOTE: This does really want to use const char * as the key.  I know, things could
    * move, but the definition of a function spec is that it is a string literal only.  So,
    * let it go.
-   *
    */
   struct StringLiteralLess
   {
@@ -158,7 +142,6 @@ public:
   /**
    * @brief Class <b>Traceback::Preserve</b> serves as a sentry for traceback
    * stack preservation during additional extension and unwinding.
-   *
    */
   class Preserve
   {
@@ -166,7 +149,6 @@ public:
     /**
      * @brief Creates a new <b>Traceback::Preserve</b> sentry.  When the sentry
      * is in place, the traceback stack is preserved from extension and clearing.
-     *
      */
     Preserve() {
       Traceback::preserveStack();
@@ -174,7 +156,6 @@ public:
 
     /**
      * @brief Destroys a <b>Preserve</b> sentry which allows traceback stack
-     *
      */
     ~Preserve() {
       Traceback::releaseStack();
@@ -203,11 +184,9 @@ public:
 #endif
   }
 
-
   /**
    * @brief Destroys a <b>Traceback</b> instance, resulting in the pushing of
    * the function specification if unwinding the stack.
-   *
    */
   ~Traceback() {
     if (!s_tracebackPreserve && std::uncaught_exception() && s_tracebackState == RUNNING) {
@@ -224,7 +203,6 @@ public:
   /**
    * @brief Member function <b>enableTracebackDisplay</b> enables the display of the
    * traceback.
-   *
    */
   inline static void enableTracebackDisplay() {
     --s_tracebackDisplay;
@@ -233,7 +211,6 @@ public:
   /**
    * @brief Member function <b>disableTracebackDisplay</b> disables the display of the
    * traceback.
-   *
    */
   inline static void disableTracebackDisplay() {
     ++s_tracebackDisplay;
@@ -253,7 +230,6 @@ public:
   /**
    * @brief Member function <b>preserveStack</b> increments the traceback stack
    * preservation counter.
-   *
    */
   inline static void preserveStack() {
     ++s_tracebackPreserve;
@@ -262,7 +238,6 @@ public:
   /**
    * @brief Member function <b>releaseStack</b> decrements the traceback stack
    * preservation counter.
-   *
    */
   inline static void releaseStack() {
     --s_tracebackPreserve;
@@ -275,7 +250,6 @@ public:
    *
    * @param coverage_enabled	a <b>bool</b> value to set the coverage enabled
    *				flag.
-   *
    */
   inline static void enableCoverage(bool coverage_enabled = true) {
     s_coverageEnabled = coverage_enabled;
@@ -295,8 +269,6 @@ public:
   /**
    * @brief Member function <b>getTracebackState</b> returns the value of the
    * traceback state.
-   *
-   * @return an <b>int</b> ...
    */
   inline static TracebackState getTracebackState() {
     return s_tracebackState;
@@ -304,7 +276,6 @@ public:
 
   /**
    * @brief Class <b>PrintCoverage</b> is a type holder class for printing the stack.
-   *
    */
   struct PrintCoverage
   {};
@@ -351,7 +322,7 @@ private:
 
 /**
  * @brief Class <b>Trace</b> serves as a sentry for entering routines.  Creating a
- * trace object prints the specified member function name to the specfied diag_writer and
+ * trace object prints the specified member function name to the specified diag_writer and
  * pushes the diag_writer depth.  On destruction, it prints the member function name again
  * and pops the depth.
  *
@@ -366,13 +337,11 @@ public:
   /**
    * @brief Typedef <b>ExtraFuncPtr</b> declares the extra function pointer
    * signature.
-   *
    */
   typedef Writer & (*ExtraFuncPtr)(Writer &);
 
   /**
    * @brief Typedef <b>TraceList</b> declares the trace list data type.
-   *
    */
   struct TraceList : public std::vector<const char *> {
   public:
@@ -390,7 +359,6 @@ public:
 
   /**
    * @brief Enumeration to describe the trace back flags.
-   *
    */
   enum {
     IN_TRACE_LIST  = 0x01    ///< Tracing enabled by this function
@@ -411,14 +379,12 @@ public:
    *
    * @param do_trace            a <b>bool</b> that provide an extra dynamic means of
    *                            turning off tracing.
-   *
    */
   Trace(Writer &dout, const char *function_name, int print_mask = LOG_TRACE, bool do_trace = true);
 
   /**
    * @brief Destroys a <b>Trace</b> instance, resulting in the printing of the
    * member function name and popping the diag_writer depth.
-   *
    */
   ~Trace();
 
@@ -453,7 +419,6 @@ public:
   /**
    * @brief Member function <b>clearTraceFunctions</b> removes all function prefixes
    * from the function signature prefix list.
-   *
    */
   inline static void clearTraceFunctions() {
     for (auto it = s_traceList.begin(); it != s_traceList.end(); ++it) {
@@ -517,7 +482,6 @@ inline std::ostream &operator<<(std::ostream &os, const Traceback::PrintCoverage
   return Traceback::printCoverage(os);
 }
 
-
 } // namespace diag
 } // namespace stk
 
