@@ -62,23 +62,13 @@ enum LogMask {
   LOG_TIMER             = 0x0000040
 };
 
-/**
- * @brief Class <b>message_type</b> ...
- *
- */
 enum message_type {
   MSG_WARNING = stk::MSG_WARNING,
   MSG_FATAL = stk::MSG_DOOMED,
   MSG_INFORMATION,
-  MSG_EXCEPTION,
-  MSG_PARALLEL_EXCEPTION
+  MSG_EXCEPTION
 };
 
-
-/**
- * @brief Class <b>type</b> ...
- *
- */
 enum message_throttle_type {
   MSG_APPLICATION = stk::MSG_APPLICATION,
   MSG_TIME_STEP
@@ -90,45 +80,13 @@ enum TimerSetMask {
   TIMER_SEARCH		= 0x00000004,		///< Enable search timers
   TIMER_TRANSFER	= 0x00000008,		///< Enable transfer timers
   TIMER_ALL		= 0xFFFFFFFF,		///< Force timer to be active
-
   TIMER_FORCE		= 0x00000000		///< Force timer to be active
 };
 
-stk::diag::Writer &dw();
-
 stk::diag::TimerSet &timerSet();
 
 stk::diag::Timer &timer();
 
-void my_report_handler(const char *message, int type);
-
-/**
- * Print the sucess or failure of a use_case by combining the success
- * flags for all procs in comm. Prints a string that should be grepped for
- * in the test XML files.
- *
- * Returns true if all procs passed.
- */
-bool print_status(stk::ParallelMachine comm, bool success);
-
-struct UseCaseEnvironment
-{
-  // Will initialize a comm
-  UseCaseEnvironment(int *argc, char ***argv);
-
-  // Assumes already-initialized comm
-  UseCaseEnvironment(int *argc, char ***argv, stk::ParallelMachine comm);
-
-  // shared constructor implementation; do not call directly
-  void initialize(int* argc, char ***argv);
-
-  ~UseCaseEnvironment();
-
-  const stk::ParallelMachine    m_comm;
-  std::string                   m_workingDirectory;
-  bool                          m_need_to_finalize;
-};
-
 } // namespace use_case
 
 #endif // stk_util_use_cases_UseCaseEnvironement_hpp
