@@ -44,13 +44,12 @@
 
 #include "BelosTpetraAdapter.hpp"
 #include "Stokhos_Sacado_Kokkos_UQ_PCE.hpp"
+#include "Kokkos_MV_GEMM.hpp"
 
 #ifdef HAVE_BELOS_TSQR
 #  include <Tpetra_TsqrAdaptor_UQ_PCE.hpp>
 #endif // HAVE_BELOS_TSQR
 
-#include "Kokkos_DefaultArithmetic.hpp"
-
 namespace Belos {
 
   ////////////////////////////////////////////////////////////////////
@@ -59,8 +58,6 @@ namespace Belos {
   //
   ////////////////////////////////////////////////////////////////////
 
-#if defined(TPETRA_HAVE_KOKKOS_REFACTOR)
-
   /// \brief Partial specialization of MultiVecTraits for MV = Tpetra::MultiVector.
   ///
   /// This interface lets Belos' solvers work directly with
@@ -71,34 +68,32 @@ namespace Belos {
   /// correspond exactly to the four template parameters of
   /// Tpetra::MultiVector.  See the Tpetra::MultiVector documentation
   /// for more information.
-  template<class BaseScalar, class Storage, class LO, class GO, class Device>
-  class MultiVecTraits<BaseScalar,
+  template<class Storage, class LO, class GO, class Node>
+  class MultiVecTraits<typename Storage::value_type,
                        Tpetra::MultiVector< Sacado::UQ::PCE<Storage>,
-                                            LO,GO,
-                                            Kokkos::Compat::KokkosDeviceWrapperNode<Device> > > {
+                                            LO, GO, Node > > {
   public:
-    typedef Kokkos::Compat::KokkosDeviceWrapperNode<Device> Node;
-  private:
     typedef typename Storage::ordinal_type s_ordinal;
+    typedef typename Storage::value_type BaseScalar;
     typedef Sacado::UQ::PCE<Storage> Scalar;
     typedef Tpetra::MultiVector<Scalar, LO, GO, Node> MV;
   public:
     typedef typename Tpetra::MultiVector<Scalar,LO,GO,Node>::dot_type dot_type;
     typedef typename Tpetra::MultiVector<Scalar,LO,GO,Node>::mag_type mag_type;
 
-    /// \brief Create a new multivector with \c numvecs columns.
+    /// \brief Create a new MultiVector with \c numVecs columns.
     ///
     /// The returned Tpetra::MultiVector has the same Tpetra::Map
-    /// (distribution over one or more parallel processes) as \c mv.
+    /// (distribution over one or more parallel processes) as \c X.
     /// Its entries are not initialized and have undefined values.
-    static Teuchos::RCP<Tpetra::MultiVector<Scalar,LO,GO,Node> >
-    Clone (const Tpetra::MultiVector<Scalar,LO,GO,Node>& mv, const int numvecs)
-    {
-      return Teuchos::rcp (new MV (mv.getMap (), numvecs, false));
+    static Teuchos::RCP<MV> Clone (const MV& X, const int numVecs) {
+      Teuchos::RCP<MV> Y (new MV (X.getMap (), numVecs, false));
+      Y->setCopyOrView (Teuchos::View);
+      return Y;
     }
 
-    static Teuchos::RCP<Tpetra::MultiVector<Scalar,LO,GO,Node> >
-    CloneCopy (const Tpetra::MultiVector<Scalar,LO,GO,Node>& X)
+    //! Create and return a deep copy of X.
+    static Teuchos::RCP<MV> CloneCopy (const MV& X)
     {
       // Make a deep copy of X.  The one-argument copy constructor
       // does a shallow copy by default; the second argument tells it
@@ -114,21 +109,32 @@ namespace Belos {
       return X_copy;
     }
 
-    static Teuchos::RCP<Tpetra::MultiVector<Scalar,LO,GO,Node> >
-    CloneCopy (const Tpetra::MultiVector<Scalar,LO,GO,Node>& mv,
-               const std::vector<int>& index)
+    /// \brief Create and return a deep copy of the given columns of mv.
+    ///
+    /// \pre \code mv.getNumVectors() != 0 || index.size() == 0 \endcode
+    /// \pre For all k such that <tt>0 <= k < index.size()</tt>,
+    ///   \code
+    ///   0 <= index[k] < mv.getNumVectors();
+    ///   \endcode
+    /// \post If this method returns Y:
+    ///   \code
+    ///   Y->isConstantStride() && Y->getNumVectors() == index.size();
+    ///   \endcode
+    static Teuchos::RCP<MV>
+    CloneCopy (const MV& mv, const std::vector<int>& index)
     {
 #ifdef HAVE_TPETRA_DEBUG
       const char fnName[] = "Belos::MultiVecTraits::CloneCopy(mv,index)";
+      const size_t inNumVecs = mv.getNumVectors ();
       TEUCHOS_TEST_FOR_EXCEPTION(
         index.size () > 0 && *std::min_element (index.begin (), index.end ()) < 0,
         std::runtime_error, fnName << ": All indices must be nonnegative.");
       TEUCHOS_TEST_FOR_EXCEPTION(
         index.size () > 0 &&
-        static_cast<size_t> (*std::max_element (index.begin (), index.end ())) >= mv.getNumVectors (),
+        static_cast<size_t> (*std::max_element (index.begin (), index.end ())) >= inNumVecs,
         std::runtime_error,
         fnName << ": All indices must be strictly less than the number of "
-        "columns " << mv.getNumVectors () << " of the input multivector mv.");
+        "columns " << inNumVecs << " of the input multivector mv.");
 #endif // HAVE_TPETRA_DEBUG
 
       // Tpetra wants an array of size_t, not of int.
@@ -144,9 +150,14 @@ namespace Belos {
       return X_copy;
     }
 
-    static Teuchos::RCP<Tpetra::MultiVector<Scalar,LO,GO,Node> >
-    CloneCopy (const Tpetra::MultiVector<Scalar,LO,GO,Node>& mv,
-               const Teuchos::Range1D& index)
+    /// \brief Create and return a deep copy of the given columns of mv.
+    ///
+    /// \post If this method returns Y:
+    ///   \code
+    ///   Y->isConstantStride() && Y->getNumVectors() == index.size();
+    ///   \endcode
+    static Teuchos::RCP<MV>
+    CloneCopy (const MV& mv, const Teuchos::Range1D& index)
     {
       const bool validRange = index.size() > 0 &&
         index.lbound() >= 0 &&
@@ -175,9 +186,8 @@ namespace Belos {
     }
 
 
-    static Teuchos::RCP<Tpetra::MultiVector<Scalar,LO,GO,Node> >
-    CloneViewNonConst (Tpetra::MultiVector<Scalar,LO,GO,Node>& mv,
-                       const std::vector<int>& index)
+    static Teuchos::RCP<MV>
+    CloneViewNonConst (MV& mv, const std::vector<int>& index)
     {
 #ifdef HAVE_TPETRA_DEBUG
       const char fnName[] = "Belos::MultiVecTraits::CloneViewNonConst(mv,index)";
@@ -203,25 +213,12 @@ namespace Belos {
       // continuous column index range in
       // MultiVector::subViewNonConst, so we don't have to check here.
       Teuchos::RCP<MV> X_view = mv.subViewNonConst (columns ());
-      // FIXME (mfh 14 Aug 2014) For some reason I currently don't
-      // understand, the Belos MVOpTester and/or OrthoManager tests
-      // fail if I uncomment the line below.  This is true for both
-      // the "classic" and Kokkos refactor versions of Tpetra.  I
-      // don't know why this is the case.  Belos shouldn't care
-      // whether Tpetra uses copy or view semantics, and the Kokkos
-      // refactor version of Tpetra _always_ uses view semantics.
-      // Nevertheless, the tests fail, so I will leave the following
-      // line commented out for now.  This is true for both CloneView
-      // overloads as well as both CloneViewNonConst overloads.
-
-      //X_view->setCopyOrView (Teuchos::View);
+      X_view->setCopyOrView (Teuchos::View);
       return X_view;
     }
 
-
-    static Teuchos::RCP<Tpetra::MultiVector<Scalar,LO,GO,Node> >
-    CloneViewNonConst (Tpetra::MultiVector<Scalar,LO,GO,Node>& mv,
-                       const Teuchos::Range1D& index)
+    static Teuchos::RCP<MV>
+    CloneViewNonConst (MV& mv, const Teuchos::Range1D& index)
     {
       // NOTE (mfh 11 Jan 2011) We really should check for possible
       // overflow of int here.  However, the number of columns in a
@@ -249,25 +246,12 @@ namespace Belos {
           os.str() << "Should never get here!");
       }
       Teuchos::RCP<MV> X_view = mv.subViewNonConst (index);
-      // FIXME (mfh 14 Aug 2014) For some reason I currently don't
-      // understand, the Belos MVOpTester and/or OrthoManager tests
-      // fail if I uncomment the line below.  This is true for both
-      // the "classic" and Kokkos refactor versions of Tpetra.  I
-      // don't know why this is the case.  Belos shouldn't care
-      // whether Tpetra uses copy or view semantics, and the Kokkos
-      // refactor version of Tpetra _always_ uses view semantics.
-      // Nevertheless, the tests fail, so I will leave the following
-      // line commented out for now.  This is true for both CloneView
-      // overloads as well as both CloneViewNonConst overloads.
-
-      //X_view->setCopyOrView (Teuchos::View);
+      X_view->setCopyOrView (Teuchos::View);
       return X_view;
     }
 
-
-    static Teuchos::RCP<const Tpetra::MultiVector<Scalar,LO,GO,Node> >
-    CloneView (const Tpetra::MultiVector<Scalar,LO,GO,Node>& mv,
-               const std::vector<int>& index)
+    static Teuchos::RCP<const MV>
+    CloneView (const MV& mv, const std::vector<int>& index)
     {
 #ifdef HAVE_TPETRA_DEBUG
       const char fnName[] = "Belos::MultiVecTraits<Scalar, "
@@ -293,24 +277,12 @@ namespace Belos {
       // continuous column index range in MultiVector::subView, so we
       // don't have to check here.
       Teuchos::RCP<const MV> X_view = mv.subView (columns);
-      // FIXME (mfh 14 Aug 2014) For some reason I currently don't
-      // understand, the Belos MVOpTester and/or OrthoManager tests
-      // fail if I uncomment the line below.  This is true for both
-      // the "classic" and Kokkos refactor versions of Tpetra.  I
-      // don't know why this is the case.  Belos shouldn't care
-      // whether Tpetra uses copy or view semantics, and the Kokkos
-      // refactor version of Tpetra _always_ uses view semantics.
-      // Nevertheless, the tests fail, so I will leave the following
-      // line commented out for now.  This is true for both CloneView
-      // overloads as well as both CloneViewNonConst overloads.
-
-      //Teuchos::rcp_const_cast<MV> (X_view)->setCopyOrView (Teuchos::View);
+      Teuchos::rcp_const_cast<MV> (X_view)->setCopyOrView (Teuchos::View);
       return X_view;
     }
 
-    static Teuchos::RCP<const Tpetra::MultiVector<Scalar,LO,GO,Node> >
-    CloneView (const Tpetra::MultiVector<Scalar,LO,GO,Node>& mv,
-               const Teuchos::Range1D& index)
+    static Teuchos::RCP<const MV>
+    CloneView (const MV& mv, const Teuchos::Range1D& index)
     {
       // NOTE (mfh 11 Jan 2011) We really should check for possible
       // overflow of int here.  However, the number of columns in a
@@ -335,33 +307,19 @@ namespace Belos {
           os.str() << "Should never get here!");
       }
       Teuchos::RCP<const MV> X_view = mv.subView (index);
-      // FIXME (mfh 14 Aug 2014) For some reason I currently don't
-      // understand, the Belos MVOpTester and/or OrthoManager tests
-      // fail if I uncomment the line below.  This is true for both
-      // the "classic" and Kokkos refactor versions of Tpetra.  I
-      // don't know why this is the case.  Belos shouldn't care
-      // whether Tpetra uses copy or view semantics, and the Kokkos
-      // refactor version of Tpetra _always_ uses view semantics.
-      // Nevertheless, the tests fail, so I will leave the following
-      // line commented out for now.  This is true for both CloneView
-      // overloads as well as both CloneViewNonConst overloads.
-
-      //Teuchos::rcp_const_cast<MV> (X_view)->setCopyOrView (Teuchos::View);
+      Teuchos::rcp_const_cast<MV> (X_view)->setCopyOrView (Teuchos::View);
       return X_view;
     }
 
-    static ptrdiff_t
-    GetGlobalLength (const Tpetra::MultiVector<Scalar,LO,GO,Node>& mv) {
-      return Teuchos::as<ptrdiff_t>(mv.getGlobalLength ());
+    static ptrdiff_t GetGlobalLength (const MV& mv) {
+      return static_cast<ptrdiff_t> (mv.getGlobalLength ());
     }
 
-    static int
-    GetNumberVecs (const Tpetra::MultiVector<Scalar,LO,GO,Node>& mv) {
-      return mv.getNumVectors ();
+    static int GetNumberVecs (const MV& mv) {
+      return static_cast<int> (mv.getNumVectors ());
     }
 
-    static bool
-    HasConstantStride (const Tpetra::MultiVector<Scalar,LO,GO,Node>& mv) {
+    static bool HasConstantStride (const MV& mv) {
       return mv.isConstantStride ();
     }
 
@@ -374,7 +332,6 @@ namespace Belos {
     {
       using Teuchos::RCP;
       using Teuchos::rcp;
-      using Kokkos::Compat::persistingView;
 
       // Check if numRowsB == numColsB == 1, in which case we can call update()
       const int numRowsB = B.numRows ();
@@ -387,66 +344,39 @@ namespace Belos {
 
       // Ensure A and C have constant stride
       RCP<const MV> Atmp, Ctmp;
-      if (A.isConstantStride() == false) Atmp = rcp (new MV (A));
+      if (A.isConstantStride() == false) Atmp = rcp (new MV (A, Teuchos::Copy));
       else Atmp = rcp(&A,false);
 
-      if (C.isConstantStride() == false) Ctmp = rcp (new MV (C));
+      if (C.isConstantStride() == false) Ctmp = rcp (new MV (C, Teuchos::Copy));
       else Ctmp = rcp(&C,false);
 
-      // Create flattened Kokkos::MultiVector's
+      // Create flattened view's
       typedef Tpetra::MultiVector<dot_type,LO,GO,Node> FMV;
-      typedef typename FMV::dual_view_type::t_dev view_type;
-      typedef typename view_type::execution_space execution_space;
-      typedef KokkosClassic::MultiVector<dot_type,Node> DKMV;
-      view_type A_view = Atmp->template getLocalView<execution_space>();
-      view_type C_view = Ctmp->template getLocalView<execution_space>();
-      DKMV A_mv(A.getMap()->getNode());
-      DKMV C_mv(A.getMap()->getNode());
-      size_t A_stride[8], C_stride[8];
-      A_view.stride(A_stride);
-      C_view.stride(C_stride);
-      const size_t LDA =
-        A_view.dimension_1() > 1 ? A_stride[1] : A_view.dimension_0();
-      const size_t LDC =
-        C_view.dimension_1() > 1 ? C_stride[1] : C_view.dimension_0();
-      A_mv.initializeValues(A_view.dimension_0(),
-                            A_view.dimension_1(),
-                            persistingView(A_view),
-                            LDA);
-      C_mv.initializeValues(C_view.dimension_0(),
-                            C_view.dimension_1(),
-                            persistingView(C_view),
-                            LDC);
+      typedef typename FMV::dual_view_type::t_dev flat_view_type;
+      typedef typename flat_view_type::execution_space execution_space;
+      flat_view_type flat_A_view = Atmp->template getLocalView<execution_space>();
+      flat_view_type flat_C_view = Ctmp->template getLocalView<execution_space>();
 
-      // Create a view for B
-      typedef Kokkos::View<dot_type**, Kokkos::LayoutLeft, execution_space> b_view_type;
-      typedef typename b_view_type::HostMirror b_host_view_type;
-      b_host_view_type B_view( B.values(), strideB, numColsB);
+      // Create a view for B on the host
+      typedef Kokkos::View<dot_type**, Kokkos::LayoutLeft, Kokkos::HostSpace> b_host_view_type;
+      b_host_view_type B_view_host( B.values(), strideB, numColsB);
 
       // Create view for B on the device -- need to be careful to get the
       // right stride to match B
+      typedef Kokkos::View<dot_type**, Kokkos::LayoutLeft, execution_space> b_view_type;
       typedef Kokkos::View<dot_type*, Kokkos::LayoutLeft, execution_space> b_1d_view_type;
       b_1d_view_type B_1d_view_dev(Kokkos::ViewAllocateWithoutInitializing("B"), strideB*numColsB);
       b_view_type B_view_dev( B_1d_view_dev.ptr_on_device(), strideB, numColsB);
-      Kokkos::deep_copy(B_view_dev, B_view);
-
-      // Make a Kokkos::MultiVector for B
-      DKMV B_mv(A.getMap()->getNode());
-      B_mv.initializeValues(numRowsB, numColsB, persistingView(B_view_dev),
-                            strideB);
+      Kokkos::deep_copy(B_view_dev, B_view_host);
 
       // Do local multiply
-      typedef KokkosClassic::DefaultArithmetic<DKMV> MVT;
-      MVT::GEMM(C_mv, Teuchos::NO_TRANS, Teuchos::NO_TRANS, alpha,
-                A_mv, B_mv, beta);
+      Kokkos::DeviceGEMM<dot_type,execution_space>::GEMM(
+        Teuchos::NO_TRANS, Teuchos::NO_TRANS,
+        alpha, flat_A_view, B_view_dev, beta, flat_C_view);
 
-      // Copy back into C if necessary
+      // Copy back to C if we made a copy
       if (C.isConstantStride() == false)
-        Tpetra::deep_copy(C, *Ctmp);
-
-      // Release A and C if necessary
-      Atmp = Teuchos::null;
-      Ctmp = Teuchos::null;
+        C.assign(*Ctmp);
     }
 
     /// \brief <tt>mv := alpha*A + beta*B</tt>
@@ -502,87 +432,70 @@ namespace Belos {
       using Teuchos::rcp;
       using Teuchos::REDUCE_SUM;
       using Teuchos::reduceAll;
-      using Kokkos::Compat::persistingView;
 
       // Check if numRowsC == numColsC == 1, in which case we can call dot()
       const int numRowsC = C.numRows ();
       const int numColsC = C.numCols ();
       const int strideC  = C.stride ();
       if (numRowsC == 1 && numColsC == 1) {
+        if (alpha == Teuchos::ScalarTraits<Scalar>::zero ()) {
+          // Short-circuit, as required by BLAS semantics.
+          C(0,0) = alpha;
+          return;
+        }
         A.dot (B, Teuchos::ArrayView<dot_type> (C.values (), 1));
+        if (alpha != Teuchos::ScalarTraits<Scalar>::one ()) {
+          C(0,0) *= alpha;
+        }
         return;
       }
 
       // Ensure A and B have constant stride
       RCP<const MV> Atmp, Btmp;
-      if (A.isConstantStride() == false) Atmp = rcp (new MV (A));
+      if (A.isConstantStride() == false) Atmp = rcp (new MV (A, Teuchos::Copy));
       else Atmp = rcp(&A,false);
 
-      if (B.isConstantStride() == false) Btmp = rcp (new MV (B));
+      if (B.isConstantStride() == false) Btmp = rcp (new MV (B, Teuchos::Copy));
       else Btmp = rcp(&B,false);
 
       // Create flattened Kokkos::MultiVector's
       typedef Tpetra::MultiVector<dot_type,LO,GO,Node> FMV;
-      typedef typename FMV::dual_view_type::t_dev view_type;
-      typedef typename view_type::execution_space execution_space;
-      typedef KokkosClassic::MultiVector<dot_type,Node> DKMV;
-      view_type A_view = Atmp->template getLocalView<execution_space>();
-      view_type B_view = Btmp->template getLocalView<execution_space>();
-      DKMV A_mv(A.getMap()->getNode());
-      DKMV B_mv(A.getMap()->getNode());
-      size_t A_stride[8], B_stride[8];
-      A_view.stride(A_stride);
-      B_view.stride(B_stride);
-      const size_t LDA =
-        A_view.dimension_1() > 1 ? A_stride[1] : A_view.dimension_0();
-      const size_t LDB =
-        B_view.dimension_1() > 1 ? B_stride[1] : B_view.dimension_0();
-      A_mv.initializeValues(A_view.dimension_0(),
-                            A_view.dimension_1(),
-                            persistingView(A_view),
-                            LDA);
-      B_mv.initializeValues(B_view.dimension_0(),
-                            B_view.dimension_1(),
-                            persistingView(B_view),
-                            LDB);
+      typedef typename FMV::dual_view_type::t_dev flat_view_type;
+      typedef typename flat_view_type::execution_space execution_space;
+      flat_view_type flat_A_view = Atmp->template getLocalView<execution_space>();
+      flat_view_type flat_B_view = Btmp->template getLocalView<execution_space>();
 
-      // Create a view for C
-      typedef Kokkos::View<dot_type**, Kokkos::LayoutLeft, execution_space> c_view_type;
-      typedef typename c_view_type::HostMirror c_host_view_type;
-      c_host_view_type C_view( C.values(), strideC, numColsC);
+      // Create a view for C on the host
+       typedef Kokkos::View<dot_type**, Kokkos::LayoutLeft, Kokkos::HostSpace> c_host_view_type;
+      c_host_view_type C_view_host( C.values(), strideC, numColsC);
 
       // Create view for C on the device -- need to be careful to get the
       // right stride to match C (allow setting to 0 for first-touch)
+      typedef Kokkos::View<dot_type**, Kokkos::LayoutLeft, execution_space> c_view_type;
       typedef Kokkos::View<dot_type*, Kokkos::LayoutLeft, execution_space> c_1d_view_type;
       c_1d_view_type C_1d_view_dev("C", strideC*numColsC);
       c_view_type C_view_dev( C_1d_view_dev.ptr_on_device(), strideC, numColsC);
 
-      // Make a Kokkos::MultiVector for C
-      DKMV C_mv(A.getMap()->getNode());
-      C_mv.initializeValues(numRowsC, numColsC, persistingView(C_view_dev),
-                            strideC);
-
       // Do local multiply
-      typedef KokkosClassic::DefaultArithmetic<DKMV> MVT;
-      MVT::GEMM(C_mv, Teuchos::CONJ_TRANS, Teuchos::NO_TRANS, alpha,
-                A_mv, B_mv, Kokkos::Details::ArithTraits<dot_type>::zero());
-
-      // Release A and B if necessary
-      Atmp = Teuchos::null;
-      Btmp = Teuchos::null;
+      Kokkos::DeviceGEMM<dot_type,execution_space>::GEMM(
+        Teuchos::CONJ_TRANS, Teuchos::NO_TRANS,
+        alpha, flat_A_view, flat_B_view,
+        Kokkos::Details::ArithTraits<dot_type>::zero(),
+        C_view_dev);
 
       // reduce across processors -- could check for RDMA
       RCP<const Comm<int> > pcomm = A.getMap()->getComm ();
       if (pcomm->getSize () == 1)
-        Kokkos::deep_copy(C_view, C_view_dev);
+        Kokkos::deep_copy(C_view_host, C_view_dev);
       else {
-        typedef typename c_1d_view_type::HostMirror c_1d_host_view_type;
+        typedef Kokkos::View<dot_type*, Kokkos::LayoutLeft, Kokkos::HostSpace> c_1d_host_view_type;
         c_1d_host_view_type C_1d_view_tmp(Kokkos::ViewAllocateWithoutInitializing("C_tmp"), strideC*numColsC);
         c_host_view_type C_view_tmp( C_1d_view_tmp.ptr_on_device(),
-                                    strideC, numColsC);
+                                     strideC, numColsC);
         Kokkos::deep_copy(C_view_tmp, C_view_dev);
         reduceAll<int> (*pcomm, REDUCE_SUM, strideC*numColsC,
-                        C_view_tmp.ptr_on_device(), C_view.ptr_on_device());
+                        C_view_tmp.ptr_on_device(),
+                        C_view_host.ptr_on_device());
       }
     }
 
@@ -658,38 +571,30 @@ namespace Belos {
     }
 
     static void
-    SetBlock (const Tpetra::MultiVector<Scalar,LO,GO,Node>& A,
-              const std::vector<int>& index,
-              Tpetra::MultiVector<Scalar,LO,GO,Node>& mv)
+    SetBlock (const MV& A, const std::vector<int>& index, MV& mv)
     {
       using Teuchos::Range1D;
       using Teuchos::RCP;
-      typedef std::vector<int>::size_type size_type;
-
+      const size_t inNumVecs = A.getNumVectors ();
 #ifdef HAVE_TPETRA_DEBUG
       TEUCHOS_TEST_FOR_EXCEPTION(
-        static_cast<size_type> (A.getNumVectors ()) < index.size (),
-        std::invalid_argument,
-        "Belos::MultiVecTraits::SetBlock(A,index,mv): The index argument must "
-        "have the same number of entries as the number of columns in A.  "
-        "index.size() = " << index.size () << " != A.getNumVectors() = "
-        << A.getNumVectors () << ".");
-#endif
+        inNumVecs < static_cast<size_t> (index.size ()), std::invalid_argument,
+        "Belos::MultiVecTraits::SetBlock(A,index,mv): 'index' argument must "
+        "have no more entries as the number of columns in the input MultiVector"
+        " A.  A.getNumVectors() = " << inNumVecs << " < index.size () = "
+        << index.size () << ".");
+#endif // HAVE_TPETRA_DEBUG
       RCP<MV> mvsub = CloneViewNonConst (mv, index);
-      if (static_cast<size_type> (A.getNumVectors ()) > index.size ()) {
+      if (inNumVecs > static_cast<size_t> (index.size ())) {
         RCP<const MV> Asub = A.subView (Range1D (0, index.size () - 1));
-        Tpetra::deep_copy (*mvsub, *Asub);
+        ::Tpetra::deep_copy (*mvsub, *Asub);
+      } else {
+        ::Tpetra::deep_copy (*mvsub, A);
       }
-      else {
-        Tpetra::deep_copy (*mvsub, A);
-      }
-      mvsub = Teuchos::null;
     }
 
     static void
-    SetBlock (const Tpetra::MultiVector<Scalar,LO,GO,Node>& A,
-              const Teuchos::Range1D& index,
-              Tpetra::MultiVector<Scalar,LO,GO,Node>& mv)
+    SetBlock (const MV& A, const Teuchos::Range1D& index, MV& mv)
     {
       // Range1D bounds are signed; size_t is unsigned.
       // Assignment of Tpetra::MultiVector is a deep copy.
@@ -698,26 +603,29 @@ namespace Belos {
       // fair to assume that the number of vectors won't overflow int,
       // since the typical use case of multivectors involves few
       // columns, but it's friendly to check just in case.
-      const size_t maxInt = static_cast<size_t> (Teuchos::OrdinalTraits<int>::max());
-      const bool overflow = maxInt < A.getNumVectors() && maxInt < mv.getNumVectors();
+      const size_t maxInt =
+        static_cast<size_t> (Teuchos::OrdinalTraits<int>::max ());
+      const bool overflow =
+        maxInt < A.getNumVectors () && maxInt < mv.getNumVectors ();
       if (overflow) {
         std::ostringstream os;
         os << "Belos::MultiVecTraits::SetBlock(A, index=[" << index.lbound ()
            << ", " << index.ubound () << "], mv): ";
-        TEUCHOS_TEST_FOR_EXCEPTION(maxInt < A.getNumVectors(), std::range_error,
-                                   os.str() << "Number of columns in the input multi"
-                                   "vector 'A' (a size_t) overflows int.");
-        TEUCHOS_TEST_FOR_EXCEPTION(maxInt < mv.getNumVectors(), std::range_error,
-                                   os.str() << "Number of columns in the output multi"
-                                   "vector 'mv' (a size_t) overflows int.");
+        TEUCHOS_TEST_FOR_EXCEPTION(
+          maxInt < A.getNumVectors (), std::range_error, os.str () << "Number "
+          "of columns (size_t) in the input MultiVector 'A' overflows int.");
+        TEUCHOS_TEST_FOR_EXCEPTION(
+          maxInt < mv.getNumVectors (), std::range_error, os.str () << "Number "
+          "of columns (size_t) in the output MultiVector 'mv' overflows int.");
       }
       // We've already validated the static casts above.
-      const int numColsA = static_cast<int> (A.getNumVectors());
-      const int numColsMv = static_cast<int> (mv.getNumVectors());
+      const int numColsA = static_cast<int> (A.getNumVectors ());
+      const int numColsMv = static_cast<int> (mv.getNumVectors ());
       // 'index' indexes into mv; it's the index set of the target.
-      const bool validIndex = index.lbound() >= 0 && index.ubound() < numColsMv;
+      const bool validIndex =
+        index.lbound () >= 0 && index.ubound () < numColsMv;
       // We can't take more columns out of A than A has.
-      const bool validSource = index.size() <= numColsA;
+      const bool validSource = index.size () <= numColsA;
 
       if (! validIndex || ! validSource) {
         std::ostringstream os;
@@ -758,12 +666,10 @@ namespace Belos {
         A_view = CloneView (A, Teuchos::Range1D (0, index.size () - 1));
       }
 
-      Tpetra::deep_copy (*mv_view, *A_view);
+      ::Tpetra::deep_copy (*mv_view, *A_view);
     }
 
-    static void
-    Assign (const Tpetra::MultiVector<Scalar,LO,GO,Node>& A,
-            Tpetra::MultiVector<Scalar,LO,GO,Node>& mv)
+    static void Assign (const MV& A, MV& mv)
     {
       const char errPrefix[] = "Belos::MultiVecTraits::Assign(A, mv): ";
 
@@ -774,17 +680,19 @@ namespace Belos {
       // fair to assume that the number of vectors won't overflow int,
       // since the typical use case of multivectors involves few
       // columns, but it's friendly to check just in case.
-      const size_t maxInt = static_cast<size_t> (Teuchos::OrdinalTraits<int>::max());
-      const bool overflow = maxInt < A.getNumVectors() && maxInt < mv.getNumVectors();
+      const size_t maxInt =
+        static_cast<size_t> (Teuchos::OrdinalTraits<int>::max ());
+      const bool overflow =
+        maxInt < A.getNumVectors () && maxInt < mv.getNumVectors ();
       if (overflow) {
         TEUCHOS_TEST_FOR_EXCEPTION(
           maxInt < A.getNumVectors(), std::range_error,
-          errPrefix << "Number of columns in the input multivector 'A' (a "
-          "size_t) overflows int.");
+          errPrefix << "Number of columns in the input multivector 'A' "
+          "(a size_t) overflows int.");
         TEUCHOS_TEST_FOR_EXCEPTION(
           maxInt < mv.getNumVectors(), std::range_error,
-          errPrefix << "Number of columns in the output multivector 'mv' (a "
-          "size_t) overflows int.");
+          errPrefix << "Number of columns in the output multivector 'mv' "
+          "(a size_t) overflows int.");
         TEUCHOS_TEST_FOR_EXCEPTION(
           true, std::logic_error, "Should never get here!");
       }
@@ -798,36 +706,27 @@ namespace Belos {
           "but output multivector 'mv' has only " << numColsMv << " columns.");
         TEUCHOS_TEST_FOR_EXCEPTION(true, std::logic_error, "Should never get here!");
       }
-      // Assignment of Tpetra::MultiVector objects via operator=
-      // assumes that both arguments have compatible Maps.  If
-      // HAVE_TPETRA_DEBUG is defined at compile time, operator= may
-      // throw an std::runtime_error if the Maps are incompatible.
       if (numColsA == numColsMv) {
-        Tpetra::deep_copy (mv, A);
+        ::Tpetra::deep_copy (mv, A);
       } else {
         Teuchos::RCP<MV> mv_view =
-          CloneViewNonConst (mv, Teuchos::Range1D (0, numColsA-1));
-        Tpetra::deep_copy (*mv_view, A);
+          CloneViewNonConst (mv, Teuchos::Range1D (0, numColsA - 1));
+        ::Tpetra::deep_copy (*mv_view, A);
       }
     }
 
 
-    static void
-    MvRandom (Tpetra::MultiVector<Scalar,LO,GO,Node>& mv)
-    {
+    static void MvRandom (MV& mv) {
       mv.randomize ();
     }
 
     static void
-    MvInit (Tpetra::MultiVector<Scalar,LO,GO,Node>& mv,
-            Scalar alpha = Teuchos::ScalarTraits<Scalar>::zero ())
+    MvInit (MV& mv, const Scalar alpha = Teuchos::ScalarTraits<Scalar>::zero ())
     {
       mv.putScalar (alpha);
     }
 
-    static void
-    MvPrint (const Tpetra::MultiVector<Scalar,LO,GO,Node>& mv, std::ostream& os)
-    {
+    static void MvPrint (const MV& mv, std::ostream& os) {
       Teuchos::FancyOStream fos (Teuchos::rcpFromRef (os));
       mv.describe (fos, Teuchos::VERB_EXTREME);
     }
@@ -840,8 +739,6 @@ namespace Belos {
 #endif // HAVE_BELOS_TSQR
   };
 
-#endif
-
   ////////////////////////////////////////////////////////////////////
   //
   // Implementation of the Belos::OperatorTraits for Tpetra::Operator.
@@ -849,8 +746,8 @@ namespace Belos {
   ////////////////////////////////////////////////////////////////////
 
   /// \brief Partial specialization of OperatorTraits for Tpetra::Operator.
-  template <class BaseScalar, class Storage, class LO, class GO, class Node>
-  class OperatorTraits <BaseScalar,
+  template <class Storage, class LO, class GO, class Node>
+  class OperatorTraits <typename Storage::value_type,
                         Tpetra::MultiVector<Sacado::UQ::PCE<Storage>,
                                              LO,GO,Node>,
                         Tpetra::Operator<Sacado::UQ::PCE<Storage>,
