@@ -57,8 +57,6 @@ namespace Details {
 template <typename XV, class SizeType>
 struct V_ReciprocalThresholdSelfFunctor;
 
-#if defined( KOKKOS_USING_EXPERIMENTAL_VIEW )
-
 // Mean-based implementation of ReciprocalThreshold
 template <typename S, typename ... P, class SizeType>
 struct V_ReciprocalThresholdSelfFunctor<
@@ -130,81 +128,6 @@ struct LocalReciprocalThreshold<
   }
 };
 
-#else
-
-// Mean-based implementation of ReciprocalThreshold
-template <typename T, typename L, typename D, typename M, class SizeType>
-struct V_ReciprocalThresholdSelfFunctor<
-  Kokkos::View< T,L,D,M,Kokkos::Impl::ViewPCEContiguous >,
-  SizeType >
-{
-  typedef Kokkos::View< T,L,D,M,Kokkos::Impl::ViewPCEContiguous > XVector;
-  typedef typename XVector::array_type array_type;
-
-  typedef typename array_type::execution_space   execution_space;
-  typedef SizeType                                     size_type;
-  typedef typename array_type::non_const_value_type   value_type;
-  typedef Kokkos::Details::ArithTraits<value_type>           KAT;
-  typedef typename KAT::mag_type                        mag_type;
-
-  const XVector    m_x;
-  const value_type m_min_val;
-  const value_type m_min_val_mag;
-  const size_type  m_n_pce;
-
-  V_ReciprocalThresholdSelfFunctor(
-    const XVector& x,
-    const typename XVector::non_const_value_type& min_val) :
-    m_x(x),
-    m_min_val(min_val.fastAccessCoeff(0)),
-    m_min_val_mag(KAT::abs(m_min_val)),
-    m_n_pce(x.sacado_size()) {}
-  //--------------------------------------------------------------------------
-
-  KOKKOS_INLINE_FUNCTION
-  void operator()( const size_type i) const
-  {
-    value_type z = m_x(i).fastAccessCoeff(0);
-    if (KAT::abs(z) < m_min_val_mag)
-      z = m_min_val;
-    else
-      z = KAT::one() / z;
-    m_x(i) = z;
-  }
-};
-
-template<class XV, class SizeType>
-struct LocalReciprocalThreshold;
-
-template<class T, class L, class D, class M, class SizeType>
-struct LocalReciprocalThreshold<
-  Kokkos::View<T,L,D,M,Kokkos::Impl::ViewPCEContiguous>, SizeType > {
-  typedef Kokkos::View<T,L,D,M,Kokkos::Impl::ViewPCEContiguous> XV;
-
-  static void
-  compute (const XV& X,
-           const typename XV::non_const_value_type& minVal)
-  {
-    if (!Sacado::is_constant(minVal)) {
-      Kokkos::Impl::raise_error(
-        "LocalReciprocalThreshold not implemented for non-constant minVal");
-    }
-
-    if (X.sacado_size() == 1) {
-      typedef typename XV::flat_array_type Flat_XV;
-      Flat_XV flat_X = X;
-      LocalReciprocalThreshold< Flat_XV, SizeType>::compute( flat_X,
-                                                             minVal.coeff(0) );
-    }
-    else {
-      V_ReciprocalThresholdSelfFunctor<XV, SizeType> op (X, minVal);
-      Kokkos::parallel_for( X.dimension_0(), op );
-    }
-  }
-};
-
-#endif
-
 }
 }
 
