@@ -62,17 +62,6 @@
 
 #include "Kokkos_View_Utils.hpp"
 
-// ivdep is necessary to get the intel compiler to vectorize through
-// expresion template assignent operators
-#if defined(__INTEL_COMPILER) && ! defined(__CUDA_ARCH__)
-#define STOKHOS_HAVE_PRAGMA_IVDEP
-#endif
-
-// unrolling appears to slow everything down
-#if 0 && ( defined(__INTEL_COMPILER) || defined(__CUDA_ARCH__) )
-#define STOKHOS_HAVE_PRAGMA_UNROLL
-#endif
-
 namespace Sacado {
 
   //! Namespace for multipoint classes
@@ -209,7 +198,7 @@ namespace Sacado {
        * Sets size to 1 and first coefficient to x (represents a constant).
        */
       KOKKOS_INLINE_FUNCTION
-      Vector(const value_type& x) : s(1) { s.init(x); }
+      Vector(const value_type& x) : s(1,x) {}
 
       //! View constructor
       /*!
@@ -255,6 +244,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -548,6 +540,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -579,6 +574,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -602,6 +600,15 @@ namespace Sacado {
       {
         const typename Expr<S>::derived_type & x = xx.derived();
 
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for ( ordinal_type i = 0 ; i < s.size() ; ++i ) { s[i] = x.coeff(i); }
 
         return *this ;
@@ -618,6 +625,15 @@ namespace Sacado {
       {
         const typename Expr<S>::derived_type & x = xx.derived();
 
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for ( ordinal_type i = 0 ; i < s.size() ; ++i ) { s[i] = x.coeff(i); }
 
         return *this ;
@@ -823,6 +839,15 @@ namespace Sacado {
       //! Addition-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       Vector& operator += (const value_type& x) {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] += x;
         return *this;
@@ -831,6 +856,15 @@ namespace Sacado {
       //! Addition-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       Vector& operator += (const volatile value_type& x) {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] += x;
         return *this;
@@ -839,6 +873,15 @@ namespace Sacado {
       //! Addition-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       /*volatile*/ Vector& operator += (const value_type& x) volatile {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] += x;
         return const_cast<Vector&>(*this);
@@ -847,6 +890,15 @@ namespace Sacado {
       //! Addition-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       /*volatile*/ Vector& operator += (const volatile value_type& x) volatile {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] += x;
         return const_cast<Vector&>(*this);
@@ -855,6 +907,15 @@ namespace Sacado {
       //! Subtraction-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       Vector& operator -= (const value_type& x) {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] -= x;
         return *this;
@@ -863,6 +924,15 @@ namespace Sacado {
       //! Subtraction-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       Vector& operator -= (const volatile value_type& x) {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] -= x;
         return *this;
@@ -871,6 +941,15 @@ namespace Sacado {
       //! Subtraction-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       /*volatile*/ Vector& operator -= (const value_type& x) volatile {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] -= x;
         return const_cast<Vector&>(*this);
@@ -879,6 +958,15 @@ namespace Sacado {
       //! Subtraction-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       /*volatile*/ Vector& operator -= (const volatile value_type& x) volatile {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] -= x;
         return const_cast<Vector&>(*this);
@@ -887,6 +975,15 @@ namespace Sacado {
       //! Multiplication-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       Vector& operator *= (const value_type& x) {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] *= x;
         return *this;
@@ -895,6 +992,15 @@ namespace Sacado {
       //! Multiplication-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       Vector& operator *= (const volatile value_type& x) {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] *= x;
         return *this;
@@ -903,6 +1009,15 @@ namespace Sacado {
       //! Multiplication-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       /*volatile*/ Vector& operator *= (const value_type& x) volatile {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] *= x;
         return const_cast<Vector&>(*this);
@@ -911,6 +1026,15 @@ namespace Sacado {
       //! Multiplication-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       /*volatile*/ Vector& operator *= (const volatile value_type& x) volatile {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] *= x;
         return const_cast<Vector&>(*this);
@@ -919,6 +1043,15 @@ namespace Sacado {
       //! Division-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       Vector& operator /= (const value_type& x) {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] /= x;
         return *this;
@@ -927,6 +1060,15 @@ namespace Sacado {
       //! Division-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       Vector& operator /= (const volatile value_type& x) {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] /= x;
         return *this;
@@ -935,6 +1077,15 @@ namespace Sacado {
       //! Division-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       /*volatile*/ Vector& operator /= (const value_type& x) volatile {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] /= x;
         return const_cast<Vector&>(*this);
@@ -943,6 +1094,15 @@ namespace Sacado {
       //! Division-assignment operator with constant right-hand-side
       KOKKOS_INLINE_FUNCTION
       /*volatile*/ Vector& operator /= (const volatile value_type& x) volatile {
+#ifdef STOKHOS_HAVE_PRAGMA_IVDEP
+#pragma ivdep
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
+#ifdef STOKHOS_HAVE_PRAGMA_UNROLL
+#pragma unroll
+#endif
         for (ordinal_type i=0; i<s.size(); i++)
           s[i] /= x;
         return const_cast<Vector&>(*this);
@@ -968,6 +1128,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1001,6 +1164,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1034,6 +1200,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1067,6 +1236,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1100,6 +1272,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1133,6 +1308,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1166,6 +1344,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1199,6 +1380,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1232,6 +1416,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1265,6 +1452,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1298,6 +1488,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1331,6 +1524,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1364,6 +1560,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1397,6 +1596,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1430,6 +1632,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
@@ -1463,6 +1668,9 @@ namespace Sacado {
 #ifdef STOKHOS_HAVE_PRAGMA_IVDEP
 #pragma ivdep
 #endif
+#ifdef STOKHOS_HAVE_PRAGMA_VECTOR_ALIGNED
+#pragma vector aligned
+#endif
 #ifdef STOKHOS_HAVE_PRAGMA_UNROLL
 #pragma unroll
 #endif
