@@ -61,7 +61,8 @@ namespace Stokhos {
 namespace details {
 
 template <typename Matrix, typename InputVector, typename OutputVector,
-          typename Update = MultiplyAssign>
+          typename Update = MultiplyAssign,
+          typename Enabled = void>
 class MPMultiply {};
 
 // Kernel implementing y = A * x where
@@ -71,38 +72,31 @@ class MPMultiply {};
 // We spell everything out here to make sure the ranks and devices match.
 //
 // This implementation uses overloaded operators for MP::Vector.
-template <typename Device,
-          typename ViewDevice,
+template <typename MatrixDevice,
           typename MatrixStorage,
           typename MatrixOrdinal,
           typename MatrixMemory,
           typename MatrixSize,
           typename InputStorage,
-          typename InputLayout,
-          typename InputMemory,
+          typename ... InputP,
           typename OutputStorage,
-          typename OutputLayout,
-          typename OutputMemory,
+          typename ... OutputP,
           typename Update>
 class MPMultiply< KokkosSparse::CrsMatrix< Sacado::MP::Vector<MatrixStorage>,
-                                     MatrixOrdinal,
-                                     Device,
-                                     MatrixMemory,
-                                     MatrixSize>,
+                                           MatrixOrdinal,
+                                           MatrixDevice,
+                                           MatrixMemory,
+                                           MatrixSize>,
                   Kokkos::View< Sacado::MP::Vector<InputStorage>*,
-                                InputLayout,
-#ifdef KOKKOS_HAVE_CUDA
-    typename Kokkos::Impl::if_c<!Kokkos::Impl::is_same<Device,Kokkos::Cuda>::value,ViewDevice,void>::type,
-#else
-                                ViewDevice,
-#endif
-                                InputMemory >,
+                                InputP... >,
                   Kokkos::View< Sacado::MP::Vector<OutputStorage>*,
-                                OutputLayout,
-                                ViewDevice,
-                                OutputMemory >,
+                                OutputP... >,
                   Update
-                >
+#ifdef KOKKOS_HAVE_CUDA
+                  , typename std::enable_if<
+                      !std::is_same<MatrixDevice,Kokkos::Cuda>::value >::type
+#endif
+                  >
 {
 
 public:
@@ -112,22 +106,18 @@ public:
   typedef Sacado::MP::Vector<OutputStorage> OutputVectorValue;
   typedef OutputVectorValue scalar_type;
 
-  typedef Device execution_space;
+  typedef MatrixDevice execution_space;
   typedef typename execution_space::size_type size_type;
 
   typedef KokkosSparse::CrsMatrix< MatrixValue,
-                             MatrixOrdinal,
-                             Device,
-                             MatrixMemory,
-                             MatrixSize> matrix_type;
+                                   MatrixOrdinal,
+                                   MatrixDevice,
+                                   MatrixMemory,
+                                   MatrixSize > matrix_type;
   typedef Kokkos::View< InputVectorValue*,
-                        InputLayout,
-                        Device,
-                        InputMemory > input_vector_type;
+                        InputP... > input_vector_type;
   typedef Kokkos::View< OutputVectorValue*,
-                        OutputLayout,
-                        Device,
-                        OutputMemory > output_vector_type;
+                        OutputP... > output_vector_type;
   typedef Update update_type;
 
   const matrix_type  m_A;
@@ -176,37 +166,30 @@ public:
 // We spell everything out here to make sure the ranks and devices match.
 //
 // This implementation uses overloaded operators for MP::Vector.
-template <typename Device,
-          typename ViewDevice,
+template <typename MatrixDevice,
           typename MatrixStorage,
           typename MatrixOrdinal,
           typename MatrixMemory,
           typename MatrixSize,
           typename InputStorage,
-          typename InputLayout,
-          typename InputMemory,
+          typename ... InputP,
           typename OutputStorage,
-          typename OutputLayout,
-          typename OutputMemory,
+          typename ... OutputP,
           typename Update>
 class MPMultiply< KokkosSparse::CrsMatrix< Sacado::MP::Vector<MatrixStorage>,
-                                     MatrixOrdinal,
-                                     Device,
-                                     MatrixMemory,
-                                     MatrixSize>,
+                                           MatrixOrdinal,
+                                           MatrixDevice,
+                                           MatrixMemory,
+                                           MatrixSize >,
                   Kokkos::View< Sacado::MP::Vector<InputStorage>**,
-                                InputLayout,
-#ifdef KOKKOS_HAVE_CUDA
-    typename Kokkos::Impl::if_c<!Kokkos::Impl::is_same<Device,Kokkos::Cuda>::value,ViewDevice,void>::type,
-#else
-                                ViewDevice,
-#endif
-                                InputMemory >,
+                                InputP... >,
                   Kokkos::View< Sacado::MP::Vector<OutputStorage>**,
-                                OutputLayout,
-                                ViewDevice,
-                                OutputMemory >,
+                                OutputP... >,
                   Update
+#ifdef KOKKOS_HAVE_CUDA
+                  , typename std::enable_if<
+                    !std::is_same<MatrixDevice,Kokkos::Cuda>::value >::type
+#endif
                   >
 {
 public:
@@ -215,23 +198,19 @@ public:
   typedef Sacado::MP::Vector<OutputStorage> OutputVectorValue;
   typedef OutputVectorValue scalar_type;
 
-  typedef Device execution_space;
+  typedef MatrixDevice execution_space;
   typedef typename execution_space::size_type size_type;
 
   typedef KokkosSparse::CrsMatrix< MatrixValue,
-                             MatrixOrdinal,
-                             Device,
-                             MatrixMemory,
-                             MatrixSize> matrix_type;
+                                   MatrixOrdinal,
+                                   MatrixDevice,
+                                   MatrixMemory,
+                                   MatrixSize > matrix_type;
   typedef typename matrix_type::values_type matrix_values_type;
   typedef Kokkos::View< InputVectorValue**,
-                        InputLayout,
-                        ViewDevice,
-                        InputMemory > input_vector_type;
+                        InputP... > input_vector_type;
   typedef Kokkos::View< OutputVectorValue**,
-                        OutputLayout,
-                        ViewDevice,
-                        OutputMemory > output_vector_type;
+                        OutputP... > output_vector_type;
   typedef Update update_type;
 
   const matrix_type  m_A;
@@ -289,30 +268,24 @@ public:
 // We spell everything out here to make sure the ranks and devices match.
 //
 // This implementation uses overloaded operators for MP::Vector.
-template <typename Device,
+template <typename MatrixDevice,
           typename MatrixStorage,
           typename MatrixOrdinal,
           typename MatrixMemory,
           typename MatrixSize,
           typename InputStorage,
-          typename InputLayout,
-          typename InputMemory,
+          typename ... InputP,
           typename OutputStorage,
-          typename OutputLayout,
-          typename OutputMemory>
+          typename ... OutputP>
 class Multiply< KokkosSparse::CrsMatrix< Sacado::MP::Vector<MatrixStorage>,
-                                   MatrixOrdinal,
-                                   Device,
-                                   MatrixMemory,
-                                   MatrixSize>,
+                                         MatrixOrdinal,
+                                         MatrixDevice,
+                                         MatrixMemory,
+                                         MatrixSize >,
                 Kokkos::View< Sacado::MP::Vector<InputStorage>*,
-                              InputLayout,
-                              Device,
-                              InputMemory >,
+                              InputP... >,
                 Kokkos::View< Sacado::MP::Vector<OutputStorage>*,
-                              OutputLayout,
-                              Device,
-                              OutputMemory >
+                              OutputP... >
                 >
 {
 public:
@@ -320,23 +293,19 @@ public:
   typedef Sacado::MP::Vector<InputStorage> InputVectorValue;
   typedef Sacado::MP::Vector<OutputStorage> OutputVectorValue;
 
-  typedef Device execution_space;
+  typedef MatrixDevice execution_space;
   typedef typename execution_space::size_type size_type;
 
   typedef KokkosSparse::CrsMatrix< MatrixValue,
-                             MatrixOrdinal,
-                             Device,
-                             MatrixMemory,
-                             MatrixSize> matrix_type;
+                                   MatrixOrdinal,
+                                   MatrixDevice,
+                                   MatrixMemory,
+                                   MatrixSize > matrix_type;
   typedef typename matrix_type::values_type matrix_values_type;
   typedef Kokkos::View< InputVectorValue*,
-                        InputLayout,
-                        Device,
-                        InputMemory > input_vector_type;
+                        InputP... > input_vector_type;
   typedef Kokkos::View< OutputVectorValue*,
-                        OutputLayout,
-                        Device,
-                        OutputMemory > output_vector_type;
+                        OutputP... > output_vector_type;
 
 public:
 
@@ -356,30 +325,24 @@ public:
 // We spell everything out here to make sure the ranks and devices match.
 //
 // This implementation uses overloaded operators for MP::Vector.
-template <typename Device,
+template <typename MatrixDevice,
           typename MatrixStorage,
           typename MatrixOrdinal,
           typename MatrixMemory,
           typename MatrixSize,
           typename InputStorage,
-          typename InputLayout,
-          typename InputMemory,
+          typename ... InputP,
           typename OutputStorage,
-          typename OutputLayout,
-          typename OutputMemory>
+          typename ... OutputP>
 class Multiply< KokkosSparse::CrsMatrix< Sacado::MP::Vector<MatrixStorage>,
-                                   MatrixOrdinal,
-                                   Device,
-                                   MatrixMemory,
-                                   MatrixSize>,
+                                         MatrixOrdinal,
+                                         MatrixDevice,
+                                         MatrixMemory,
+                                         MatrixSize >,
                 Kokkos::View< Sacado::MP::Vector<InputStorage>**,
-                              InputLayout,
-                              Device,
-                              InputMemory >,
+                              InputP... >,
                 Kokkos::View< Sacado::MP::Vector<OutputStorage>**,
-                              OutputLayout,
-                              Device,
-                              OutputMemory >
+                              OutputP... >
                 >
 {
 public:
@@ -387,23 +350,19 @@ public:
   typedef Sacado::MP::Vector<InputStorage> InputVectorValue;
   typedef Sacado::MP::Vector<OutputStorage> OutputVectorValue;
 
-  typedef Device execution_space;
+  typedef MatrixDevice execution_space;
   typedef typename execution_space::size_type size_type;
 
   typedef KokkosSparse::CrsMatrix< MatrixValue,
-                             MatrixOrdinal,
-                             Device,
-                             MatrixMemory,
-                             MatrixSize> matrix_type;
+                                   MatrixOrdinal,
+                                   MatrixDevice,
+                                   MatrixMemory,
+                                   MatrixSize > matrix_type;
   typedef typename matrix_type::values_type matrix_values_type;
   typedef Kokkos::View< InputVectorValue**,
-                        InputLayout,
-                        Device,
-                        InputMemory > input_vector_type;
+                        InputP... > input_vector_type;
   typedef Kokkos::View< OutputVectorValue**,
-                        OutputLayout,
-                        Device,
-                        OutputMemory > output_vector_type;
+                        OutputP... > output_vector_type;
 
 public:
 
@@ -424,36 +383,25 @@ template <typename AlphaType,
           typename BetaType,
           typename MatrixType,
           typename InputType,
-          typename InputLayout,
-          typename InputDevice,
-          typename InputMemory,
+          typename ... InputP,
           typename OutputType,
-          typename OutputLayout,
-          typename OutputDevice,
-          typename OutputMemory>
-void
+          typename ... OutputP>
+typename std::enable_if<
+  Kokkos::is_view_mp_vector< Kokkos::View< InputType, InputP... > >::value &&
+  Kokkos::is_view_mp_vector< Kokkos::View< OutputType, OutputP... > >::value
+  >::type
 spmv(
   const char mode[],
   const AlphaType& a,
   const MatrixType& A,
-  const Kokkos::View< InputType,
-                      InputLayout,
-                      InputDevice,
-                      InputMemory,
-                      Kokkos::Impl::ViewMPVectorContiguous >& x,
+  const Kokkos::View< InputType, InputP... >& x,
   const BetaType& b,
-  const Kokkos::View< OutputType,
-                      OutputLayout,
-                      OutputDevice,
-                      OutputMemory,
-                      Kokkos::Impl::ViewMPVectorContiguous >& y,
+  const Kokkos::View< OutputType, OutputP... >& y,
   const RANK_ONE)
 {
-  typedef Kokkos::View< OutputType, OutputLayout, OutputDevice, OutputMemory,
-    Kokkos::Impl::ViewMPVectorContiguous > OutputVectorType;
-  typedef Kokkos::View< InputType, InputLayout, InputDevice, InputMemory,
-    Kokkos::Impl::ViewMPVectorContiguous > InputVectorType;
-  typedef typename InputVectorType::intrinsic_scalar_type value_type;
+  typedef Kokkos::View< OutputType, OutputP... > OutputVectorType;
+  typedef Kokkos::View< InputType, InputP... > InputVectorType;
+  typedef typename InputVectorType::array_type::non_const_value_type value_type;
 
   if(mode[0]!='N') {
     Kokkos::Impl::raise_error(
@@ -512,29 +460,20 @@ template <typename AlphaType,
           typename BetaType,
           typename MatrixType,
           typename InputType,
-          typename InputLayout,
-          typename InputDevice,
-          typename InputMemory,
+          typename ... InputP,
           typename OutputType,
-          typename OutputLayout,
-          typename OutputDevice,
-          typename OutputMemory>
-void
+          typename ... OutputP>
+typename std::enable_if<
+  Kokkos::is_view_mp_vector< Kokkos::View< InputType, InputP... > >::value &&
+  Kokkos::is_view_mp_vector< Kokkos::View< OutputType, OutputP... > >::value
+  >::type
 spmv(
   const char mode[],
   const AlphaType& a,
   const MatrixType& A,
-  const Kokkos::View< InputType,
-                      InputLayout,
-                      InputDevice,
-                      InputMemory,
-                      Kokkos::Impl::ViewMPVectorContiguous >& x,
+  const Kokkos::View< InputType, InputP... >& x,
   const BetaType& b,
-  const Kokkos::View< OutputType,
-                      OutputLayout,
-                      OutputDevice,
-                      OutputMemory,
-                      Kokkos::Impl::ViewMPVectorContiguous >& y,
+  const Kokkos::View< OutputType, OutputP... >& y,
   const RANK_TWO)
 {
   if(mode[0]!='N') {
@@ -547,11 +486,9 @@ spmv(
     spmv(mode, a, A, x_1D, b, y_1D, RANK_ONE());
   }
   else {
-    typedef Kokkos::View< OutputType, OutputLayout, OutputDevice, OutputMemory,
-      Kokkos::Impl::ViewMPVectorContiguous > OutputVectorType;
-    typedef Kokkos::View< InputType, InputLayout, InputDevice, InputMemory,
-      Kokkos::Impl::ViewMPVectorContiguous > InputVectorType;
-    typedef typename InputVectorType::intrinsic_scalar_type value_type;
+    typedef Kokkos::View< OutputType, OutputP... > OutputVectorType;
+    typedef Kokkos::View< InputType, InputP... > InputVectorType;
+    typedef typename InputVectorType::array_type::non_const_value_type value_type;
 
     if (!Sacado::is_constant(a) || !Sacado::is_constant(b)) {
       Kokkos::Impl::raise_error(
