@@ -127,7 +127,6 @@ struct LocalViewTraits {
 
 #if defined( KOKKOS_HAVE_CUDA )
 
-#if defined( KOKKOS_USING_EXPERIMENTAL_VIEW )
 template <typename ViewType>
 struct LocalViewTraits<
   ViewType,
@@ -148,45 +147,6 @@ struct LocalViewTraits<
   }
 };
 
-#else
-
-template <typename T, typename L, typename M>
-struct LocalViewTraits< Kokkos::View<T,L,Kokkos::Cuda,M,Kokkos::Impl::ViewMPVectorContiguous> > {
-  typedef Kokkos::Impl::ViewMPVectorContiguous Specialize;
-  typedef Kokkos::View<T,L,Kokkos::Cuda,M,Specialize> view_type;
-  typedef typename Kokkos::LocalMPVectorView<view_type,1>::type local_view_type;
-  typedef typename local_view_type::value_type local_value_type;
-  static const bool use_team = true;
-
-  KOKKOS_INLINE_FUNCTION
-  static local_view_type create_local_view(const view_type& v,
-                                           const unsigned local_rank)
-  {
-    local_view_type local_v =
-      Kokkos::partition<local_view_type>(v, local_rank, local_rank+1);
-    return local_v;
-  }
-};
-
-template <typename T, typename M, typename V>
-struct LocalViewTraits< Kokkos::View<T,Kokkos::Cuda,M,V,Kokkos::Impl::ViewMPVectorContiguous> > {
-  typedef Kokkos::Impl::ViewMPVectorContiguous Specialize;
-  typedef Kokkos::View<T,Kokkos::Cuda,M,V,Specialize> view_type;
-  typedef typename Kokkos::LocalMPVectorView<view_type,1>::type local_view_type;
-  typedef typename local_view_type::value_type local_value_type;
-  static const bool use_team = true;
-
-  KOKKOS_INLINE_FUNCTION
-  static local_view_type create_local_view(const view_type& v,
-                                           const unsigned local_rank)
-  {
-    local_view_type local_v =
-      Kokkos::partition<local_view_type>(v, local_rank, local_rank+1);
-    return local_v;
-  }
-};
-#endif
-
 #endif /* #if defined( KOKKOS_HAVE_CUDA ) */
 
 // Compute DeviceConfig struct's based on scalar type
