@@ -216,14 +216,12 @@ bool AztecOOLinearOpWithSolveFactory::supportsPreconditionerInputType(
   switch(precOpType) {
     case PRECONDITIONER_INPUT_TYPE_AS_OPERATOR:
       return true;
-      break;
     case PRECONDITIONER_INPUT_TYPE_AS_MATRIX:
       return useAztecPrec_;
-      break;
     default:
       TEUCHOS_TEST_FOR_EXCEPT(true);
   }
-  return PRECONDITIONER_INPUT_TYPE_AS_OPERATOR; // Should never be called!
+  TEUCHOS_UNREACHABLE_RETURN(PRECONDITIONER_INPUT_TYPE_AS_OPERATOR);
 }
 
 
@@ -589,7 +587,7 @@ void AztecOOLinearOpWithSolveFactory::initializeOp_impl(
   EOpTransp epetra_epetraPrecOpTransp;
   EApplyEpetraOpAs epetra_epetraPrecOpApplyAs;
   EAdjointEpetraOp epetra_epetraPrecOpAdjointSupport;
-  EOpTransp overall_epetra_epetraPrecOpTransp;
+  EOpTransp overall_epetra_epetraPrecOpTransp=NOTRANS;
   if(rightPrecOp.get()) {
     RCP<const LinearOpBase<double> > tmpWrappedPrecOp;
     unwrap(
