@@ -111,14 +111,19 @@ int tLSCStabilized::runTest(int verbosity,std::ostream & stdstrm,std::ostream &
    allTests &= status;
    failcount += status ? 0 : 1;
    totalrun++;
-
 /*
+   status = test_diagonalNotSym(verbosity,failstrm);
+   Teko_TEST_MSG(stdstrm,1,"   \"diagonalNotSym\" ... PASSED","   \"diagonalNotSym\" ... FAILED");
+   allTests &= status;
+   failcount += status ? 0 : 1;
+   totalrun++;
+*/
    status = test_strategy(verbosity,failstrm);
    Teko_TEST_MSG(stdstrm,1,"   \"strategy\" ... PASSED","   \"strategy\" ... FAILED");
    allTests &= status;
    failcount += status ? 0 : 1;
    totalrun++;
-*/
+
 
    status = allTests;
    if(verbosity >= 10) {
