@@ -40,30 +40,19 @@
 // @HEADER
 
 #include "Teuchos_CommHelpers.hpp"
-#ifdef HAVE_MPI
+#ifdef HAVE_TEUCHOS_MPI
 #  include "Teuchos_Details_MpiCommRequest.hpp"
-#endif // HAVE_MPI
+#  include "Teuchos_Details_MpiTypeTraits.hpp"
+#endif // HAVE_TEUCHOS_MPI
+#ifdef HAVE_TEUCHOSCORE_CXX11
+#  include <memory>
+#endif
 
 namespace Teuchos {
-namespace { // (anonymous)
 
-#ifdef HAVE_MPI
-//! Get the raw MPI_Op corresponding to the given reduction type enum value.
-MPI_Op getMpiOpForEReductionType (const enum EReductionType reductionType) {
-  switch (reductionType) {
-  case REDUCE_SUM: return MPI_SUM;
-  case REDUCE_MIN: return MPI_MIN;
-  case REDUCE_MAX: return MPI_MAX;
-  case REDUCE_AND: return MPI_LAND; // logical AND, not bitwise AND
-  default:
-    TEUCHOS_TEST_FOR_EXCEPTION(true, std::invalid_argument,
-      "The given EReductionType value is invalid.");
-  }
-}
+#ifdef HAVE_TEUCHOS_MPI
+namespace Details {
 
-/// \brief MPI's error string corresponding to the given integer error code.
-///
-/// \param errCode [in] Integer error code returned by MPI functions.
 std::string getMpiErrorString (const int errCode) {
   // Space for storing the error string returned by MPI.
   // Leave room for null termination, since I don't know if MPI does this.
@@ -80,133 +69,15 @@ std::string getMpiErrorString (const int errCode) {
   return std::string (errString); // This copies the original string.
 }
 
-/// \class MpiTypeTraits
-/// \brief Traits class mapping from type T to its MPI_Datatype
-/// \tparam T The type being sent or received.  T must be default
-///   constructible.  It must also be either one of C++'s built-in
-///   types (like \c int or \c double), or a struct or "struct-like"
-///   type like <tt>std::complex<double</tt>, for which sizeof(T)
-///   correctly conveys the amount of data to send or receive.
-template<class T>
-class MpiTypeTraits {
-public:
-  /// \brief The MPI_Datatype corresponding to the given T instance.
-  ///
-  /// For more generality, this method requires passing in a T
-  /// instance.  The method may or may not ignore this instance,
-  /// depending on the type T.
-  static MPI_Datatype getType (const T&);
-};
-
-// amb See note in .hpp file.
-#if 0
-#ifdef HAVE_TEUCHOS_COMPLEX
-template<>
-class MpiTypeTraits<std::complex<double> > {
-public:
-  static MPI_Datatype getType (const std::complex<double>&) {
-    return MPI_C_DOUBLE_COMPLEX;
-  }
-};
-
-template<>
-class MpiTypeTraits<std::complex<float> > {
-public:
-  static MPI_Datatype getType (const std::complex<float>&) {
-    return MPI_C_FLOAT_COMPLEX;
-  }
-};
-#endif // HAVE_TEUCHOS_COMPLEX
-#endif // if 0
-
-template<>
-class MpiTypeTraits<double> {
-public:
-  static MPI_Datatype getType (const double&) {
-    return MPI_DOUBLE;
-  }
-};
-
-template<>
-class MpiTypeTraits<float> {
-public:
-  static MPI_Datatype getType (const float&) {
-    return MPI_FLOAT;
-  }
-};
-
-#ifdef HAVE_TEUCHOS_LONG_LONG_INT
-template<>
-class MpiTypeTraits<long long> {
-public:
-  static MPI_Datatype getType (const long long&) {
-    return MPI_LONG_LONG;
-  }
-};
-
-template<>
-class MpiTypeTraits<unsigned long long> {
-public:
-  static MPI_Datatype getType (const unsigned long long&) {
-    return MPI_UNSIGNED_LONG_LONG;
-  }
-};
-#endif // HAVE_TEUCHOS_LONG_LONG_INT
-
-template<>
-class MpiTypeTraits<long> {
-public:
-  static MPI_Datatype getType (const long&) {
-    return MPI_LONG;
-  }
-};
-
-template<>
-class MpiTypeTraits<unsigned long> {
-public:
-  static MPI_Datatype getType (const unsigned long&) {
-    return MPI_UNSIGNED_LONG;
-  }
-};
-
-template<>
-class MpiTypeTraits<int> {
-public:
-  static MPI_Datatype getType (const int&) {
-    return MPI_INT;
-  }
-};
-
-template<>
-class MpiTypeTraits<unsigned int> {
-public:
-  static MPI_Datatype getType (const unsigned int&) {
-    return MPI_UNSIGNED;
-  }
-};
-
-template<>
-class MpiTypeTraits<short> {
-public:
-  static MPI_Datatype getType (const short&) {
-    return MPI_SHORT;
-  }
-};
-
-template<>
-class MpiTypeTraits<unsigned short> {
-public:
-  static MPI_Datatype getType (const unsigned short&) {
-    return MPI_UNSIGNED_SHORT;
-  }
-};
-#endif // HAVE_MPI
+} // namespace Details
+#endif // HAVE_TEUCHOS_MPI
 
+namespace { // (anonymous)
 
 /// \brief Generic implementation of reduceAll().
 /// \tparam T The type of data on which to reduce.  The requirements
 ///   for this type are the same as for the template parameter T of
-///   MpiTypeTraits.
+///   Teuchos::Details::MpiTypeTraits.
 ///
 /// This generic implementation factors out common code among all full
 /// specializations of reduceAll() in this file.
@@ -218,7 +89,9 @@ reduceAllImpl (const Comm<int>& comm,
                const T sendBuffer[],
                T globalReducts[])
 {
-#ifdef HAVE_MPI
+#ifdef HAVE_TEUCHOS_MPI
+  using Teuchos::Details::MpiTypeTraits;
+
   // mfh 17 Oct 2012: Even in an MPI build, Comm might be either a
   // SerialComm or an MpiComm.  If it's something else, we fall back
   // to the most general implementation.
@@ -229,36 +102,52 @@ reduceAllImpl (const Comm<int>& comm,
     if (serialComm == NULL) {
       // We don't know what kind of Comm we have, so fall back to the
       // most general implementation.
-      std::auto_ptr<ValueTypeReductionOp<int, T> > reductOp (createOp<int, T> (reductType));
+#ifdef HAVE_TEUCHOSCORE_CXX11
+      std::unique_ptr<ValueTypeReductionOp<int, T> >
+#else
+      std::auto_ptr<ValueTypeReductionOp<int, T> >
+#endif
+          reductOp (createOp<int, T> (reductType));
       reduceAll (comm, *reductOp, count, sendBuffer, globalReducts);
     }
     else { // It's a SerialComm; there is only 1 process, so just copy.
       std::copy (sendBuffer, sendBuffer + count, globalReducts);
     }
   } else { // It's an MpiComm.  Invoke MPI directly.
-    MPI_Op rawMpiOp = getMpiOpForEReductionType (reductType);
+    MPI_Op rawMpiOp = ::Teuchos::Details::getMpiOpForEReductionType (reductType);
     MPI_Comm rawMpiComm = * (mpiComm->getRawMpiComm ());
     T t;
     MPI_Datatype rawMpiType = MpiTypeTraits<T>::getType (t);
-    const int err = MPI_Allreduce (const_cast<T*> (sendBuffer),
-      globalReducts, count, rawMpiType, rawMpiOp, rawMpiComm);
+
+    int err = MPI_SUCCESS;
+    if (sendBuffer == globalReducts) {
+      // NOTE (mfh 31 May 2017) This is only safe if the communicator
+      // is NOT an intercomm.  The usual case is that communicators
+      // are intracomms.
+      err = MPI_Allreduce (MPI_IN_PLACE, globalReducts,
+                           count, rawMpiType, rawMpiOp, rawMpiComm);
+    }
+    else {
+      err = MPI_Allreduce (const_cast<T*> (sendBuffer), globalReducts,
+                           count, rawMpiType, rawMpiOp, rawMpiComm);
+    }
     TEUCHOS_TEST_FOR_EXCEPTION(
       err != MPI_SUCCESS,
       std::runtime_error,
       "MPI_Allreduce failed with the following error: "
-      << getMpiErrorString (err));
+      << ::Teuchos::Details::getMpiErrorString (err));
   }
 #else
   // We've built without MPI, so just assume it's a SerialComm and copy the data.
   std::copy (sendBuffer, sendBuffer + count, globalReducts);
-#endif // HAVE_MPI
+#endif // HAVE_TEUCHOS_MPI
 }
 
 
 /// \brief Generic implementation of gather().
 /// \tparam T The type of data on which to reduce.  The requirements
 ///   for this type are the same as for the template parameter T of
-///   MpiTypeTraits.
+///   Teuchos::Details::MpiTypeTraits.
 ///
 /// This generic implementation factors out common code among all full
 /// specializations of gather() in this file.
@@ -271,7 +160,9 @@ gatherImpl (const T sendBuf[],
             const int root,
             const Comm<int>& comm)
 {
-#ifdef HAVE_MPI
+#ifdef HAVE_TEUCHOS_MPI
+  using Teuchos::Details::MpiTypeTraits;
+
   // mfh 17 Oct 2012: Even in an MPI build, Comm might be either a
   // SerialComm or an MpiComm.  If it's something else, we fall back
   // to the most general implementation.
@@ -298,19 +189,19 @@ gatherImpl (const T sendBuf[],
       err != MPI_SUCCESS,
       std::runtime_error,
       "MPI_Gather failed with the following error: "
-      << getMpiErrorString (err));
+      << ::Teuchos::Details::getMpiErrorString (err));
   }
 #else
   // We've built without MPI, so just assume it's a SerialComm and copy the data.
   std::copy (sendBuf, sendBuf + sendCount, recvBuf);
-#endif // HAVE_MPI
+#endif // HAVE_TEUCHOS_MPI
 }
 
 
 /// \brief Generic implementation of scatter().
 /// \tparam T The type of data on which to scatter.  The requirements
 ///   for this type are the same as for the template parameter T of
-///   MpiTypeTraits.
+///   Teuchos::Details::MpiTypeTraits.
 ///
 /// This generic implementation factors out common code among all full
 /// specializations of scatter() in this file.
@@ -323,7 +214,9 @@ scatterImpl (const T sendBuf[],
              const int root,
              const Comm<int>& comm)
 {
-#ifdef HAVE_MPI
+#ifdef HAVE_TEUCHOS_MPI
+  using Teuchos::Details::MpiTypeTraits;
+
   // mfh 17 Oct 2012: Even in an MPI build, Comm might be either a
   // SerialComm or an MpiComm.  If it's something else, we fall back
   // to the most general implementation.
@@ -350,20 +243,20 @@ scatterImpl (const T sendBuf[],
     TEUCHOS_TEST_FOR_EXCEPTION
       (err != MPI_SUCCESS, std::runtime_error,
       "MPI_Scatter failed with the following error: "
-      << getMpiErrorString (err));
+      << ::Teuchos::Details::getMpiErrorString (err));
   }
 #else
   // We've built without MPI, so just assume it's a SerialComm and
   // copy the data.
   std::copy (sendBuf, sendBuf + sendCount, recvBuf);
-#endif // HAVE_MPI
+#endif // HAVE_TEUCHOS_MPI
 }
 
 
 /// \brief Generic implementation of reduce().
 /// \tparam T The type of data on which to reduce.  The requirements
 ///   for this type are the same as for the template parameter T of
-///   MpiTypeTraits.
+///   Teuchos::Details::MpiTypeTraits.
 ///
 /// This generic implementation factors out common code among all full
 /// specializations of reduce() in this file.
@@ -376,7 +269,9 @@ reduceImpl (const T sendBuf[],
             const int root,
             const Comm<int>& comm)
 {
-#ifdef HAVE_MPI
+#ifdef HAVE_TEUCHOS_MPI
+  using Teuchos::Details::MpiTypeTraits;
+
   // mfh 17 Oct 2012: Even in an MPI build, Comm might be either a
   // SerialComm or an MpiComm.  If it's something else, we fall back
   // to the most general implementation.
@@ -393,7 +288,7 @@ reduceImpl (const T sendBuf[],
       std::copy (sendBuf, sendBuf + count, recvBuf);
     }
   } else { // It's an MpiComm.  Invoke MPI directly.
-    MPI_Op rawMpiOp = getMpiOpForEReductionType (reductType);
+    MPI_Op rawMpiOp = ::Teuchos::Details::getMpiOpForEReductionType (reductType);
     MPI_Comm rawMpiComm = * (mpiComm->getRawMpiComm ());
     T t;
     MPI_Datatype rawMpiType = MpiTypeTraits<T>::getType (t);
@@ -401,19 +296,19 @@ reduceImpl (const T sendBuf[],
                                 rawMpiType, rawMpiOp, root, rawMpiComm);
     TEUCHOS_TEST_FOR_EXCEPTION
       (err != MPI_SUCCESS, std::runtime_error, "MPI_Reduce failed with the "
-       "following error: " << getMpiErrorString (err));
+       "following error: " << ::Teuchos::Details::getMpiErrorString (err));
   }
 #else
   // We've built without MPI, so just assume it's a SerialComm and copy the data.
   std::copy (sendBuf, sendBuf + count, recvBuf);
-#endif // HAVE_MPI
+#endif // HAVE_TEUCHOS_MPI
 }
 
 
 /// \brief Generic implementation of gatherv().
 /// \tparam T The type of data on which to gather.  The requirements
 ///   for this type are the same as for the template parameter T of
-///   MpiTypeTraits.
+///   Teuchos::Details::MpiTypeTraits.
 ///
 /// This generic implementation factors out common code among all full
 /// specializations of gatherv() in this file.
@@ -427,7 +322,9 @@ gathervImpl (const T sendBuf[],
              const int root,
              const Comm<int>& comm)
 {
-#ifdef HAVE_MPI
+#ifdef HAVE_TEUCHOS_MPI
+  using Teuchos::Details::MpiTypeTraits;
+
   // mfh 17 Oct 2012: Even in an MPI build, Comm might be either a
   // SerialComm or an MpiComm.  If it's something else, we fall back
   // to the most general implementation.
@@ -469,7 +366,7 @@ gathervImpl (const T sendBuf[],
       err != MPI_SUCCESS,
       std::runtime_error,
       "MPI_Gatherv failed with the following error: "
-      << getMpiErrorString (err));
+      << ::Teuchos::Details::getMpiErrorString (err));
   }
 #else
   // We've built without MPI, so just assume it's a SerialComm and copy the data.
@@ -483,7 +380,7 @@ gathervImpl (const T sendBuf[],
   // amount to receive, so it's the amount to copy.  Start writing
   // to recvbuf at the offset displs[0].
   std::copy (sendBuf, sendBuf + recvCounts[0], recvBuf + displs[0]);
-#endif // HAVE_MPI
+#endif // HAVE_TEUCHOS_MPI
 }
 
 /// \brief Generic implementation of ireceive() for any Comm subclass.
@@ -533,7 +430,7 @@ ireceiveGeneral (const ArrayRCP<Packet> &recvBuffer,
 /// \brief Generic implementation of ireceive() for MpiComm.
 /// \tparam T The type of data to receive.  The requirements for this
 ///   type are the same as for the template parameter T of
-///   MpiTypeTraits.
+///   Teuchos::Details::MpiTypeTraits.
 ///
 /// This generic implementation factors out common code among all full
 /// specializations of ireceive() in this file.
@@ -548,7 +445,9 @@ ireceiveImpl (const Comm<int>& comm,
               const ArrayRCP<T>& recvBuffer,
               const int sourceRank)
 {
-#ifdef HAVE_MPI
+#ifdef HAVE_TEUCHOS_MPI
+  using Teuchos::Details::MpiTypeTraits;
+
   // Even in an MPI build, Comm might be either a SerialComm or an
   // MpiComm.  If it's something else, we fall back to the most
   // general implementation.
@@ -581,7 +480,7 @@ ireceiveImpl (const Comm<int>& comm,
     TEUCHOS_TEST_FOR_EXCEPTION(
       err != MPI_SUCCESS, std::runtime_error,
       "MPI_Irecv failed with the following error: "
-      << getMpiErrorString (err));
+      << ::Teuchos::Details::getMpiErrorString (err));
 
     ArrayRCP<const char> buf =
       arcp_const_cast<const char> (arcp_reinterpret_cast<char> (recvBuffer));
@@ -603,7 +502,7 @@ ireceiveImpl (const Comm<int>& comm,
   // doesn't have unreachable code (which never gets tested).
 
   //return null; // Guard to avoid compiler warning about not returning a value.
-#endif // HAVE_MPI
+#endif // HAVE_TEUCHOS_MPI
 }
 
 /// \brief Variant of ireceiveImpl that takes a tag.
@@ -615,7 +514,9 @@ ireceiveImpl (const ArrayRCP<T>& recvBuffer,
               const int tag,
               const Comm<int>& comm)
 {
-#ifdef HAVE_MPI
+#ifdef HAVE_TEUCHOS_MPI
+  using Teuchos::Details::MpiTypeTraits;
+
   // Even in an MPI build, Comm might be either a SerialComm or an
   // MpiComm.  If it's something else, we fall back to the most
   // general implementation.
@@ -647,7 +548,7 @@ ireceiveImpl (const ArrayRCP<T>& recvBuffer,
     TEUCHOS_TEST_FOR_EXCEPTION(
       err != MPI_SUCCESS, std::runtime_error,
       "MPI_Irecv failed with the following error: "
-      << getMpiErrorString (err));
+      << ::Teuchos::Details::getMpiErrorString (err));
 
     ArrayRCP<const char> buf =
       arcp_const_cast<const char> (arcp_reinterpret_cast<char> (recvBuffer));
@@ -661,7 +562,7 @@ ireceiveImpl (const ArrayRCP<T>& recvBuffer,
     "ireceiveImpl: Not implemented for a serial communicator.");
 
   return null; // Guard to avoid compiler warning about not returning a value.
-#endif // HAVE_MPI
+#endif // HAVE_TEUCHOS_MPI
 }
 
 /// \brief Generic implementation of send() for any Comm subclass.
@@ -705,7 +606,7 @@ sendGeneral (const T sendBuffer[],
 /// \brief Generic implementation of send() for MpiComm.
 /// \tparam T The type of data to send.  The requirements for this
 ///   type are the same as for the template parameter T of
-///   MpiTypeTraits.
+///   Teuchos::Details::MpiTypeTraits.
 ///
 /// This generic implementation factors out common code among all full
 /// specializations of send() in this file.
@@ -721,7 +622,9 @@ sendImpl (const Comm<int>& comm,
           const T sendBuffer[],
           const int destRank)
 {
-#ifdef HAVE_MPI
+#ifdef HAVE_TEUCHOS_MPI
+  using Teuchos::Details::MpiTypeTraits;
+
   // Even in an MPI build, Comm might be either a SerialComm or an
   // MpiComm.  If it's something else, we fall back to the most
   // general implementation.
@@ -752,14 +655,14 @@ sendImpl (const Comm<int>& comm,
       err != MPI_SUCCESS,
       std::runtime_error,
       "MPI_Send failed with the following error: "
-      << getMpiErrorString (err));
+      << ::Teuchos::Details::getMpiErrorString (err));
   }
 #else
   TEUCHOS_TEST_FOR_EXCEPTION(
     true,
     std::logic_error,
     "sendImpl: Not implemented for a serial communicator.");
-#endif // HAVE_MPI
+#endif // HAVE_TEUCHOS_MPI
 }
 
 /// \brief Variant of sendImpl that takes a tag.
@@ -772,7 +675,9 @@ sendImpl (const T sendBuffer[],
           const int tag,
           const Comm<int>& comm)
 {
-#ifdef HAVE_MPI
+#ifdef HAVE_TEUCHOS_MPI
+  using Teuchos::Details::MpiTypeTraits;
+
   // Even in an MPI build, Comm might be either a SerialComm or an
   // MpiComm.  If it's something else, we fall back to the most
   // general implementation.
@@ -802,14 +707,14 @@ sendImpl (const T sendBuffer[],
       err != MPI_SUCCESS,
       std::runtime_error,
       "MPI_Send failed with the following error: "
-      << getMpiErrorString (err));
+      << ::Teuchos::Details::getMpiErrorString (err));
   }
 #else
   TEUCHOS_TEST_FOR_EXCEPTION(
     true,
     std::logic_error,
     "sendImpl: Not implemented for a serial communicator.");
-#endif // HAVE_MPI
+#endif // HAVE_TEUCHOS_MPI
 }
 
 /// \brief Generic implementation of isend() for any Comm subclass.
@@ -865,7 +770,9 @@ isendImpl (const ArrayRCP<const T>& sendBuffer,
            const int tag,
            const Comm<int>& comm)
 {
-#ifdef HAVE_MPI
+#ifdef HAVE_TEUCHOS_MPI
+  using Teuchos::Details::MpiTypeTraits;
+
   // Even in an MPI build, Comm might be either a SerialComm or an
   // MpiComm.  If it's something else, we fall back to the most
   // general implementation.
@@ -900,7 +807,7 @@ isendImpl (const ArrayRCP<const T>& sendBuffer,
       err != MPI_SUCCESS,
       std::runtime_error,
       "MPI_Isend failed with the following error: "
-      << getMpiErrorString (err));
+      << ::Teuchos::Details::getMpiErrorString (err));
 
     ArrayRCP<const char> buf = arcp_reinterpret_cast<const char> (sendBuffer);
     RCP<Details::MpiCommRequest> req (new Details::MpiCommRequest (rawRequest, buf));
@@ -911,31 +818,12 @@ isendImpl (const ArrayRCP<const T>& sendBuffer,
     true,
     std::logic_error,
     "isendImpl: Not implemented for a serial communicator.");
-#endif // HAVE_MPI
+#endif // HAVE_TEUCHOS_MPI
 }
 
 } // namespace (anonymous)
 
 
-const char*
-toString (const EReductionType reductType)
-{
-  switch (reductType) {
-  case REDUCE_SUM: return "REDUCE_SUM";
-  case REDUCE_MIN: return "REDUCE_MIN";
-  case REDUCE_MAX: return "REDUCE_MAX";
-  case REDUCE_AND: return "REDUCE_AND";
-  default:
-    TEUCHOS_TEST_FOR_EXCEPTION(
-      true, std::invalid_argument, "Teuchos::toString(EReductionType): "
-      "Invalid EReductionType value " << reductType << ".  Valid values "
-      "include REDUCE_SUM = " << REDUCE_SUM << ", REDUCE_MIN = " << REDUCE_MIN
-      << ", REDUCE_MAX = " << REDUCE_MIN << ", and REDUCE_AND = " << REDUCE_AND
-      << ".");
-  }
-}
-
-
 // mfh 18 Oct 2012: Note on full template specializations
 //
 // To make Windows builds happy, declarations of full template
