@@ -1,8 +1,14 @@
 #include <KokkosCompat_ClassicNodeAPI_Wrapper.hpp>
 #include <Kokkos_Core.hpp>
+#include <cerrno>
 #include <cstdlib> // getenv
 #include <sstream>
 
+
+#if defined(KOKKOS_HAVE_OPENMP) || defined(KOKKOS_HAVE_PTHREAD) || defined(KOKKOS_HAVE_CUDA)
+  // The struct and function here only get used if at least one of
+  // Kokkos::Cuda, Kokkos::OpenMP, or Kokkos::Threads are enabled.
+
 namespace { // (anonymous)
 
   struct CmdLineArgs {
@@ -268,8 +274,11 @@ namespace { // (anonymous)
     }
     return argsOut;
   }
+
 } // namespace (anonymous)
 
+#endif // defined(KOKKOS_HAVE_OPENMP) || defined(KOKKOS_HAVE_PTHREAD)
+
 namespace Kokkos {
   namespace Compat {
     namespace Details {
@@ -306,37 +315,27 @@ namespace Kokkos {
       }
     } // namespace Details
 
-    // mfh 01 Jan 2014: These definitions of the class variable count
-    // need to be inside the namespace.  Declaring them as "template<>
-    // int Kokkos::Compat::KokkosCudaWrapperNode::count = 0" in the
-    // global namespace is a C++11 extension and results in compiler
-    // warnings with Clang 3.2 on MacOS X.
-#ifdef KOKKOS_HAVE_CUDA
-    template<> int KokkosCudaWrapperNode::count = 0;
-#endif
-#ifdef KOKKOS_HAVE_OPENMP
-    template<> int KokkosOpenMPWrapperNode::count = 0;
-#endif
-#ifdef KOKKOS_HAVE_PTHREAD
-    template<> int KokkosThreadsWrapperNode::count = 0;
-#endif
-#ifdef KOKKOS_HAVE_SERIAL
-    template<> int KokkosSerialWrapperNode::count = 0;
-#endif // KOKKOS_HAVE_SERIAL
-
 #ifdef KOKKOS_HAVE_PTHREAD
     template<>
     KokkosDeviceWrapperNode<Kokkos::Threads>::
     ~KokkosDeviceWrapperNode<Kokkos::Threads> ()
     {
       count--;
-      if (count == 0 && Threads::is_initialized ()) {
+      // Only call Kokkos::Threads::finalize if the Node reference
+      // count is zero, if Kokkos::Threads is already initialized, and
+      // if Node's constructor was responsible for initializing it.
+      // (See Github Issue #510.)
+      if (count == 0 && Threads::is_initialized () && nodeResponsibleForFinalizingExecutionSpace_) {
 #ifdef KOKKOS_HAVE_CUDA
+        // If any instances of KokkosDeviceWrapperNode<Kokkos::Cuda>
+        // exist, they are responsible for calling finalize on Cuda's
+        // host execution space.
         if (! Impl::is_same<Kokkos::Threads,HostSpace::execution_space>::value ||
             KokkosDeviceWrapperNode<Kokkos::Cuda>::count == 0)
-#endif
+#endif // KOKKOS_HAVE_CUDA
           Threads::finalize ();
       }
+      checkDestructorEnd ();
     }
 
     template<>
@@ -365,23 +364,26 @@ namespace Kokkos {
         //   Device = args.numDevice; // Threads doesn't need this one
         // }
 
-        if(NumNUMA>0 && NumCoresPerNUMA>0)
-          Kokkos::Threads::initialize ( NumThreads, NumNUMA, NumCoresPerNUMA );
-        else if (NumNUMA > 0)
-          Kokkos::Threads::initialize ( NumThreads, NumNUMA );
+        if (NumNUMA > 0 && NumCoresPerNUMA > 0) {
+          Kokkos::Threads::initialize (NumThreads, NumNUMA, NumCoresPerNUMA);
+        }
+        else if (NumNUMA > 0) {
+          Kokkos::Threads::initialize (NumThreads, NumNUMA);
+        }
         else if (NumThreads > 0) {
           if (debug) {
             cerr << "Tpetra Threads wrapper Node: NumThreads = "
                  << NumThreads << endl;
           }
-          Kokkos::Threads::initialize ( NumThreads );
+          Kokkos::Threads::initialize (NumThreads);
           if (debug) {
             cerr << "Tpetra Threads wrapper Node: Concurrency = "
                  << Kokkos::Threads::concurrency () << endl;
           }
         }
-        else
-          Kokkos::Threads::initialize ( );
+        else {
+          Kokkos::Threads::initialize ();
+        }
       }
     }
 
@@ -395,27 +397,58 @@ namespace Kokkos {
     template<>
     KokkosDeviceWrapperNode<Kokkos::OpenMP>::~KokkosDeviceWrapperNode<Kokkos::OpenMP>() {
       count--;
-      if (count == 0 && OpenMP::is_initialized ()) {
+      // Only call Kokkos::OpenMP::finalize if the Node reference
+      // count is zero, if Kokkos::OpenMP is already initialized, and
+      // if Node's constructor was responsible for initializing it.
+      // (See Github Issue #510.)
+      if (count == 0 && OpenMP::is_initialized () && nodeResponsibleForFinalizingExecutionSpace_) {
 #ifdef KOKKOS_HAVE_CUDA
+        // If any instances of KokkosDeviceWrapperNode<Kokkos::Cuda>
+        // exist, they are responsible for calling finalize on Cuda's
+        // host execution space.
         if (! Impl::is_same<Kokkos::OpenMP, HostSpace::execution_space>::value ||
             KokkosDeviceWrapperNode<Kokkos::Cuda>::count == 0)
-#endif
+#endif // KOKKOS_HAVE_CUDA
         OpenMP::finalize ();
       }
+      checkDestructorEnd ();
     }
 
     template<>
     void KokkosDeviceWrapperNode<Kokkos::OpenMP>::
-    init (int NumThreads, int NumNUMA, int NumCoresPerNUMA, int Device) {
+    init (int NumThreads, int NumNUMA, int NumCoresPerNUMA, int /* Device */)
+    {
       if (! Kokkos::OpenMP::is_initialized ()) {
-        if(NumNUMA>0 && NumCoresPerNUMA>0)
-          Kokkos::OpenMP::initialize ( NumThreads, NumNUMA, NumCoresPerNUMA );
-        else if (NumNUMA > 0)
-          Kokkos::OpenMP::initialize ( NumThreads, NumNUMA );
-        else if (NumThreads > 0)
-          Kokkos::OpenMP::initialize ( NumThreads );
-        else
-          Kokkos::OpenMP::initialize ( );
+
+        // Attempt to read command-line arguments that were stored in
+        // Teuchos::GlobalMPISession. User settings override these.
+        CmdLineArgs args = getCommandLineArgs ();
+
+        if (args.numThreads != -1) {
+          NumThreads = args.numThreads;
+        }
+        if (args.numNuma != -1) {
+          NumNUMA = args.numNuma;
+        }
+        if (args.deviceId != -1) {
+          NumCoresPerNUMA = args.deviceId;
+        }
+        // if (args.numDevice != -1) {
+        //   Device = args.numDevice; // OpenMP doesn't need this one
+        // }
+
+        if (NumNUMA > 0 && NumCoresPerNUMA > 0) {
+          Kokkos::OpenMP::initialize (NumThreads, NumNUMA, NumCoresPerNUMA);
+        }
+        else if (NumNUMA > 0) {
+          Kokkos::OpenMP::initialize (NumThreads, NumNUMA);
+        }
+        else if (NumThreads > 0) {
+          Kokkos::OpenMP::initialize (NumThreads);
+        }
+        else {
+          Kokkos::OpenMP::initialize ();
+        }
       }
     }
 
@@ -429,24 +462,32 @@ namespace Kokkos {
     template<>
     KokkosDeviceWrapperNode<Kokkos::Serial>::~KokkosDeviceWrapperNode<Kokkos::Serial>() {
       count--;
-      if (count == 0 && Serial::is_initialized ()) {
-        // FIXME (mfh 02 Nov 2014) This doesn't look right to me
-        // somehow.  What if CUDA is NOT enabled?  Wouldn't that
-        // disable the first branch of the OR, which could trigger
-        // even if CUDA is not enabled?
+      // Only call Kokkos::Serial::finalize if the Node reference
+      // count is zero, if Kokkos::Serial is already initialized, and
+      // if Node's constructor was responsible for initializing it.
+      // (See Github Issue #510.)
+      if (count == 0 && Serial::is_initialized () && nodeResponsibleForFinalizingExecutionSpace_) {
 #ifdef KOKKOS_HAVE_CUDA
+        // If any instances of KokkosDeviceWrapperNode<Kokkos::Cuda>
+        // exist, they are responsible for calling finalize on Cuda's
+        // host execution space.
         if (! Impl::is_same<Kokkos::Serial, HostSpace::execution_space>::value ||
             KokkosDeviceWrapperNode<Kokkos::Cuda>::count == 0)
 #endif // KOKKOS_HAVE_CUDA
           Serial::finalize ();
       }
+      checkDestructorEnd ();
     }
 
     template<>
     void KokkosDeviceWrapperNode<Kokkos::Serial>::
-    init (int NumThreads, int NumNUMA, int NumCoresPerNUMA, int Device) {
+    init (int /* NumThreads */,
+          int /* NumNUMA */,
+          int /* NumCoresPerNUMA */,
+          int /* Device */)
+    {
       if (! Kokkos::Serial::is_initialized ()) {
-          Kokkos::Serial::initialize ();
+        Kokkos::Serial::initialize ();
       }
     }
 
@@ -460,50 +501,143 @@ namespace Kokkos {
     template<>
     KokkosDeviceWrapperNode<Kokkos::Cuda>::~KokkosDeviceWrapperNode<Kokkos::Cuda>() {
       count--;
-      if(count==0) {
-        if(HostSpace::execution_space::is_initialized()) {
-          // make sure that no Actual DeviceWrapper node of the mirror_execution_space is in use
-          if(KokkosDeviceWrapperNode<HostSpace::execution_space>::count==0) {
-            HostSpace::execution_space::finalize();
-          }
+      if (count == 0) {
+        // Don't call finalize on the host execution space until all
+        // Node instances corresponding to the host execution space
+        // are gone.  Also, don't call finalize on it if Node wasn't
+        // responsible for calling initialize on it (see Github Issue
+        // #510).
+        if (HostSpace::execution_space::is_initialized () &&
+            KokkosDeviceWrapperNode<HostSpace::execution_space>::count == 0 &&
+            KokkosDeviceWrapperNode<HostSpace::execution_space>::nodeResponsibleForFinalizingExecutionSpace_) {
+          HostSpace::execution_space::finalize ();
+        }
+        // Only call Kokkos::Cuda::finalize if the Node reference
+        // count is zero, if Kokkos::Cuda is already initialized, and
+        // if Node's constructor was responsible for initializing it.
+        // (See Github Issue #510.)
+        if (Cuda::is_initialized () && nodeResponsibleForFinalizingExecutionSpace_) {
+          Cuda::finalize ();
         }
-        if(Cuda::is_initialized())
-          Cuda::finalize();
       }
+      checkDestructorEnd ();
     }
+
     template<>
     void KokkosDeviceWrapperNode<Kokkos::Cuda>::
-    init(int NumThreads, int NumNUMA, int NumCoresPerNUMA, int Device) {
-
+    init (int NumThreads, int NumNUMA, int NumCoresPerNUMA, int Device)
+    {
       // Setting (currently) necessary environment variables for NVIDIA UVM
-      #ifdef KOKKOS_USE_CUDA_UVM
-        putenv("CUDA_LAUNCH_BLOCKING=1");
-      #else
-        throw std::runtime_error("Using CudaWrapperNode without UVM is not allowed.");
-      #endif
+#ifdef KOKKOS_USE_CUDA_UVM
+      // We want to override any existing setting of CUDA_LAUNCH_BLOCKING.
+      const int overwrite = 1;
+      const int errCode = setenv ("CUDA_LAUNCH_BLOCKING", "1", overwrite);
 
-      if(!Kokkos::HostSpace::execution_space::is_initialized()) {
-        if(NumNUMA>0 && NumCoresPerNUMA>0)
-          Kokkos::HostSpace::execution_space::initialize ( NumThreads, NumNUMA, NumCoresPerNUMA );
-        else if (NumNUMA > 0)
-          Kokkos::HostSpace::execution_space::initialize ( NumThreads, NumNUMA );
-        else if (NumThreads > 0)
-          Kokkos::HostSpace::execution_space::initialize ( NumThreads );
-        else
-          Kokkos::HostSpace::execution_space::initialize ( );
+      //putenv("CUDA_LAUNCH_BLOCKING=1"); // see note below
+
+      // mfh 22 Jul 2016: POSIX prefers use of setenv over putenv:
+      //
+      // http://pubs.opengroup.org/onlinepubs/009695399/functions/putenv.html
+      //
+      // There are two problems with putenv:
+      //
+      // 1. It takes its input as a nonconst pointer.  This causes a
+      //    build warning (e.g., "conversion from a string literal to
+      //    'char *' is deprecated") when using a string literal, in
+      //    this case "CUDA_LAUNCH_BLOCKING=1", as the input argument.
+      //
+      // 2. putenv does not let us fix the above build warning by
+      //    copying into a temporary nonconst char array and passing
+      //    that into putenv.  This is because putenv is free to keep
+      //    the original input pointer, rather than copying the input
+      //    string.  Thus, if anyone tries to read the environment
+      //    variable (via getenv) after the temporary array has been
+      //    freed, they would be reading invalid memory.  The above
+      //    POSIX standard entry alludes to this: "A potential error
+      //    is to call putenv() with an automatic variable as the
+      //    argument, then return from the calling function while
+      //    string is still part of the environment."
+
+      if (errCode != 0) {
+        // Printing operations may change errno, so we save it first.
+        const int savedErrno = errno;
+        std::ostringstream os;
+        os << "KokkosCudaWrapperNode attempted to call "
+          "setenv(\"CUDA_LAUNCH_BLOCKING\", \"1\", " << overwrite << "), "
+          "but it returned a nonzero error code.  ";
+        if (savedErrno == EINVAL) {
+          os << "errno == EINVAL; this should never happen, because it implies "
+            "that the input strings were NULL; they certainly were not in this "
+            "case.";
+          throw std::logic_error (os.str ());
+        }
+        else if (savedErrno == ENOMEM) {
+          // If setenv ran out of memory, we're probably in trouble
+          // and not even able to construct the error string, but
+          // we'll try regardless.
+          os << "errno == ENOMEM; this means setenv ran out of memory.";
+          throw std::runtime_error (os.str ());
+        }
+        else {
+          os << "errno != EINVAL && errno != ENOMEM; not sure what this means.";
+          throw std::runtime_error (os.str ());
+        }
+      }
+#else
+      throw std::runtime_error ("Using KokkosCudaWrapperNode "
+                                "(KokkosDeviceWrapperNode<Kokkos::Cuda, ...> "
+                                "without UVM is not allowed.");
+#endif // KOKKOS_USE_CUDA_UVM
+
+      // Attempt to read command-line arguments that were stored in
+      // Teuchos::GlobalMPISession. User settings override these.
+      CmdLineArgs args = getCommandLineArgs ();
+
+      if (args.numThreads != -1) {
+        NumThreads = args.numThreads;
+      }
+      if (args.numNuma != -1) {
+        NumNUMA = args.numNuma;
+      }
+      // mfh 22 Jul 2016: Kokkos::initialize doesn't actually set
+      // NumCoresPerNUMA when it reads command-line arguments, in the
+      // Cuda case.
+      //
+      // if (args.numDevices != -1) {
+      //   NumCoresPerNUMA = args.numDevices; // ???
+      // }
+      if (args.deviceId != -1) {
+        Device = args.deviceId;
+      }
+
+      if (! Kokkos::HostSpace::execution_space::is_initialized ()) {
+        if (NumNUMA > 0 && NumCoresPerNUMA > 0) {
+          Kokkos::HostSpace::execution_space::initialize (NumThreads, NumNUMA, NumCoresPerNUMA);
+        }
+        else if (NumNUMA > 0) {
+          Kokkos::HostSpace::execution_space::initialize (NumThreads, NumNUMA);
+        }
+        else if (NumThreads > 0) {
+          Kokkos::HostSpace::execution_space::initialize (NumThreads);
+        }
+        else {
+          Kokkos::HostSpace::execution_space::initialize ();
+        }
+      }
+      Kokkos::Cuda::SelectDevice select_device (Device);
+      if (! Kokkos::Cuda::is_initialized ()) {
+        Kokkos::Cuda::initialize (select_device);
       }
-      Kokkos::Cuda::SelectDevice select_device(Device);
-      if(!Kokkos::Cuda::is_initialized())
-        Kokkos::Cuda::initialize(select_device);
     }
+
     template<>
     std::string KokkosDeviceWrapperNode<Kokkos::Cuda>::name() {
       return std::string("Cuda/Wrapper");
     }
+#endif // KOKKOS_HAVE_CUDA
 
-#endif
-  }
-}
+  } // namespace Compat
+} // namespace Kokkos
 
 
 
