@@ -368,7 +368,7 @@ rowStatIsSupportedImpl(
       return false;
   }
 
-  return false; // Will never be called!
+  TEUCHOS_UNREACHABLE_RETURN(false);
 }
 
 
