@@ -108,7 +108,48 @@ protected:
   /** @name Overridden protected functions from MultiVectorBase */
   //@{
   /** \brief . */
-  void assignImpl(Scalar alpha);
+  virtual void assignImpl(Scalar alpha);
+
+  /** \brief . */
+  virtual void assignMultiVecImpl(const MultiVectorBase<Scalar>& mv);
+
+  /** \brief . */
+  virtual void scaleImpl(Scalar alpha);
+
+  /** \brief . */
+  virtual void updateImpl(
+    Scalar alpha,
+    const MultiVectorBase<Scalar>& mv
+    );
+
+  /** \brief . */
+  virtual void linearCombinationImpl(
+    const ArrayView<const Scalar>& alpha,
+    const ArrayView<const Ptr<const MultiVectorBase<Scalar> > >& mv,
+    const Scalar& beta
+    );
+
+  /** \brief . */
+  virtual void dotsImpl(
+    const MultiVectorBase<Scalar>& mv,
+    const ArrayView<Scalar>& prods
+    ) const;
+
+  /** \brief . */
+  virtual void norms1Impl(
+    const ArrayView<typename ScalarTraits<Scalar>::magnitudeType>& norms
+    ) const;
+
+  /** \brief . */
+  virtual void norms2Impl(
+    const ArrayView<typename ScalarTraits<Scalar>::magnitudeType>& norms
+    ) const;
+
+  /** \brief . */
+  virtual void normsInfImpl(
+    const ArrayView<typename ScalarTraits<Scalar>::magnitudeType>& norms
+    ) const;
+
   /** \brief . */
   RCP<const VectorBase<Scalar> > colImpl(Ordinal j) const;
   /** \brief . */
@@ -116,10 +157,45 @@ protected:
 
   /** \brief . */
   RCP<const MultiVectorBase<Scalar> >
-  contigSubViewImpl( const Range1D& colRng ) const;
+  contigSubViewImpl(const Range1D& colRng) const;
   /** \brief . */
   RCP<MultiVectorBase<Scalar> >
-  nonconstContigSubViewImpl( const Range1D& colRng );
+  nonconstContigSubViewImpl(const Range1D& colRng);
+  /** \brief . */
+  RCP<const MultiVectorBase<Scalar> >
+  nonContigSubViewImpl(const ArrayView<const int>& cols_in) const;
+  /** \brief . */
+  RCP<MultiVectorBase<Scalar> >
+  nonconstNonContigSubViewImpl(const ArrayView<const int>& cols_in);
+
+  /** \brief . */
+  virtual void mvMultiReductApplyOpImpl(
+    const RTOpPack::RTOpT<Scalar> &primary_op,
+    const ArrayView<const Ptr<const MultiVectorBase<Scalar> > > &multi_vecs,
+    const ArrayView<const Ptr<MultiVectorBase<Scalar> > > &targ_multi_vecs,
+    const ArrayView<const Ptr<RTOpPack::ReductTarget> > &reduct_objs,
+    const Ordinal primary_global_offset
+    ) const;
+
+  /** \brief . */
+  void acquireDetachedMultiVectorViewImpl(
+    const Range1D &rowRng,
+    const Range1D &colRng,
+    RTOpPack::ConstSubMultiVectorView<Scalar>* sub_mv
+    ) const;
+
+  /** \brief . */
+  void acquireNonconstDetachedMultiVectorViewImpl(
+    const Range1D &rowRng,
+    const Range1D &colRng,
+    RTOpPack::SubMultiVectorView<Scalar>* sub_mv
+    );
+
+  /** \brief . */
+  void commitNonconstDetachedMultiVectorViewImpl(
+    RTOpPack::SubMultiVectorView<Scalar>* sub_mv
+    );
+
 //  /** \brief . */
 //  RCP<const MultiVectorBase<Scalar> >
 //  nonContigSubViewImpl( const ArrayView<const int> &cols ) const;
@@ -140,6 +216,20 @@ protected:
   void getLocalMultiVectorDataImpl(
     const Ptr<ArrayRCP<const Scalar> > &localValues, const Ptr<Ordinal> &leadingDim
     ) const;
+
+  //@}
+
+  /** @name Overridden protected functions from MultiVectorAdapterBase */
+  //@{
+  /** \brief . */
+  virtual void euclideanApply(
+    const EOpTransp M_trans,
+    const MultiVectorBase<Scalar> &X,
+    const Ptr<MultiVectorBase<Scalar> > &Y,
+    const Scalar alpha,
+    const Scalar beta
+    ) const;
+
   //@}
 
 private:
@@ -162,6 +252,14 @@ private:
     const RCP<TpetraMultiVector_t> &tpetraMultiVector
     );
 
+  // Non-throwing Tpetra MultiVector extraction methods.
+  // Return null if casting failed.
+  RCP<Tpetra::MultiVector<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
+  getTpetraMultiVector(const RCP<MultiVectorBase<Scalar> >& mv) const;
+
+  RCP<const Tpetra::MultiVector<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
+  getConstTpetraMultiVector(const RCP<const MultiVectorBase<Scalar> >& mv) const;
+
 };
 
 
