@@ -471,7 +471,7 @@ protected:
     ) const
     {
       TEUCHOS_TEST_FOR_EXCEPT(true);
-      return(false);
+      TEUCHOS_UNREACHABLE_RETURN(false);
     }
 
   /** \brief Virtual implementation for solveSupportsSolveMeasureType(). */
