@@ -59,7 +59,6 @@
 
 namespace Thyra {
 
-
 // Nonmember constuctors
 
 
@@ -68,10 +67,14 @@ Teuchos::RCP<DummyTestModelEvaluator<Scalar> >
 dummyTestModelEvaluator(
   const Ordinal x_size,
   const ArrayView<const Ordinal> &p_sizes,
-  const ArrayView<const Ordinal> &g_sizes
+  const ArrayView<const Ordinal> &g_sizes,
+  const bool supports_x_dot,
+  const bool supports_x_dot_dot,
+  const bool supports_extended_inargs,
+  const bool supports_extended_outargs
   )
 {
-  return Teuchos::rcp(new DummyTestModelEvaluator<Scalar>(x_size, p_sizes, g_sizes));
+  return Teuchos::rcp(new DummyTestModelEvaluator<Scalar>(x_size, p_sizes, g_sizes, supports_x_dot, supports_x_dot_dot,supports_extended_inargs,supports_extended_outargs));
 }
 
 
@@ -82,7 +85,11 @@ template<class Scalar>
 DummyTestModelEvaluator<Scalar>::DummyTestModelEvaluator(
   const Ordinal x_size,
   const ArrayView<const Ordinal> &p_sizes,
-  const ArrayView<const Ordinal> &g_sizes
+  const ArrayView<const Ordinal> &g_sizes,
+  const bool supports_x_dot,
+  const bool supports_x_dot_dot,
+  const bool supports_extended_inargs,
+  const bool supports_extended_outargs
   )
 {
   
@@ -109,8 +116,16 @@ DummyTestModelEvaluator<Scalar>::DummyTestModelEvaluator(
   inArgs.setModelEvalDescription(this->description());
   inArgs.set_Np(p_space_.size());
   inArgs.setSupports(MEB::IN_ARG_x);
+  if (supports_x_dot)
+    inArgs.setSupports(MEB::IN_ARG_x_dot);
+  if (supports_x_dot_dot)
+    inArgs.setSupports(MEB::IN_ARG_x_dot_dot);
   inArgs.setSupports(MEB::IN_ARG_step_size);
   inArgs.setSupports(MEB::IN_ARG_stage_number);
+  inArgs.template setSupports<Thyra::MockExtendedInArgs<Scalar> >(true);
+  // test the removal of support
+  if (!supports_extended_inargs)
+    inArgs.template setSupports<Thyra::MockExtendedInArgs<Scalar> >(false);
   prototypeInArgs_ = inArgs;
   
   MEB::OutArgsSetup<Scalar> outArgs;
@@ -119,6 +134,10 @@ DummyTestModelEvaluator<Scalar>::DummyTestModelEvaluator(
   outArgs.setSupports(MEB::OUT_ARG_f);
   outArgs.setSupports(MEB::OUT_ARG_W_op);
   outArgs.setSupports(MEB::OUT_ARG_W_prec);
+  outArgs.template setSupports<Thyra::MockExtendedOutArgs<Scalar> >(true);
+  // test the removal of support
+  if (!supports_extended_outargs)
+    outArgs.template setSupports<Thyra::MockExtendedOutArgs<Scalar> >(false);
   prototypeOutArgs_ = outArgs;
 
   nominalValues_ = inArgs;
@@ -290,7 +309,11 @@ void DummyTestModelEvaluator<Scalar>::evalModelImpl(
   dummyTestModelEvaluator( \
     const Ordinal x_size, \
     const ArrayView<const Ordinal> &p_sizes, \
-    const ArrayView<const Ordinal> &g_sizes \
+    const ArrayView<const Ordinal> &g_sizes, \
+    const bool supports_x_dot, \
+    const bool supports_x_dot_dot,              \
+    const bool supports_extended_inargs,        \
+    const bool supports_extended_outargs        \
     ); \
 
 
