@@ -1040,13 +1040,13 @@ init (const keys_type& keys,
 
   const offset_type numKeys = static_cast<offset_type> (keys.dimension_0 ());
   {
-    const offset_type maxVal = ::Kokkos::Details::ArithTraits<offset_type>::max ();
-    const size_type maxValST = static_cast<size_type> (maxVal);
+    const offset_type theMaxVal = ::Kokkos::Details::ArithTraits<offset_type>::max ();
+    const size_type maxValST = static_cast<size_type> (theMaxVal);
     TEUCHOS_TEST_FOR_EXCEPTION
       (keys.dimension_0 () > maxValST, std::invalid_argument, prefix << "The "
        "number of keys " << keys.dimension_0 () << " does not fit in "
        "offset_type = " << TypeNameTraits<offset_type>::name () << ", whose "
-       "max value is " << maxVal << ".  This means that it is not possible to "
+       "max value is " << theMaxVal << ".  This means that it is not possible to "
        "use this constructor.");
   }
   TEUCHOS_TEST_FOR_EXCEPTION
@@ -1157,7 +1157,10 @@ init (const keys_type& keys,
   // incur overhead then.
   if (buildInParallel) {
     FHT::CountBuckets<counts_type, keys_type> functor (counts, theKeys, size);
-    Kokkos::parallel_for (theNumKeys, functor);
+
+    typedef typename counts_type::execution_space execution_space;
+    typedef Kokkos::RangePolicy<execution_space, offset_type> range_type;
+    Kokkos::parallel_for (range_type (0, theNumKeys), functor);
   }
   else {
     // Access to counts is not necessarily contiguous, but is
@@ -1231,7 +1234,8 @@ init (const keys_type& keys,
   if (buildInParallel) {
     functor_type functor (val, counts, ptr, theKeys, newStartingValue,
                           initMinKey, initMaxKey);
-    Kokkos::parallel_reduce (theNumKeys, functor, result);
+    typedef Kokkos::RangePolicy<execution_space, offset_type> range_type;
+    Kokkos::parallel_reduce (range_type (0, theNumKeys), functor, result);
   }
   else {
     for (offset_type k = 0; k < theNumKeys; ++k) {
@@ -1433,8 +1437,9 @@ checkForDuplicateKeys () const
     typedef FHT::CheckForDuplicateKeys<ptr_type, val_type> functor_type;
     functor_type functor (val_, ptr_);
     int hasDupKeys = 0;
-    Kokkos::parallel_reduce (size, functor, hasDupKeys);
-    return hasDupKeys>0;
+    typedef Kokkos::RangePolicy<execution_space, offset_type> range_type;
+    Kokkos::parallel_reduce (range_type (0, size), functor, hasDupKeys);
+    return hasDupKeys > 0;
   }
 }
 
