@@ -265,7 +265,7 @@ namespace Tpetra {
   template<class IT1>
   bool isAlreadySorted(const IT1& first, const IT1& last){
     typedef typename std::iterator_traits<IT1>::difference_type DT;
-    DT myit =OrdinalTraits<DT>::one();
+    DT myit = Teuchos::OrdinalTraits<DT>::one();
     const DT sz  = last - first;
     for(;myit < sz; ++myit){
       if(first[myit] < first[myit-1]){
@@ -393,7 +393,7 @@ namespace Tpetra {
     const IT2& last2)
   {
     typedef typename std::iterator_traits<IT1>::difference_type DT;
-    DT DT1 = OrdinalTraits<DT>::one();
+    DT DT1 = Teuchos::OrdinalTraits<DT>::one();
     if(last1-first1 > DT1){
       IT1 pivot = getPivot(first1, last1);
       pivot = partition2(first1, last1, first2, last2, pivot);
@@ -424,7 +424,7 @@ namespace Tpetra {
     const IT3& last3)
   {
     typedef typename std::iterator_traits<IT1>::difference_type DT;
-    DT DT1 = OrdinalTraits<DT>::one();
+    DT DT1 = Teuchos::OrdinalTraits<DT>::one();
     if(last1-first1 > DT1){
       IT1 pivot = getPivot(first1, last1);
       pivot = partition3(first1, last1, first2, last2, first3, last3, pivot);
@@ -451,7 +451,7 @@ namespace Tpetra {
         typedef typename std::iterator_traits<IT1>::difference_type DT;
         DT n = last1 - first1;
         DT m = n / 2;
-        DT z = OrdinalTraits<DT>::zero();
+        DT z = Teuchos::OrdinalTraits<DT>::zero();
         while (m > z)
         {
             DT max = n - m;
@@ -486,7 +486,7 @@ namespace Tpetra {
         typedef typename std::iterator_traits<IT1>::difference_type DT;
         DT n = last1 - first1;
         DT m = n / 2;
-        DT z = OrdinalTraits<DT>::zero();
+        DT z = Teuchos::OrdinalTraits<DT>::zero();
         while (m > z)
         {
             DT max = n - m;
