@@ -136,12 +136,15 @@ outOfBounds (const IntegerType x, const IntegerType exclusiveUpperBound)
       dst(k) = src(idx(k), col);
     }
 
-    static void pack(const DstView& dst,
-                     const SrcView& src,
-                     const IdxView& idx,
-                     size_t col) {
-      Kokkos::parallel_for( idx.size(),
-                            PackArraySingleColumn(dst,src,idx,col) );
+    static void
+    pack (const DstView& dst,
+          const SrcView& src,
+          const IdxView& idx,
+          size_t col)
+    {
+      typedef Kokkos::RangePolicy<execution_space, size_type> range_type;
+      Kokkos::parallel_for (range_type (0, idx.size ()),
+                            PackArraySingleColumn (dst,src,idx,col));
     }
   };
 
@@ -316,8 +319,9 @@ outOfBounds (const IntegerType x, const IntegerType exclusiveUpperBound)
                      const SrcView& src,
                      const IdxView& idx,
                      size_t numCols) {
-      Kokkos::parallel_for( idx.size(),
-                            PackArrayMultiColumn(dst,src,idx,numCols) );
+      typedef Kokkos::RangePolicy<execution_space, size_type> range_type;
+      Kokkos::parallel_for (range_type (0, idx.size ()),
+                            PackArrayMultiColumn (dst,src,idx,numCols));
     }
   };
 
@@ -487,7 +491,8 @@ outOfBounds (const IntegerType x, const IntegerType exclusiveUpperBound)
                      const IdxView& idx,
                      const ColView& col,
                      size_t numCols) {
-      Kokkos::parallel_for( idx.size(),
+      typedef Kokkos::RangePolicy<execution_space, size_type> range_type;
+      Kokkos::parallel_for (range_type (0, idx.size ()),
                             PackArrayMultiColumnVariableStride(
                               dst,src,idx,col,numCols) );
     }
@@ -683,6 +688,15 @@ outOfBounds (const IntegerType x, const IntegerType exclusiveUpperBound)
     }
   }
 
+  // FIXME (mfh 16 Dec 2016) It looks like these are totally generic
+  // and don't get specialized in Stokhos.  This suggests we can
+  // template them on the execution space, and specialize them for
+  // Kokkos::Serial so they don't do atomic update operations.  It
+  // might be better to make the unpack kernels (the pack kernels
+  // don't use atomic updates) functions that we prebuild, in the
+  // manner of KokkosKernels, or at least handle via ETI.
+
+  template<class ExecutionSpace>
   struct InsertOp {
     template <typename Scalar>
     KOKKOS_INLINE_FUNCTION
@@ -690,6 +704,19 @@ outOfBounds (const IntegerType x, const IntegerType exclusiveUpperBound)
       Kokkos::atomic_assign(&dest, src);
     }
   };
+
+#ifdef KOKKOS_HAVE_SERIAL
+  template<>
+  struct InsertOp< ::Kokkos::Serial > {
+    template <typename Scalar>
+    KOKKOS_INLINE_FUNCTION
+    void operator() (Scalar& dest, const Scalar& src) const {
+      dest = src; // no need for an atomic operation here
+    }
+  };
+#endif // KOKKOS_HAVE_SERIAL
+
+  template<class ExecutionSpace>
   struct AddOp {
     template <typename Scalar>
     KOKKOS_INLINE_FUNCTION
@@ -697,9 +724,26 @@ outOfBounds (const IntegerType x, const IntegerType exclusiveUpperBound)
       Kokkos::atomic_add(&dest, src);
     }
   };
+
+#ifdef KOKKOS_HAVE_SERIAL
+  template<>
+  struct AddOp< ::Kokkos::Serial > {
+    template <typename Scalar>
+    KOKKOS_INLINE_FUNCTION
+    void operator() (Scalar& dest, const Scalar& src) const {
+      dest += src; // no need for an atomic operation here
+    }
+  };
+#endif // KOKKOS_HAVE_SERIAL
+
+  template<class ExecutionSpace>
   struct AbsMaxOp {
     // ETP:  Is this really what we want?  This seems very odd if
     // Scalar != SCT::mag_type (e.g., Scalar == std::complex<T>)
+    //
+    // mfh: I didn't write this code, but note that we don't use T =
+    // Scalar here, we use T = ArithTraits<Scalar>::mag_type.  That
+    // makes this code reasonable.
     template <typename T>
     KOKKOS_INLINE_FUNCTION
     T max(const T& a, const T& b) const { return a > b ? a : b; }
@@ -712,6 +756,29 @@ outOfBounds (const IntegerType x, const IntegerType exclusiveUpperBound)
     }
   };
 
+#ifdef KOKKOS_HAVE_SERIAL
+  template<>
+  struct AbsMaxOp< ::Kokkos::Serial > {
+    // ETP:  Is this really what we want?  This seems very odd if
+    // Scalar != SCT::mag_type (e.g., Scalar == std::complex<T>)
+    //
+    // mfh: I didn't write this code, but note that we don't use T =
+    // Scalar here, we use T = ArithTraits<Scalar>::mag_type.  That
+    // makes this code reasonable.
+    template <typename T>
+    KOKKOS_INLINE_FUNCTION
+    T max(const T& a, const T& b) const { return a > b ? a : b; }
+
+    template <typename Scalar>
+    KOKKOS_INLINE_FUNCTION
+    void operator() (Scalar& dest, const Scalar& src) const {
+      typedef Kokkos::Details::ArithTraits<Scalar> SCT;
+      // no need for an atomic operation here
+      dest = static_cast<Scalar> (max (SCT::abs (dest), SCT::abs (src)));
+    }
+  };
+#endif // KOKKOS_HAVE_SERIAL
+
   template <typename DstView, typename SrcView, typename IdxView, typename Op>
   struct UnpackArrayMultiColumn {
     typedef typename DstView::execution_space execution_space;
@@ -743,8 +810,9 @@ outOfBounds (const IntegerType x, const IntegerType exclusiveUpperBound)
                        const IdxView& idx,
                        const Op& op,
                        size_t numCols) {
-      Kokkos::parallel_for( idx.size(),
-                            UnpackArrayMultiColumn(dst,src,idx,op,numCols) );
+      typedef Kokkos::RangePolicy<execution_space, size_type> range_type;
+      Kokkos::parallel_for (range_type (0, idx.size ()),
+                            UnpackArrayMultiColumn (dst,src,idx,op,numCols));
     }
   };
 
@@ -933,7 +1001,8 @@ outOfBounds (const IntegerType x, const IntegerType exclusiveUpperBound)
                        const ColView& col,
                        const Op& op,
                        size_t numCols) {
-      Kokkos::parallel_for( idx.size(),
+      typedef Kokkos::RangePolicy<execution_space, size_type> range_type;
+      Kokkos::parallel_for (range_type (0, idx.size ()),
                             UnpackArrayMultiColumnVariableStride(
                               dst,src,idx,col,op,numCols) );
     }
@@ -1173,8 +1242,9 @@ outOfBounds (const IntegerType x, const IntegerType exclusiveUpperBound)
                         const SrcIdxView& src_idx,
                         size_t numCols) {
       const size_type n = std::min( dst_idx.size(), src_idx.size() );
-      Kokkos::parallel_for(
-        n, PermuteArrayMultiColumn(dst,src,dst_idx,src_idx,numCols) );
+      typedef Kokkos::RangePolicy<execution_space, size_type> range_type;
+      Kokkos::parallel_for (range_type (0, n),
+                            PermuteArrayMultiColumn (dst,src,dst_idx,src_idx,numCols));
     }
   };
 
@@ -1233,9 +1303,14 @@ outOfBounds (const IntegerType x, const IntegerType exclusiveUpperBound)
                         const SrcColView& src_col,
                         size_t numCols) {
       const size_type n = std::min( dst_idx.size(), src_idx.size() );
-      Kokkos::parallel_for(
-        n, PermuteArrayMultiColumnVariableStride(
-          dst,src,dst_idx,src_idx,dst_col,src_col,numCols) );
+      typedef Kokkos::RangePolicy<execution_space, size_type> range_type;
+      Kokkos::parallel_for (range_type (0, n),
+                            PermuteArrayMultiColumnVariableStride (dst, src,
+                                                                   dst_idx,
+                                                                   src_idx,
+                                                                   dst_col,
+                                                                   src_col,
+                                                                   numCols));
     }
   };
 
