@@ -251,6 +251,7 @@ namespace { // (anonymous)
     Kokkos::View<KeyType*, Kokkos::LayoutLeft, DeviceType> keys ("keys", numKeys);
     auto keys_h = Kokkos::create_mirror_view (keys);
     Kokkos::deep_copy (keys, keys_h);
+    out << "Finished deep_copy(keys, keys_h)" << endl;
 
     // Pick something other than 0, just to make sure that it works.
     const ValueType startingValue = 1;
@@ -262,11 +263,18 @@ namespace { // (anonymous)
     Teuchos::RCP<table_type> table;
     TEST_NOTHROW( table = Teuchos::rcp (new table_type (keys_av, startingValue, keepKeys)) );
     if (table.is_null ()) {
+      out << "table is null!  Its constructor must have thrown.  "
+        "No sense in continuing." << endl;
       return; // above constructor must have thrown
     }
 
     bool duplicateKeys = false;
     TEST_NOTHROW( duplicateKeys = table->hasDuplicateKeys () );
+    if (! success) {
+      out << "table->hasDuplicateKeys() raised an exception; no sense in "
+        "continuing." << endl;
+      return;
+    }
     TEST_EQUALITY_CONST( duplicateKeys, false );
 
     KeyType key = 0;
@@ -941,14 +949,15 @@ namespace { // (anonymous)
 
 #ifdef KOKKOS_HAVE_CUDA
     {
-      if (! std::is_same<typename DeviceType::memory_space, Kokkos::CudaSpace>::value) {
-        out << "Testing copy constructor to CudaSpace" << endl;
-        TestCopyCtor<KeyType, ValueType, Kokkos::Device<Kokkos::Cuda, Kokkos::CudaSpace>,
-          DeviceType>::test (out, success, *table, keys, vals,
-                             "Kokkos::Device<Kokkos::Cuda, Kokkos::CudaSpace>",
-                             typeid(DeviceType).name ());
-        testedAtLeastOnce = true;
-      }
+      // mfh 14 Jan 2016: Only exercise CudaUVMSpace, not CudaSpace,
+      // because Tpetra (and FixedHashTable in particular) assume UVM.
+      // Testing CudaSpace here results in the following exception:
+      //
+      // p=0: *** Caught standard std::exception of type 'std::runtime_error' :
+      //
+      // Kokkos::CudaSpace::access_error attempt to execute Cuda
+      //   function from non-Cuda space
+      // Traceback functionality not available
       if (! std::is_same<typename DeviceType::memory_space, Kokkos::CudaUVMSpace>::value) {
         out << "Testing copy constructor to CudaUVMSpace" << endl;
         TestCopyCtor<KeyType, ValueType, Kokkos::Device<Kokkos::Cuda, Kokkos::CudaUVMSpace>,
@@ -1090,14 +1099,15 @@ namespace { // (anonymous)
 
 #ifdef KOKKOS_HAVE_CUDA
     {
-      if (! std::is_same<typename DeviceType::memory_space, Kokkos::CudaSpace>::value) {
-        out << "Testing copy constructor to CudaSpace" << endl;
-        TestCopyCtor<KeyType, ValueType, Kokkos::Device<Kokkos::Cuda, Kokkos::CudaSpace>,
-          DeviceType>::test (out, success, *table, keys, vals,
-                             "Kokkos::Device<Kokkos::Cuda, Kokkos::CudaSpace>",
-                             typeid (DeviceType).name (), testValues);
-        testedAtLeastOnce = true;
-      }
+      // mfh 14 Jan 2016: Only exercise CudaUVMSpace, not CudaSpace,
+      // because Tpetra (and FixedHashTable in particular) assume UVM.
+      // Testing CudaSpace here results in the following exception:
+      //
+      // p=0: *** Caught standard std::exception of type 'std::runtime_error' :
+      //
+      // Kokkos::CudaSpace::access_error attempt to execute Cuda
+      //   function from non-Cuda space
+      // Traceback functionality not available
       if (! std::is_same<typename DeviceType::memory_space, Kokkos::CudaUVMSpace>::value) {
         out << "Testing copy constructor to CudaUVMSpace" << endl;
         TestCopyCtor<KeyType, ValueType, Kokkos::Device<Kokkos::Cuda, Kokkos::CudaUVMSpace>,
@@ -1190,23 +1200,11 @@ namespace { // (anonymous)
 
 // NOTE (mfh 12 Jan 2016) Both Tpetra and the above test assume UVM.
 // Thus, it is both incorrect and unnecessary to use them with
-// Kokkos::CudaSpace as the memory space.  Furthermore, doing so
-// (correctly) raises an exception when Kokkos' bounds checking option
-// is enabled: "Kokkos::CudaSpace::access_error attempt to execute
-// Cuda function from non-Cuda space".
-
-// #ifdef KOKKOS_HAVE_CUDA
-//   typedef Kokkos::Device<Kokkos::Cuda, Kokkos::CudaSpace> cuda_device_type;
-//
-// #define UNIT_TEST_GROUP_CUDA( LO, GO ) \
-//   UNIT_TEST_GROUP_3( LO, GO, cuda_device_type )
-//
-//   TPETRA_INSTANTIATE_LG( UNIT_TEST_GROUP_CUDA )
-// #  define UNIT_TEST_GROUP_CUDA( LO, GO )
-// #else
-// #  define UNIT_TEST_GROUP_CUDA( LO, GO )
-// #endif // KOKKOS_HAVE_CUDA
-
+// Kokkos::CudaSpace as the memory space.  The right memory space is
+// CudaUVMSpace.  As a result, using CudaSpace raises an exception (as
+// it should) when Kokkos' bounds checking option is enabled:
+// "Kokkos::CudaSpace::access_error attempt to execute Cuda function
+// from non-Cuda space".
 
 #ifdef KOKKOS_HAVE_CUDA
   typedef Kokkos::Device<Kokkos::Cuda, Kokkos::CudaUVMSpace> cuda_uvm_device_type;
