@@ -49,12 +49,23 @@
 #include <Teuchos_Tuple.hpp>
 #include "Tpetra_ConfigDefs.hpp"
 #include "Tpetra_DefaultPlatform.hpp"
+#include "Tpetra_Map.hpp"
 #include "Tpetra_Import.hpp"
 #include "Tpetra_Export.hpp"
 #include "Tpetra_MultiVector.hpp"
 #include "Tpetra_Vector.hpp"
 #include <iterator>
 
+#include <Tpetra_Distributor.hpp>
+#include "Teuchos_FancyOStream.hpp"
+#include "Tpetra_Experimental_BlockCrsMatrix.hpp"
+#include "Tpetra_Experimental_BlockCrsMatrix_Helpers.hpp"
+#include "Tpetra_CrsGraph.hpp"
+#include "Tpetra_CrsMatrix.hpp"
+#include "Teuchos_FancyOStream.hpp"
+#include "Teuchos_GlobalMPISession.hpp"
+#include "Teuchos_oblackholestream.hpp"
+
 namespace {
   using Tpetra::TestingUtilities::getNode;
 
@@ -384,15 +395,106 @@ namespace {
     TEST_EQUALITY_CONST( globalSuccess_int, 0 );
   }
 
+
+ TEUCHOS_UNIT_TEST_TEMPLATE_3_DECL( ImportExport, ExportReverse, LO, GO, Node )
+  {
+    // This test reproduces an issue seen in Github Issue #114.
+    // As of time of checkin, this test will fail on CUDA but pass on other platforms.
+    // This is intentional
+    RCP<const Comm<int> > comm = getDefaultComm();
+    Tpetra::global_size_t INVALID = Teuchos::OrdinalTraits<Tpetra::global_size_t>::invalid();
+    typedef Tpetra::Map<LO,GO,Node> Tpetra_Map;
+    typedef Tpetra::Import<LO,GO,Node> Tpetra_Import;
+    typedef Tpetra::Vector<int, LO, GO,Node> IntVector;
+
+    int NumProcs = comm->getSize();
+    int MyPID    = comm->getRank();
+
+    // This problem only works on 4 procs
+    if(NumProcs!=4) {TEST_EQUALITY(true,true);return;}
+
+    // Problem setup
+    int num_per_proc;
+    if(MyPID==0) num_per_proc=7;
+    else num_per_proc=6;
+
+    GO from_gids_p0[7] = {0,1,2,3,4,5,6};
+    GO to_gids_p0[7]   = {0,4,8,12,16,20,24};
+
+    GO from_gids_p1[6] = {7,8,9,10,11,12};
+    GO to_gids_p1[6]   = {1,5,9,13,17,21};
+
+    GO from_gids_p2[6] = {13,14,15,16,17,18};
+    GO to_gids_p2[6]   = {2,6,10,14,18,22};
+
+    GO from_gids_p3[6] = {19,20,21,22,23,24};
+    GO to_gids_p3[6]   = {3,7,11,15,19,23};
+
+    // Correctness check array
+    int who_owns[25];
+    for(int i=0; i<7; i++)
+      who_owns[to_gids_p0[i]] = 0;
+    for(int i=0; i<6; i++) {
+      who_owns[to_gids_p1[i]] = 1;
+      who_owns[to_gids_p2[i]] = 2;
+      who_owns[to_gids_p3[i]] = 3;
+    }
+
+    GO *from_ptr, *to_ptr;
+    if(MyPID==0)      {from_ptr=&from_gids_p0[0]; to_ptr=&to_gids_p0[0];}
+    else if(MyPID==1) {from_ptr=&from_gids_p1[0]; to_ptr=&to_gids_p1[0];}
+    else if(MyPID==2) {from_ptr=&from_gids_p2[0]; to_ptr=&to_gids_p2[0];}
+    else if(MyPID==3) {from_ptr=&from_gids_p3[0]; to_ptr=&to_gids_p3[0];}
+    else exit(-1);
+
+    Teuchos::ArrayView<GO> myfromgids(from_ptr,num_per_proc);
+    Teuchos::ArrayView<GO> mytogids(to_ptr,num_per_proc);
+
+    // FromMap (from.getRowMap() from Zoltan2)
+    RCP<Tpetra_Map> FromMap = rcp(new Tpetra_Map(INVALID,myfromgids,0,comm));
+
+    // ToMap (tmap from Zoltan2)
+    RCP<Tpetra_Map> ToMap = rcp(new Tpetra_Map(INVALID,mytogids,0,comm));
+
+    // Importer
+    Tpetra_Import Importer(FromMap,ToMap);
+
+    // Duplicating what Zoltan2/Tpetra Does
+    IntVector FromVector(FromMap);
+    IntVector ToVector(ToMap);
+    ToVector.putScalar(MyPID);
+    FromVector.putScalar(-666);
+
+    FromVector.doExport(ToVector,Importer,Tpetra::REPLACE);
+
+    Teuchos::ArrayRCP<const int> f_rcp = FromVector.getData();
+    Teuchos::ArrayView<const int> f_view = f_rcp();
+    Teuchos::ArrayRCP<const int> t_rcp = ToVector.getData();
+    Teuchos::ArrayView<const int> t_view = t_rcp();
+
+    // Check the "FromAnswer" answer against who_owns
+    bool all_is_well=true;
+    for(size_t i=0; i<FromMap->getNodeNumElements(); i++) {
+      if(f_view[i] != who_owns[FromMap->getGlobalElement(i)]) {
+        std::cerr<<"["<<MyPID<<"] ERROR: Ownership of GID"<<FromMap->getGlobalElement(i)<<" is incorrect!"<<std::endl;
+        all_is_well=false;
+      }
+    }
+    TEST_EQUALITY(all_is_well,true);
+
+  }
+
   //
   // INSTANTIATIONS
   //
 
+
 #define UNIT_TEST_3( LO, GO, NT ) \
   TEUCHOS_UNIT_TEST_TEMPLATE_3_INSTANT( ImportExport, basic, LO, GO, NT ) \
-  TEUCHOS_UNIT_TEST_TEMPLATE_3_INSTANT( ImportExport, AbsMax, LO, GO, NT )
+  TEUCHOS_UNIT_TEST_TEMPLATE_3_INSTANT( ImportExport, AbsMax, LO, GO, NT ) \
+  TEUCHOS_UNIT_TEST_TEMPLATE_3_INSTANT( ImportExport, ExportReverse, LO, GO, NT)
 
-#define UNIT_TEST_4( SCALAR, LO, GO, NODE ) \
+  #define UNIT_TEST_4( SCALAR, LO, GO, NODE )  \
   TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT( ImportExport, GetNeighborsForward,  SCALAR, LO, GO, NODE ) \
   TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT( ImportExport, GetNeighborsBackward, SCALAR, LO, GO, NODE )
 
