@@ -522,9 +522,7 @@ namespace {
     // create a contiguous uniform distributed map with numLocal entries per node
     RCP<const Map1> map1 = createUniformContigMapWithNode<LO, GO, N1> (numGlobal, comm, n1);
     RCP<const Map2> map2 = map1->clone (n2);
-    TEST_EQUALITY( map2->getNode(), n2 );
     RCP<const Map1> map1b = map2->clone (n1);
-    TEST_EQUALITY( map1b->getNode(), n1 );
     TEST_ASSERT( map1->isCompatible (*map1b) );
     TEST_ASSERT( map1->isSameAs (*map1b) );
   }
