@@ -40,8 +40,10 @@
 // ************************************************************************
 // @HEADER
 */
-
 #include <Tpetra_ConfigDefs.hpp>
+#include <Tpetra_TestingUtilities.hpp>
+#include <Teuchos_UnitTestHarness.hpp>
+
 #include "TpetraExt_MatrixMatrix.hpp"
 #include "Tpetra_MatrixIO.hpp"
 #include "Tpetra_DefaultPlatform.hpp"
@@ -84,9 +86,6 @@ namespace {
   using Teuchos::tuple;
   using std::endl;
 
-  typedef Tpetra::Details::DefaultTypes::node_type node_type;
-  typedef CrsMatrix<double, int, int, node_type> Matrix_t;
-
 TEUCHOS_STATIC_SETUP(){
   Teuchos::CommandLineProcessor &clp = Teuchos::UnitTestRepository::getCLP();
   clp.setOption("matnames-file", &matnamesFile,
@@ -95,34 +94,34 @@ TEUCHOS_STATIC_SETUP(){
     "Whether or not to use verbose output");
 }
 
-template<class Scalar, class LO, class GO>
-RCP<CrsMatrix<Scalar, LO, GO, node_type> >
+template<class SC, class LO, class GO,class NT>
+RCP<CrsMatrix<SC, LO, GO, NT> >
 getIdentityMatrix (Teuchos::FancyOStream& out,
                    const Tpetra::global_size_t globalNumRows,
                    const Teuchos::RCP<const Teuchos::Comm<int> >& comm)
 {
   using Teuchos::RCP;
   using std::endl;
-  typedef Tpetra::CrsMatrix<Scalar, LO, GO, node_type> crs_matrix_type;
-  typedef Tpetra::Map<LO, GO, node_type> map_type;
+  typedef Tpetra::CrsMatrix<SC, LO, GO, NT> Matrix_t;
+  typedef Tpetra::Map<LO, GO, NT> Map_t;
 
   Teuchos::OSTab tab0 (out);
   out << "getIdentityMatrix" << endl;
   Teuchos::OSTab tab1 (out);
 
   out << "Create row Map" << endl;
-  RCP<const map_type> identityRowMap =
-    Tpetra::createUniformContigMapWithNode<LO, GO, node_type> (globalNumRows, comm);
+  RCP<const Map_t> identityRowMap =
+    Tpetra::createUniformContigMapWithNode<LO, GO, NT> (globalNumRows, comm);
 
   out << "Create CrsMatrix" << endl;
-  RCP<crs_matrix_type> identityMatrix =
-    Tpetra::createCrsMatrix<Scalar, LO, GO, node_type> (identityRowMap, 1);
+  RCP<Matrix_t> identityMatrix =
+    Tpetra::createCrsMatrix<SC, LO, GO, NT> (identityRowMap, 1);
 
   out << "Fill CrsMatrix" << endl;
   Teuchos::ArrayView<const GO> gblRows = identityRowMap->getNodeElementList ();
   for (auto it = gblRows.begin (); it != gblRows.end (); ++it) {
     Teuchos::Array<GO> col (1, *it);
-    Teuchos::Array<Scalar> val (1, Teuchos::ScalarTraits<Scalar>::one ());
+    Teuchos::Array<SC> val (1, Teuchos::ScalarTraits<SC>::one ());
     identityMatrix->insertGlobalValues (*it, col (), val ());
   }
 
@@ -133,6 +132,38 @@ getIdentityMatrix (Teuchos::FancyOStream& out,
   return identityMatrix;
 }
 
+template<class SC, class LO, class GO,class NT>
+RCP<CrsMatrix<SC, LO, GO, NT> >
+getIdentityMatrixWithMap (Teuchos::FancyOStream& out,
+			  Teuchos::RCP<const Tpetra::Map<LO,GO,NT> >& identityRowMap,
+			  const Teuchos::RCP<const Teuchos::Comm<int> >& comm)
+{
+  using Teuchos::RCP;
+  using std::endl;
+  typedef Tpetra::CrsMatrix<SC, LO, GO, NT> Matrix_t;
+
+  Teuchos::OSTab tab0 (out);
+  out << "getIdentityMatrix" << endl;
+  Teuchos::OSTab tab1 (out);
+
+  out << "Create CrsMatrix" << endl;
+  RCP<Matrix_t> identityMatrix =
+    Tpetra::createCrsMatrix<SC, LO, GO, NT> (identityRowMap, 1);
+
+  out << "Fill CrsMatrix" << endl;
+  Teuchos::ArrayView<const GO> gblRows = identityRowMap->getNodeElementList ();
+  for (auto it = gblRows.begin (); it != gblRows.end (); ++it) {
+    Teuchos::Array<GO> col (1, *it);
+    Teuchos::Array<SC> val (1, Teuchos::ScalarTraits<SC>::one ());
+    identityMatrix->insertGlobalValues (*it, col (), val ());
+  }
+
+  out << "Call fillComplete" << endl;
+  identityMatrix->fillComplete ();
+
+  out << "Done!" << endl;
+  return identityMatrix;
+}
 
 
 
@@ -149,47 +180,62 @@ typedef struct mult_test_results_struct{
 } mult_test_results;
 
 
-template<class Ordinal>
+template<class Matrix_t>
 add_test_results regular_add_test(
+    const std::string& name,
     RCP<Matrix_t > A,
     RCP<Matrix_t > B,
     bool AT,
     bool BT,
     RCP<Matrix_t > C,
-    RCP<const Comm<Ordinal> > comm)
+    RCP<const Comm<int> > comm)
 {
+  typedef typename Matrix_t::scalar_type SC;
+  typedef typename Matrix_t::local_ordinal_type LO;
+  typedef typename Matrix_t::global_ordinal_type GO;
+  typedef typename Matrix_t::node_type NT;
+  typedef Map<LO,GO,NT> Map_t;
+
   add_test_results toReturn;
   toReturn.correctNorm = C->getFrobeniusNorm ();
 
-  RCP<const Map<int,int, node_type> > rowmap = AT ? A->getDomainMap() : A->getRowMap();
+  RCP<const Map_t > rowmap = AT ? A->getDomainMap() : A->getRowMap();
   RCP<Matrix_t> computedC = rcp( new Matrix_t(rowmap, 1));
 
-  Tpetra::MatrixMatrix::Add(*A, AT, 1.0, *B, BT, 1.0, computedC);
-
+  SC one = Teuchos::ScalarTraits<SC>::one();
+  Tpetra::MatrixMatrix::Add(*A, AT, one, *B, BT, one, computedC);
   computedC->fillComplete(A->getDomainMap(), A->getRangeMap());
   toReturn.computedNorm = computedC->getFrobeniusNorm ();
   toReturn.epsilon = fabs(toReturn.correctNorm - toReturn.computedNorm);
 
+#if 0
+  Tpetra::MatrixMarket::Writer<Matrix_t>::writeSparseFile(
+    name+"_calculated.mtx", computedC);
+  Tpetra::MatrixMarket::Writer<Matrix_t>::writeSparseFile(
+    name+"_real.mtx", C);
+#endif
+
+
   return toReturn;
 }
 
 /// \brief Test the three-argument (A, B, C) version of CrsMatrix add,
 ///   where the output argument C is null on input.
 ///
-/// \tparam CrsMatrixType A specialization of Tpetra::CrsMatrix.
-template<class CrsMatrixType>
+/// \tparam Matrix_t A specialization of Tpetra::CrsMatrix.
+template<class Matrix_t>
 add_test_results
-null_add_test (const CrsMatrixType& A,
-               const CrsMatrixType& B,
+null_add_test (const Matrix_t& A,
+               const Matrix_t& B,
                const bool AT,
                const bool BT,
-               const CrsMatrixType& C,
+               const Matrix_t& C,
                Teuchos::FancyOStream& out)
 {
-  typedef typename CrsMatrixType::scalar_type scalar_type;
-  typedef typename CrsMatrixType::local_ordinal_type local_ordinal_type;
-  typedef typename CrsMatrixType::global_ordinal_type global_ordinal_type;
-  typedef typename CrsMatrixType::node_type NT;
+  typedef typename Matrix_t::scalar_type scalar_type;
+  typedef typename Matrix_t::local_ordinal_type local_ordinal_type;
+  typedef typename Matrix_t::global_ordinal_type global_ordinal_type;
+  typedef typename Matrix_t::node_type NT;
   typedef Teuchos::ScalarTraits<scalar_type> STS;
   typedef Tpetra::Map<local_ordinal_type, global_ordinal_type, NT> map_type;
   typedef Tpetra::Export<local_ordinal_type, global_ordinal_type, NT> export_type;
@@ -202,18 +248,18 @@ null_add_test (const CrsMatrixType& A,
   out << "  Calling 3-arg add" << endl;
   RCP<const map_type> domainMap = BT ? B.getRangeMap () : B.getDomainMap ();
   RCP<const map_type> rangeMap = BT ? B.getDomainMap () : B.getRangeMap ();
-  RCP<CrsMatrixType> C_computed =
+  RCP<Matrix_t> C_computed =
     Tpetra::MatrixMatrix::add (one, AT, A, one, BT, B,
                                domainMap, rangeMap, Teuchos::null);
   TEUCHOS_TEST_FOR_EXCEPTION(
     C_computed.is_null (), std::logic_error, "3-arg add returned null.");
 
-  RCP<CrsMatrixType> C_exported;
+  RCP<Matrix_t> C_exported;
   if (! C_computed->getRowMap ()->isSameAs (* (C.getRowMap ()))) {
     // Export C_computed to C's row Map, so we can compare the two.
     export_type exp (C_computed->getRowMap (), C.getRowMap ());
     C_exported =
-      Tpetra::exportAndFillCompleteCrsMatrix<CrsMatrixType> (C_computed, exp,
+      Tpetra::exportAndFillCompleteCrsMatrix<Matrix_t> (C_computed, exp,
                                                              C.getDomainMap (),
                                                              C.getRangeMap ());
   } else {
@@ -239,21 +285,28 @@ null_add_test (const CrsMatrixType& A,
 }
 
 
-template<class Ordinal>
+template<class Matrix_t>
 add_test_results add_into_test(
     RCP<Matrix_t > A,
     RCP<Matrix_t > B,
     bool AT,
     RCP<Matrix_t > C,
-    RCP<const Comm<Ordinal> > comm)
+    RCP<const Comm<int> > comm)
 {
+  typedef typename Matrix_t::scalar_type SC;
+  typedef typename Matrix_t::local_ordinal_type LO;
+  typedef typename Matrix_t::global_ordinal_type GO;
+  typedef typename Matrix_t::node_type NT;
+  typedef Map<LO,GO,NT> Map_t;
+
   add_test_results toReturn;
   toReturn.correctNorm = C->getFrobeniusNorm ();
 
-  RCP<const Map<int, int, node_type> > rowmap =
+  RCP<const Map_t > rowmap =
     AT ? A->getDomainMap () : A->getRowMap ();
   RCP<Matrix_t> computedC = rcp (new Matrix_t (rowmap, 1));
-  Tpetra::MatrixMatrix::Add (*A, AT, 1.0, *B, 1.0);
+  SC one = Teuchos::ScalarTraits<SC>::one();
+  Tpetra::MatrixMatrix::Add (*A, AT, one, *B, one);
   B->fillComplete ();
   toReturn.computedNorm = B->getFrobeniusNorm ();
   toReturn.epsilon = fabs (toReturn.correctNorm - toReturn.computedNorm);
@@ -261,18 +314,22 @@ add_test_results add_into_test(
   return toReturn;
 }
 
-template<class Ordinal>
-mult_test_results multiply_test(
+template<class Matrix_t>
+mult_test_results multiply_test_manualfc(
   const std::string& name,
   RCP<Matrix_t> A,
   RCP<Matrix_t> B,
   bool AT,
   bool BT,
   RCP<Matrix_t> C,
-  RCP<const Comm<Ordinal> > comm,
+  RCP<const Comm<int> > comm,
   FancyOStream& out)
 {
-  typedef Map<int, int, node_type> Map_t;
+  typedef typename Matrix_t::scalar_type SC;
+  typedef typename Matrix_t::local_ordinal_type LO;
+  typedef typename Matrix_t::global_ordinal_type GO;
+  typedef typename Matrix_t::node_type NT;
+  typedef Map<LO,GO,NT> Map_t;
   RCP<const Map_t> map = C->getRowMap();
 
   RCP<Matrix_t> computedC = rcp( new Matrix_t(map, 1));
@@ -286,9 +343,10 @@ mult_test_results multiply_test(
   Tpetra::MatrixMarket::Writer<Matrix_t>::writeSparseFile(
     name+"_real.mtx", C);
 #endif
+  SC one = Teuchos::ScalarTraits<SC>::one();
 
-  RCP<Matrix_t> diffMatrix = Tpetra::createCrsMatrix<double, int, int, node_type>(C->getRowMap());
-  Tpetra::MatrixMatrix::Add(*C, false, -1.0, *computedC, false, 1.0, diffMatrix);
+  RCP<Matrix_t> diffMatrix = Tpetra::createCrsMatrix<SC,LO,GO,NT>(C->getRowMap());
+  Tpetra::MatrixMatrix::Add(*C, false, -one, *computedC, false, one, diffMatrix);
   diffMatrix->fillComplete(C->getDomainMap(), C->getRangeMap());
 
   mult_test_results results;
@@ -299,8 +357,92 @@ mult_test_results multiply_test(
   return results;
 }
 
+template<class Matrix_t>
+mult_test_results multiply_test_autofc(
+  const std::string& name,
+  RCP<Matrix_t> A,
+  RCP<Matrix_t> B,
+  bool AT,
+  bool BT,
+  RCP<Matrix_t> C,
+  RCP<const Comm<int> > comm,
+  FancyOStream& out)
+{
+  typedef typename Matrix_t::scalar_type SC;
+  typedef typename Matrix_t::local_ordinal_type LO;
+  typedef typename Matrix_t::global_ordinal_type GO;
+  typedef typename Matrix_t::node_type NT;
+  typedef Map<LO,GO,NT> Map_t;
+  RCP<const Map_t> map = C->getRowMap();
 
-template<class Ordinal>
+  RCP<Matrix_t> computedC = rcp( new Matrix_t(map, 0));
+  SC one = Teuchos::ScalarTraits<SC>::one();
+
+  Tpetra::MatrixMatrix::Multiply(*A, AT, *B, BT, *computedC, true);
+
+  if(!C->getDomainMap()->isSameAs(*computedC->getDomainMap())) throw std::runtime_error("Domain map mismatch");
+  if(!C->getRangeMap()->isSameAs(*computedC->getRangeMap())) throw std::runtime_error("Range map mismatch");
+  if(!C->getRowMap()->isSameAs(*computedC->getRowMap())) throw std::runtime_error("Row map mismatch");
+
+#if 0
+  Tpetra::MatrixMarket::Writer<Matrix_t>::writeSparseFile(
+    name+"_calculated.mtx", computedC);
+  Tpetra::MatrixMarket::Writer<Matrix_t>::writeSparseFile(
+    name+"_real.mtx", C);
+#endif
+
+#if 0
+  RCP<Teuchos::FancyOStream> fancy = Teuchos::fancyOStream(Teuchos::rcpFromRef(std::cout));
+  std::cout<<"*** C->colMap() ***"<<std::endl;
+  C->getColMap()->describe(*fancy,Teuchos::VERB_EXTREME);
+  std::cout<<"*** C->domainMap() ***"<<std::endl;
+  C->getDomainMap()->describe(*fancy,Teuchos::VERB_EXTREME);
+  
+  if(C->getGraph()->getImporter().is_null()) std::cout<<"C->getImporter is null"<<std::endl;
+  else { 
+    std::cout<<"*** C->getImporter()->getTargetMap() ***"<<std::endl;
+    C->getGraph()->getImporter()->getTargetMap()->describe(*fancy,Teuchos::VERB_EXTREME);
+  }
+
+  std::cout<<"*** computedC->colMap() ***"<<std::endl;
+  computedC->getColMap()->describe(*fancy,Teuchos::VERB_EXTREME);
+  std::cout<<"*** computedC->domainMap() ***"<<std::endl;
+  computedC->getDomainMap()->describe(*fancy,Teuchos::VERB_EXTREME); 
+ 
+  if(computedC->getGraph()->getImporter().is_null()) std::cout<<"computedC->getImporter is null"<<std::endl;
+  else {
+    std::cout<<"*** computedC->getImporter()->getTargetMap() ***"<<std::endl;
+    computedC->getGraph()->getImporter()->getTargetMap()->describe(*fancy,Teuchos::VERB_EXTREME);
+  }
+#endif
+
+
+  RCP<Matrix_t> diffMatrix = Tpetra::createCrsMatrix<SC,LO,GO,NT>(C->getRowMap());
+  Tpetra::MatrixMatrix::Add(*C, false, -one, *computedC, false, one, diffMatrix);
+  diffMatrix->fillComplete(C->getDomainMap(), C->getRangeMap());
+
+  mult_test_results results;
+  results.cNorm    = C->getFrobeniusNorm ();
+  results.compNorm = diffMatrix->getFrobeniusNorm ();
+  results.epsilon  = results.compNorm/results.cNorm;
+
+  if(results.epsilon > 1e-3) {
+#if 0
+  Tpetra::MatrixMarket::Writer<Matrix_t>::writeSparseFile(
+    name+"_calculated.mtx", computedC);
+  Tpetra::MatrixMarket::Writer<Matrix_t>::writeSparseFile(
+    name+"_real.mtx", C);
+ 
+#endif
+  if(!comm->getRank()) printf("ERROR: TEST %s FAILED\n",name.c_str());
+  }
+
+
+  return results;
+}
+
+
+template<class Matrix_t>
 mult_test_results multiply_reuse_test(
   const std::string& name,
   RCP<Matrix_t> A,
@@ -308,16 +450,20 @@ mult_test_results multiply_reuse_test(
   bool AT,
   bool BT,
   RCP<Matrix_t> C,
-  RCP<const Comm<Ordinal> > comm,
+  RCP<const Comm<int> > comm,
   FancyOStream& out)
 {
-  typedef Map<int, int, node_type> Map_t;
-  typedef Vector<double,int,int,node_type> Vector_t;
+  typedef typename Matrix_t::scalar_type SC;
+  typedef typename Matrix_t::local_ordinal_type LO;
+  typedef typename Matrix_t::global_ordinal_type GO;
+  typedef typename Matrix_t::node_type NT;
+  typedef Map<LO,GO,NT> Map_t;
+  typedef Vector<SC,LO,GO,NT> Vector_t;
 
   RCP<const Map_t> map = C->getRowMap();
 
   // Scaling vectors
-  Teuchos::Array<typename Teuchos::ScalarTraits<double>::magnitudeType> norms(1);
+  Teuchos::Array<typename Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
 
   RCP<Vector_t> leftScaling  = rcp( new Vector_t(C->getRangeMap()) );
   leftScaling->randomize();
@@ -338,7 +484,7 @@ mult_test_results multiply_reuse_test(
 
   // NOTE (mfh 05 Jun 2016) This may even be null.  It exists at this
   // point only for the syntax.
-  RCP<node_type> node = map->getNode ();
+  RCP<NT> node = map->getNode ();
 
   // As = leftScaling * op(A) =
   //   leftScaling * A, if AT=false
@@ -362,8 +508,9 @@ mult_test_results multiply_reuse_test(
   Tpetra::MatrixMatrix::Multiply(*As, AT, *Bs, BT, *computedC2, true/*call_FillCompleteOnResult*/);
 
   // diffMatrix = computedC2 - computedC1
-  RCP<Matrix_t> diffMatrix = Tpetra::createCrsMatrix<double, int, int, node_type>(C->getRowMap());
-  Tpetra::MatrixMatrix::Add(*computedC1, false, -1.0, *computedC2, false, 1.0, diffMatrix);
+  SC one = Teuchos::ScalarTraits<SC>::one();
+  RCP<Matrix_t> diffMatrix = Tpetra::createCrsMatrix<SC,LO,GO,NT>(C->getRowMap());
+  Tpetra::MatrixMatrix::Add(*computedC1, false, -one, *computedC2, false, one, diffMatrix);
   diffMatrix->fillComplete(C->getDomainMap(), C->getRangeMap());
 
   mult_test_results results;
@@ -375,6 +522,7 @@ mult_test_results multiply_reuse_test(
 }
 
 
+template<class Matrix_t>
 mult_test_results jacobi_test(
   const std::string& name,
   RCP<Matrix_t> A,
@@ -382,11 +530,15 @@ mult_test_results jacobi_test(
   RCP<const Comm<int> > comm,
   FancyOStream& out)
 {
-  typedef Vector<double,int,int,node_type> Vector_t;
-  typedef Map<int, int, node_type> Map_t;
+  typedef typename Matrix_t::scalar_type SC;
+  typedef typename Matrix_t::local_ordinal_type LO;
+  typedef typename Matrix_t::global_ordinal_type GO;
+  typedef typename Matrix_t::node_type NT;
+  typedef Vector<SC,LO,GO,NT> Vector_t;
+  typedef Map<LO,GO,NT> Map_t;
   RCP<const Map_t> map = A->getRowMap();
 
-  double omega=1.0;
+  SC omega=Teuchos::ScalarTraits<SC>::one();
   Vector_t Dinv(B->getRowMap());
   Dinv.putScalar(1.0);
 
@@ -400,10 +552,11 @@ mult_test_results jacobi_test(
   RCP<Matrix_t> C_check = rcp(new Matrix_t(B->getRowMap(),0));
   Tpetra::MatrixMatrix::Multiply(*A,false,*B,false,*AB);
   AB->leftScale(Dinv);
-  Tpetra::MatrixMatrix::Add(*AB,false,-1.0,*B,false,1.0,C_check);
+  SC one = Teuchos::ScalarTraits<SC>::one();
+  Tpetra::MatrixMatrix::Add(*AB,false,-one,*B,false,one,C_check);
 
   // Check the difference
-  Tpetra::MatrixMatrix::Add(*C, false, -1.0, *C_check, 1.0);
+  Tpetra::MatrixMatrix::Add(*C, false, -one, *C_check, one);
   C_check->fillComplete(B->getDomainMap(),B->getRangeMap());
 
   // Error Check
@@ -417,6 +570,7 @@ mult_test_results jacobi_test(
 }
 
 
+template<class Matrix_t>
 mult_test_results jacobi_reuse_test(
   const std::string& name,
   RCP<Matrix_t> A,
@@ -424,19 +578,24 @@ mult_test_results jacobi_reuse_test(
   RCP<const Comm<int> > comm,
   FancyOStream& out)
 {
-  typedef Vector<double,int,int,node_type> Vector_t;
-  typedef Map<int, int, node_type> Map_t;
+  typedef typename Matrix_t::scalar_type SC;
+  typedef typename Matrix_t::local_ordinal_type LO;
+  typedef typename Matrix_t::global_ordinal_type GO;
+  typedef typename Matrix_t::node_type NT;
+  typedef Vector<SC,LO,GO,NT> Vector_t;
+  typedef Map<LO,GO,NT> Map_t;
 
   RCP<const Map_t> map = A->getRowMap();
 
   // Scaling vectors
-  Teuchos::Array<typename Teuchos::ScalarTraits<double>::magnitudeType> norms(1);
+  Teuchos::Array<typename Teuchos::ScalarTraits<SC>::magnitudeType> norms(1);
   RCP<Vector_t> rightScaling = rcp( new Vector_t(B->getDomainMap()) );
   rightScaling->randomize();
   rightScaling->norm2(norms);
   rightScaling->scale(1.0/norms[0]);
+  SC one = Teuchos::ScalarTraits<SC>::one();
 
-  double omega = 1.0;
+  SC omega = one;
   Vector_t Dinv(B->getRowMap());
   Dinv.putScalar(1.0);
 
@@ -449,7 +608,7 @@ mult_test_results jacobi_reuse_test(
 
   // NOTE (mfh 05 Jun 2016) This may even be null.  It exists at this
   // point only for the syntax.
-  RCP<node_type> node = map->getNode ();
+  RCP<NT> node = map->getNode ();
   RCP<Matrix_t> Bs = B->clone(node);
   Bs->rightScale(*rightScaling);
 
@@ -458,8 +617,9 @@ mult_test_results jacobi_reuse_test(
   Tpetra::MatrixMatrix::Jacobi(omega, Dinv, *A, *Bs, *computedC2);
 
   // diffMatrix = computedC2 - computedC1
-  RCP<Matrix_t> diffMatrix = Tpetra::createCrsMatrix<double, int, int, node_type>(computedC1->getRowMap());
-  Tpetra::MatrixMatrix::Add(*computedC1, false, -1.0, *computedC2, false, 1.0, diffMatrix);
+
+  RCP<Matrix_t> diffMatrix = Tpetra::createCrsMatrix<SC,LO,GO,NT>(computedC1->getRowMap());
+  Tpetra::MatrixMatrix::Add(*computedC1, false, -one, *computedC2, false, one, diffMatrix);
   diffMatrix->fillComplete(computedC1->getDomainMap(), computedC1->getRangeMap());
 
   mult_test_results results;
@@ -471,10 +631,12 @@ mult_test_results jacobi_reuse_test(
 }
 
 
-
-TEUCHOS_UNIT_TEST(Tpetra_MatMat, operations_test)
-{
+TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(Tpetra_MatMat, operations_test,SC,LO, GO, NT)  {
   RCP<const Comm<int> > comm = DefaultPlatform::getDefaultPlatform().getComm();
+  
+  // NOTE: The matrix reader doesn't read real matrices into a complex data type, so we just swap down to MT here
+  typedef typename Teuchos::ScalarTraits<SC>::magnitudeType MT;
+  typedef CrsMatrix<MT,LO,GO,NT> Matrix_t;
   const int myRank = comm->getRank ();
   //const int numProcs = comm->getSize();
 
@@ -504,7 +666,7 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, operations_test)
       "Bad tag's name: " << it->first <<
       "Type name: " << it->second.getAny().typeName() <<
       endl << endl);
-
+ 
     ParameterList currentSystem = matrixSystems->sublist (it->first);
     std::string name = currentSystem.name();
     std::string A_file = currentSystem.get<std::string> ("A");
@@ -524,9 +686,22 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, operations_test)
 
     if (op == "multiply") {
       if (verbose)
-        newOut << "Running multiply test for " << currentSystem.name() << endl;
+        newOut << "Running multiply test (manual FC) for " << currentSystem.name() << endl;
 
-      mult_test_results results = multiply_test(name, A, B, AT, BT, C, comm, newOut);
+      mult_test_results results = multiply_test_manualfc(name, A, B, AT, BT, C, comm, newOut);
+
+      if (verbose) {
+        newOut << "Results:"     << endl;
+        newOut << "\tEpsilon: "  << results.epsilon  << endl;
+        newOut << "\tcNorm: "    << results.cNorm    << endl;
+        newOut << "\tcompNorm: " << results.compNorm << endl;
+      }
+      TEST_COMPARE(results.epsilon, <, epsilon);
+
+      if (verbose)
+        newOut << "Running multiply test (auto FC) for " << currentSystem.name() << endl;
+
+      results = multiply_test_autofc(name, A, B, AT, BT, C, comm, newOut);
 
       if (verbose) {
         newOut << "Results:"     << endl;
@@ -583,7 +758,7 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, operations_test)
         newOut << "Running 3-argument add test (nonnull C on input) for "
                << currentSystem.name() << endl;
 
-      add_test_results results = regular_add_test(A, B, AT, BT, C, comm);
+      add_test_results results = regular_add_test(name+"_add",A, B, AT, BT, C, comm);
 
       TEST_COMPARE(results.epsilon, <, epsilon);
       newOut << "Regular Add Test Results: " << endl;
@@ -647,8 +822,13 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, operations_test)
  * assumption in the Matrix Matrix Multiply Kernel.
  * KLN 15/06/2011
  */
-TEUCHOS_UNIT_TEST(Tpetra_MatMat, range_row_test){
+
+
+TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(Tpetra_MatMat, range_row_test, SC, LO, GO, NT)  {
   RCP<const Comm<int> > comm = DefaultPlatform::getDefaultPlatform().getComm();
+  typedef Map<LO,GO,NT>         Map_t;
+  typedef CrsMatrix<SC,LO,GO,NT> Matrix_t;
+
   const int myRank = comm->getRank ();
   const int numProcs = comm->getSize();
 
@@ -674,30 +854,28 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, range_row_test){
   int rank = comm->getRank();
   global_size_t globalNumRows = numRowsPerProc*numProcs;
 
-  newOut << "Create identityMatrix" << endl;
-  RCP<CrsMatrix<double,int,int,node_type> > identityMatrix =
-    getIdentityMatrix<double,int,int> (newOut, globalNumRows, comm);
+  RCP<Matrix_t > dummy =
+    getIdentityMatrix<SC,LO,GO,NT> (newOut, globalNumRows, comm);
 
   // This is just to fulfill syntax requirements.  It could even be null.
-  RCP<node_type> node = identityMatrix->getNode ();
+  RCP<NT> node = dummy->getNode ();
 
-  newOut << "Fill identityMatrix" << endl;
 //Create "B"
-  Array<int> myRows = tuple<int>(
+  Array<GO> myRows = tuple<GO>(
     rank*numRowsPerProc,
     rank*numRowsPerProc+1,
     rank*numRowsPerProc+2,
     rank*numRowsPerProc+3);
-  Array<int> rangeElements;
+  Array<GO> rangeElements;
   if(rank == 0){
-    rangeElements = tuple<int>(
+    rangeElements = tuple<GO>(
       (numProcs-1)*numRowsPerProc+1,
       (numProcs-1)*numRowsPerProc+2,
       (numProcs-1)*numRowsPerProc,
       (numProcs-1)*numRowsPerProc+3);
   }
   else{
-    rangeElements = tuple<int>(
+    rangeElements = tuple<GO>(
       (rank-1)*numRowsPerProc+1,
       (rank-1)*numRowsPerProc+2,
       (rank-1)*numRowsPerProc,
@@ -705,25 +883,29 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, range_row_test){
   }
 
   newOut << "Create row, range, and domain Maps of B" << endl;
-  RCP<const Map<int,int,node_type> > bRowMap =
-    Tpetra::createNonContigMapWithNode<int,int,node_type>(myRows, comm, node);
-  RCP<const Map<int,int,node_type> > bRangeMap =
-    Tpetra::createNonContigMapWithNode<int,int,node_type>(rangeElements, comm, node);
+  RCP<const Map_t > bRowMap =
+    Tpetra::createNonContigMapWithNode<LO,GO,NT>(myRows, comm, node);
+  RCP<const Map_t > bRangeMap =
+    Tpetra::createNonContigMapWithNode<LO,GO,NT>(rangeElements, comm, node);
   //We divide by 2 to make the matrix tall and "skinny"
-  RCP<const Map<int,int,node_type> > bDomainMap =
-    Tpetra::createUniformContigMapWithNode<int,int,node_type>(globalNumRows/2, comm, node);
+  RCP<const Map_t > bDomainMap =
+    Tpetra::createUniformContigMapWithNode<LO,GO,NT>(globalNumRows/2, comm, node);
+
+  newOut << "Create identityMatrix" << endl;
+  RCP<Matrix_t > identityMatrix =
+    getIdentityMatrixWithMap<SC,LO,GO,NT> (newOut, bRowMap, comm);
+
 
   newOut << "Create bMatrix" << endl;
-  RCP<CrsMatrix<double,int,int,node_type> > bMatrix =
-    Tpetra::createCrsMatrix<double,int,int,node_type>(bRowMap, 1);
+  RCP<Matrix_t > bMatrix =
+    Tpetra::createCrsMatrix<SC,LO,GO,NT>(bRowMap, 1);
 
   newOut << "Fill bMatrix" << endl;
   {
-    typedef int GO;
     Teuchos::ArrayView<const GO> gblRows = bRowMap->getNodeElementList ();
     for (auto it = gblRows.begin (); it != gblRows.end (); ++it) {
-      Array<int> col(1,(*it)/2);
-      Array<double> val(1,3.0);
+      Array<GO> col(1,(*it)/2);
+      Array<SC> val(1,3.0);
       bMatrix->insertGlobalValues(*it, col(), val());
     }
   }
@@ -732,7 +914,7 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, range_row_test){
   bMatrix->fillComplete(bDomainMap, bRangeMap);
 
   newOut << "Regular I*P" << endl;
-  mult_test_results results = multiply_test(
+  mult_test_results results = multiply_test_manualfc(
     "Different Range and Row Maps",
     identityMatrix,
     bMatrix,
@@ -750,32 +932,31 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, range_row_test){
   TEST_COMPARE(results.epsilon, <, defaultEpsilon);
 
   newOut << "Create identity2" << endl;
-  RCP<CrsMatrix<double,int,int,node_type> > identity2 =
-    getIdentityMatrix<double,int,int> (newOut, globalNumRows/2, comm);
+  RCP<Matrix_t > identity2 =
+    getIdentityMatrix<SC,LO,GO,NT> (newOut, globalNumRows/2, comm);
 
-  RCP<const Map<int,int,node_type> > bTransRowMap =
-    Tpetra::createUniformContigMapWithNode<int,int,node_type>(globalNumRows/2,comm);
+  RCP<const Map_t > bTransRowMap =
+    Tpetra::createUniformContigMapWithNode<LO,GO,NT>(globalNumRows/2,comm);
 
   newOut << "Create and fill bTrans" << endl;
-  RCP<CrsMatrix<double,int,int,node_type> > bTrans =
-    Tpetra::createCrsMatrix<double,int,int,node_type>(bTransRowMap, 1);
-  Array<int> bTransRangeElements;
+  RCP<Matrix_t> bTrans = Tpetra::createCrsMatrix<SC,LO,GO,NT>(bTransRowMap, 1);
+  Array<GO> bTransRangeElements;
   if(rank == 0){
-    bTransRangeElements = tuple<int>(
+    bTransRangeElements = tuple<GO>(
       (numProcs-1)*(numRowsPerProc/2)+1,
       (numProcs-1)*(numRowsPerProc/2));
   }
   else{
-    bTransRangeElements = tuple<int>(
+    bTransRangeElements = tuple<GO>(
       (rank-1)*(numRowsPerProc/2)+1,
       (rank-1)*(numRowsPerProc/2));
   }
   newOut << bTransRangeElements << endl;
 
-  RCP<const Map<int,int,node_type> > bTransRangeMap =
-    Tpetra::createNonContigMapWithNode<int,int,node_type>(bTransRangeElements, comm, node);
-  RCP<const Map<int,int,node_type> > bTransDomainMap =
-    Tpetra::createUniformContigMapWithNode<int,int,node_type>(globalNumRows, comm, node);
+  RCP<const Map_t > bTransRangeMap =
+    Tpetra::createNonContigMapWithNode<LO,GO,NT>(bTransRangeElements, comm, node);
+  RCP<const Map_t > bTransDomainMap =
+    Tpetra::createUniformContigMapWithNode<LO,GO,NT>(globalNumRows, comm, node);
 
   newOut << "Compute identity * transpose(bTrans)" << endl;
   Tpetra::MatrixMatrix::Multiply(*identity2,false,*bMatrix, true, *bTrans, false);
@@ -784,15 +965,14 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, range_row_test){
   bTrans->fillComplete(bTransDomainMap, bTransRangeMap);
 
   newOut << "Create and fill bTransTest" << endl;
-  RCP<CrsMatrix<double,int,int,node_type> > bTransTest =
-    Tpetra::createCrsMatrix<double,int,int,node_type>(bTransRowMap, 1);
+  RCP<Matrix_t > bTransTest =
+    Tpetra::createCrsMatrix<SC,LO,GO,NT>(bTransRowMap, 1);
 
   {
-    typedef int GO;
     Teuchos::ArrayView<const GO> gblRows = bRowMap->getNodeElementList ();
     for (auto it = gblRows.begin (); it != gblRows.end (); ++it) {
-      Teuchos::Array<int> col(1,*it);
-      Teuchos::Array<double> val(1,3.0);
+      Teuchos::Array<GO> col(1,*it);
+      Teuchos::Array<SC> val(1,3.0);
       bTransTest->insertGlobalValues((*it)/2, col(), val());
     }
   }
@@ -805,9 +985,9 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, range_row_test){
   // meaningful to someone.
   newOut << "Regular I*P^T" << endl;
 
-  RCP<CrsMatrix<double,int,int,node_type> > bTransDiff =
-    Tpetra::createCrsMatrix<double,int,int,node_type>(bTransRowMap, 1);
-  Tpetra::MatrixMatrix::Add<double,int,int,node_type>(*bTransTest, false, -1.0, *bTrans, false, 1.0,bTransDiff);
+  RCP<Matrix_t > bTransDiff =
+    Tpetra::createCrsMatrix<SC,LO,GO,NT>(bTransRowMap, 1);
+  Tpetra::MatrixMatrix::Add<SC,LO,GO,NT>(*bTransTest, false, -1.0, *bTrans, false, 1.0,bTransDiff);
 
   newOut << "Call fillComplete on bTransDiff" << endl;
   bTransDiff->fillComplete(bTransDomainMap, bDomainMap);
@@ -836,15 +1016,17 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, range_row_test){
   TEST_EQUALITY_CONST( gblSuccess, 1 );
 }
 
+
 /**
  * This test was written at the request of Chris Siefert
  * in order to verity that A^T * I produces correct results
  * when A's rowmap and rangemap are differnt.
  * KLN 23/06/2011
  */
-TEUCHOS_UNIT_TEST(Tpetra_MatMat, ATI_range_row_test)
-{
+TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(Tpetra_MatMat, ATI_range_row_test, SC, LO, GO, NT)  {
   RCP<const Comm<int> > comm = DefaultPlatform::getDefaultPlatform().getComm();
+  typedef Map<LO,GO,NT>          Map_t;
+  typedef CrsMatrix<SC,LO,GO,NT> Matrix_t;
 
   // Create an output stream that prints immediately, rather than
   // waiting until the test finishes.  This lets us get debug output
@@ -872,52 +1054,51 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, ATI_range_row_test)
   global_size_t globalNumRows = numRowsPerProc*numProcs;
 
   newOut << "Create identity matrix" << endl;
-  RCP<CrsMatrix<double,int,int,node_type> > identityMatrix =
-    getIdentityMatrix<double,int,int> (newOut, globalNumRows, comm);
+  RCP<Matrix_t> identityMatrix =
+    getIdentityMatrix<SC,LO,GO,NT> (newOut, globalNumRows, comm);
 
   // NOTE (mfh 05 Jun 2016) This may even be null.  It exists at this
   // point only for the syntax.
-  RCP<node_type> node = identityMatrix->getNode ();
+  RCP<NT> node = identityMatrix->getNode ();
 
   newOut << "Create Maps for matrix aMat" << endl;
-  Array<int> aMyRows = tuple<int>(
+  Array<GO> aMyRows = tuple<GO>(
     rank*numRowsPerProc,
     rank*numRowsPerProc+1,
     rank*numRowsPerProc+2,
     rank*numRowsPerProc+3);
-  RCP<const Map<int,int,node_type> > aRowMap =
-    Tpetra::createNonContigMapWithNode<int,int,node_type>(aMyRows, comm, node);
-  RCP<const Map<int,int,node_type> > aDomainMap =
-    Tpetra::createUniformContigMapWithNode<int,int,node_type>(globalNumRows/2, comm, node);
-  Array<int> aRangeElements;
+  RCP<const Map_t> aRowMap =
+    Tpetra::createNonContigMapWithNode<LO,GO,NT>(aMyRows, comm, node);
+  RCP<const Map_t> aDomainMap =
+    Tpetra::createUniformContigMapWithNode<LO,GO,NT>(globalNumRows/2, comm, node);
+  Array<GO> aRangeElements;
   if(rank == 0){
-    aRangeElements = tuple<int>(
+    aRangeElements = tuple<GO>(
       (numProcs-1)*numRowsPerProc+1,
       (numProcs-1)*numRowsPerProc+2,
       (numProcs-1)*numRowsPerProc,
       (numProcs-1)*numRowsPerProc+3);
   }
   else{
-    aRangeElements = tuple<int>(
+    aRangeElements = tuple<GO>(
       (rank-1)*numRowsPerProc+1,
       (rank-1)*numRowsPerProc+2,
       (rank-1)*numRowsPerProc,
       (rank-1)*numRowsPerProc+3);
   }
-  RCP<const Map<int,int,node_type> > aRangeMap =
-    Tpetra::createNonContigMapWithNode<int,int,node_type>(aRangeElements, comm, node);
+  RCP<const Map<LO,GO,NT> > aRangeMap =
+    Tpetra::createNonContigMapWithNode<LO,GO,NT>(aRangeElements, comm, node);
 
   newOut << "Create matrix aMat" << endl;
-  RCP<CrsMatrix<double,int,int,node_type> > aMat =
-    Tpetra::createCrsMatrix<double,int,int,node_type>(aRowMap, 1);
+  RCP<Matrix_t> aMat =
+    Tpetra::createCrsMatrix<SC,LO,GO,NT>(aRowMap, 1);
 
   newOut << "Fill matrix aMat" << endl;
   {
-    typedef int GO;
     Teuchos::ArrayView<const GO> gblRows = aRowMap->getNodeElementList ();
     for (auto it = gblRows.begin (); it != gblRows.end (); ++it) {
-      Teuchos::Array<int> col(1,(*it)/2);
-      Teuchos::Array<double> val(1,3.0);
+      Teuchos::Array<GO> col(1,(*it)/2);
+      Teuchos::Array<SC> val(1,3.0);
       aMat->insertGlobalValues(*it, col(), val());
     }
   }
@@ -925,16 +1106,15 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, ATI_range_row_test)
   aMat->fillComplete(aDomainMap, aRangeMap);
 
   newOut << "Create RowMatrixTransposer with aMat" << endl;
-  RowMatrixTransposer<double,int,int,node_type> transposer (aMat);
+  RowMatrixTransposer<SC,LO,GO,NT> transposer (aMat);
 
   newOut << "Use RowMatrixTransposer to create transpose of aMat" << endl;
-  RCP<CrsMatrix<double, int, int, node_type> > knownAMat =
-    transposer.createTranspose();
+  RCP<Matrix_t > knownAMat = transposer.createTranspose();
 
   // FIXME (mfh 03 May 2016) I'm not sure what this message means, so
   // I'll leave it.
   newOut << "Regular I*P" << endl;
-  mult_test_results results = multiply_test(
+  mult_test_results results = multiply_test_manualfc(
     "Different Range and Row Maps",
     aMat,
     identityMatrix,
@@ -960,7 +1140,6 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, ATI_range_row_test)
   }
   TEST_EQUALITY_CONST( gblSuccess, 1 );
 }
-
 /*
  * This test was added at the request of Chris Siefert
  * Turns out it fails because the original algorithm in
@@ -974,12 +1153,12 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, ATI_range_row_test)
   ParameterList defaultParameters;
   RCP<Matrix_t > A = Reader<Matrix_t >::readSparseFile("matrices/denserATa.mtx", comm);
   RCP<Matrix_t > C = Reader<Matrix_t >::readSparseFile("matrices/denserATc.mtx", comm, true, true);
-  RowMatrixTransposer<double, int,int,node_type> transposer(*A);
+  RowMatrixTransposer<double, int,int,NT> transposer(*A);
   RCP<Matrix_t> AT = transposer.createTranspose();
 
   RCP<Matrix_t> importedC =
-    Tpetra::createCrsMatrix<double, int, int, node_type>(AT->getRowMap());
-  Tpetra::Import<int,int,node_type> importer(C->getRowMap(), importedC->getRowMap());
+    Tpetra::createCrsMatrix<double, int, int, NT>(AT->getRowMap());
+  Tpetra::Import<int,int,NT> importer(C->getRowMap(), importedC->getRowMap());
   importedC->doImport(*C, importer, Tpetra::REPLACE);
   importedC->fillComplete(AT->getDomainMap(), AT->getRangeMap());
 
@@ -1003,7 +1182,16 @@ TEUCHOS_UNIT_TEST(Tpetra_MatMat, ATI_range_row_test)
 }*/
 
 
-} //namespace Tpetra
+#define UNIT_TEST_GROUP_SC_LO_GO_NO( SC, LO, GO, NT )			\
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(Tpetra_MatMat, operations_test,SC, LO, GO, NT) \
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(Tpetra_MatMat, range_row_test, SC, LO, GO, NT) \
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(Tpetra_MatMat, ATI_range_row_test, SC, LO, GO, NT)
 
 
+  TPETRA_ETI_MANGLING_TYPEDEFS()
+
+  TPETRA_INSTANTIATE_SLGN_NO_ORDINAL_SCALAR( UNIT_TEST_GROUP_SC_LO_GO_NO )
+
+
+  } //namespace Tpetra
 
