@@ -49,15 +49,6 @@
 #include "MueLu_CreateTpetraPreconditioner.hpp"
 #include "Kokkos_CrsMatrix.hpp"
 
-namespace Sacado {
-  namespace UQ {
-    template <typename Storage> class PCE;
-  }
-  namespace MP {
-    template <typename Storage> class Vector;
-  }
-}
-
 namespace Kokkos {
 namespace Example {
 
@@ -84,77 +75,6 @@ namespace Example {
     MeanViewType mean_vals;
   };
 
-  //! Get mean values matrix for mean-based preconditioning
-  /*! Specialization for Sacado::UQ::PCE
-   */
-  template <class Storage, class Layout, class Memory, class Device>
-  class GetMeanValsFunc< Kokkos::View< Sacado::UQ::PCE<Storage>*,
-                                       Layout, Memory, Device > > {
-  public:
-    typedef Sacado::UQ::PCE<Storage> Scalar;
-    typedef Kokkos::View< Scalar*, Layout, Memory, Device > ViewType;
-    typedef ViewType MeanViewType;
-    typedef typename ViewType::execution_space execution_space;
-    typedef typename ViewType::size_type size_type;
-
-    GetMeanValsFunc(const ViewType& vals_) : vals(vals_)
-    {
-      const size_type nnz = vals.dimension_0();
-      mean_vals = ViewType("mean-values", vals.cijk(), nnz, 1);
-      Kokkos::parallel_for( nnz, *this );
-    }
-
-    KOKKOS_INLINE_FUNCTION
-    void operator() (const size_type i) const
-    {
-      mean_vals(i) = vals(i).fastAccessCoeff(0);
-    }
-
-     MeanViewType getMeanValues() const { return mean_vals; }
-
-  private:
-    MeanViewType mean_vals;
-    ViewType vals;
-  };
-
-  //! Get mean values matrix for mean-based preconditioning
-  /*! Specialization for Sacado::MP::Vector
-   */
-  template <class Storage, class Layout, class Memory, class Device>
-  class GetMeanValsFunc< Kokkos::View< Sacado::MP::Vector<Storage>*,
-                                       Layout, Memory, Device > > {
-  public:
-    typedef Sacado::MP::Vector<Storage> Scalar;
-    typedef Kokkos::View< Scalar*, Layout, Memory, Device > ViewType;
-    typedef ViewType MeanViewType;
-    typedef typename ViewType::execution_space execution_space;
-    typedef typename ViewType::size_type size_type;
-
-    GetMeanValsFunc(const ViewType& vals_) :
-      vals(vals_), vec_size(vals.sacado_size())
-    {
-      const size_type nnz = vals.dimension_0();
-      mean_vals = ViewType("mean-values", nnz, 1);
-      Kokkos::parallel_for( nnz, *this );
-    }
-
-    KOKKOS_INLINE_FUNCTION
-    void operator() (const size_type i) const
-    {
-      typename Scalar::value_type s = 0.0;
-      for (size_type j=0; j<vec_size; ++j)
-        s += vals(i).fastAccessCoeff(j);
-      mean_vals(i) = s;
-    }
-
-    MeanViewType getMeanValues() const { return mean_vals; }
-
-  private:
-    MeanViewType mean_vals;
-    ViewType vals;
-    const size_type vec_size;
-  };
-
   /*!
    * \brief A stochastic preconditioner based on applying the inverse of the
    * mean.
