@@ -55,13 +55,14 @@
 #include <fenl.hpp>
 #include <fenl_functors_pce.hpp>
 #include <fenl_impl.hpp>
+#if defined(HAVE_TRILINOSCOUPLINGS_BELOS) && defined(HAVE_TRILINOSCOUPLINGS_MUELU)
 #include <MeanBasedPreconditioner.hpp>
+#endif
 
 namespace Kokkos {
 namespace Example {
 
-#if defined( KOKKOS_USING_EXPERIMENTAL_VIEW )
-
+#if defined(HAVE_TRILINOSCOUPLINGS_BELOS) && defined(HAVE_TRILINOSCOUPLINGS_MUELU)
   //! Get mean values matrix for mean-based preconditioning
   /*! Specialization for Sacado::UQ::PCE
    */
@@ -97,43 +98,6 @@ namespace Example {
     ViewType vals;
   };
 
-#else
-
-  //! Get mean values matrix for mean-based preconditioning
-  /*! Specialization for Sacado::UQ::PCE
-   */
-  template <class Storage, class Layout, class Memory, class Device>
-  class GetMeanValsFunc< Kokkos::View< Sacado::UQ::PCE<Storage>*,
-                                       Layout, Memory, Device > > {
-  public:
-    typedef Sacado::UQ::PCE<Storage> Scalar;
-    typedef Kokkos::View< Scalar*, Layout, Memory, Device > ViewType;
-    typedef ViewType MeanViewType;
-    typedef typename ViewType::execution_space execution_space;
-    typedef typename ViewType::size_type size_type;
-
-    GetMeanValsFunc(const ViewType& vals_) : vals(vals_)
-    {
-      const size_type nnz = vals.dimension_0();
-      mean_vals = ViewType("mean-values", vals.cijk(), nnz, 1);
-      Kokkos::parallel_for( nnz, *this );
-    }
-
-    KOKKOS_INLINE_FUNCTION
-    void operator() (const size_type i) const
-    {
-      mean_vals(i) = vals(i).fastAccessCoeff(0);
-    }
-
-     MeanViewType getMeanValues() const { return mean_vals; }
-
-  private:
-    MeanViewType mean_vals;
-    ViewType vals;
-  };
-
-#endif
-
   /*!
    * \brief A stochastic preconditioner based on applying the inverse of the
    * mean.  Specialized for UQ::PCE
@@ -219,5 +183,6 @@ namespace Example {
 
   }; // class MeanBasedPreconditioner
 
+#endif
 }
 }
