@@ -776,7 +776,7 @@ void brdcst_cmd_info (
   case HYPERGRAPH_FILE:
   case MATRIXMARKET_FILE:
   case MATRIXMARKET_PLUS_FILE:
-    mesh->data_type = HYPERGRAPH;
+    mesh->data_type = ZOLTAN_HYPERGRAPH;
     break;
   }
 
