@@ -496,7 +496,7 @@ int setup_zoltan(struct Zoltan_Struct *zz, int Proc, PROB_INFO_PTR prob,
   }
 
   /* Hypergraph-based callbacks */
-  if ((mesh->data_type == HYPERGRAPH) && Test.Hypergraph_Callbacks) {
+  if ((mesh->data_type == ZOLTAN_HYPERGRAPH) && Test.Hypergraph_Callbacks) {
 
     if (Zoltan_Set_Fn(zz, ZOLTAN_HG_SIZE_CS_FN_TYPE,
 		      (void (*)()) get_hg_size_compressed_pin_storage,
@@ -908,6 +908,9 @@ exit(-1);
       /* Not yet impl. */
     }
 
+    {
+    double kddstart = MPI_Wtime();
+
     if (Zoltan_Order(zz, num_gid_entries,
 	mesh->num_elems, order_gids,
 	order) == ZOLTAN_FATAL) {
@@ -918,6 +921,12 @@ exit(-1);
       return 0;
     }
 
+    MPI_Barrier(MPI_COMM_WORLD);
+    if (Proc == 0)
+      printf("\nOrdering time = %f seconds\n", MPI_Wtime() - kddstart);
+
+    }
+
     /* Evaluate the new ordering */
     if (Debug_Driver > 0) {
       if (Proc == 0) printf("\nAFTER ordering\n");
@@ -1101,7 +1110,7 @@ MESH_INFO_PTR mesh;
 
   STOP_CALLBACK_TIMER;
 
-  if ((mesh->data_type == HYPERGRAPH) && mesh->visible_nvtx) {
+  if ((mesh->data_type == ZOLTAN_HYPERGRAPH) && mesh->visible_nvtx) {
     int i, cnt = 0;
     for (i = 0; i < mesh->num_elems; i++)
       if (mesh->elements[i].globalID <= mesh->visible_nvtx) cnt++;
@@ -1142,7 +1151,7 @@ void get_elements(void *data, int num_gid_entries, int num_lid_entries,
     if (mesh->blank && mesh->blank[i]) continue;
 
     current_elem = &elem[i];
-    if ((mesh->data_type == HYPERGRAPH) && mesh->visible_nvtx &&
+    if ((mesh->data_type == ZOLTAN_HYPERGRAPH) && mesh->visible_nvtx &&
 	(current_elem->globalID > mesh->visible_nvtx)) continue;
 
     for (j = 0; j < gid; j++) global_id[idx*num_gid_entries+j]=0;
