@@ -178,7 +178,7 @@ const char *yo = "migrate_elements";
   }
 
 
-  if (Test.Null_Lists == NONE) {
+  if (Test.Null_Lists == NO_NULL_LISTS) {
     if (zz.Migrate(num_imp, imp_gids, imp_lids, imp_procs, imp_to_part,
                    num_exp, exp_gids, exp_lids, exp_procs, exp_to_part)
                    == ZOLTAN_FATAL) {
@@ -607,11 +607,11 @@ void migrate_post_process(void *data, int num_gid_entries, int num_lid_entries,
     Gen_Error(0, "Fatal: error rebuilding elem comm maps");
   }
 
-  if (mesh->data_type == HYPERGRAPH && !update_elem_dd(mesh)) {
+  if (mesh->data_type == ZOLTAN_HYPERGRAPH && !update_elem_dd(mesh)) {
     Gen_Error(0, "Fatal: error updating element dd");
   }
 
-  if (mesh->data_type == HYPERGRAPH && mesh->hvertex_proc &&
+  if (mesh->data_type == ZOLTAN_HYPERGRAPH && mesh->hvertex_proc &&
        !update_hvertex_proc(mesh)) {
     Gen_Error(0, "Fatal: error updating hyperedges");
   }
