@@ -49,7 +49,7 @@
 
 #include <mpi.h>
 #include <stddef.h>
-#ifndef WIN32
+#ifndef _WIN32
 #include <unistd.h>
 #endif
 #include <limits.h>
