@@ -82,7 +82,12 @@ class AlgRCM : public Algorithm<Adapter>
   {
   }
 
-  int order(const RCP<OrderingSolution<lno_t, gno_t> > &solution)
+  int globalOrder(const RCP<GlobalOrderingSolution<gno_t> > &solution)
+  {
+    throw std::logic_error("AlgRCM does not yet support global ordering.");
+  }
+
+  int localOrder(const RCP<LocalOrderingSolution<lno_t> > &solution)
   {
     int ierr= 0;
 
