@@ -1,6 +1,8 @@
 #ifndef _ZOLTAN2_MatcherHelper_hpp_
 #define _ZOLTAN2_MatcherHelper_hpp_
 
+//#define _ZOLTAN2_MatcherHelper_hpp_
+
 
 #ifdef ZOLTAN2ND_HAVE_OMP
 #include <omp.h>
@@ -32,47 +34,50 @@ namespace Zoltan2 {
 
 */
 ////////////////////////////////////////////////////////////////////////////////
+
+
+template <typename LO>
 class Matcher 
 {
 private:
 
-    int *mCRS_rowPtrs;
-    int *mCRS_cols;
+    LO *mCRS_rowPtrs;
+    LO *mCRS_cols;
   
     // Number of vertices in u set (num row vertices)
-    int numU;
+    LO numU;
 
     // Number of vertices in v set (num col vertices)
-    int numV;
+    LO numV;
 
     // For each u vertex, the matching v vertex
-    std::vector<int> matchedVertexForU;
+    std::vector<LO> matchedVertexForU;
 
     // For each v vertex, the matching u vertex
-    std::vector<int> matchedVertexForV;
+    std::vector<LO> matchedVertexForV;
 
-    std::vector<int> queue;
-    int* LV_;
-    int* LU_;
-    int* unmatchedU_;
-    int *parent_;
-    int *lookahead_;
+    std::vector<LO> queue;
+    LO* LV_;
+    LO* LU_;
+    LO* unmatchedU_;
+    LO *parent_;
+    LO *lookahead_;
     bool finish_;
-    int numE,avgDegU_,k_star_,icm_,BFSInd_,numThread_,Qst_,Qend_,numMatched;
+    LO numE,avgDegU_,k_star_,icm_,BFSInd_,numThread_,Qst_,Qend_,numMatched;
 
-    int *visitedV_;
+    LO *visitedV_;
 
     void delete_matched_v();
-    int SGM();  
-    int match_dfs();
-    int match_hk();
-    int construct_layered_graph();
-    int find_set_del_M();
-    int recursive_path_finder(int, int);
-    int dfs_path_finder(int);
-    int dfs_augment();
-    int augment_matching(int);
-    int DW_phase();
+    LO SGM();  
+    LO match_dfs();
+    LO match_hk();
+    LO construct_layered_graph();
+    LO find_set_del_M();
+    LO recursive_path_finder(LO, LO);
+    LO dfs_path_finder(LO);
+    LO dfs_augment();
+    LO augment_matching(LO);
+    LO DW_phase();
 
 public:
     /** @ingroup matching_grp
@@ -82,7 +87,7 @@ public:
     \param[in] Number of vertices in u set (num row vertices)
     \param[in] Number of vertices in v set (num col vertices)
     */
-    Matcher(int *_rowPtr, int *_cols, int _numU, int _numV, int _numE);
+    Matcher(LO *_rowPtr, LO *_cols, LO _numU, LO _numV, LO _numE);
 
 
 
@@ -96,9 +101,9 @@ public:
     Returns the number of matched vertices from Maximum Cardinality
      Matching set
     */
-    int getNumberOfMatchedVertices()
+    LO getNumberOfMatchedVertices()
     {
-      int count=0;
+      LO count=0;
       for(unsigned int i=0;i<matchedVertexForU.size(); i++)
       {
         if(matchedVertexForU[i]!=-1)
@@ -111,19 +116,31 @@ public:
 
 
 
-    const std::vector<int> &getVertexUMatches() {return matchedVertexForU;};
-    const std::vector<int> &getVertexVMatches() {return matchedVertexForV;};
+    const std::vector<LO> &getVertexUMatches() {return matchedVertexForU;};
+    const std::vector<LO> &getVertexVMatches() {return matchedVertexForV;};
+
+
+    // Perhaps should be moved outside of class eventually or reworked to use internal variables
+    void getVCfromMatching(const std::vector<LO> &bigraphCRSRowPtr,
+		       std::vector<LO> &bigraphCRSCols,
+                       const std::vector<LO> &vertUMatches,
+		       const std::vector<LO> &vertVMatches,
+		       const std::vector<LO> &bigraphVMapU,
+		       const std::vector<LO> &bigraphVMapV,
+		       std::vector<LO> &VC);
+
 
     /** @ingroup matching_grp
     Computes the maximum cardinality matching.
     */
-    int match();
+    LO match();
 };
 ////////////////////////////////////////////////////////////////////////////////
 
 ////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////
-Matcher::Matcher(int *_rowPtr, int *_cols, int _numU, int _numV, int _numE)
+template <typename LO>
+Matcher<LO>::Matcher(LO *_rowPtr, LO *_cols, LO _numU, LO _numV, LO _numE)
   :mCRS_rowPtrs(_rowPtr),mCRS_cols(_cols),numU(_numU),numV(_numV),numE(_numE)
 {
     finish_=false;
@@ -131,10 +148,10 @@ Matcher::Matcher(int *_rowPtr, int *_cols, int _numU, int _numV, int _numE)
     matchedVertexForU.resize(numU);
     matchedVertexForV.resize(numV);
 
-    lookahead_=new int[numU];
-    unmatchedU_=new int[numU];
+    lookahead_=new LO[numU];
+    unmatchedU_=new LO[numU];
 
-    for(int i=0;i<numU;i++)
+    for(LO i=0;i<numU;i++)
     {
         matchedVertexForU[i]=-1;
 
@@ -142,11 +159,11 @@ Matcher::Matcher(int *_rowPtr, int *_cols, int _numU, int _numV, int _numE)
         unmatchedU_[i]=i;
     }
 
-    visitedV_=new int[numV];
+    visitedV_=new LO[numV];
 
-    parent_=new int[numV];
+    parent_=new LO[numV];
 
-    for(int i=0;i<numV;i++)
+    for(LO i=0;i<numV;i++)
     {
         visitedV_[i]=0;
 
@@ -161,7 +178,8 @@ Matcher::Matcher(int *_rowPtr, int *_cols, int _numU, int _numV, int _numE)
 
 ////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////
-Matcher::~Matcher()
+template <typename LO>
+Matcher<LO>::~Matcher()
 {
     delete [] lookahead_;
     delete [] unmatchedU_;
@@ -183,9 +201,10 @@ Matcher::~Matcher()
 // backtraking using parent array. while tracing back we flip the unmatched
 // edges to matched edges.
 ////////////////////////////////////////////////////////////////////////////////
-int Matcher::augment_matching(int tv)
+template <typename LO>
+LO Matcher<LO>::augment_matching(LO tv)
 {
-    int u,v,t,lnt=1;
+    LO u,v,t,lnt=1;
     v=tv;
     while(true)
     {
@@ -211,9 +230,10 @@ int Matcher::augment_matching(int tv)
 // scanning adjacency list alternately from backward and from forward in
 // alternate iterations for PPF and HKDW.
 ////////////////////////////////////////////////////////////////////////////////
-int Matcher::dfs_path_finder(int u)
+template <typename LO>
+LO Matcher<LO>::dfs_path_finder(LO u)
 {
-    int i,ind=-1,res=0;
+    LO i,ind=-1,res=0;
 
         for(i=lookahead_[u];i<mCRS_rowPtrs[u+1];i++) // the lookahead scheme
         {
@@ -221,7 +241,7 @@ int Matcher::dfs_path_finder(int u)
             assert(ind>=0 && ind<numV);
             if(matchedVertexForV[ind]==-1)
             {
-	      int lock2=0;
+	      LO lock2=0;
 	      if (visitedV_[ind]==0)
                 {
                   visitedV_[ind]=1;
@@ -245,7 +265,7 @@ int Matcher::dfs_path_finder(int u)
                 ind=mCRS_cols[i];
                 assert(ind>=0 && ind<numV);
 
-	      int lock2=0;
+	      LO lock2=0;
 	      if (visitedV_[ind]==0)
                 {
                   visitedV_[ind]=1;
@@ -269,7 +289,7 @@ int Matcher::dfs_path_finder(int u)
                 assert(ind>=0 && ind<numV);
 
 
-	      int lock2=0;
+	      LO lock2=0;
 	      if (visitedV_[ind]==0)
                 {
                   visitedV_[ind]=1;
@@ -377,9 +397,10 @@ int Matcher::dfs_path_finder(int u)
     //This function is the starter function for PPF and DFS. It unsets the locks
     //the call dfs_path_finder and then call the augment_matching.
 ////////////////////////////////////////////////////////////////////////////////
-int Matcher::dfs_augment()
+template <typename LO>
+LO Matcher<LO>::dfs_augment()
 {
-    int i,flag=0,flag1=0,count=0,totc=0,index=numU,cur=0;
+    LO i,flag=0,flag1=0,count=0,totc=0,index=numU,cur=0;
     icm_=0;
 
     while(true)
@@ -403,8 +424,8 @@ int Matcher::dfs_augment()
         for(i=0;i<index;i++)
         {
             flag=1;
-            int u=unmatchedU_[i];
-            int ind=dfs_path_finder(u);
+            LO u=unmatchedU_[i];
+            LO ind=dfs_path_finder(u);
             if(ind!=-1)
             {
                 flag1=1;
@@ -470,9 +491,10 @@ int Matcher::dfs_augment()
 
 ////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////
-int Matcher::SGM()
+template <typename LO>
+LO Matcher<LO>::SGM()
 {
-  int i,j,ind,count=0;
+  LO i,j,ind,count=0;
 
   for(i=0;i<numU;i++)
     {
@@ -480,7 +502,7 @@ int Matcher::SGM()
         {
 	  ind=mCRS_cols[j];
 
-	  int lock2=0;
+	  LO lock2=0;
 	  if (visitedV_[ind]==0)
           {
             visitedV_[ind]=1;
@@ -504,9 +526,10 @@ int Matcher::SGM()
 ////////////////////////////////////////////////////////////////////////////////
 // Forking function for DFS based algorithm
 ////////////////////////////////////////////////////////////////////////////////
-int Matcher::match_dfs()
+template <typename LO>
+LO Matcher<LO>::match_dfs()
 {
-    int totc=0;
+    LO totc=0;
     icm_=0;
 
     totc=dfs_augment();
@@ -517,11 +540,12 @@ int Matcher::match_dfs()
 
 ////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////
-int Matcher::match()
+template <typename LO>
+LO Matcher<LO>::match()
 {
   // User interface function for the matching..                                                                                                             
 
-  int totc=0;
+  LO totc=0;
   totc=SGM();
   totc+=match_dfs();
 
@@ -549,24 +573,25 @@ int Matcher::match()
 // However, I decided not to do this for now since I'm changing some of these
 // member variables in this function
 ////////////////////////////////////////////////////////////////////////////////
-void getVCfromMatching(const std::vector<int> &bigraphCRSRowPtr,
-		       std::vector<int> &bigraphCRSCols,
-                       const std::vector<int> &vertUMatches,
-		       const std::vector<int> &vertVMatches,
-		       const std::vector<int> &bigraphVMapU,
-		       const std::vector<int> &bigraphVMapV,
-		       std::vector<int> &VC)
+template <typename LO>
+void Matcher<LO>::getVCfromMatching(const std::vector<LO> &bigraphCRSRowPtr,
+		       std::vector<LO> &bigraphCRSCols,
+                       const std::vector<LO> &vertSMatches,
+		       const std::vector<LO> &vertTMatches,
+		       const std::vector<LO> &bigraphVMapU,
+		       const std::vector<LO> &bigraphVMapV,
+		       std::vector<LO> &VC)
 {
-   int numU = vertUMatches.size();
-   int numV = vertVMatches.size();
+   LO numS = vertSMatches.size();
+   LO numT = vertTMatches.size();
 
    //////////////////////////////////////////////////////////////////////
    // Build X
    //////////////////////////////////////////////////////////////////////
-   std::set<int> X;
-   for(int i=0;i<numU; i++)
+   std::set<LO> X;
+   for(LO i=0;i<numS; i++)
    {
-     if(vertUMatches[i]==-1)
+     if(vertSMatches[i]==-1)
      {
        X.insert(i);
      }
@@ -578,13 +603,13 @@ void getVCfromMatching(const std::vector<int> &bigraphCRSRowPtr,
    // Removed matches edges from bipartite graph (set to -1)
    //   -- perhaps replace this with something more efficient/compact
    //////////////////////////////////////////////////////////////////////
-   for (int uID=0;uID<numU;uID++)
+   for (LO uID=0;uID<numS;uID++)
    {
-     for (int eIdx=bigraphCRSRowPtr[uID];eIdx<bigraphCRSRowPtr[uID+1];eIdx++)
+     for (LO eIdx=bigraphCRSRowPtr[uID];eIdx<bigraphCRSRowPtr[uID+1];eIdx++)
      {
-       int vID = bigraphCRSCols[eIdx];
+       LO vID = bigraphCRSCols[eIdx];
 
-       if (vertUMatches[uID]==vID)
+       if (vertSMatches[uID]==vID)
        {
          bigraphCRSCols[eIdx]=-1;
        }
@@ -596,37 +621,40 @@ void getVCfromMatching(const std::vector<int> &bigraphCRSRowPtr,
    //////////////////////////////////////////////////////////////////////
    // Calculate L - set of vertices in (U union V, E') that can be reached from X
    //////////////////////////////////////////////////////////////////////
-   std::set<int> L;
+   std::set<LO> L;
 
-   std::queue<int> queue;
+   std::queue<LO> vqueue;
 
    std::copy(X.begin(), X.end(), std::inserter( L, L.begin() ) );
 
-   for(std::set<int>::const_iterator iter = X.begin(); iter != X.end(); ++iter)
+
+
+   typename std::set<LO>::const_iterator iter;
+   for(iter = X.begin(); iter != X.end(); ++iter)
    {
      L.insert(bigraphVMapU[*iter]);   // L contains all vertices in X
 
-     queue.push(*iter); // copy on to queue
+     vqueue.push(*iter); // copy on to vqueue
    }
 
-   int iteration=0;
-   while(queue.size()!=0)
+   LO iteration=0;
+   while(vqueue.size()!=0)
    {
      //Number of active vertices on this side of bipartite graph
-     int nstarts=queue.size();
+     LO nstarts=vqueue.size();
 
-     for (int i=0; i<nstarts; i++)
+     for (LO i=0; i<nstarts; i++)
      {
-       int start = queue.front();
-       queue.pop();
+       LO start = vqueue.front();
+       vqueue.pop();
 
        //Traverse from U to V
        if(iteration%2==0)
        {
          //Traverse edges starting from vertex "start"
-         for (int eIdx=bigraphCRSRowPtr[start];eIdx<bigraphCRSRowPtr[start+1];eIdx++)
+         for (LO eIdx=bigraphCRSRowPtr[start];eIdx<bigraphCRSRowPtr[start+1];eIdx++)
 	 {
-	   int newV = bigraphCRSCols[eIdx];
+	   LO newV = bigraphCRSCols[eIdx];
 
            //Edge is in correct direction (U to V) => newV is valid
            if (newV!=-1)
@@ -635,7 +663,7 @@ void getVCfromMatching(const std::vector<int> &bigraphCRSRowPtr,
              if(L.find(bigraphVMapV[newV])==L.end())
 	     {
                L.insert(bigraphVMapV[newV]);
-               queue.push(newV);
+               vqueue.push(newV);
 	     }
 	   }
 	 }
@@ -645,13 +673,13 @@ void getVCfromMatching(const std::vector<int> &bigraphCRSRowPtr,
        //Traverse from V to U
        else
        {
-         int newU = vertVMatches[start];
+         LO newU = vertTMatches[start];
 
          // If this vertex has not been reached
          if(L.find(bigraphVMapU[newU])==L.end())
 	 {
            L.insert(bigraphVMapU[newU]);
-           queue.push(newU);
+           vqueue.push(newU);
 	 }
        }
      } // for
@@ -663,7 +691,7 @@ void getVCfromMatching(const std::vector<int> &bigraphCRSRowPtr,
    //////////////////////////////////////////////////////////////////////
    // Calc VC = (U-L) union (B intersection L)
    //////////////////////////////////////////////////////////////////////
-   for(int uID=0;uID<numU;uID++)
+   for(LO uID=0;uID<numS;uID++)
    {
      // if vertex not in L, it is in VC
      if(L.find(bigraphVMapU[uID])==L.end())
@@ -672,7 +700,7 @@ void getVCfromMatching(const std::vector<int> &bigraphCRSRowPtr,
      }
    }
 
-   for(int vID=0;vID<numV;vID++)
+   for(LO vID=0;vID<numT;vID++)
    {
      // if vertex is in L, it is in VC
      if(L.find(bigraphVMapV[vID])!=L.end())
