@@ -74,38 +74,14 @@ public:
   {
     throw std::runtime_error(
           "BUILD ERROR:  PuLP requested but not compiled into Zoltan2.\n"
-          "Please set CMake flag Zoltan2_ENABLE_PuLP:BOOL=ON.");
+          "Please set CMake flag TPL_ENABLE_PuLP:BOOL=ON.");
   }
 
   /*! \brief Set up validators specific to this algorithm
   */
   static void getValidParameters(ParameterList & pl)
   {
-    pl.set("pulp_vert_imbalance", 1.1, "vertex imbalance tolerance, ratio of "
-      "maximum load over average load",
-      Environment::getAnyDoubleValidator());
-
-    pl.set("pulp_edge_imbalance", 1.1, "edge imbalance tolerance, ratio of "
-      "maximum load over average load",
-      Environment::getAnyDoubleValidator());
-
-    // bool parameter
-    pl.set("pulp_lp_init", false, "perform label propagation-based "
-      "initialization", Environment::getBoolValidator() );
-
-    // bool parameter
-    pl.set("pulp_minimize_maxcut", false, "perform per-part max cut "
-      "minimization", Environment::getBoolValidator() );
-
-    // bool parameter
-    pl.set("pulp_verbose", false, "verbose output",
-      Environment::getBoolValidator() );
-
-    // bool parameter
-    pl.set("pulp_do_repart", false, "perform repartitioning",
-      Environment::getBoolValidator() );
-
-    pl.set("pulp_seed", 0, "set pulp seed", Environment::getAnyIntValidator());
+    // No parameters needed in this error-handling version of AlgPuLP
   }
 };
 
@@ -238,6 +214,37 @@ public:
     buildModel(flags);
   }
 
+  /*! \brief Set up validators specific to this algorithm
+  */
+  static void getValidParameters(ParameterList & pl)
+  {
+    pl.set("pulp_vert_imbalance", 1.1, "vertex imbalance tolerance, ratio of "
+      "maximum load over average load",
+      Environment::getAnyDoubleValidator());
+
+    pl.set("pulp_edge_imbalance", 1.1, "edge imbalance tolerance, ratio of "
+      "maximum load over average load",
+      Environment::getAnyDoubleValidator());
+
+    // bool parameter
+    pl.set("pulp_lp_init", false, "perform label propagation-based "
+      "initialization", Environment::getBoolValidator() );
+
+    // bool parameter
+    pl.set("pulp_minimize_maxcut", false, "perform per-part max cut "
+      "minimization", Environment::getBoolValidator() );
+
+    // bool parameter
+    pl.set("pulp_verbose", false, "verbose output",
+      Environment::getBoolValidator() );
+
+    // bool parameter
+    pl.set("pulp_do_repart", false, "perform repartitioning",
+      Environment::getBoolValidator() );
+
+    pl.set("pulp_seed", 0, "set pulp seed", Environment::getAnyIntValidator());
+  }
+
   void partition(const RCP<PartitioningSolution<Adapter> > &solution);
 
 private:
@@ -492,7 +499,7 @@ void AlgPuLP<Adapter>::partition(
 
 
   if (verbose_output) {
-    printf("procid: %d, n: %i, m: %li, vb: %lf, eb: %lf, p: %i\n",
+    printf("procid: %d, n: %i, m: %li, vb: %f, eb: %f, p: %i\n",
       problemComm->getRank(), 
       num_verts, num_edges, vert_imbalance, edge_imbalance, num_parts);
   }
@@ -572,6 +579,19 @@ void AlgPuLP<Adapter>::scale_weights(
     if (fw > max_wgt) max_wgt = fw;
   }
 
+  // Get agreement across processors
+  double gmax_wgt;
+  double ltmp[2], gtmp[2];
+  ltmp[0] = nonint;
+  ltmp[1] = sum_wgt;
+  Teuchos::reduceAll<int,double>(*problemComm, Teuchos::REDUCE_SUM, 2,
+                                 ltmp, gtmp);
+  Teuchos::reduceAll<int,double>(*problemComm, Teuchos::REDUCE_MAX, 1,
+                                 &max_wgt, &gmax_wgt);
+  nonint = gtmp[0];
+  sum_wgt = gtmp[1];
+  max_wgt = gmax_wgt;
+
   // Scaling needed if weights are not integers or weights' 
   // range is not sufficient
   double scale = 1.0;
