@@ -78,8 +78,27 @@ enum BaseAdapterType {
 
  */
 
+class BaseAdapterRoot {
+public:
+  virtual ~BaseAdapterRoot() {}; // required virtual declaration
+
+  /*! \brief Returns the number of objects on this process
+   *
+   *  Objects may be coordinates, graph vertices, matrix rows, etc.
+   *  They are the objects to be partitioned, ordered, or colored.
+   */
+  virtual size_t getLocalNumIDs() const = 0;
+
+  /*! \brief Returns the number of weights per object.
+   *   Number of weights per object should be zero or greater.  If
+   *   zero, then it is assumed that all objects are equally weighted.
+   *   Default is zero weights per ID.
+   */
+  virtual int getNumWeightsPerID() const { return 0; };
+};
+
 template <typename User>
-  class BaseAdapter {
+  class BaseAdapter : public BaseAdapterRoot {
 
 public:
   typedef typename InputTraits<User>::lno_t lno_t;
@@ -95,13 +114,6 @@ public:
    */
   virtual ~BaseAdapter() {};
 
-  /*! \brief Returns the number of objects on this process
-   *
-   *  Objects may be coordinates, graph vertices, matrix rows, etc.
-   *  They are the objects to be partitioned, ordered, or colored.
-   */
-  virtual size_t getLocalNumIDs() const = 0;
-
   /*! \brief Provide a pointer to this process' identifiers.
 
       \param Ids will on return point to the list of the global Ids for 
@@ -109,13 +121,6 @@ public:
    */
   virtual void getIDsView(const gno_t *&Ids) const = 0;
 
-  /*! \brief Returns the number of weights per object.
-   *   Number of weights per object should be zero or greater.  If
-   *   zero, then it is assumed that all objects are equally weighted.
-   *   Default is zero weights per ID.
-   */ 
-  virtual int getNumWeightsPerID() const { return 0;};
-
   /*! \brief Provide pointer to a weight array with stride.
    *    \param wgt on return a pointer to the weights for this idx
    *    \param stride on return, the value such that
