@@ -55,6 +55,7 @@
 #include <Tpetra_CrsMatrix.hpp>
 #include <Tpetra_RowMatrix.hpp>
 #include <Tpetra_CrsGraph.hpp>
+#include <Tpetra_RowGraph.hpp>
 
 #ifdef HAVE_ZOLTAN2_EPETRA
 #include <Epetra_CrsMatrix.h>
@@ -158,6 +159,7 @@ class BasicUserTypes{
  *  \li Epetra_CrsGraph
  *  \li Xpetra::RowMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node>
  *  \li Tpetra::RowMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node>
+ *  \li Tpetra::RowGraphx<LocalOrdinal,GlobalOrdinal,Node>
  *  \li Xpetra::Vector<Scalar,LocalOrdinal,GlobalOrdinal,Node>
  *  \li Tpetra::Vector<Scalar,LocalOrdinal,GlobalOrdinal,Node>
  *  \li Epetra_Vector
@@ -166,7 +168,6 @@ class BasicUserTypes{
  *  \li Epetra_MultiVector
  *  \li BasicUserTypes
  *
- * \todo Tpetra::RowMatrix
  */
 template <typename User>
 struct InputTraits {
@@ -201,17 +202,52 @@ struct InputTraits {
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 
+// This combination of macros is used to define a single line
+// Z2_STATIC_ASSERT_TYPES for each InputTraits with custom template types
+#define Z2_ISSAME(s,type) (std::is_same< s, type >::value)
+
+#define Z2_STYPES(s) ( Z2_ISSAME(s,float) || \
+  Z2_ISSAME(s,double) || Z2_ISSAME(s,int) )
+
+#define Z2_LTYPES(l) ( Z2_ISSAME(l,int) ||  \
+  Z2_ISSAME(l,long) || Z2_ISSAME(l,long long) || Z2_ISSAME(l,ssize_t) )
+
+#define Z2_GTYPES(g) ( Z2_ISSAME(g,int) || Z2_ISSAME(g,long) || \
+  Z2_ISSAME(g,long long) || Z2_ISSAME(g,ssize_t) || \
+  Z2_ISSAME(g,unsigned int) || Z2_ISSAME(g,unsigned long) || \
+  Z2_ISSAME(g,unsigned long long) || Z2_ISSAME(g,size_t) )
+
+#define Z2_SERROR "Invalid scalar type. It must be float, double, or int."
+
+#define Z2_LERROR "Invalid local ordinal type. It must be int, long, " \
+  "long long, or ssize_t."
+
+#define Z2_GERROR "Invalid global ordinal type. It must be int, long, " \
+  "long long, ssize_t, unsigned int, unsigned long long, size_t."
+
+#ifdef Z2_INVERT_STATIC_ASSERT_FOR_UNIT_TESTING
+  #define Z2_STATIC_ASSERT_TYPES static_assert( ( !Z2_STYPES(scalar_t) || \
+  !Z2_LTYPES(lno_t) || !Z2_GTYPES(gno_t) ), \
+  "Inverted unit test for InputTraits was supposed to fail but did not." );
+#else
+  #define Z2_STATIC_ASSERT_TYPES static_assert( Z2_STYPES(scalar_t), \
+  Z2_SERROR ); static_assert( Z2_LTYPES(lno_t), Z2_LERROR ); \
+  static_assert( Z2_GTYPES(gno_t), Z2_GERROR );
+#endif
+
 template <typename Scalar,
-          typename LNO,
-          typename GNO>
-struct InputTraits<BasicUserTypes<Scalar, LNO, GNO> >
+          typename LocalOrdinal,
+          typename GlobalOrdinal>
+struct InputTraits<BasicUserTypes<Scalar, LocalOrdinal, GlobalOrdinal> >
 {
   typedef Scalar        scalar_t;
-  typedef LNO lno_t;
-  typedef GNO gno_t;
+  typedef LocalOrdinal  lno_t;
+  typedef GlobalOrdinal gno_t;
   typedef Zoltan2::default_part_t  part_t;
   typedef Zoltan2::default_node_t node_t;
   static inline std::string name() {return "BasicUserTypes";}
+
+  Z2_STATIC_ASSERT_TYPES // validate the types
 };
 
 template <typename Scalar,
@@ -226,6 +262,8 @@ struct InputTraits<Xpetra::CrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
   typedef Zoltan2::default_part_t  part_t;
   typedef Node          node_t;
   static inline std::string name() {return "Xpetra::CrsMatrix";}
+
+  Z2_STATIC_ASSERT_TYPES // validate the types
 };
 
 template <typename Scalar,
@@ -240,6 +278,8 @@ struct InputTraits<Tpetra::CrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
   typedef Zoltan2::default_part_t  part_t;
   typedef Node          node_t;
   static inline std::string name() {return "Tpetra::CrsMatrix";}
+
+  Z2_STATIC_ASSERT_TYPES // validate the types
 };
 
 #ifdef HAVE_ZOLTAN2_EPETRA
@@ -267,6 +307,8 @@ struct InputTraits<Xpetra::RowMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
   typedef Zoltan2::default_part_t  part_t;
   typedef Node          node_t;
   static inline std::string name() {return "Xpetra::RowMatrix";}
+
+  Z2_STATIC_ASSERT_TYPES // validate the types
 };
 
 template <typename Scalar,
@@ -281,6 +323,21 @@ struct InputTraits<Tpetra::RowMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
   typedef Zoltan2::default_part_t  part_t;
   typedef Node          node_t;
   static inline std::string name() {return "Tpetra::RowMatrix";}
+
+  Z2_STATIC_ASSERT_TYPES // validate the types
+};
+
+template <typename LocalOrdinal,
+          typename GlobalOrdinal,
+          typename Node>
+struct InputTraits<Tpetra::RowGraph<LocalOrdinal,GlobalOrdinal,Node> >
+{
+  typedef default_scalar_t scalar_t;
+  typedef LocalOrdinal  lno_t;
+  typedef GlobalOrdinal gno_t;
+  typedef Zoltan2::default_part_t  part_t;
+  typedef Node          node_t;
+  static inline std::string name() {return "Tpetra::RowGraph";}
 };
 
 template <typename LocalOrdinal,
@@ -294,6 +351,8 @@ struct InputTraits<Xpetra::CrsGraph<LocalOrdinal,GlobalOrdinal,Node> >
   typedef Zoltan2::default_part_t  part_t;
   typedef Node          node_t;
   static inline std::string name() {return "Xpetra::CrsGraph";}
+
+  Z2_STATIC_ASSERT_TYPES // validate the types
 };
 
 template <typename LocalOrdinal,
@@ -307,6 +366,8 @@ struct InputTraits<Tpetra::CrsGraph<LocalOrdinal,GlobalOrdinal,Node> >
   typedef Zoltan2::default_part_t  part_t;
   typedef Node          node_t;
   static inline std::string name() {return "Tpetra::CrsGraph";}
+
+  Z2_STATIC_ASSERT_TYPES // validate the types
 };
 
 #ifdef HAVE_ZOLTAN2_EPETRA
@@ -334,6 +395,8 @@ struct InputTraits<Xpetra::Vector<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
   typedef Zoltan2::default_part_t  part_t;
   typedef Node          node_t;
   static inline std::string name() {return "Xpetra::Vector";}
+
+  Z2_STATIC_ASSERT_TYPES // validate the types
 };
 
  /*! \todo A Tpetra::Vector is a Tpetra::MultiVector - can we just
@@ -351,6 +414,8 @@ struct InputTraits<Tpetra::Vector<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
   typedef Zoltan2::default_part_t  part_t;
   typedef Node          node_t;
   static inline std::string name() {return "Tpetra::Vector";}
+
+  Z2_STATIC_ASSERT_TYPES  // validate the types
 };
 
 #ifdef HAVE_ZOLTAN2_EPETRA
@@ -378,6 +443,8 @@ struct InputTraits<Xpetra::MultiVector<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
   typedef Zoltan2::default_part_t  part_t;
   typedef Node          node_t;
   static inline std::string name() {return "Xpetra::MultiVector";}
+
+  Z2_STATIC_ASSERT_TYPES // validate the types
 };
 
 template <typename Scalar,
@@ -392,6 +459,8 @@ struct InputTraits<Tpetra::MultiVector<Scalar,LocalOrdinal,GlobalOrdinal,Node> >
   typedef Zoltan2::default_part_t  part_t;
   typedef Node          node_t;
   static inline std::string name() {return "Tpetra::MultiVector";}
+
+  Z2_STATIC_ASSERT_TYPES // validate the types
 };
 
 #ifdef HAVE_ZOLTAN2_EPETRA
