@@ -126,13 +126,14 @@ class MeshAdapter : public BaseAdapter<User> {
 public:
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-  typedef typename InputTraits<User>::scalar_t              scalar_t;
-  typedef typename InputTraits<User>::lno_t                 lno_t;
-  typedef typename InputTraits<User>::gno_t                 gno_t;
-  typedef typename InputTraits<User>::part_t                part_t;
-  typedef typename InputTraits<User>::node_t                node_t;
-  typedef User                                              user_t;
-  typedef User                                              userCoord_t;
+  typedef typename InputTraits<User>::scalar_t scalar_t;
+  typedef typename InputTraits<User>::lno_t lno_t;
+  typedef typename InputTraits<User>::gno_t gno_t;
+  typedef typename InputTraits<User>::part_t part_t;
+  typedef typename InputTraits<User>::node_t node_t;
+  typedef User user_t;
+  typedef User userCoord_t;
+  typedef MeshAdapter<User> base_adapter_t;
 #endif
 
   enum BaseAdapterType adapterType() const {return MeshAdapterType;}
@@ -184,7 +185,7 @@ public:
                                  enum EntityTopologyType const *&Types) const
   {
     Types = NULL;
-    Z2_THROW_NOT_IMPLEMENTED_IN_ADAPTER
+    Z2_THROW_NOT_IMPLEMENTED
   }
 
   /*! \brief Return the number of weights per entity.
@@ -212,7 +213,7 @@ public:
   {
     weights = NULL;
     stride = 0;
-    Z2_THROW_NOT_IMPLEMENTED_IN_ADAPTER
+    Z2_THROW_NOT_IMPLEMENTED
   }
 
 
@@ -241,7 +242,7 @@ public:
   {
     coords = NULL;
     stride = 0;
-    Z2_THROW_NOT_IMPLEMENTED_IN_ADAPTER
+    Z2_THROW_NOT_IMPLEMENTED
   }
 
 
@@ -273,7 +274,7 @@ public:
   {
     offsets = NULL;
     adjacencyIds = NULL;
-    Z2_THROW_NOT_IMPLEMENTED_IN_ADAPTER
+    Z2_THROW_NOT_IMPLEMENTED
   }
 
 
@@ -313,7 +314,7 @@ public:
   {
     offsets = NULL;
     adjacencyIds = NULL;
-    Z2_THROW_NOT_IMPLEMENTED_IN_ADAPTER
+    Z2_THROW_NOT_IMPLEMENTED
   }
 
   /*! \brief Returns the number (0 or greater) of weights per second adjacency.
@@ -340,7 +341,7 @@ public:
   {
     weights = NULL;
     stride = 0;
-    Z2_THROW_NOT_IMPLEMENTED_IN_ADAPTER
+    Z2_THROW_NOT_IMPLEMENTED
   }
 
   ////////////////////////////////////////////////////////////////////////////
