@@ -187,9 +187,15 @@ public:
   void getRowWeightsView(const scalar_t *&weights, int &stride,
                            int idx = 0) const
   {
-    env_->localInputAssertion(__FILE__, __LINE__,
-      "invalid weight index",
-      idx >= 0 && idx < nWeightsPerRow_, BASIC_ASSERTION);
+    if(idx<0 || idx >= nWeightsPerRow_)
+    {
+      std::ostringstream emsg;
+      emsg << __FILE__ << ":" << __LINE__
+           << "  Invalid row weight index " << idx << std::endl;
+      throw std::runtime_error(emsg.str()); 
+    }
+
+
     size_t length;
     rowWeights_[idx].getStridedList(length, weights, stride);
   }
@@ -206,12 +212,9 @@ public:
 
 private:
 
-  RCP<Environment> env_;    // for error messages, etc.
-
   RCP<const User> matrix_;
   RCP<const Tpetra::Map<lno_t, gno_t, node_t> > rowMap_;
   RCP<const Tpetra::Map<lno_t, gno_t, node_t> > colMap_;
-  lno_t base_;
   ArrayRCP<lno_t> offset_;
   ArrayRCP<gno_t> columnIds_;  // TODO:  KDD Is it necessary to copy and store
   ArrayRCP<scalar_t> values_;  // TODO:  the matrix here?  Would prefer views.
@@ -233,8 +236,7 @@ private:
 template <typename User, typename UserCoord>
   TpetraRowMatrixAdapter<User,UserCoord>::TpetraRowMatrixAdapter(
     const RCP<const User> &inmatrix, int nWeightsPerRow):
-      env_(rcp(new Environment)),
-      matrix_(inmatrix), rowMap_(), colMap_(), base_(),
+      matrix_(inmatrix), rowMap_(), colMap_(), 
       offset_(), columnIds_(),
       nWeightsPerRow_(nWeightsPerRow), rowWeights_(), numNzWeight_(),
       mayHaveDiagonalEntries(true)
@@ -243,7 +245,6 @@ template <typename User, typename UserCoord>
 
   rowMap_ = matrix_->getRowMap();
   colMap_ = matrix_->getColMap();
-  base_ = rowMap_->getIndexBase();
 
   size_t nrows = matrix_->getNodeNumRows();
   size_t nnz = matrix_->getNodeNumEntries();
@@ -257,7 +258,7 @@ template <typename User, typename UserCoord>
   ArrayRCP<scalar_t> nzs(maxnumentries);  // Diff from CrsMatrix
   lno_t next = 0;
   for (size_t i=0; i < nrows; i++){
-    lno_t row = i + base_;
+    lno_t row = i;
     matrix_->getLocalRowCopy(row, indices(), nzs(), nnz); // Diff from CrsMatrix
     for (size_t j=0; j < nnz; j++){
       values_[next] = nzs[j];
@@ -300,9 +301,14 @@ template <typename User, typename UserCoord>
     const scalar_t *weightVal, int stride, int idx)
 {
   typedef StridedData<lno_t,scalar_t> input_t;
-  env_->localInputAssertion(__FILE__, __LINE__,
-    "invalid row weight index",
-    idx >= 0 && idx < nWeightsPerRow_, BASIC_ASSERTION);
+  if(idx<0 || idx >= nWeightsPerRow_)
+  {
+      std::ostringstream emsg;
+      emsg << __FILE__ << ":" << __LINE__
+           << "  Invalid row weight index " << idx << std::endl;
+      throw std::runtime_error(emsg.str()); 
+  }
+
   size_t nvtx = getLocalNumRows();
   ArrayRCP<const scalar_t> weightV(weightVal, 0, nvtx*stride, false);
   rowWeights_[idx] = input_t(weightV, stride);
@@ -330,9 +336,14 @@ template <typename User, typename UserCoord>
   void TpetraRowMatrixAdapter<User,UserCoord>::setRowWeightIsNumberOfNonZeros(
     int idx)
 {
-  env_->localInputAssertion(__FILE__, __LINE__,
-    "invalid row weight index",
-    idx >= 0 && idx < nWeightsPerRow_, BASIC_ASSERTION);
+  if(idx<0 || idx >= nWeightsPerRow_)
+  {
+      std::ostringstream emsg;
+      emsg << __FILE__ << ":" << __LINE__
+           << "  Invalid row weight index " << idx << std::endl;
+      throw std::runtime_error(emsg.str()); 
+  }
+
 
   numNzWeight_[idx] = true;
 }
@@ -412,11 +423,10 @@ RCP<User> TpetraRowMatrixAdapter<User,UserCoord>::doMigration(
                            "implement migration for your RowMatrix.");
   }
 
-  lno_t base = 0;
-
   // source map
   const RCP<const map_t> &smap = from.getRowMap();
   gno_t numGlobalRows = smap->getGlobalNumElements();
+  gno_t base = smap->getMinAllGlobalIndex();
 
   // target map
   ArrayView<const gno_t> rowList(myNewRows, numLocalRows);
