@@ -221,8 +221,15 @@ public:
   void getVertexWeightsView(const scalar_t *&weights, int &stride,
                             int idx) const
   {
-    env_->localInputAssertion(__FILE__, __LINE__, "invalid weight index",
-      idx >= 0 && idx < nWeightsPerVertex_, BASIC_ASSERTION);
+    if(idx<0 || idx >= nWeightsPerVertex_)
+    {
+      std::ostringstream emsg;
+      emsg << __FILE__ << ":" << __LINE__
+           << "  Invalid vertex weight index " << idx << std::endl;
+      throw std::runtime_error(emsg.str()); 
+    }
+
+
     size_t length;
     vertexWeights_[idx].getStridedList(length, weights, stride);
   }
@@ -233,8 +240,15 @@ public:
 
   void getEdgeWeightsView(const scalar_t *&weights, int &stride, int idx) const
   {
-    env_->localInputAssertion(__FILE__, __LINE__, "invalid weight index",
-      idx >= 0 && idx < nWeightsPerEdge_, BASIC_ASSERTION);
+    if(idx<0 || idx >= nWeightsPerEdge_)
+    {
+      std::ostringstream emsg;
+      emsg << __FILE__ << ":" << __LINE__
+           << "  Invalid edge weight index " << idx << std::endl;
+      throw std::runtime_error(emsg.str()); 
+    }
+
+
     size_t length;
     edgeWeights_[idx].getStridedList(length, weights, stride);
   }
@@ -267,10 +281,6 @@ private:
   int coordinateDim_;
   ArrayRCP<StridedData<lno_t, scalar_t> > coords_;
 
-  // A default Environment for error messages.  User-written
-  // InputAdapter classes can use some other error return convention
-  // if desired.
-  RCP<const Environment> env_;
 };
 
 /////////////////////////////////////////////////////////////////
@@ -283,8 +293,7 @@ template <typename User, typename UserCoord>
       ingraph_(ingraph), graph_(), comm_() , offs_(), adjids_(),
       nWeightsPerVertex_(nVtxWgts), vertexWeights_(), vertexDegreeWeight_(),
       nWeightsPerEdge_(nEdgeWgts), edgeWeights_(),
-      coordinateDim_(0), coords_(),
-      env_(rcp(new Environment))
+      coordinateDim_(0), coords_()
 {
   typedef StridedData<lno_t,scalar_t> input_t;
 
@@ -303,12 +312,25 @@ template <typename User, typename UserCoord>
 
   size_t n = nvtx + 1;
   lno_t *offs = new lno_t [n];
-  env_->localMemoryAssertion(__FILE__, __LINE__, n, offs);
+
+  if (!offs)
+  {
+    std::cerr << "Error: " << __FILE__ << ", " << __LINE__<< std::endl;
+    std::cerr << n << " objects" << std::endl;
+    throw std::bad_alloc();
+  }
 
   gno_t *adjids = NULL;
-  if (nedges){
+  if (nedges)
+  {
     adjids = new gno_t [nedges];
-    env_->localMemoryAssertion(__FILE__, __LINE__, nedges, adjids);
+
+    if (!adjids)
+    {
+      std::cerr << "Error: " << __FILE__ << ", " << __LINE__<< std::endl;
+      std::cerr << nedges << " objects" << std::endl;
+      throw std::bad_alloc();
+    }
   }
 
   offs[0] = 0;
@@ -353,8 +375,15 @@ template <typename User, typename UserCoord>
     const scalar_t *weightVal, int stride, int idx)
 {
   typedef StridedData<lno_t,scalar_t> input_t;
-  env_->localInputAssertion(__FILE__, __LINE__, "invalid vertex weight index",
-    idx >= 0 && idx < nWeightsPerVertex_, BASIC_ASSERTION);
+
+  if(idx<0 || idx >= nWeightsPerVertex_)
+  {
+      std::ostringstream emsg;
+      emsg << __FILE__ << ":" << __LINE__
+           << "  Invalid vertex weight index " << idx << std::endl;
+      throw std::runtime_error(emsg.str()); 
+  }
+
   size_t nvtx = getLocalNumVertices();
   ArrayRCP<const scalar_t> weightV(weightVal, 0, nvtx*stride, false);
   vertexWeights_[idx] = input_t(weightV, stride);
@@ -381,8 +410,13 @@ template <typename User, typename UserCoord>
   void XpetraCrsGraphAdapter<User,UserCoord>::setVertexWeightIsDegree(
     int idx)
 {
-  env_->localInputAssertion(__FILE__, __LINE__, "invalid vertex weight index",
-    idx >= 0 && idx < nWeightsPerVertex_, BASIC_ASSERTION);
+  if(idx<0 || idx >= nWeightsPerVertex_)
+  {
+      std::ostringstream emsg;
+      emsg << __FILE__ << ":" << __LINE__
+           << "  Invalid vertex weight index " << idx << std::endl;
+      throw std::runtime_error(emsg.str()); 
+  }
 
   vertexDegreeWeight_[idx] = true;
 }
@@ -393,8 +427,15 @@ template <typename User, typename UserCoord>
     const scalar_t *weightVal, int stride, int idx)
 {
   typedef StridedData<lno_t,scalar_t> input_t;
-  env_->localInputAssertion(__FILE__, __LINE__, "invalid edge weight index",
-    idx >= 0 && idx < nWeightsPerEdge_, BASIC_ASSERTION);
+
+  if(idx<0 || idx >= nWeightsPerEdge_)
+  {
+      std::ostringstream emsg;
+      emsg << __FILE__ << ":" << __LINE__
+           << "  Invalid edge weight index " << idx << std::endl;
+      throw std::runtime_error(emsg.str()); 
+  }
+
   size_t nedges = getLocalNumEdges();
   ArrayRCP<const scalar_t> weightV(weightVal, 0, nedges*stride, false);
   edgeWeights_[idx] = input_t(weightV, stride);
