@@ -158,9 +158,6 @@ private:
 
   RCP<MatchingSolution<Adapter> > solution_;
 
-  RCP<Comm<int> > problemComm_;
-  RCP<const Comm<int> > problemCommConst_;
-
 };
 
 
@@ -189,13 +186,13 @@ void MatchingProblem<Adapter>::solve(bool newData)
   if (method.compare("SerialGreedy") == 0)
   {
       AlgSerialGreedy<Adapter> alg(this->graphModel_, this->params_,
-                                   this->env_, problemComm_);
+                                   this->env_, this->comm_);
       alg.color(this->solution_);
   }
 #if 0 // TODO later
   else if (method.compare("speculative") == 0) // Gebremedhin-Manne
   {
-      AlgGM<base_adapter_t> alg(this->graphModel_, problemComm_);
+      AlgGM<base_adapter_t> alg(this->graphModel_, this->comm_);
       alg.color(this->solution_, this->params_);
   }
 #endif
@@ -229,9 +226,6 @@ void MatchingProblem<Adapter>::createMatchingProblem()
 
   // Create a copy of the user's communicator.
 
-  problemComm_ = this->comm_->duplicate();
-  problemCommConst_ = rcp_const_cast<const Comm<int> > (problemComm_);
-
   // Only graph model supported.
   // TODO: Allow hypergraph later?
 
@@ -248,7 +242,7 @@ void MatchingProblem<Adapter>::createMatchingProblem()
     graphFlags.set(REMOVE_SELF_EDGES);
     graphFlags.set(BUILD_LOCAL_GRAPH);
     this->graphModel_ = rcp(new GraphModel<base_adapter_t>(
-      this->baseInputAdapter_, this->envConst_, problemCommConst_, graphFlags));
+      this->baseInputAdapter_, this->envConst_, this->comm_, graphFlags));
 
     this->baseModel_ = rcp_implicit_cast<const Model<base_adapter_t> >(
       this->graphModel_);
