@@ -112,48 +112,34 @@ public:
   typedef typename Adapter::user_t user_t;
   typedef typename Adapter::base_adapter_t base_adapter_t;
 
-#ifdef HAVE_ZOLTAN2_MPI
-  typedef Teuchos::OpaqueWrapper<MPI_Comm> mpiWrapper_t;
-  /*! \brief Constructor where MPI communicator can be specified
-   */
-  PartitioningProblem(Adapter *A, ParameterList *p, MPI_Comm comm):
-      Problem<Adapter>(A,p,comm), solution_(),
+  //! \brief Constructor where Teuchos communicator is specified
+  PartitioningProblem(Adapter *A, ParameterList *p,
+                      const RCP<const Teuchos::Comm<int> > &comm):
+      Problem<Adapter>(A,p,comm), 
+      solution_(),
       inputType_(InvalidAdapterType),
-      graphFlags_(), idFlags_(), coordFlags_(), algName_(),
-      numberOfWeights_(), partIds_(), partSizes_(),
+      graphFlags_(), idFlags_(), coordFlags_(),
+      algName_(), numberOfWeights_(), partIds_(), partSizes_(),
       numberOfCriteria_(), levelNumberParts_(), hierarchical_(false)
   {
     for(int i=0;i<MAX_NUM_MODEL_TYPES;i++) modelAvail_[i]=false;
     initializeProblem();
   }
+
+#ifdef HAVE_ZOLTAN2_MPI
+  /*! \brief Constructor where MPI communicator can be specified
+   */
+  PartitioningProblem(Adapter *A, ParameterList *p, MPI_Comm mpicomm):
+  PartitioningProblem(A, p, 
+                      rcp<const Comm<int> >(new Teuchos::MpiComm<int>(
+                                            Teuchos::opaqueWrapper(mpicomm))))
+  {}
 #endif
 
   //! \brief Constructor where communicator is the Teuchos default.
   PartitioningProblem(Adapter *A, ParameterList *p):
-      Problem<Adapter>(A,p), solution_(),
-      inputType_(InvalidAdapterType),
-      graphFlags_(), idFlags_(), coordFlags_(), algName_(),
-      numberOfWeights_(),
-      partIds_(), partSizes_(), numberOfCriteria_(),
-      levelNumberParts_(), hierarchical_(false)
-  {
-    for(int i=0;i<MAX_NUM_MODEL_TYPES;i++) modelAvail_[i]=false;
-    initializeProblem();
-  }
-
-  //! \brief Constructor where Teuchos communicator is specified
-  PartitioningProblem(Adapter *A, ParameterList *p,
-                      const RCP<const Teuchos::Comm<int> > &comm):
-      Problem<Adapter>(A,p,comm), solution_(),
-      inputType_(InvalidAdapterType),
-      graphFlags_(), idFlags_(), coordFlags_(), algName_(),
-      numberOfWeights_(),
-      partIds_(), partSizes_(), numberOfCriteria_(),
-      levelNumberParts_(), hierarchical_(false)
-  {
-    for(int i=0;i<MAX_NUM_MODEL_TYPES;i++) modelAvail_[i]=false;
-    initializeProblem();
-  }
+  PartitioningProblem(A, p, Teuchos::DefaultComm<int>::getComm()) 
+  {}
 
   /*! \brief Destructor
    */
@@ -176,7 +162,7 @@ public:
   //  but different problem parameters, than that which was used to compute
   //  the most recent solution.
 
-  void solve(bool updateInputData=true );
+  void solve(bool updateInputData=true);
 
   //!  \brief Get the solution to the problem.
   //
@@ -308,6 +294,10 @@ public:
     pl.set("algorithm", "random", "partitioning algorithm",
       algorithm_Validator);
 
+    // bool parameter
+    pl.set("keep_partition_tree", false, "If true, will keep partition tree",
+      Environment::getBoolValidator());
+
     // bool parameter
     pl.set("rectilinear", false, "If true, then when a cut is made, all of the "
       "dots located on the cut are moved to the same side of the cut. The "
@@ -341,7 +331,8 @@ public:
       Teuchos::rcp( new Teuchos::EnhancedNumberValidator<int>(
         0, Teuchos::EnhancedNumberTraits<int>::max()) ); // no maximum
     pl.set("num_local_parts", 0, "number of parts to compute for this "
-      "process (0 means one)", num_local_parts_Validator);
+      "process (num_global_parts == sum of all num_local_parts)", 
+      num_local_parts_Validator);
 
     RCP<Teuchos::StringValidator> partitioning_approach_Validator =
       Teuchos::rcp( new Teuchos::StringValidator(
