@@ -383,6 +383,35 @@ public:
     else                   return NULL;
   }
 
+  /*! \brief calculate if partition tree is binary.
+   */
+  virtual bool isPartitioningTreeBinary() const
+  {
+    if (this->algorithm_ == Teuchos::null)
+      throw std::logic_error("no partitioning algorithm has been run yet");
+    return this->algorithm_->isPartitioningTreeBinary();
+  }
+
+  /*! \brief get the partition tree - fill the relevant arrays
+   */
+  void getPartitionTree(part_t & numTreeVerts,
+                        std::vector<part_t> & permPartNums,
+                        std::vector<part_t> & splitRangeBeg,
+                        std::vector<part_t> & splitRangeEnd,
+                        std::vector<part_t> & treeVertParents) const {
+
+    part_t numParts = static_cast<part_t>(getTargetGlobalNumberOfParts());
+
+    if (this->algorithm_ == Teuchos::null)
+      throw std::logic_error("no partitioning algorithm has been run yet");
+    this->algorithm_->getPartitionTree(
+      numParts, // may want to change how this is passed through
+      numTreeVerts,
+      permPartNums,
+      splitRangeBeg,
+      splitRangeEnd,
+      treeVertParents);
+  }
 
   /*! \brief returns the part box boundary list.
    */
@@ -1343,7 +1372,7 @@ template <typename Adapter>
   // TODO:  remapping.  This problem will go away after we separate process
   // TODO:  mapping from setParts.  But for MueLu's use case, the part
   // TODO:  remapping is all that matters; they do not use the process mapping.
-  int doRemap = 0;
+  bool doRemap = false;
   const Teuchos::ParameterEntry *pe =
                  env_->getParameters().getEntryPtr("remap_parts");
   if (pe) doRemap = pe->getValue(&doRemap);
@@ -1478,7 +1507,7 @@ template <typename Adapter>
     int numLocalParts, int numGlobalParts)
 {
 #ifdef _MSC_VER
-	typedef SSIZE_T ssize_t;
+  typedef SSIZE_T ssize_t;
 #endif
   int nprocs = comm_->getSize();
   ssize_t reducevals[4];
@@ -1486,7 +1515,7 @@ template <typename Adapter>
   ssize_t sumGlobal=0, sumLocal=0;
   ssize_t maxGlobal=0, maxLocal=0;
   ssize_t vals[4] = {haveNumGlobalParts, haveNumLocalParts,
-      numGlobalParts, numLocalParts};
+                     numGlobalParts, numLocalParts};
 
   partDist_.clear();
   procDist_.clear();
