@@ -627,7 +627,6 @@ int GeometricGenInterface(RCP<const Teuchos::Comm<int> > &comm,
 
     typedef Zoltan2::XpetraMultiVectorAdapter<tMVector_t> inputAdapter_t;
     typedef Zoltan2::EvaluatePartition<inputAdapter_t> quality_t;
-    typedef inputAdapter_t::base_adapter_t base_adapter_t;
     //inputAdapter_t ia(coordsConst);
     inputAdapter_t *ia = new inputAdapter_t(coordsConst,weights, stride);
 
@@ -739,7 +738,6 @@ int testFromDataFile(
     RCP<const tMVector_t> coordsConst = rcp_const_cast<const tMVector_t>(coords);
     typedef Zoltan2::XpetraMultiVectorAdapter<tMVector_t> inputAdapter_t;
     typedef Zoltan2::EvaluatePartition<inputAdapter_t> quality_t;
-    typedef inputAdapter_t::base_adapter_t base_adapter_t;
     inputAdapter_t *ia = new inputAdapter_t(coordsConst);
 
     Teuchos::RCP <Teuchos::ParameterList> params ;
@@ -983,7 +981,6 @@ int testFromSeparateDataFiles(
 
     typedef Zoltan2::XpetraMultiVectorInput<tMVector_t> inputAdapter_t;
     typedef Zoltan2::EvaluatePartition<inputAdapter_t> quality_t;
-    typedef inputAdapter_t::base_adapter_t base_adapter_t;
     inputAdapter_t *ia = new inputAdapter_t(coordsConst);
 
     Teuchos::RCP <Teuchos::ParameterList> params ;
@@ -1318,12 +1315,6 @@ int main(int argc, char *argv[])
             }
             throw s;
         }
-        catch(char const * s){
-            if(tcomm->getRank() == 0){
-                print_usage(argv[0]);
-            }
-            throw s;
-        }
 
         int ierr = 0;
 
@@ -1377,11 +1368,6 @@ int main(int argc, char *argv[])
             cerr << s << endl;
     }
 
-    catch(char const* s){
-        if (rank == 0)
-            cerr << s << endl;
-    }
-
     Kokkos::finalize ();
     return 0;
 }
