@@ -164,7 +164,6 @@ int main(int argc, char *argv[]){
     //create partitioning problem
     typedef Zoltan2::PartitioningProblem<my_adapter_t> xcrsGraph_problem_t; // xpetra_graph problem type
     typedef Zoltan2::EvaluatePartition<my_adapter_t> quality_t;
-    typedef my_adapter_t::base_adapter_t base_adapter_t;
     ParameterList zoltan2_parameters;
     zoltan2_parameters.set("compute_metrics", true); // bool parameter
     zoltan2_parameters.set("imbalance_tolerance", 1.0);
@@ -359,8 +358,5 @@ int main(int argc, char *argv[]){
   catch(char * s){
     cerr << s << endl;
   }
-  catch(char const * s){
-    cerr << s << endl;
-  }
 }
 
