@@ -103,8 +103,7 @@ void testFromDataFile(
   params.set("num_global_parts", nParts);
   params.set("algorithm", "rcb");
   params.set("imbalance_tolerance", 1.1);
-  params.set("bisection_num_test_cuts", 7);
-  if (doRemap) params.set("remap_parts", "yes");
+  if (doRemap) params.set("remap_parts", true); // bool parameter
 
 #ifdef HAVE_ZOLTAN2_MPI
   Zoltan2::PartitioningProblem<inputAdapter_t> problem(&ia, &params,
@@ -150,8 +149,7 @@ void serialTest(int numParts, bool doRemap)
   params.set("num_global_parts", numParts);
   params.set("algorithm", "rcb");
   params.set("imbalance_tolerance", 1.1);
-  params.set("bisection_num_test_cuts", 7);
-  if (doRemap) params.set("remap_parts", "yes");
+  if (doRemap) params.set("remap_parts", true); // bool parameter
 
 #ifdef HAVE_ZOLTAN2_MPI
   Zoltan2::PartitioningProblem<inputAdapter_t> serialProblem(
@@ -185,8 +183,7 @@ void meshCoordinatesTest(const RCP<const Teuchos::Comm<int> > & comm)
   inputAdapter_t ia(localCount, globalIds, x, y, z, 1, 1, 1);
 
   Teuchos::ParameterList params("test params");
-  params.set("bisection_num_test_cuts", 7);
-  params.set("rectilinear", "yes");
+  params.set("rectilinear", true); // bool parameter
 
 #ifdef HAVE_ZOLTAN2_MPI
   Zoltan2::PartitioningProblem<inputAdapter_t> problem(&ia, &params, MPI_COMM_WORLD);
